<?php

namespace App\Http\Controllers;

use App\Models\Areas;
use Illuminate\Http\Request;

class AreaController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $areas = Areas::all();
        return view('area.index', ['areas' => $areas]);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('area.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $request->validate([
            'area' => 'required'
        ]);
        $area = Areas::create([
            'area' => trim($request->input('area'))
        ]);

        $areas = Areas::all();
        if ($area){
            return view('area.index', ['areas' => $areas]);
        }
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Areas  $area
     * @return \Illuminate\Http\Response
     */
    public function show(Areas $area)
    {
        $area = Areas::find($area->id);
        return view('area.show', ['area' => $area]);
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Areas  $area
     * @return \Illuminate\Http\Response
     */
    public function edit(Areas $area)
    {
        return view('area.edit', ['area' => $area]);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Areas  $area
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Areas $area)
    {
        $request->validate([
            'area' => 'required'
        ]);
        $areaUpdate = Areas::where('id', $area->id)->update([
            'area'=>trim($request->input('area'))
        ]);

        if ($areaUpdate){
            return redirect()->route('area.show', ['area' => $area->id])->with('success', __("Data successfully changed"));
        }
        return back()->withInput();
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Areas  $area
     * @return \Illuminate\Http\Response
     */
    public function destroy(Request $request)
    {
        $findArea = Areas::find($request->input('id_area'));

        try{
            $findArea->delete();
            return back()->withInput()->with('success', __("Data successfully deleted"));
        }
        catch (\Illuminate\Database\QueryException $e){
            return back()->withInput()->with('errors', __("Item can't be deleted because it's in use"));
        }


        return back()->withInput()->with('errors', __("Data cannot be deleted"));
    }
}
