<?php

namespace App\Http\Controllers;

use App\Models\Campains;
use Illuminate\Http\Request;

class CampainsController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $campains = Campains::all();
        return view('campain.index', ['campains' => $campains]);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('campain.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $request->validate([
            'campain' => 'required'
        ]);
        $create = Campains::create([
            'campain' => trim($request->input('campain'))
        ]);

        if ($create){
            return redirect()->route('campain.index');
        }
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Models\Campains  $campain
     * @return \Illuminate\Http\Response
     */
    public function show(Campains $campain)
    {
        return view('campain.show', ['campain' => $campain]);
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Models\Campains  $campain
     * @return \Illuminate\Http\Response
     */
    public function edit(Campains $campain)
    {
        $campain = Campains::find($campain->id);

        return view('campain.edit', ['campain' => $campain]);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Models\Campains  $campain
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Campains $campain)
    {
        $request->validate([
            'campain' => 'required'
        ]);
        $update = Campains::where('id', $campain->id)->update([
            'campain'=>trim($request->input('campain'))
        ]);

        if ($update){
            return redirect()->route('campain.show', ['campain' => $campain->id])->with('success', __("Data successfully changed"));
        }
        return back()->withInput();
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function destroy(Request $request)
    {
        $findCampain = Campains::find($request->input('id_campain'));

        try{
            $findCampain->delete();
            return back()->withInput()->with('success', __("Data successfully deleted"));
        }
        catch (\Illuminate\Database\QueryException $e){
            return back()->withInput()->with('error', __("Item can't be deleted because it's in use"));
        }
        return back()->withInput()->with('error', __("Data cannot be deleted"));
    }
}
