<?php

namespace App\Http\Controllers;

use App\Models\Equipment_categories;
use App\Models\Equipment;
use App\Models\Equipment_types;
use Illuminate\Http\Request;

class ConstEquipmentController extends Controller
{
    private function categories(){
        $categories = Equipment_categories::all();
        return $categories;
    }

    private function types(){
        $types = Equipment_types::all();
        return $types;
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $eModel = new Equipment();
        $equipment = $eModel->equipmentIndex();
        return view('constEquipment.index', ['equipment' => $equipment]);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('constEquipment.create', ['categories' => $this->categories(), 'types' => $this->types()]);
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $request->validate([
            'code' => 'required',
            'equipment' => 'required',
            'category' => 'required'
        ]);
        $equipmentCreate = Equipment::create([
            'code' => trim($request->input('code')),
            'equipment' => trim($request->input('equipment')),
            'id_category' => trim($request->input('category')),
            'type' => $request->input('type')
        ]);

        $eModel = new Equipment();
        $equipment = $eModel->equipmentIndex();
        if ($equipmentCreate){
            return view('constEquipment.index', ['equipment' => $equipment]);
        }
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Equipment  $const_equipment
     * @return \Illuminate\Http\Response
     */
    public function show(Equipment $const_equipment)
    {
        $eModel = new Equipment();
        $equipment = $eModel->equipmentData($const_equipment->id);
        return view('constEquipment.show', ['equipment' => $equipment]);
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Equipment  $const_equipment
     * @return \Illuminate\Http\Response
     */
    public function edit(Equipment $const_equipment)
    {
        $eModel = new Equipment();
        $equipment = $eModel->equipmentData($const_equipment->id);

        return view('constEquipment.edit', ['equipment' => $equipment, 'categories' => $this->categories(), 'types' => $this->types()]);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Equipment  $equipment
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Equipment $const_equipment)
    {
        $request->validate([
            'code' => 'required',
            'equipment' => 'required',
            'category' => 'required'
        ]);
        $equipmentUpdate = Equipment::where('id', $const_equipment->id)->update([
            'code' => trim($request->input('code')),
            'equipment' => trim($request->input('equipment')),
            'id_category' => trim($request->input('category')),
            'type' => $request->input('type'),
            'is_active' => $request->input('is_active')
        ]);

        if ($equipmentUpdate){
            return redirect()->route('const_equipment.show', ['const_equipment' => $const_equipment->id])->with('success', __("Data successfully changed"));
        }
        return back()->withInput();
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function destroy(Request $request)
    {
        $findEquipment = Equipment::find($request->input('id_equipment'));

        try{
            $findEquipment->delete();
            return back()->withInput()->with('success', __("Data successfully deleted"));
        }
        catch (\Illuminate\Database\QueryException $e){
            return back()->withInput()->with('errors', __("Data cannot be deleted"));
        }


        return back()->withInput()->with('errors', __("Data cannot be deleted"));
    }
}
