<?php

namespace App\Http\Controllers;

use App\Models\Equipment_categories;
use Illuminate\Http\Request;

class ConstEquipmentTypeController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $categories = Equipment_categories::all();
        return view('constEquipmentType.index', ['categories' => $categories]);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('constEquipmentType.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $request->validate([
            'equipment_type' => 'required'
        ]);
        $typeCreate = Equipment_categories::create([
            'category' => trim($request->input('equipment_type'))
        ]);

        $categories = Equipment_categories::all();
        if ($typeCreate){
            return view('constEquipmentType.index', ['categories' => $categories]);
        }
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Equipment_categories  $const_equipment_type
     * @return \Illuminate\Http\Response
     */
    public function show(Equipment_categories $const_equipment_type)
    {
        $equipmentCategory = Equipment_categories::find($const_equipment_type->id);
        return view('constEquipmentType.show', ['category' => $equipmentCategory]);
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Equipment_categories  $const_equipment_type
     * @return \Illuminate\Http\Response
     */
    public function edit(Equipment_categories $const_equipment_type)
    {
        $equipmentCategory = Equipment_categories::find($const_equipment_type->id);

        return view('constEquipmentType.edit', ['category' => $equipmentCategory]);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Equipment_categories  $const_equipment_type
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Equipment_categories $const_equipment_type)
    {
        $request->validate([
            'category' => 'required'
        ]);
        $categoryUpdate = Equipment_categories::where('id', $const_equipment_type->id)->update([
            'category'=>trim($request->input('category'))
        ]);

        if ($categoryUpdate){
            return redirect()->route('const_equipment_type.show', ['const_equipment_type' => $const_equipment_type->id])->with('success', __("Data successfully changed"));
        }
        return back()->withInput();
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function destroy(Request $request)
    {
        $findCategory = Equipment_categories::find($request->input('id_category'));

        try{
            $findCategory->delete();
            return back()->withInput()->with('success', __("Data successfully deleted"));
        }
        catch (\Illuminate\Database\QueryException $e){
            return back()->withInput()->with('errors', __("Data cannot be deleted"));
        }


        return back()->withInput()->with('errors', __("Data cannot be deleted"));
    }
}
