<?php

namespace App\Http\Controllers;

use App\Models\Work_categories;
use Illuminate\Http\Request;

class ConstWorkTypeController extends Controller
{

    private function categories(){
        $categories = Work_categories::all();
        return $categories;
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        return view('constWorkType.index', ['categories' => $this->categories()]);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('constWorkType.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $request->validate([
            'work_type' => 'required'
        ]);
        $typeCreate = Work_categories::create([
            'category' => trim($request->input('work_type'))
        ]);

        if ($typeCreate){
            return view('constWorkType.index', ['categories' => $this->categories()]);
        }
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Work_categories  $work_category
     * @return \Illuminate\Http\Response
     */
    public function show(Work_categories $work_category)
    {
        $category = Work_categories::find($work_category->id);
        return view('constWorkType.show', ['category' => $category]);
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Work_categories  $work_category
     * @return \Illuminate\Http\Response
     */
    public function edit(Work_categories $work_category)
    {
        $category = Work_categories::find($work_category->id);

        return view('constWorkType.edit', ['category' => $category]);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Work_categories  $work_category
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Work_categories $work_category)
    {
        $request->validate([
            'category' => 'required'
        ]);
        $categoryUpdate = Work_categories::where('id', $work_category->id)->update([
            'category'=>trim($request->input('category'))
        ]);

        if ($categoryUpdate){
            return redirect()->route('const_work_type.show', ['work_category' => $work_category->id])->with('success',  __("Data successfully changed"));
        }
        return back()->withInput();
    }

    /**
     * Remove the specified resource from storage.
     *
     * @return \Illuminate\Http\Response
     */
    public function destroy(Request $request)
    {
        $findCategory = Work_categories::find($request->input('id_category'));

        try{
            $findCategory->delete();
            return back()->withInput()->with('success',  __("Data successfully deleted"));
        }
        catch (\Illuminate\Database\QueryException $e){
            return back()->withInput()->with('errors', __("Item can't be deleted because it's in use"));
        }

        return back()->withInput()->with('errors', __("Data cannot be deleted"));
    }
}
