<?php

namespace App\Http\Controllers;

use App\Models\Construction_status;
use Illuminate\Http\Request;

class ConstructionStatusController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $statuses = Construction_status::all();
        return view('constructionStatus.index', ['statuses' => $statuses]);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('constructionStatus.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $request->validate([
            'status' => 'required'
        ]);
        $status = Construction_status::create([
            'status' => trim($request->input('status'))
        ]);

        $statuses = Construction_status::all();
        if ($status){
            return view('constructionStatus.index', ['statuses' => $statuses]);
        }
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Construction_status  $construction_status
     * @return \Illuminate\Http\Response
     */
    public function show(Construction_status $construction_status)
    {
        $status = Construction_status::find($construction_status->id);
        return view('constructionStatus.show', ['status' => $status]);
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Construction_status  $construction_status
     * @return \Illuminate\Http\Response
     */
    public function edit(Construction_status $construction_status)
    {
        $status = Construction_status::find($construction_status->id);

        return view('constructionStatus.edit', ['status' => $status]);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Construction_status  $construction_status
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Construction_status $construction_status)
    {
        $request->validate([
            'status' => 'required'
        ]);
        $statusUpdate = Construction_status::where('id', $construction_status->id)->update([
            'status'=>trim($request->input('status'))
        ]);

        if ($statusUpdate){
            return redirect()->route('construction_status.show', ['construction_status' => $construction_status->id])->with('success', __("Data successfully changed"));
        }
        return back()->withInput();
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Construction_status  $construction_status
     * @return \Illuminate\Http\Response
     */
    public function destroy(Request $request)
    {
        $findStatus = Construction_status::find($request->input('id_status'));

        try{
            $findStatus->delete();
            return back()->withInput()->with('success', __("Data successfully deleted"));
        }
        catch (\Illuminate\Database\QueryException $e){
            return back()->withInput()->with('errors', __("Data cannot be deleted"));
        }


        return back()->withInput()->with('errors', __("Data cannot be deleted"));
    }
}
