<?php

namespace App\Http\Controllers;

use App\Models\Equipment_types;
use App\Const_delivery_notes;
use App\Const_equipment_delivery;
use App\Models\Equipment;
use App\Models\Hw_site_equipment;
use App\Models\Storage_logs;
use App\Magz;
use App\Models\Equipment_categories;
use App\Models\Worker_storage_logs;
use App\Traits\Util;
use App\Models\Worker_equipment;
use App\Models\Storage_equipment;
use App\User;
use Illuminate\Http\Request;

class ConstructionStorageController extends Controller
{
    private function magz(){
        $magModel = new Magz();
        $magz = $magModel->magzForUser(Util::userId());
        return $magz;
    }
    private function linkForgeryCheck($magId){
        $magModel = new Magz();
        $forgery = $magModel->linkForgeryCheck($magId, Util::userId());
        return $forgery;
    }

    private function updateChangeLog($equipmentId, $storageId, $quantity){
        if($quantity != 0){
            Storage_logs::create([
                'equipment_id' => $equipmentId,
                'user_id' => Util::userId(),
                'storage_id' => $storageId,
                'quantity' => $quantity
            ]);
        }
    }
    public function construction_storage(){
        $builders = Util::builders();
        $monters = Util::allWorkers();
        $workers = $builders->merge($monters);
        $equipModel = new Worker_equipment();
        return view('constructionStorage.storage', ['workers' => $workers, 'equipModel' => $equipModel]);
    }

    public function worker_storage(Request $request){
        $id = $request->input('id');
        $equipModel = new Worker_equipment();
        $equipmentCategories = Equipment_categories::all();
        $equipment = $equipModel->equipment_for_user($id);
        if(Util::isAdmin())
            $storages = Magz::all();
        else
            $storages = $this->magz();
        $user = User::find($id);
        return view('constructionStorage.worker', [
            'equipment' => $equipment, 
            'equipmentCategories' => $equipmentCategories, 
            'user' => $user, 
            'storages' => $storages
        ]);
    }

    public function storages(){
        if(Util::isAdmin()){
            $magz = Magz::all();
        }
        else{
            $magz = $this->magz();
        }
        return view('constructionStorage.storages', ['magz' => $magz]);
    }

    public function equipment_storage(Request $request){
        $id = $request->input('id');
        if($this->linkForgeryCheck($id) && !Util::isAdmin())
            return back()->withInput();
        $equipModel = new Storage_equipment();
        $equipmentCategories = Equipment_categories::all();
        $equipment = $equipModel->equipment_for_storage($id);
        $storage = Magz::find($id);
        $fitters = Util::allWorkers();
        return view('constructionStorage.storage_equipment', [
            'equipment' => $equipment, 
            'equipmentCategories' => $equipmentCategories, 
            'storage' => $storage,
            'fitters' => $fitters
        ]);
    }

    public function storage_logs(Request $request){
        $storageId = $request->input('storage_id');
        $logsModel = new Storage_logs();
        $logs = $logsModel->logs($storageId);
        return view('constructionStorage.logs', [
            'logs' => $logs
        ]);
    }

    public function storage_logs_search(Request $request){
        $storageId = $request->input('storage_id');
        $receiveNumber = $request->input('s_receive_number');
        $fitter = $request->input('fitter');
        $from = $request->input('s_from');
        $logsModel = new Storage_logs();
        $logs = $logsModel->logs_search($storageId, $receiveNumber, $from, $fitter);
        return view('constructionStorage.logs', ['logs' => $logs]);
    }

    public function stockpile(){
        $types = Equipment_types::all();
        return view('constructionStorage.stockpile', ['types' => $types]);
    }

    public function stockpile_goods($type){
        $equipModel = new Storage_equipment();
        if(Util::isSuperAdmin()) {
            $magz = Magz::all();
        }
        else{
            $magz = $this->magz();
        }
        $stockpile = array();
        foreach($magz as $mag){
            $equipment = $equipModel->equipment_for_storage($mag->id, $type);
            foreach ($equipment as $num=>$eq){
                $stockpile[$mag->naziv][$num]['code'] = $eq->code;
                $stockpile[$mag->naziv][$num]['equipment'] = $eq->equipment;
                $stockpile[$mag->naziv][$num]['quantity'] = $eq->quantity;
            }
        }

        $availableGoods = array();
        $equipment = $equipModel->available_goods(true, $type);
        foreach ($equipment as $num=>$eq){
            $availableGoods[$num]['code'] = $eq->code;
            $availableGoods[$num]['equipment'] = $eq->equipment;
            $availableGoods[$num]['quantity'] = $eq->sumasumarum;
        }

        $allGoods = array();
        $equipment = $equipModel->allGoods($type);
        foreach ($equipment as $num=>$eq){
            $allGoods[$num]['code'] = $eq->code;
            $allGoods[$num]['equipment'] = $eq->equipment;
            $allGoods[$num]['quantity'] = $eq->sumasumarum;
        }

        $seMod = new Hw_site_equipment();
        $usedEquipment = $seMod->usedEquipment($type);

        return view('constructionStorage.stockpile_goods', [
            'stockpile' => $stockpile,
            'usedEquipment' => $usedEquipment,
            'availableGoods' => $availableGoods,
            'allGoods' => $allGoods
        ]);
    }

    public function delivery_notes(){
        $dnModel = new Const_delivery_notes();
        $deliveryNotes = $dnModel->delivery_notes();
        $currentUser = Util::username();
        $userId = Util::userId();
        return view('constructionStorage.delivery_notes', [
            'deliveryNotes' => $deliveryNotes,
            'currentUser' => $currentUser,
            'userId' => $userId
        ]);
    }

    public function add_delivery_note(Request $request){
        $currentUser = Util::userId();
        $company = $request->input('company');
        $acceptor = $request->input('acceptor');
        $idNo = $request->input('id_no');
        $regNo = $request->input('reg_no');

        $create = Const_delivery_notes::create([
            'storekeeper_id' => $currentUser,
            'company' => $company,
            'acceptor' => $acceptor,
            'id_no' => $idNo,
            'reg_no' => $regNo
        ]);

        if($create){
            return back()->with('success', __("Data successfully added"));
        }
        else {
            return back()->with('error', __("Error"));
        }
    }

    public function edit_delivery_note(Request $request){
        $id = $request->input('e_id');
        $currentUser = Util::userId();
        $company = $request->input('e_company');
        $acceptor = $request->input('e_acceptor');
        $idNo = $request->input('e_id_no');
        $regNo = $request->input('e_reg_no');

        $update = Const_delivery_notes::where('id', $id)->update([
            'storekeeper_id' => $currentUser,
            'company' => $company,
            'acceptor' => $acceptor,
            'id_no' => $idNo,
            'reg_no' => $regNo
        ]);

        if($update){
            return back()->with('succes',  __("Data successfully changed"));
        }
        else {
            return back()->with('error',  __("Error"));
        }
    }

    public function delivery_notes_equipment(Request $request){
        $deliveryId = $request->input('deliveryId');
        $acceptor = $request->input('acceptor');
        $deModel = new Const_equipment_delivery();
        $allEquipment = Equipment::all();
        $equipment = $deModel->equipment_list($deliveryId);
        $magz = Magz::all();
        return view('constructionStorage.delivery_notes_equipment', [
            'deliveryId' => $deliveryId,
            'acceptor' => $acceptor,
            'equipment' => $equipment,
            'allEquipment' => $allEquipment,
            'magz' => $magz
        ]);
    }

    public function delivery_notes_scan(Request $request){
        $deliveryId = $request->input('deliveryId');
        $equipmentId = $request->input('equipment');
        $quantity = $request->input('quantity');
        $warehouse = $request->input('warehouse');
        $fitter = $request->input('fitter');
        $request->validate([
            'quantity' => 'required|numeric',
            'equipment' => 'required',
            'warehouse' => 'required'
        ]);

        $sModel = new Storage_equipment();
        $storageEquipment = $sModel->specific_equipment($warehouse, $equipmentId);
        //if storage equipment have values, but quantity is 0.
        if($storageEquipment)
            $storageAmmount = $storageEquipment->quantity;
        else
            $storageAmmount = 0;
        if($storageAmmount >= $quantity){
            $sModel->storage_update($warehouse, $equipmentId, -$quantity);
            $this->updateChangeLog($equipmentId, $warehouse, -$quantity, null, $fitter);
            Worker_storage_logs::create([
                'equipment_id' => $equipmentId,
                'worker_id' => $fitter,
                'storage_id' => $warehouse,
                'quantity' => $quantity
            ]);
        }
        else {
            return back()->with('error',__("not enough goods in warehouse"));
        }

        $duplicate = Const_equipment_delivery::where('delivery_id', $deliveryId)->where('equipment_id', $equipmentId)->get();
        if($duplicate->isEmpty()){
            $hasDuplicate = false;
        }
        else{
            $hasDuplicate = true;
        }

        if($hasDuplicate){
            Const_equipment_delivery::where('delivery_id', $deliveryId)->where('equipment_id', $equipmentId)->increment('quantity', $quantity);
            return back()->with('success', __("Equipment successfully added"));
        }
        else {
            $create = Const_equipment_delivery::create([
                'equipment_id' => $equipmentId,
                'delivery_id' => $deliveryId,
                'quantity' => $quantity
            ]);
            if ($create)
                return back()->with('succes', __("Equipment successfully added"));
            else
                return back()->with('errors', __("Error"));
        }

    }

    public function delete_delivery_note(Request $request){
        $id = $request->input('id_delivery_note');
        $delete = Const_delivery_notes::where('id', $id)->delete();
        if($delete)
            return back()->with('succes',  __("Data successfully deleted"));
        else
            return back()->with('error',  __("Data cannot be deleted"));
    }

    public function delete_equipment_from_documents(Request $request){
        $param = $request->input('param');
        $documentId = $request->input('document_id');
        $equipmentId = $request->input('equipment_id');
        if ($param == 'delivery'){
            $delete = Const_equipment_delivery::where('equipment_id', $equipmentId)->where('delivery_id', $documentId)->delete();
            if ($delete)
                return back()->withInput()->with('succes', __("Equipment successfully deleted"));
            else
                return back()->withInput()->with('errors', __("Error"));
        }
        else {
            return back()->withInput();
        }
    }

    public function delivery_search(){

    }

}
