<?php

namespace App\Http\Controllers;

use App\Models\Device_categories;
use App\Models\Device_types;
use App\Models\Origin;
use App\Uredjaji;
use Illuminate\Http\Request;

class DeviceController extends Controller
{

    private function allDevices(){
        $devModel = new Uredjaji();
        $devices = $devModel->devices();
        return $devices;
    }

    private function findDevice($id){
        $devModel = new Uredjaji();
        $device = $devModel->findDevice($id);
        return $device[0];
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        return view('device.index', ['devices' => $this->allDevices()]);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $types = Device_types::all();
        $origin = Origin::all();
        $categories = Device_categories::all();
        return view('device.create', ['types' => $types, 'origin' => $origin, 'categories' => $categories]);
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $request->merge([
            'price' => str_replace(',', '.', $request->input('price'))
        ]);
        $request->validate([
            'device' => 'required',
            'price' => 'numeric'
        ]);
        $device = Uredjaji::create([
            'uredjaj' => trim($request->input('device')),
            'device_type_id' => $request->input('type'),
            'category_id' => $request->input('category'),
            'origin_id' => $request->input('origin'),
            'price' => $request->input('price')
        ]);

        if ($device){
            return view('device.index', ['devices' => $this->allDevices()]);
        }
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Uredjaji  $device
     * @return \Illuminate\Http\Response
     */
    public function show(Uredjaji $device)
    {
        return view('device.show', ['device' => $this->findDevice($device->id)]);
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Uredjaji  $uredjaji
     * @return \Illuminate\Http\Response
     */
    public function edit(Uredjaji $device)
    {
        return view('device.edit', [
            'device' => $this->findDevice($device->id), 
            'types' => Device_types::all(), 
            'categories' => Device_categories::all(),
            'origin' => Origin::all()]);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Uredjaji  $uredjaji
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Uredjaji $device)
    {
        $request->merge([
            'price' => str_replace(',', '.', $request->input('price'))
        ]);
        $request->validate([
            'device' => 'required',
            'price' => 'numeric'
        ]);
        $deviceUpdate = Uredjaji::where('id', $device->id)->update([
            'uredjaj'=>trim($request->input('device')),
            'device_type_id' => $request->input('type'),
            'category_id' => $request->input('category'),
            'origin_id' => $request->input('origin'),
            'price' => $request->input('price')
        ]);

        if ($deviceUpdate){
            return redirect()->route('device.show', ['device' => $device->id])->with('success',  __("Data successfully changed"));
        }
        return back()->withInput();
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Uredjaji  $uredjaji
     * @return \Illuminate\Http\Response
     */
    public function destroy(Request $request)
    {
        $findDevice = Uredjaji::find($request->input('id_device'));

        try{
            $findDevice->delete();
            return back()->withInput()->with('success',  __("Data successfully deleted"));
        }
        catch (\Illuminate\Database\QueryException $e){
            return back()->withInput()->with('errors', __("Item can't be deleted because it's in use"));
        }


        return back()->withInput()->with('errors', __("Data cannot be deleted"));
    }
}
