<?php

namespace App\Http\Controllers;

use App\Klijenti_prodaja;
use App\Models\Fobos_comments;
use App\Models\Fobos_statuses;
use App\Traits\Util;
use App\Teams;
use App\Models\Fobos;
use Illuminate\Http\Request;
use Illuminate\Support\Arr;
use App\Firma;

class FobosController extends Controller
{
    private function sellersIds(){
        $tMod = new Teams();
        $sellersIds = $tMod->sellersLead(Util::userId());
        $ids = Arr::pluck($sellersIds, 'id');

        return $ids;
    }

    private function statuses(){
        $statuses = Fobos_statuses::all();
        return $statuses;
    }

    private function firmId(){
        $firmModel = new Firma();
        $firma = $firmModel->podaci_o_firmi();
        return $firma->id;
    }

    /**
     * link abuse prevention
     * @return array
     */
    private function linkCheck(){
        if (Util::isLider()){
            $sellersIds = $this->sellersIds();
            array_push($sellersIds, Util::userId());
        }
        else{
            $sellersIds = [Util::userId()];
        }
        return $sellersIds;
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $fobosModel = new Fobos();
        if (Util::isAdmin()){
            $clients = $fobosModel->clientsIndex();
        }
        elseif (Util::isProdavac()){
            $clients = $fobosModel->clientsIndex(Util::userId());
        }
        elseif (Util::isLider()){
            $clients = $fobosModel->clientsIndex($this->sellersIds(), Util::userId());
        }
        else{
            $clients = array();
        }
        session(['search_route' => false]);
        return view ('fobos.index', [
            'clients' => $clients,
            'isAdmin' => Util::isAdmin(),
            'isSuperAdmin' => Util::isSuperAdmin(),
            'isLider' => Util::isLider()
        ]);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('fobos.create', [
            'isAdmin' => Util::isAdmin(),
            'sellers' => Util::prodavci(),
            'statuses' => $this->statuses()
        ]);
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $request->validate([
            'name_phone' => 'required',
            'surname_phone' => 'required',
            'setup_boxes' => 'nullable|integer'
        ]);

        if (Util::isProdavac())
            $seller = Util::userId();
        else
            $seller = $request->input('seller');

        $fobos = Fobos::create([
            'cluster' => $request->input('cluster'),
            'name_phone' => $request->input('name_phone'),
            'surname_phone' => $request->input('surname_phone'),
            'street' => $request->input('street'),
            'home_no' => $request->input('home_no'),
            'enterance' => $request->input('enterance'),
            'tel1' => $request->input('tel1'),
            'tel2' => $request->input('tel2'),
            'tel3' => $request->input('tel3'),
            'floor' => $request->input('floor'),
            'apartment' => $request->input('apartment'),
            'statement_type' => $request->input('statement_type'),
            'network_group' => $request->input('network_group'),
            'tis_id' => $request->input('tis_id'),
            'packet' => $request->input('packet'),
            'uo_expire' => $request->input('uo_expire'),
            'black_list' => $request->input('black_list')?1:0,
            'recomended_tariff' => $request->input('recomended_tariff'),
            'name_adsl' => $request->input('name_adsl'),
            'surname_adsl' => $request->input('surname_adsl'),
            'adsl_tis_id' => $request->input('adsl_tis_id'),
            'adsl_isp' => $request->input('adsl_isp'),
            'uo_expire_adsl' => $request->input('uo_expire_adsl'),
            'speed' => $request->input('speed'),
            'name_iptv' => $request->input('name_iptv'),
            'surname_iptv' => $request->input('surname_iptv'),
            'iptv_tis' => $request->input('iptv_tis'),
            'hd_service' => $request->input('hd_service'),
            'setup_boxes' => $request->input('setup_boxes'),
            'uo_expire_iptv' => $request->input('uo_expire_iptv'),
            'iptv_packet' => $request->input('iptv_packet'),
            'first_offer' => $request->input('first_offer'),
            'operator' => $request->input('operator'),
            'month' => $request->input('month'),
            'year' => $request->input('year'),
            'status_id' => $request->input('status'),
            'withdrawal_date' => database_date($request->input('withdrawal_date')),
            'contract_expire_date' => database_date($request->input('contract_expire_date')),
            'withdrawal_reason' => $request->input('withdrawal_reason'),
            'seller_id' => $seller,
            'created_by' => Util::userId(),
            'updated_by' => Util::userId()
        ]);

        if ($request->input('comment') && $fobos) {
            Fobos_comments::create([
                'comment' => $request->input('comment'),
                'user_id' => Util::userId(),
                'fobos_id' => $fobos->id
            ]);
        }

        return redirect()->route('fobos.index')->with('success', __("Data successfully added"));
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Fobos  $fobo
     * @return \Illuminate\Http\Response
     */
    public function show(Fobos $fobo)
    {
        $fobosModel = new Fobos();
        $fobos = $fobosModel->clientData($fobo->id);
        $commentModel = new Fobos_comments();
        $comments = $commentModel->comments($fobo->id);
        $sellersIds = $this->linkCheck();

        return view('fobos.show', [
            'fobos' => $fobos,
            'isAdmin' => Util::isAdmin(),
            'isLider' => Util::isLider(),
            'comments' => $comments,
            'sellersIds' => $sellersIds
        ]);
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Fobos  $fobo
     * @return \Illuminate\Http\Response
     */
    public function edit(Fobos $fobo)
    {
        $fModel = new Fobos();
        $fobos = $fModel->clientData($fobo->id);
        $statuses = Fobos_statuses::all();
        $sellers = Util::prodavci();

        //kod biz proneta se samo natasa spasic pojavljuje u select
        if($this->firmId() == 1){
            $sellers = $sellers->merge(Util::lideri());
        }

        $comModel = new Fobos_comments();
        $comments = $comModel->comments($fobo->id);

        //link abuse prevention
        $sellersIds = $this->linkCheck();

        return view('fobos.edit', [
            'fobos' => $fobos,
            'isAdmin' => Util::isAdmin(),
            'comments' => $comments,
            'isSuperAdmin' => Util::isSuperAdmin(),
            'sellersIds' => $sellersIds,
            'statuses' => $statuses,
            'sellers' => $sellers
        ]);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Fobos  $fobo
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Fobos $fobo)
    {
        $request->validate([
            'name_phone' => 'required',
            'surname_phone' => 'required',
            'setup_boxes' => 'nullable|integer'
        ]);

        if (Util::isProdavac())
            $seller = Util::userId();
        else
            $seller = $request->input('seller');

        $fobosUpdate = Fobos::where('id', $fobo->id)->update([
            'cluster' => $request->input('cluster'),
            'name_phone' => $request->input('name_phone'),
            'surname_phone' => $request->input('surname_phone'),
            'street' => $request->input('street'),
            'home_no' => $request->input('home_no'),
            'enterance' => $request->input('enterance'),
            'tel1' => $request->input('tel1'),
            'tel2' => $request->input('tel2'),
            'tel3' => $request->input('tel3'),
            'floor' => $request->input('floor'),
            'apartment' => $request->input('apartment'),
            'statement_type' => $request->input('statement_type'),
            'network_group' => $request->input('network_group'),
            'tis_id' => $request->input('tis_id'),
            'packet' => $request->input('packet'),
            'uo_expire' => $request->input('uo_expire'),
            'black_list' => $request->input('black_list')?1:0,
            'recomended_tariff' => $request->input('recomended_tariff'),
            'name_adsl' => $request->input('name_adsl'),
            'surname_adsl' => $request->input('surname_adsl'),
            'adsl_tis_id' => $request->input('adsl_tis_id'),
            'adsl_isp' => $request->input('adsl_isp'),
            'uo_expire_adsl' => $request->input('uo_expire_adsl'),
            'speed' => $request->input('speed'),
            'name_iptv' => $request->input('name_iptv'),
            'surname_iptv' => $request->input('surname_iptv'),
            'iptv_tis' => $request->input('iptv_tis'),
            'hd_service' => $request->input('hd_service'),
            'setup_boxes' => $request->input('setup_boxes'),
            'uo_expire_iptv' => $request->input('uo_expire_iptv'),
            'iptv_packet' => $request->input('iptv_packet'),
            'first_offer' => $request->input('first_offer'),
            'operator' => $request->input('operator'),
            'month' => $request->input('month'),
            'year' => $request->input('year'),
            'seller_id' => $request->input('seller'),
            'status_id' => $request->input('status'),
            'withdrawal_date' => database_date($request->input('withdrawal_date')),
            'contract_expire_date' => database_date($request->input('contract_expire_date')),
            'withdrawal_reason' => $request->input('withdrawal_reason'),
            'seller_id' => $seller,
            'updated_by' => Util::userId(),
            'project_manager' => $request->input('project_manager')
        ]);

        if ($request->input('comment') && $fobosUpdate) {
            Fobos_comments::create([
                'comment' => $request->input('comment'),
                'user_id' => Util::userId(),
                'fobos_id' => $fobo->id
            ]);
        }

        if ($fobosUpdate){
            return redirect()->route('fobos.show', ['fobo'=>$fobo->id])->with('success', __("Data successfully changed"));
        }

        return back()->withInput();
    }

    /**
     * @param Request $request
     * @return $this
     */
    public function destroy(Request $request)
    {
        $findFobos = Fobos::find($request->input('id_fobos'));
        try{
            $findFobos->delete();
            return back()->withInput()->with('success', __("Data successfully deleted"));
        }
        catch (\Illuminate\Database\QueryException $e){
            return back()->withInput()->with('error', __("Data cannot be deleted"));
        }
    }

    public function delete_comment(Request $request){
        $findComment = Fobos_comments::find($request->input('id_comment'));
        if($findComment->delete()){
            return back()->with('success', __("Data successfully deleted"));
        }
    }

    public function search(){
        return view('fobos.search', [
            'isAdmin' => Util::isAdmin(),
            'sellers' => Util::prodavci(),
            'statuses' => $this->statuses()
        ]);
    }

    public function search_result(Request $request){
        $cluster = $request->input('cluster');
        $namePhone = $request->input('name_phone');
        $surnamePhone = $request->input('surname_phone');
        $street = $request->input('street');
        $homeNo = $request->input('home_no');
        $enterance = $request->input('enterance');
        $tel1 = $request->input('tel1');
        $tel2 = $request->input('tel2');
        $tel3 = $request->input('tel3');
        $floor = $request->input('floor');
        $apartment = $request->input('apartment');
        $statementType = $request->input('statement_type');
        $networkGroup = $request->input('network_group');
        $tisId = $request->input('tis_id');
        $packet = $request->input('packet');
        $uoExpire = $request->input('uo_expire');
        $blackList = $request->input('black_list')?1:0;
        $recommendedTariff = $request->input('recomended_tariff');
        $nameAdsl = $request->input('name_adsl');
        $surnameAdsl = $request->input('surname_adsl');
        $adslTisId = $request->input('adsl_tis_id');
        $adslIsp = $request->input('adsl_isp');
        $uoExpireAdsl = $request->input('uo_expire_adsl');
        $speed = $request->input('speed');
        $nameIptv = $request->input('name_iptv');
        $surnameIptv = $request->input('surname_iptv');
        $iptvTis = $request->input('iptv_tis');
        $hdService = $request->input('hd_service');
        $setupBoxes = $request->input('setup_boxes');
        $uoExpireIptv = $request->input('uo_expire_iptv');
        $iptvPacket = $request->input('iptv_packet');
        $firstOffer = $request->input('first_offer');
        $operator = $request->input('operator');
        $month = $request->input('month');
        $year = $request->input('year');
        $statusId = $request->input('status');
        $withdrawalDate = database_date($request->input('withdrawal_date'));
        $contractExpireDate = database_date($request->input('contract_expire_date'));
        $withdrawalReason = $request->input('withdrawal_reason');
        $accepted = $request->input('accepted');
        if($accepted){
            $accepted = 1;
        }
        else {
            $accepted = 0;
        }

        if (Util::isProdavac())
            $sellerId = Util::userId();
        else
            $sellerId = $request->input('seller');

        $fmodel = new Fobos();
        $fobos = $fmodel->search($cluster, $namePhone, $surnamePhone, $street, $homeNo, $enterance, $tel1, $tel2, $tel3, $floor, $apartment, $statementType, $networkGroup,
                                $tisId, $packet, $uoExpire, $blackList, $recommendedTariff, $nameAdsl, $surnameAdsl, $adslTisId, $adslIsp, $uoExpireAdsl,
                                $speed, $nameIptv, $surnameIptv, $iptvTis, $hdService, $setupBoxes, $uoExpireIptv, $iptvPacket, $firstOffer, $operator, $month, 
                                $year, $statusId, $accepted, $contractExpireDate, $withdrawalDate, $withdrawalReason, $sellerId);

        session(['search_route' => url()->full()]);
        return view('fobos.search_result', [
            'fobos' => $fobos,
            'isAdmin' => Util::isAdmin(),
            'isSuperAdmin' => Util::isSuperAdmin(),
            'isLider' => Util::isLider()
        ]);
    }

    public function expedition(Request $request){
        $id = $request->input('id_expedition');
        Fobos::where('id', $id)->update(['expedited' => 1, 'status_id' => 1]);
        return back()->withInput()->with('success', __("Expedited"));
    }

    public function accept(Request $request){
        $id = $request->input('fobos_accept');
        $importName = $request->input('import_name');
        $client = explode(' ', $importName);
        $fobosUpdate = Fobos::where('id', $id)->update(['expedited' => 0, 'accepted' => 1]);
        if ($fobosUpdate){
            $fobos = Fobos::find($id);
            Klijenti_prodaja::create([
                'ime' => $client[0],
                'prezime' => $client[1],
                'mrezna_grupa' => $fobos->network_group,
                'tel1' => $fobos->tel1,
                'tel2' => $fobos->tel2,
                'tel3' => $fobos->tel3,
                'tis_id' => $fobos->tis_id,
                'id_prodavac' => $fobos->seller_id,
                'fobos_id' => $fobos->id
            ]);
        }
        return back()->withInput()->with('success', __("Accepted"));
    }

    public function return(Request $request){
        $id = $request->input('fobos_return');
        Fobos::where('id', $id)->update(['expedited' => 0, 'accepted' => 0]);
        return back()->withInput()->with('success', __("Returned"));
    }

    public function claims(){
        $fmodel = new Fobos();
        $clients = $fmodel->clientsIndex($this->sellersIds(), null, true);
        return view ('fobos.claims', [
            'clients' => $clients,
            'isAdmin' => Util::isAdmin(),
            'isSuperAdmin' => Util::isSuperAdmin(),
            'isLider' => Util::isLider()
        ]);
    }

    public function import_index(){
        return view('fobos.import');
    }
    public function import(Request $request){
        require '../vendor/autoload.php';
        $file = $request->file('import');
        $user = auth()->user();

        $reader = new \PhpOffice\PhpSpreadsheet\Reader\Xlsx();
        if ($file){
            $allowedExtensions = array('xls', 'xlsx');
            $extension = $file->getClientOriginalExtension();
            if (in_array($extension, $allowedExtensions)){

                $spreadsheet = $reader->load($file);
                $sheetData = $spreadsheet->getActiveSheet()->toArray();
                $errorMessages = array();

                foreach ($sheetData as $br=>$data){
                    if ($br == 0 || (!$data[2] && !$data[3]))
                        continue;

//                    if (date('Y-m-d', strtotime($data[2])) == '1970-01-01' && $data[2] != null)
//                        $errorMessages[] = __("Invalid date format: cell number ").' '.($br+1).'.  - ('. $sheetData[0][2].')';
                    if (strlen(trim($data[10])) != 3 && $data[10])
                        $errorMessages[] = __("The network group must have 3 digits: cell number").' '.($br+1);
                    if(!is_int((int)$data[27]))
                        $errorMessages[] = __("Setup box number has to be integer: cell number").' '.($br+1);
                }

                if (!empty($errorMessages))
                    return view('fobos.import', ['errorMessages'=>$errorMessages]);

                foreach ($sheetData as $key=>$data){
                    if ($key == 0 || (!$data[2] && !$data[3]))
                        continue;

                    $fobosCreate = Fobos::create([
                        'cluster' => $data[0],
                        'tis_id' =>$data[1],
                        'surname_phone' => $data[2],
                        'name_phone' => $data[3],
                        'black_list' => $data[4]?1:0,
                        'street' => $data[5],
                        'home_no' => $data[6],
                        'enterance' => $data[7],
                        'floor' => $data[8],
                        'apartment' => $data[9],
                        'network_group' => $data[10],
                        'tel1' => $data[11],
                        'statement_type' => $data[12],
                        'packet' => $data[13],
                        'uo_expire' => $data[14],
                        'tel2' => $data[15],
                        'recomended_tariff' => $data[16],
                        'surname_adsl' => $data[17],
                        'name_adsl' => $data[18],
                        'adsl_tis_id' => $data[19],
                        'adsl_isp' => $data[20],
                        'uo_expire_adsl' => $data[21],
                        'speed' => $data[22],
                        'surname_iptv' => $data[23],
                        'name_iptv' => $data[24],
                        'iptv_tis' => $data[25],
                        'hd_service' => $data[26],
                        'setup_boxes' => $data[27],
                        'uo_expire_iptv' => $data[28],
                        'iptv_packet' => $data[29],
                        'first_offer' => $data[30],
                        'tel3' => $data[35],
                        'operator' => $data[36],
                        'month' => $data[37],
                        'year' => $data[38],
                        'created_by' => $user->id
                    ]);

                    if($fobosCreate){
                        if($data[31]){
                            Fobos_comments::create([
                                'comment' => $data[31],
                                'user_id' => Util::userId(),
                                'fobos_id' => $fobosCreate->id
                            ]);
                        }
                        if($data[32]){
                            Fobos_comments::create([
                                'comment' => $data[32],
                                'user_id' => Util::userId(),
                                'fobos_id' => $fobosCreate->id
                            ]);
                        }
                        if($data[34]){
                            Fobos_comments::create([
                                'comment' => $data[34],
                                'user_id' => Util::userId(),
                                'fobos_id' => $fobosCreate->id
                            ]);
                        }
                    }
                }

                return redirect()->route('fobos_import_index')->with('success', __("Data successfully imported to database"));

            }
            else {
                return redirect()->route('fobos_import_index')->with('errors', __("Valid file extension is xls or xslx"));
            }
        }
        else {
            return redirect()->route('fobos_import_index')->with('errors', __("Import excel file"));
        }
    }

    public function expire_list(){
        $fobosModel = new Fobos();
        $clients = $fobosModel->expireList();
        session(['search_route' => false]);
        session(['expire_list' => false]);
        return view ('fobos.expire_list', [
            'clients' => $clients,
            'isAdmin' => Util::isAdmin(),
            'isSuperAdmin' => Util::isSuperAdmin(),
            'isLider' => Util::isLider()
        ]);
    }
}
