<?php

namespace App\Http\Controllers;

use App\Klijenti_prodaja;
use Illuminate\Support\Arr;
use App\Models\Fobos_comments;
use App\Models\Campains;
use App\Models\Postpaid_tariffs;
use App\Traits\Util;
use App\Models\Fobos_copper;
use App\Firma;
use App\Models\Fobos_statuses;
use App\Teams;
use Illuminate\Http\Request;

class FobosCopperController extends Controller
{

    private function sellersIds(){
        $tMod = new Teams();
        $sellersIds = $tMod->sellersLead(Util::userId());
        $ids = Arr::pluck($sellersIds, 'id');

        return $ids;
    }

    private function statuses(){
        $statuses = Fobos_statuses::all();
        return $statuses;
    }

    private function firmId(){
        $firmModel = new Firma();
        $firma = $firmModel->podaci_o_firmi();
        return $firma->id;
    }

    private function linkCheck(){
        if (Util::isLider()){
            $sellersIds = $this->sellersIds();
            array_push($sellersIds, Util::userId());
        }
        else{
            $sellersIds = [Util::userId()];
        }
        return $sellersIds;
    }

    private function tariffs(){
        $tariffs = Postpaid_tariffs::all();
        return $tariffs;
    }

    private function campains(){
        $campains = Campains::all();
        return $campains;
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $fobosModel = new Fobos_copper();
        if (Util::isAdmin()){
            $clients = $fobosModel->clientsIndex();
        }
        elseif (Util::isProdavac()){
            $clients = $fobosModel->clientsIndex(Util::userId());
        }
        elseif (Util::isLider()){
            $clients = $fobosModel->clientsIndex($this->sellersIds(), Util::userId());
        }
        else{
            $clients = array();
        }
        session(['search_route' => false]);
        return view ('fobosCopper.index', [
            'clients' => $clients,
            'isAdmin' => Util::isAdmin(),
            'isSuperAdmin' => Util::isSuperAdmin(),
            'isLider' => Util::isLider()
        ]);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('fobosCopper.create', [
            'isAdmin' => Util::isAdmin(),
            'sellers' => Util::prodavci(),
            'statuses' => $this->statuses(),
            'postpaidTarrifs' => $this->tariffs(),
            'campains' => $this->campains()
        ]);
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $request->validate([
            'name' => 'required',
            'surname' => 'required',
            'cust_id' => 'nullable|integer',
            'total_stb_box' => 'nullable|integer',
            'cust_id_adsl' => 'nullable|integer',
            'free_pair' => 'nullable|integer',
            'free_adsl' => 'nullable|integer',
            'free_vdsl' => 'nullable|integer',
            'cust_id_iptv' => 'nullable|integer',
            'points' => 'nullable|numeric'
        ]);

        $note = $request->input('note');

        $create = Fobos_copper::create([
            'cust_id' => $request->input('cust_id'),
            'name' => $request->input('name'),
            'surname' => $request->input('surname'),
            'distributor' => $request->input('distributor'),
            'town' => $request->input('town'),
            'subsettlement' => $request->input('subsettlement'),
            'street' => $request->input('street'),
            'home_no' => $request->input('home_no'),
            'tel1' => $request->input('tel1'),
            'tel2' => $request->input('tel2'),
            'tel3' => $request->input('tel3'),
            'network_group' => $request->input('network_group'),
            'packet' => $request->input('packet'),
            'expiration_date_box' => database_date($request->input('expiration_date_box')),
            'resource' => $request->input('resource'),
            'max_net' => $request->input('max_net'),
            'stb_no' => $request->input('stb_no'),
            'total_stb_box' => $request->input('total_stb_box'),
            'postpaid_number' => $request->input('postpaid_number'),
            'postpaid_expiration_date' => database_date($request->input('postpaid_expiration_date')),
            'benefit' => $request->input('benefit'),
            'postpaid_tariff' => $request->input('postpaid_tariff'),
            'recommended_tariff' => $request->input('recommended_tariff'),
            'name_adsl' => $request->input('name_adsl'),
            'surname_adsl' => $request->input('surname_adsl'),
            'cust_id_adsl' => $request->input('cust_id_adsl'),
            'expiration_date_adsl' => database_date($request->input('expiration_date_adsl')),
            'campain_adsl' => $request->input('campain_adsl'),
            'speed_adsl' => $request->input('speed_adsl'),
            'modem_type' => $request->input('modem_type'),
            'free_pair' => $request->input('free_pair'),
            'free_adsl' => $request->input('free_adsl'),
            'free_vdsl' => $request->input('free_vdsl'),
            'name_iptv' => $request->input('name_iptv'),
            'surname_iptv' => $request->input('surname_iptv'),
            'cust_id_iptv' => $request->input('cust_id_iptv'),
            'iptv_expiration_date' => database_date($request->input('iptv_expiration_date')),
            'campain_vdsl' => $request->input('campain_vdsl'),
            'iptv_packet' => $request->input('iptv_packet'),
            'first_offer' => $request->input('first_offer'),
            'second_offer' => $request->input('second_offer'),
            'other_operators' => $request->input('other_operators'),
            'connection_date' => database_date($request->input('connection_date')),
            'box2' => $request->input('box2'),
            'box3' => $request->input('box3'),
            'box4' => $request->input('box4'),
            'campain_box' => $request->input('campain_box'),
            'postpaid_tariff_box' => $request->input('postpaid_tariff_box'),
            'adsl' => $request->input('adsl'),
            'campain_adsl_solo' => $request->input('campain_adsl_solo'),
            'speed_adsl_solo' => $request->input('speed_adsl_solo'),
            'iptv' => $request->input('iptv'),
            'iptv_solo' => $request->input('iptv_solo'),
            'campain_iptv_solo' => $request->input('campain_iptv_solo'),
            'status_id' => $request->input('status'),
            'points' => $request->input('points'),
            'seller_id' => $request->input('seller'),
            'contract_expire_date' => database_date($request->input('contract_expire_date')),
            'withdrawal_date' => database_date($request->input('withdrawal_date')),
            'withdrawal_reason' => $request->input('withdrawal_reason'),
            'created_by' => Util::userId()
        ]);

        if($create && $note){
            Fobos_comments::create([
                'comment' => $note,
                'user_id' => Util::userId(),
                'fobos_copper_id' => $create->id
            ]);
        }

        return redirect()->route('fobos_copper.index')->with('success', __("Data successfully added"));
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Fobos_copper  $fobos_copper
     * @return \Illuminate\Http\Response
     */
    public function show(Fobos_copper $fobos_copper)
    {
        $fobosModel = new Fobos_copper();
        $fobos = $fobosModel->clientData($fobos_copper->id);
        $commentModel = new Fobos_comments();
        $comments = $commentModel->commentsCopper($fobos_copper->id);
        $sellersIds = $this->linkCheck();

        return view('fobosCopper.show', [
            'fobos' => $fobos,
            'isAdmin' => Util::isAdmin(),
            'isLider' => Util::isLider(),
            'comments' => $comments,
            'sellersIds' => $sellersIds
        ]);
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Fobos_copper  $fobos_copper
     * @return \Illuminate\Http\Response
     */
    public function edit(Fobos_copper $fobos_copper)
    {
        $fModel = new Fobos_copper();
        $fobos = $fModel->clientData($fobos_copper->id);
        $sellers = Util::prodavci();

        //kod biz proneta se samo natasa spasic pojavljuje u select
        if($this->firmId() == 1){
            $sellers = $sellers->merge(Util::lideri());
        }

        $comModel = new Fobos_comments();
        $comments = $comModel->commentsCopper($fobos_copper->id);

        //link abuse prevention
        $sellersIds = $this->linkCheck();

        return view('fobosCopper.edit', [
            'fobos' => $fobos_copper,
            'isAdmin' => Util::isAdmin(),
            'comments' => $comments,
            'isSuperAdmin' => Util::isSuperAdmin(),
            'sellersIds' => $sellersIds,
            'sellers' => $sellers,
            'sellers' => Util::prodavci(),
            'statuses' => $this->statuses(),
            'postpaidTarrifs' => $this->tariffs(),
            'campains' => $this->campains()

        ]);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Fobos_copper  $fobos_copper
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Fobos_copper $fobos_copper)
    {
        $request->validate([
            'name' => 'required',
            'surname' => 'required',
            'cust_id' => 'nullable|integer',
            'total_stb_box' => 'nullable|integer',
            'cust_id_adsl' => 'nullable|integer',
            'free_pair' => 'nullable|integer',
            'free_adsl' => 'nullable|integer',
            'free_vdsl' => 'nullable|integer',
            'cust_id_iptv' => 'nullable|integer',
            'points' => 'nullable|numeric'
        ]);

        $note = $request->input('note');

        $update = Fobos_copper::where('id', $fobos_copper->id)->update([
            'cust_id' => $request->input('cust_id'),
            'name' => $request->input('name'),
            'surname' => $request->input('surname'),
            'distributor' => $request->input('distributor'),
            'town' => $request->input('town'),
            'subsettlement' => $request->input('subsettlement'),
            'street' => $request->input('street'),
            'home_no' => $request->input('home_no'),
            'tel1' => $request->input('tel1'),
            'tel2' => $request->input('tel2'),
            'tel3' => $request->input('tel3'),
            'network_group' => $request->input('network_group'),
            'packet' => $request->input('packet'),
            'expiration_date_box' => database_date($request->input('expiration_date_box')),
            'resource' => $request->input('resource'),
            'max_net' => $request->input('max_net'),
            'stb_no' => $request->input('stb_no'),
            'total_stb_box' => $request->input('total_stb_box'),
            'postpaid_number' => $request->input('postpaid_number'),
            'postpaid_expiration_date' => database_date($request->input('postpaid_expiration_date')),
            'benefit' => $request->input('benefit'),
            'postpaid_tariff' => $request->input('postpaid_tariff'),
            'recommended_tariff' => $request->input('recommended_tariff'),
            'name_adsl' => $request->input('name_adsl'),
            'surname_adsl' => $request->input('surname_adsl'),
            'cust_id_adsl' => $request->input('cust_id_adsl'),
            'expiration_date_adsl' => database_date($request->input('expiration_date_adsl')),
            'campain_adsl' => $request->input('campain_adsl'),
            'speed_adsl' => $request->input('speed_adsl'),
            'modem_type' => $request->input('modem_type'),
            'free_pair' => $request->input('free_pair'),
            'free_adsl' => $request->input('free_adsl'),
            'free_vdsl' => $request->input('free_vdsl'),
            'name_iptv' => $request->input('name_iptv'),
            'surname_iptv' => $request->input('surname_iptv'),
            'cust_id_iptv' => $request->input('cust_id_iptv'),
            'iptv_expiration_date' => database_date($request->input('iptv_expiration_date')),
            'campain_vdsl' => $request->input('campain_vdsl'),
            'iptv_packet' => $request->input('iptv_packet'),
            'first_offer' => $request->input('first_offer'),
            'second_offer' => $request->input('second_offer'),
            'other_operators' => $request->input('other_operators'),
            'connection_date' => database_date($request->input('connection_date')),
            'box2' => $request->input('box2'),
            'box3' => $request->input('box3'),
            'box4' => $request->input('box4'),
            'campain_box' => $request->input('campain_box'),
            'postpaid_tariff_box' => $request->input('postpaid_tariff_box'),
            'adsl' => $request->input('adsl'),
            'campain_adsl_solo' => $request->input('campain_adsl_solo'),
            'speed_adsl_solo' => $request->input('speed_adsl_solo'),
            'iptv' => $request->input('iptv'),
            'iptv_solo' => $request->input('iptv_solo'),
            'campain_iptv_solo' => $request->input('campain_iptv_solo'),
            'status_id' => $request->input('status'),
            'points' => $request->input('points'),
            'seller_id' => $request->input('seller'),
            'contract_expire_date' => database_date($request->input('contract_expire_date')),
            'withdrawal_date' => database_date($request->input('withdrawal_date')),
            'withdrawal_reason' => $request->input('withdrawal_reason'),
            'updated_by' => Util::userId()
        ]);

        if($update && $note){
            Fobos_comments::create([
                'comment' => $note,
                'user_id' => Util::userId(),
                'fobos_copper_id' => $fobos_copper->id
            ]);
        }

        return redirect()->route('fobos_copper.show', ['fobos_copper' => $fobos_copper]);
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function destroy(Request $request)
    {
        $findFobos = Fobos_copper::find($request->input('id_fobos'));
        try{
            $findFobos->delete();
            return back()->withInput()->with('success', __("Data successfully deleted"));
        }
        catch (\Illuminate\Database\QueryException $e){
            return back()->withInput()->with('error', __("Item can't be deleted because it's in use"));
        }
    }

    public function import_index(){
        return view('fobosCopper.import');
    }

    public function import(Request $request){
        require '../vendor/autoload.php';
        $file = $request->file('import');
        $user = auth()->user();

        /*note da se belezi u komentare*/

        $reader = new \PhpOffice\PhpSpreadsheet\Reader\Xlsx();
        if ($file){
            $allowedExtensions = array('xls', 'xlsx');
            $extension = $file->getClientOriginalExtension();
            if (in_array($extension, $allowedExtensions)){

                $spreadsheet = $reader->load($file);
                $sheetData = $spreadsheet->getActiveSheet()->toArray();
                $errorMessages = array();

                foreach ($sheetData as $br=>$data){
                    if ($br == 0 || (!$data[3] && !$data[4]))
                        continue;

                    if (date('Y-m-d', strtotime($data[14])) == '1970-01-01' && $data[14] != null)
                       $errorMessages[] = __("Invalid date format: cell number").' '.($br+1).'.  - ('. $data[14].')';
                    if (date('Y-m-d', strtotime($data[20])) == '1970-01-01' && $data[20] != null)
                       $errorMessages[] = __("Invalid date format: cell number").' '.($br+1).'.  - ('. $data[20].')';
                    if (date('Y-m-d', strtotime($data[27])) == '1970-01-01' && $data[27] != null)
                       $errorMessages[] = __("Invalid date format: cell number").' '.($br+1).'.  - ('. $data[27].')';
                    if (date('Y-m-d', strtotime($data[37])) == '1970-01-01' && $data[37] != null)
                       $errorMessages[] = __("Invalid date format: cell number").' '.($br+1).'.  - ('. $data[37].')';
                    if (strlen(trim($data[11])) != 3 && $data[11])
                        $errorMessages[] = __("The network group must have 3 digits: cell number").' '.($br+1).$data[11];
                    if(!is_int((int)$data[2]) && $data[2] != null)
                        $errorMessages[] = 'Cust_ID'.' '.__("has to be integer: cell number").' '.($br+1);
                    if(!is_int((int)$data[18]) && $data[18] != null)
                        $errorMessages[] = __("Stb box number").' '.__("has to be integer: cell number").' '.($br+1);
                    if(!is_int((int)$data[26]) && $data[26] != null)
                        $errorMessages[] = 'Cust_ID_ADSL'.' '.__("has to be integer: cell number").' '.($br+1);
                    if(!is_int((int)$data[31]) && $data[31] != null)
                        $errorMessages[] = __("Free pairs").' '.__("has to be integer: cell number").' '.($br+1);
                    if(!is_int((int)$data[32]) && $data[32] != null)
                        $errorMessages[] = __("Free ADSL boxes").' '.__("has to be integer: cell number").' '.($br+1);
                    if(!is_int((int)$data[33]) && $data[33] != null)
                        $errorMessages[] = __("Free VDSL boxes").' '.__("has to be integer: cell number").' '.($br+1);
                    if(!is_int((int)$data[36]) && $data[36] != null)
                        $errorMessages[] = __("Nuber of setup boxes").' '.__("has to be integer: cell number").' '.($br+1);
                }

                if (!empty($errorMessages))
                    return view('fobosCopper.import', ['errorMessages'=>$errorMessages]);

                foreach ($sheetData as $key=>$data){
                    if ($key == 0 || (!$data[3] && !$data[4]))
                        continue;

                    $fobosCreate = Fobos_copper::create([
                        'distributor' => $data[1],
                        'cust_id' => $data[2],
                        'name' => $data[4],
                        'surname' => $data[3],
                        'town' => $data[5],
                        'subsettlement' => $data[6],
                        'street' => $data[7],
                        'home_no' => $data[8],
                        'tel1' => $data[12],
                        'tel2' => $data[9],
                        'tel3' => $data[10],
                        'network_group' => $data[11],
                        'packet'  => $data[13],
                        'expiration_date_box' => database_date($data[14]),
                        'resource' => $data[15],
                        'max_net' => $data[16],
                        'stb_no' => $data[17],
                        'total_stb_box' => $data[18],
                        'postpaid_number' => $data[19],
                        'postpaid_expiration_date' => database_date($data[20]),
                        'benefit' => $data[21],
                        'postpaid_tariff' => $data[22],
                        'recommended_tariff' => $data[23],
                        'name_adsl' => $data[25],
                        'surname_adsl' => $data[24],
                        'cust_id_adsl' => $data[26],
                        'expiration_date_adsl' => database_date($data[27]),
                        'campain_adsl' => $data[28],
                        'speed_adsl' => $data[29],
                        'modem_type' => $data[30],
                        'free_pair' => $data[31],
                        'free_adsl' => $data[32],
                        'free_vdsl' => $data[33],
                        'name_iptv' => $data[35],
                        'surname_iptv' => $data[34],
                        'cust_id_iptv' => $data[36],
                        'iptv_expiration_date' => database_date($data[37]),
                        'campain_vdsl' => $data[38],
                        'iptv_packet' => $data[39],
                        'first_offer' => $data[40],
                        'second_offer' => $data[41]
                    ]);

                }

                return redirect()->route('fobos_copper_import_index')->with('success', __("Data successfully imported to database"));

            }
            else {
                return redirect()->route('fobos_copper_import_index')->with('errors', __("Valid file extension is xls or xslx"));
            }
        }
        else {
            return redirect()->route('fobos_copper_import_index')->with('errors', __("Import excel file"));
        }
    }

    public function expedition(Request $request){
        $id = $request->input('id_expedition');
        Fobos_copper::where('id', $id)->update(['expedited' => 1, 'status_id' => 1]);
        return back()->withInput()->with('success',__("Expedited"));
    }

    public function accept(Request $request){
        $id = $request->input('fobos_copper_accept');
        $importName = $request->input('import_name');
        $client = explode(' ', $importName);
        $fobosUpdate = Fobos_copper::where('id', $id)->update(['expedited' => 0, 'accepted' => 1]);
        if ($fobosUpdate){
            $fobos = Fobos_copper::find($id);
            Klijenti_prodaja::create([
                'ime' => $client[0],
                'prezime' => $client[1],
                'mrezna_grupa' => $fobos->network_group,
                'tel1' => $fobos->tel1,
                'tel2' => $fobos->tel2,
                'tel3' => $fobos->tel3,
                'tis_id' => $fobos->tis_id,
                'id_prodavac' => $fobos->seller_id,
                'fobos_copper_id' => $fobos->id,
                'created_by' => Util::userId(),
                'updated_by' => Util::userId()
            ]);
        }
        return back()->withInput()->with('success', __("Accepted"));
    }

    public function return(Request $request){
        $id = $request->input('fobos_copper_return');
        Fobos_copper::where('id', $id)->update(['expedited' => 0, 'accepted' => 0]);
        return back()->with('success', __("Returned"));
    }

    public function claims(){
        $fmodel = new Fobos_copper();
        $clients = $fmodel->clientsIndex($this->linkCheck(), null, true);
        return view ('fobosCopper.claims', [
            'clients' => $clients,
            'isAdmin' => Util::isAdmin(),
            'isSuperAdmin' => Util::isSuperAdmin(),
            'isLider' => Util::isLider()
        ]);
    }

    public function expire_list(){
        $fobosModel = new Fobos_copper();
        $clients = $fobosModel->expireList();
        session(['search_route' => false]);
        session(['expire_list' => false]);
        return view ('fobosCopper.expire_list', [
            'clients' => $clients,
            'isAdmin' => Util::isAdmin(),
            'isSuperAdmin' => Util::isSuperAdmin(),
            'isLider' => Util::isLider()
        ]);
    }

    public function search(){
        return view('fobosCopper.search', [
            'isAdmin' => Util::isAdmin(),
            'sellers' => Util::prodavci(),
            'statuses' => $this->statuses(),
            'postpaidTarrifs' => $this->tariffs(),
            'campains' => $this->campains()
        ]);
    }

    public function search_result(Request $request){
        $accepted = $request->input('accepted');
        $custId = $request->input('cust_id');
        $name = $request->input('name');
        $surname = $request->input('surname');
        $distributor = $request->input('distributor');
        $town = $request->input('town');
        $subsettlement = $request->input('subsettlement');
        $street = $request->input('street');
        $homeNo = $request->input('home_no');
        $tel1 = $request->input('tel1');
        $tel2 = $request->input('tel2');
        $tel3 = $request->input('tel3');
        $networkGroup = $request->input('network_group');
        $packet = $request->input('packet');
        $expirationDateBox = database_date($request->input('expiration_date_box'));
        $resource = $request->input('resource');
        $maxNet = $request->input('max_net');
        $stbNo = $request->input('stb_no');
        $totalStbBox = $request->input('total_stb_box');
        $postpaidNumber = $request->input('postpaid_number');
        $postpaidExpiratonDate = database_date($request->input('postpaid_expiration_date'));
        $benefit = $request->input('benefit');
        $postpaidTariff = $request->input('postpaid_tariff');
        $recommendedTariff = $request->input('recommended_tariff');
        $nameAdsl = $request->input('name_adsl');
        $surnameAdsl = $request->input('surname_adsl');
        $custIdAdsl = $request->input('cust_id_adsl');
        $expirationDateAdsl = database_date($request->input('expiration_date_adsl'));
        $campainAdsl = $request->input('campain_adsl');
        $speedAdsl = $request->input('speed_adsl');
        $modemType =$request->input('modem_type');
        $freePair = $request->input('free_pair');
        $freeAdsl = $request->input('free_adsl');
        $freeVdsl = $request->input('free_vdsl');
        $nameIptv = $request->input('name_iptv');
        $surnameIptv = $request->input('surname_iptv');
        $custIdIptv = $request->input('cust_id_iptv');
        $iptvExpirationDate = database_date($request->input('iptv_expiration_date'));
        $campainVdsl = $request->input('campain_vdsl');
        $iptvPacket = $request->input('iptv_packet');
        $firstOffer = $request->input('first_offer');
        $secondOffer = $request->input('second_offer');
        $otherOperators = $request->input('other_operators');
        $connectionDate = database_date($request->input('connection_date'));
        $box2 = $request->input('box2');
        $box3 = $request->input('box3');
        $box4 = $request->input('box4');
        $campainBox = $request->input('campain_box');
        $postpaidTariffBox = $request->input('postpaid_tariff_box');
        $adsl = $request->input('adsl');
        $campainAdslSolo = $request->input('campain_adsl_solo');
        $speedAdslSolo = $request->input('speed_adsl_solo');
        $iptv = $request->input('iptv');
        $iptvSolo = $request->input('iptv_solo');
        $campainIptvSolo = $request->input('campain_iptv_solo');
        $statusId = $request->input('status');
        $points = $request->input('points');
        $contractExpireDate = database_date($request->input('contract_expire_date'));
        $withdrawalDate = database_date($request->input('withdrawal_date'));
        $withdrawalReason = $request->input('withdrawal_reason');
        
        if($accepted){
            $accepted = 1;
        }
        else {
            $accepted = 0;
        }

        if (Util::isProdavac())
            $sellerId = Util::userId();
        else
            $sellerId = $request->input('seller');

        $fmodel = new Fobos_copper();
        $fobos = $fmodel->search($custId,$name,$surname,$distributor,$town,$subsettlement,$street,$homeNo,$tel1,$tel2,$tel3,$networkGroup,$packet,
        $expirationDateBox,$resource,$maxNet,$stbNo,$totalStbBox,$postpaidNumber,$postpaidExpiratonDate,$benefit,$postpaidTariff,$recommendedTariff,
        $nameAdsl,$surnameAdsl,$custIdAdsl,$expirationDateAdsl,$campainAdsl,$speedAdsl,$modemType,$freePair,$freeAdsl,$freeVdsl,$nameIptv,$surnameIptv,
        $custIdIptv,$iptvExpirationDate,$campainVdsl,$iptvPacket,$firstOffer,$secondOffer,$otherOperators,$connectionDate,$box2,$box3,$box4,$campainBox,
        $postpaidTariffBox,$adsl,$campainAdslSolo,$speedAdslSolo,$iptv,$iptvSolo,$campainIptvSolo,$statusId,$points,$sellerId,$contractExpireDate,
        $withdrawalDate,$withdrawalReason,$accepted);

        session(['search_route' => url()->full()]);
        return view('fobosCopper.search_result', [
            'fobos' => $fobos,
            'isAdmin' => Util::isAdmin(),
            'isSuperAdmin' => Util::isSuperAdmin(),
            'isLider' => Util::isLider()
        ]);
    }
}
