<?php

namespace App\Http\Controllers;

use App\Models\Areas;
use App\Models\Ger_change_history;
use App\Models\Ger_images;
use App\Models\Ger_works;
use App\Models\Ger_construction_sites;
use Illuminate\Http\Request;
use App\Traits\Util;
use App\Models\Const_teams;
use App\Models\Ger_absent_workers;
use App\Models\Ger_comments;
use App\Models\Ger_site_work;
use App\Models\Polish_logs;
use App\Models\Providers;
use App\User;
use Illuminate\Support\Arr;
use Intervention\Image\ImageManager as Img;

class GerConstructionSitesController extends Controller
{
    private function linkValidationCheck($leader)
    {
        if(!Util::isSuperAdmin()){
            if($leader != Util::userId() && !Util::isConstructionManager()){
                echo 'sta ces ovde be'; exit;
            }
        }
    }

    private function someAdmin(){
        return Util::isConstructionManager() || Util::isAdmin() || Util::isSuperAdmin();
    }

    public function index()
    {
        $deMod = new Ger_construction_sites();
        if(Util::isColumnLeader())
            $constructionSites = $deMod->index(Util::userId(), Util::userPlace(),Util::provider());
        else
            $constructionSites = $deMod->index();

        $tMod = new Const_teams();
        return view('gerConstructionSites.index', ['constructionSites' => $constructionSites, 'isSuperAdmin' => Util::isSuperAdmin(), 'deMod' => $deMod, 'tMod' => $tMod]);
    }

    public function create()
    {
        $leaders = Util::columnLeaders();
        $areas = Areas::all();
        $providers = Providers::all();
        return view('gerConstructionSites.create', [
            'leaders' => $leaders, 
            'areas' => $areas, 
            'isColumnLeader' => Util::isColumnLeader(), 
            'providers' => $providers,
            'isSuperAdmin' => Util::isSuperAdmin()
        ]);
    }

    public function store(Request $request)
    {
        $date = database_date($request->input('date'));
        $polisherReport = $request->input('polisher_report');
        $leader = $request->input('leader');
        $area = $request->input('area');
        $insertDate = $request->input('insert_date');
        if($insertDate){
            $polishDate = date('Y-m-d');
        }
        else {
            $polishDate = database_date($request->input('polish_date'));
        }
        if($request->input('number_of_workers')){
            $numberOfWorkers = $request->input('number_of_workers');
        }
        else{
            $tMod = new Const_teams();
            $numberOfWorkers = count($tMod->workersLead($leader = $request->input('leader')));
        }
        $comment = $request->input('comment');
        $workStart = $request->input('work_start');
        $workEnd = $request->input('work_end');
        $pause = $request->input('pause');
        $place = $request->input('place');
        $street = $request->input('street');
        $pop = $request->input('pop');
        $dp = $request->input('dp');

        if(Util::isColumnLeader())
            $provider = Util::provider();
        else
            $provider = $request->input('provider');

        if(Util::isColumnLeader())
            $leader = Util::userId();
        $request->validate([
            'date' => 'required',
            'work_start' => 'required',
            'work_end' => 'required',
            'pause' => 'required'
        ]);

        $create = Ger_construction_sites::create([
            'date' => $date,
            'polisher_report' => $polisherReport,
            'polish_date' => $polishDate,
            'leader' => $leader,
            'area' => $area,
            'number_of_workers' => $numberOfWorkers,
            'work_start' => $workStart,
            'work_end' => $workEnd,
            'pause' => $pause,
            'place' => $place,
            'street' => $street,
            'provider' => $provider,
            'pop' => $pop,
            'dp' => $dp
        ]);

        if($create && $comment){
            Ger_comments::create([
                'comment' => $comment,
                'id_site' => $create->id,
                'id_user' => Util::userId()
            ]);
        }

        if($create){
            Ger_change_history::create([
                'id_user' => Util::userId(),
                'id_site' => $create->id
            ]);
            if($insertDate){
                Polish_logs::create([
                    'user_id' => Util::userId(),
                    'site_id' => $create->id
                ]);
            }
            return redirect()->route('ger_construction_sites.show', [$create->id])->with('success', __("Data successfully added"));
        }
        else
            return back()->with('error', __("Error"));
    }

    public function show(Ger_construction_sites $ger_construction_site)
    {
        $this->linkValidationCheck($ger_construction_site->leader);
        $deMod = new Ger_construction_sites();
        $site = $deMod->data($ger_construction_site->id);
        $hMod = new Ger_change_history();
        $history = $hMod->history($ger_construction_site->id);
        $cMod = new Ger_comments();
        $comments = $cMod->comments($ger_construction_site->id);
        $iMod = new Ger_images();
        $images = $iMod->images($ger_construction_site->id);
        $wMod = new Ger_site_work();
        $works = $wMod->works($ger_construction_site->id);
        $workHours = timeDifference($ger_construction_site->work_start, $ger_construction_site->work_end);
        $logMod = new Polish_logs();
        $logs = $logMod->logs($ger_construction_site->id, false);
        $changedBy = $logMod->logs($ger_construction_site->id, true);
        if($changedBy){
            $changedBy = $changedBy->name.' '.$changedBy->surname.' ('.date('d.m.Y', strtotime($changedBy->created_at)).')';
        }

        return view('gerConstructionSites.show', [
            'site' => $site, 
            'history' => $history, 
            'comments' => $comments,
            'images' => $images,
            'works' => $works,
            'workHours' => $workHours,
            'isColumnLeader' => Util::isColumnLeader(),
            'isSuperAdmin' => Util::isSuperAdmin(),
            'logs' => $logs,
            'changedBy' => $changedBy
        ]);
    }

    public function edit(Ger_construction_sites $ger_construction_site)
    {
        $this->linkValidationCheck($ger_construction_site->leader);
        $leaders = Util::columnLeaders();
        $areas = Areas::all();
        $providers = Providers::all();
        $iMod = new Ger_images();
        $cMod = new Ger_comments();
        $deMod = new Ger_works();
        $wsMod = new Ger_site_work();
        $absMod = new Ger_absent_workers();
        $images = $iMod->images($ger_construction_site->id);
        $comments = $cMod->comments($ger_construction_site->id);
        $absentWorkers = $absMod->absentWorkers($ger_construction_site->id);

        $tMod = new Const_teams();
        $workers = $tMod->workersLead($ger_construction_site->leader);

        $worksAll = Ger_works::all();
        $workIds = Arr::pluck($worksAll, 'id');
        $works = array();
        foreach($workIds as $key=>$id){
            $work = $deMod->work_data($id);
            $quantity = $wsMod->workQuantity($ger_construction_site->id, $id);
            $works[$key]['id'] = $id;
            $works[$key]['code'] = $work->code;
            $works[$key]['work'] = $work->work;
            $works[$key]['unit'] = $work->unit_short;
            $works[$key]['quantity'] = $quantity;
        }
        return view('gerConstructionSites.edit', [
            'leaders' => $leaders,
            'areas' => $areas,
            'providers' => $providers,
            'site' => $ger_construction_site,
            'images' => $images,
            'comments' => $comments,
            'isSuperAdmin' => Util::isSuperAdmin(),
            'isColumnLeader' => Util::isColumnLeader(),
            'works' => $works,
            'isColumnLeader' => Util::isColumnLeader(),
            'someAdmin' => $this->someAdmin(),
            'workers' => $workers,
            'absentWorkers' => $absentWorkers
        ]);
    }

    public function update(Request $request, Ger_construction_sites $ger_construction_site)
    {
        $date = database_date($request->input('date'));
        $polisherReport = $request->input('polisher_report');
        $area = $request->input('area');
        $comment = $request->input('comment');
        $workStart = $request->input('work_start');
        $workEnd = $request->input('work_end');
        $pause = $request->input('pause');
        $place = $request->input('place');
        $street = $request->input('street');
        $pop = $request->input('pop');
        $dp = $request->input('dp');
        $images = $request->file('images');
        $insertDate = $request->input('insert_date');
        $absentWorkers = $request->input('absent_workers');
        $absMod = new Ger_absent_workers();
        $tMod = new Const_teams();
        if(Util::isColumnLeader())
            $provider = Util::provider();
        else
            $provider = $request->input('provider');
        if($insertDate){
            $polishDate = date('Y-m-d');
        }
        else {
            $polishDate = database_date($request->input('polish_date'));
        }
        if(Util::isColumnLeader())
            $leader = Util::userId();
        else
            $leader = $request->input('leader');
            
        if($request->input('number_of_workers') && Util::isSuperAdmin()){
            $numberOfWorkers = $request->input('number_of_workers');
        }
        else{
            $numberOfWorkers = count($tMod->workersLead($leader = $leader));
        }
        $request->validate([
            'date' => 'required',
            'work_start' => 'required',
            'work_end' => 'required',
            'pause' => 'required'
        ]);

        if($this->someAdmin()){
            $update = Ger_construction_sites::where('id', $ger_construction_site->id)->update([
                'date' => $date,
                'polisher_report' => $polisherReport,
                'polish_date' => $polishDate,
                'leader' => $leader,
                'area' => $area,
                'number_of_workers' => $numberOfWorkers,
                'work_start' => $workStart,
                'work_end' => $workEnd,
                'pause' => $pause,
                'place' => $place,
                'street' => $street,
                'provider' => $provider,
                'pop' => $pop,
                'dp' => $dp
            ]);
        }
        else {
            $update = Ger_construction_sites::where('id', $ger_construction_site->id)->update([
                'date' => $date,
                'leader' => $leader,
                'area' => $area,
                'number_of_workers' => $numberOfWorkers,
                'work_start' => $workStart,
                'work_end' => $workEnd,
                'pause' => $pause,
                'place' => $place,
                'street' => $street,
                'provider' => $provider,
                'pop' => $pop,
                'dp' => $dp
            ]);
        }

        if($update && $images){
            if($images){
                $this->validate($request, [
                    'images.*' => 'image|mimes:jpeg,png,jpg,gif'
                ]);
                $num = 0;
                $img = new Img();
                $folder = 'uploads/ger_images/'.quartal();
                if (!file_exists($folder)){
                    mkdir($folder, 0755, true);
                }
                foreach($images as $file){
                    $extension = $file->getClientOriginalExtension();
                    $filename = time().'-'.$num.'-de'.'.'.$extension;
                    $num++;
                    $fileInt = $img->make($file->getRealPath());
                    $fileInt->save($folder.'/'.$filename, 50);
                    Ger_images::create([
                        'url' => '/'.$folder.'/'.$filename,
                        'id_site' => $ger_construction_site->id
                    ]);
                }
            }
        }

        if($update && $comment){
            Ger_comments::create([
                'comment' => $comment,
                'id_site' => $ger_construction_site->id,
                'id_user' => Util::userId()
            ]);
        }

        if($update){
            Ger_change_history::create([
                'id_user' => Util::userId(),
                'id_site' => $ger_construction_site->id
            ]);
            if($insertDate){
                Polish_logs::create([
                    'user_id' => Util::userId(),
                    'site_id' => $ger_construction_site->id
                ]);
            }
            if($absentWorkers){
                foreach($absentWorkers as $id => $worker){
                    $exists = Ger_absent_workers::where('site_id',$ger_construction_site->id)->where('worker_id',$id)->first();
                    if(!$exists){
                        Ger_absent_workers::create([
                            'worker_id' => $id,
                            'site_id' => $ger_construction_site->id
                        ]);
                    }
                }
                $numberOfWorkers = count($tMod->workersLead($leader = $leader)) - $absMod->count($ger_construction_site->id);
                Ger_construction_sites::where('id', $ger_construction_site->id)->update([
                    'number_of_workers' => $numberOfWorkers
                ]);
            }
            else {
                Ger_absent_workers::where('site_id',$ger_construction_site->id)->delete();
            }
            return redirect()->route('ger_construction_sites.show', [$ger_construction_site->id])->with('success', __("Data successfully added"));
        }
        else
            return back()->with('error', __("Error"));
    }

    public function destroy(Request $request)
    {
        $findSite = Ger_construction_sites::find($request->input('id_site'));

        try{
            $images = Ger_images::where('id_site', $request->input('id_site'))->get();
            if($findSite->delete()){
                foreach ($images as $img){
                    $file = ltrim($img->url,'/');
                    if (file_exists($file)){
                        unlink($file);
                    }
                }
            }
            return back()->withInput()->with('success', __("Data successfully deleted"));
        }
        catch (\Illuminate\Database\QueryException $e){
            return back()->withInput()->with('error', __("Item can't be deleted because it's in use"));
        }


        return back()->withInput()->with('error', __("Data cannot be deleted"));
    }

    public function delete_comment(Request $request){
        $findComment = Ger_comments::find($request->input('id_comment'));
        if($findComment->delete()){
            return back()->with('success', __("Comment successfully deleted"));
        }
        else {
            return back()->with('errors', __("Error"));
        }
    }

    public function delete_image(Request $request){
        $findImage = Ger_images::find($request->input('id_image'));
        $file = ltrim($findImage->url,'/');

        if(file_exists($file)){
            unlink($file);
        }

        if($findImage->delete()){
            return back()->with('success', __("Image successfully deleted"));
        }
        else {
            return back()->with('errors', __("Error"));
        }
    }

    public function add_ger_work(Request $request){
        $siteId = $request->get('site_id');
        $workId = $request->get('work_id');
        $operation = $request->get('operation');
        $quantity = $request->get('work_quantity');
        $request->validate([
            'work_quantity' => 'required|numeric'
        ]);
        if($operation == 'minus')
            $quantity = -$quantity;
        if($workId) {
            $specWork = Ger_works::where('id', $workId)->first();
            $price = $specWork->price;
            Ger_site_work::create([
                'site_id' => $siteId,
                'work_id' => $workId,
                'quantity' => $quantity,
                'price' => $quantity*$price
            ]);
        }
        return redirect(url()->previous().'#deWorks');
    }

    public function search(){
        return view('gerConstructionSites.search');
    }

    public function search_result(Request $request){
        $deMod = new Ger_construction_sites();
        $dateStart = database_date($request->input("date_start"));
        $dateEnd = database_date($request->input("date_end"));
        if(Util::isColumnLeader())
            $constructionSites = $deMod->filter(Util::userId(), $dateStart, $dateEnd, Util::userPlace(), Util::provider());
        else
            $constructionSites = $deMod->filter(null, $dateStart, $dateEnd);
        return view('gerConstructionSites.search_result', ['constructionSites' => $constructionSites, 'isSuperAdmin' => Util::isSuperAdmin(), 'deMod' => $deMod]);
    }

    public function statistic(Request $request){
        $start = $request->input('start');
        $end = $request->input('end');

        if ($start && $end){
            $from = date('Y-m-d', strtotime($start));
            $to = date('Y-m-d', strtotime($end));
        }
        else {
            $from = date('Y-m-01');
            $to = date('Y-m-t');
        }


        $workMod = new Ger_site_work();
        if(Util::isSuperAdmin()){
            $leaders = Util::columnLeaders();
        }
        else {
            $leaders = User::where('id',Util::userId())->get();
        }

        return view ('gerConstructionSites.statistic', ['workMod' => $workMod, 'total' => 0, 'leaders' => $leaders, 'from' => $from, 'to' => $to]);
    }
}