<?php

namespace App\Http\Controllers;

use App\Models\Site_work;
use App\Models\Huawei;
use App\Models\Kir;
use App\Models\Wf_task_equipment;
use App\Models\Worker_equipment;
use App\Models\Wf_statuses;
use App\Models\Wf_task_work;
use App\Models\Wf_project_task;
use App\Firma;
use App\Klijent;
use App\Klijenti_bakar;
use App\Klijenti_optika;
use App\Klijenti_prodaja;
use App\Klijenti_supernova;
use App\Models\Construction_sites;
use App\Models\De_construction_sites;
use App\Models\Fobos;
use App\Models\Fobos_rune;
use App\Models\Rune_comments;
use App\Models\Rune_optics;
use App\Napomene;
use App\Statusi;
use App\User;
use Illuminate\Http\Request;

class HomeController extends Controller
{
    /**
     * Create a new controller instance.
     *
     * @return void
     */
    public function __construct()
    {
        $this->middleware('auth');
    }

    private function isAdmin(){
        $user = auth()->user();
        if (in_array($user->role_id, config('app.admins')))
            return true;
        else
            return false;
    }

    /**
     * Show the application dashboard.
     *
     * @return \Illuminate\Contracts\Support\Renderable
     */
    public function index()
    {
        $firmaModel = new Firma();
        $klijentModel = new Klijent();
        $klijentOptModel = new Klijenti_optika();
        $klijentSupModel = new Klijenti_supernova();
        $klijentBakModel = new Klijenti_bakar();
        $constructionModel = new Construction_sites();
        $runeMod = new Rune_optics();
        $taskModel = new Wf_project_task();
        $wMod = new Wf_task_work();
        $hwModel = new Huawei();
        $kirModel = new Kir();
        $user = auth()->user();
        session(['ids_export' => false]);

        if (in_array($user->role_id, config('app.sellers'))){
            if(env('SERVER_ID') != 3){
                $prodajaModel = new Klijenti_prodaja();
                $vraceno = $prodajaModel->vraceno($user->id);
                if ($vraceno)
                    session(['vraceno' => true]);
                return redirect()->route('klijentiProdaja.index');
            }
            else {
                return redirect()->route('fobos_rune.index');
            }
        }

        if (in_array($user->role_id, config('app.construction_workers'))){
            return redirect()->route('construction_sites.index');
        }

        if($user->role_id == 4){
            return redirect()->route('magacin.index');
        }

        if($user->role_id == 9){
            return redirect()->route('huawei.index');
        }


        if ($user->online_status != 1){
            User::where('id', '=', $user->id)->update(['online_status'=>1, 'last_login' => date('Y-m-d H:i:s')]);
        }

        if ($this->isAdmin()) {
            $odlozeni = $klijentModel->odlozeni(date('Y-m-d'));
            if($odlozeni)
                session(['odlozen'=>true]);
            $firma = $firmaModel->podaci_o_firmi();
            $fmodel = new Fobos();
            $expireList = $fmodel->expireList();
            if ($expireList)
                session(['expire_list' => $expireList]);
            else
                session(['expire_list' => false]);

            return view('home', [
                'firma' => $firma,
                'isAdmin' => $this->isAdmin(),
            ]);
        }
        else{
            $napModel = new Napomene();
            $klijenti = $klijentModel->zakazaniMonter(date('Y-m-d'), $user->id);
            $klijentiOptika = $klijentOptModel->zakazaniMonter(date('Y-m-d'), $user->id);
            $runeOptics = $runeMod->appointed(date('Y-m-d'), $user->id);
            $klijentiSupernova = $klijentSupModel->zakazaniMonter(date('Y-m-d'), $user->id);
            $klijentiBakar = $klijentBakModel->zakazaniMonter(date('Y-m-d'), $user->id);
            $constructionSites = $constructionModel->construction_monter($user->id);
            $tasks = $taskModel->dashboardTasks($user->id);
            $huaweiSites = $hwModel->dashboard($user->id);
            $kirSites = $kirModel->dashboard($user->id);
            $storageModel = new Worker_equipment();
            $teMod = new Wf_task_equipment();
            
            if($tasks->isEmpty()){
                $statuses = [];
                $workerEquipment = [];
            }
            else{
                $statuses = Wf_statuses::all();
                $workerEquipment = $storageModel->equipment_for_user($user->id);
            }
            $runeComMod = new Rune_comments();
            return view('home', [
                'isAdmin' => $this->isAdmin(),
                'klijenti' => $klijenti,
                'napModel' => $napModel,
                'runeComMod' => $runeComMod,
                'klijentiOptika' => $klijentiOptika,
                'runeOptics' => $runeOptics,
                'klijentiSupernova' => $klijentiSupernova,
                'klijentiBakar' => $klijentiBakar,
                'constructionSites' => $constructionSites,
                'tasks' => $tasks,
                'wMod' => $wMod,
                'statuses' => $statuses,
                'equipment' => $workerEquipment,
                'teMod' => $teMod,
                'huaweiSites' => $huaweiSites,
                'kirSites' => $kirSites
            ]);
        }

    }

    private function montSynthetics($montageDate, $start, $end){
        $opticsMod = new Rune_optics();
        $statuses = [5, 21, 31, 32];
        $montSynth = [];
        foreach($statuses as $status){
            $n = $opticsMod->countMontages($montageDate, 1, null, $start, $end, $status);
            $p = $opticsMod->countMontages($montageDate, 2, null, $start, $end, $status);
            $po = $opticsMod->countMontages($montageDate, 3, null, $start, $end, $status);
            switch($status){
                case 5 :
                    $nPrice = 280;
                    $pPrice = 238.9;
                    $poPrice = 238.9;
                    break;
                case 21 :
                    $nPrice = 0;
                    $pPrice = 0;
                    $poPrice = 0;
                    break;
                case 31 :
                    $nPrice = 168;
                    $pPrice = 143.34;
                    $poPrice = 143.34;
                    break;
                case 32 :
                    $nPrice = 112;
                    $pPrice = 95.56;
                    $poPrice = 95.56;
                    break;
            }
            $nTotal = $n*$nPrice;
            $pTotal = $p*$pPrice;
            $poTotal = $po*$poPrice;
            $montTotal = $nTotal + $pTotal + $poTotal;
    
            $montSynth[] = ['n' => $n, 'p' => $p, 'po' => $po, 'nTotal' => $nTotal, 'pTotal' => $pTotal, 'poTotal' => $poTotal, 'total' => $montTotal, 'nPrice' => $nPrice,
                        'pPrice'  => $pPrice, 'poPrice' => $poPrice, 'status' => Statusi::find($status)->status];
        }

        return $montSynth;
    }

    private function montAnalythics($montageDate,$start,$end){
        $roMod = new Rune_optics();
        $fitters = User::where('role_id', 3)->orderBy('ime', "ASC")->get();
        $result = [];
        foreach($fitters as $fitter){
            $clients = $roMod->clientsForUser($fitter->id, $montageDate, $start, $end);
            foreach($clients as $client){
                switch($client->status_id){
                    case 5 :
                        if($client->montage_type == 1)
                            $price = 280;
                        else
                            $price = 238.9;
                        break;
                    case 21 :
                        $price = 0;
                        break;
                    case 31 :
                        if($client->montage_type == 1)
                            $price = 168;
                        else
                            $price = 143.34;
                        break;
                    case 32 :
                        if($client->montage_type == 1)
                            $price = 112;
                        else
                            $price = 95.56;
                        break;
                    default :
                        $price = 0;
                        break;
                }
                $result[$fitter->ime.' '.$fitter->prezime][] = ['cluster' => $client->cluster, 'name' => $client->name.' '.$client->surname, 
                'montage_type' => $client->tip, 'price' => $price, 'status' => $client->status, 'status_id' => $client->status_id, 'pan' => $client->pan];
            }
        }
        return $result;
    }

    private function saleSynt($date,$start,$end){
        $sellers = User::all();
        $fMod = new Fobos_rune();
        $result = [];
        foreach($sellers as $seller){
            $data = $fMod->scoreboard($date, $start, $end, $seller->id, 1);
            if($data->count > 0)
                $result[] = $data;
        }
        return $result;
    }


    private function totalSale($date,$start,$end){
        $fMod = new Fobos_rune();
        return $fMod->scoreboardTotal($date, $start, $end);
    }
    

    private function saleAnalyth($date, $start, $end){
        $fMod = new Fobos_rune();
        $data = $fMod->scoreboardAnal($date, $start, $end, 1);
        return $data;
    }


    public function scoreboard(Request $request){
        $start = $request->input('start');
        $end = $request->input('end');
        $singleDate = database_date($request->input('single_date'));
        $deMod = new De_construction_sites();
        
        if ($start && $end){
            $from = date('Y-m-d', strtotime($start));
            $to = date('Y-m-d', strtotime($end));
            $singleDate = null;
        }
        else {
            $from = null;
            $to = null;
            if(!$singleDate)
                $singleDate = date('Y-m-d');
        }


        //montage                       
        $montSynth = $this->montSynthetics($singleDate, $from, $to);
        $montAnalyth = $this->montAnalythics($singleDate, $from, $to);

        //de sites
        $constructionSites = $deMod->scoreboardData($singleDate, $from, $to);
        $totalSites = $deMod->totalForSiteS($singleDate, $from, $to);
        $totalConfirmed = $deMod->totalForSiteS($singleDate, $from, $to, 1);
        $totalNotConfirmed = $deMod->totalForSiteS($singleDate, $from, $to, 0);

        //sale
        $saleSynt = $this->saleSynt($singleDate,$from,$to);
        $saleAnalyth = $this->saleAnalyth($singleDate,$from,$to);
        $totalSales = $this->totalSale($singleDate,$from,$to);


        $total = $totalSites + $totalSales;
        $totalMontage = 0;
        
        foreach($montSynth as $item){
            $totalMontage += $item['total'];
        }
        $total+=$totalMontage;
        
        $green = $totalSales + $totalConfirmed + $totalMontage;
        $orange = $totalNotConfirmed;

        return view('scoreboard.scoreboard', [
            'from' => date('01.m.Y.', strtotime($from)),
            'to' => date('t.m.Y.', strtotime($to)),
            'montSynth' => $montSynth,
            'montAnalyth' => $montAnalyth,
            'saleSynt' => $saleSynt,
            'saleAnalyth' => $saleAnalyth,
            'salePrice' => 30,
            'constructionSites' => $constructionSites,
            'deMod' => $deMod,
            'total' => $total,
            'green' => $green,
            'orange' => $orange
        ]);
    }
}
