<?php

namespace App\Http\Controllers;

use App\Models\Huawei_vertical_statuses;
use Illuminate\Http\Request;

class HwVerticalStatusController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $statuses = Huawei_vertical_statuses::all();
        return view('hwVerticalStatus.index', ['statuses' => $statuses]);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('hwVerticalStatus.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
       $request->validate([
        'status' => 'required'
       ]);
       $status = Huawei_vertical_statuses::create([
           'status' => trim($request->input('status')),
           'default' => 0
       ]);

       if ($status){
           return redirect()->route('hw_vertical_status.index')->with('success', __("Data successfully added"));
       }
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Models\Huawei_vertical_statuses  $huawei_vertical_status
     * @return \Illuminate\Http\Response
     */
    public function show(Huawei_vertical_statuses $hw_vertical_status)
    {
        return view('hwVerticalStatus.show', ['status' => $hw_vertical_status]);
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Models\Huawei_vertical_statuses  $hw_vertical_status
     * @return \Illuminate\Http\Response
     */
    public function edit(Huawei_vertical_statuses $hw_vertical_status)
    {
        $status = Huawei_vertical_statuses::find($hw_vertical_status->id);

        return view('hwVerticalStatus.edit', ['status' => $status]);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Models\Huawei_vertical_statuses  $hw_vertical_status
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Huawei_vertical_statuses $hw_vertical_status)
    {
        $request->validate([
            'status' => 'required'
        ]);
        $statusUpdate = Huawei_vertical_statuses::where('id', $hw_vertical_status->id)->update([
            'status'=>trim($request->input('status')),
            'default'=>0
        ]);

        if ($statusUpdate){
            return redirect()->route('hw_vertical_status.show', ['hw_vertical_status' => $hw_vertical_status->id])->with('success', __("Data successfully changed"));
        }
        return back()->withInput();
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function destroy(Request $request)
    {
        $findStatus = Huawei_vertical_statuses::find($request->input('id_status'));

        try{
            $findStatus->delete();
            return back()->withInput()->with('success', __("Data successfully deleted"));
        }
        catch (\Illuminate\Database\QueryException $e){
            return back()->withInput()->with('error', __("Data cannot be deleted"));
        }


        return back()->withInput()->with('error', __("Data cannot be deleted"));
    }
}
