<?php

namespace App\Http\Controllers;

use App\Models\Units;
use App\Models\Hw_vertical_works;
use Illuminate\Http\Request;

class HwVerticalWorksController extends Controller
{
    private function units(){
        return Units::all();
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $wcModel = new Hw_vertical_works();
        $works = $wcModel->h_works();
        return view('hwVerticalWorks.index', ['works' => $works]);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('hwVerticalWorks.create', ['units' => $this->units()]);
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $request->validate([
            'code' => 'required',
            'work' => 'required',
            'price' => 'nullable|numeric'
        ]);
        $workCreate = Hw_vertical_works::create([
            'code' => trim($request->input('code')),
            'work' => trim($request->input('work')),
            'unit_id' => $request->input('unit'),
            'price' => $request->input('price'),
            'fixed' => $request->input('fixed')
        ]);

        if ($workCreate){
            return redirect()->route('hw_vertical_work.index')->with('success', __("Data successfully added"));
        }
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Hw_vertical_works  $hw_vertical_work
     * @return \Illuminate\Http\Response
     */
    public function show(Hw_vertical_works $hw_vertical_work)
    {
        $wModel = new Hw_vertical_works();
        $work = $wModel->workData($hw_vertical_work->id);
        return view('hwVerticalWorks.show', ['work' => $work]);
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Hw_vertical_works  $hw_vertical_work
     * @return \Illuminate\Http\Response
     */
    public function edit(Hw_vertical_works $hw_vertical_work)
    {
        $wModel = new Hw_vertical_works();
        $work = $wModel->workData($hw_vertical_work->id);

        return view('hwVerticalWorks.edit', ['work' => $work, 'units' => $this->units()]);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Hw_vertical_works  $hw_vertical_work
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Hw_vertical_works $hw_vertical_work)
    {
        $request->validate([
            'code' => 'required',
            'work' => 'required',
            'price' => 'nullable|numeric'
        ]);
        $workUpdate = Hw_vertical_works::where('id', $hw_vertical_work->id)->update([
            'code' => trim($request->input('code')),
            'work' => trim($request->input('work')),
            'unit_id' => $request->input('unit'),
            'price' => $request->input('price'),
            'fixed' => $request->input('fixed')
        ]);

        if ($workUpdate){
            return redirect()->route('hw_vertical_work.show', ['hw_vertical_work' => $hw_vertical_work->id])->with('success', __("Data successfully changed"));
        }
        return back()->withInput();
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function destroy(Request $request)
    {
        $findWork = Hw_vertical_works::find($request->input('id_work'));

        try{
            $findWork->delete();
            return back()->withInput()->with('success', __("Data successfully deleted"));
        }
        catch (\Illuminate\Database\QueryException $e){
            return back()->withInput()->with('errors', __("Data cannot be deleted"));
        }


        return back()->withInput()->with('errors', __("Data cannot be deleted"));
    }
}
