<?php

namespace App\Http\Controllers;

use App\Models\Image_types;
use Illuminate\Http\Request;

class ImageTypeController extends Controller
{
    private function allTypes(){
        $imageTypes = Image_types::all();
        return $imageTypes;
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $imageTypes = $this->allTypes();
        return view('imageType.index', ['imageTypes' => $imageTypes]);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('imageType.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $request->validate([
            'image_type' => 'required'
        ]);
        $imageTypeCreate = Image_types::create([
            'type' => trim($request->input('image_type'))
        ]);

        $imageTypes = $this->allTypes();
        if ($imageTypeCreate){
            return view('imageType.index', ['imageTypes' => $imageTypes]);
        }
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Image_types  $image_type
     * @return \Illuminate\Http\Response
     */
    public function show(Image_types $image_type)
    {
        $imageType = Image_types::find($image_type->id);
        return view('imageType.show', ['imageType' => $imageType]);
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Image_types  $image_type
     * @return \Illuminate\Http\Response
     */
    public function edit(Image_types $image_type)
    {
        $imageType = Image_types::find($image_type->id);

        return view('imageType.edit', ['imageType' => $image_type]);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Image_types  $image_type
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Image_types $image_type)
    {
        $request->validate([
            'image_type' => 'required'
        ]);
        $typeUpdate = Image_types::where('id', $image_type->id)->update([
            'type'=>trim($request->input('image_type'))
        ]);

        if ($typeUpdate){
            return redirect()->route('image_type.show', ['imageType' => $image_type->id])->with('success', __("Data successfully changed"));
        }
        return back()->withInput();
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function destroy(Request $request)
    {
        $findType = Image_types::find($request->input('image_type'));

        try{
            $findType->delete();
            return back()->withInput()->with('success', __("Data successfully deleted"));
        }
        catch (\Illuminate\Database\QueryException $e){
            return back()->withInput()->with('errors', __("Data cannot be deleted"));
        }


        return back()->withInput()->with('errors', __("Data cannot be deleted"));
    }
}
