<?php

namespace App\Http\Controllers;

use App\Models\Kir_access_works;
use App\Models\Kir_work_categories;
use App\Models\Units;
use Illuminate\Http\Request;

class KirAccessWorksController extends Controller
{
    private function categories(){
        return Kir_work_categories::all();
    }

    private function units(){
        return Units::all();
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $wcModel = new Kir_access_works();
        $works = $wcModel->h_works();
        return view('kirAccessWorks.index', ['works' => $works]);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('kirAccessWorks.create', ['categories' => $this->categories(), 'units' => $this->units()]);
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $request->validate([
            'code' => 'required',
            'work' => 'required',
            'category' => 'required',
            'price' => 'nullable|numeric'
        ]);
        $workCreate = Kir_access_works::create([
            'code' => trim($request->input('code')),
            'work' => trim($request->input('work')),
            'category_id' => $request->input('category'),
            'unit_id' => $request->input('unit'),
            'fixed' => $request->input('fixed'),
            'price' => $request->input('price')
        ]);

        if ($workCreate){
            return redirect()->route('kir_access_work.index')->with('success', __("Data successfully added"));
        }
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Models\Kir_access_works  $kir_access_work
     * @return \Illuminate\Http\Response
     */
    public function show(Kir_access_works $kir_access_work)
    {
        $wModel = new Kir_access_works();
        $work = $wModel->workData($kir_access_work->id);
        return view('kirAccessWorks.show', ['work' => $work]);
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Kir_access_works  $kir_access_work
     * @return \Illuminate\Http\Response
     */
    public function edit(Kir_access_works $kir_access_work)
    {
        $wModel = new Kir_access_works();
        $work = $wModel->workData($kir_access_work->id);
        $units = Units::all();

        return view('kirAccessWorks.edit', ['work' => $work, 'categories' => $this->categories(), 'units' => $units]);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Kir_access_works  $kir_access_work
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Kir_access_works $kir_access_work)
    {
        $request->validate([
            'code' => 'required',
            'work' => 'required',
            'category' => 'required',
            'price' => 'nullable|numeric'
        ]);
        $workUpdate = Kir_access_works::where('id', $kir_access_work->id)->update([
            'code' => trim($request->input('code')),
            'work' => trim($request->input('work')),
            'category_id' => $request->input('category'),
            'unit_id' => $request->input('unit'),
            'fixed' => $request->input('fixed'),
            'price' => $request->input('price')
        ]);

        if ($workUpdate){
            return redirect()->route('kir_access_work.show', ['kir_access_work' => $kir_access_work->id])->with('success', __("Data successfully changed"));
        }
        return back()->withInput();
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function destroy(Request $request)
    {
        $findWork = Kir_access_works::find($request->input('id_work'));

        try{
            $findWork->delete();
            return back()->withInput()->with('success', __("Work successfully deleted"));
        }
        catch (\Illuminate\Database\QueryException $e){
            return back()->withInput()->with('errors', __("Data cannot be deleted"));
        }


        return back()->withInput()->with('errors', __("Data cannot be deleted"));
    }
}
