<?php

namespace App\Http\Controllers;

use App\Models\Companies;
use App\Models\Equipment;
use App\Models\Folders;
use App\Models\Kir_access_works;
use App\Models\Kir_required_equipment;
use App\Models\Kir_vertical_works;
use App\Models\Hw_documentation;
use App\Models\Hw_final_statuses;
use App\Models\Storage_equipment;
use App\Models\Worker_equipment;
use App\Change_history;
use App\Models\Areas;
use App\Models\Cities;
use App\Models\Clusters;
use App\Models\Equipment_categories;
use App\Models\Files;
use App\Models\Huawei_access_statuses;
use App\Models\Construction_comments;
use App\Models\Huawei_vertical_statuses;
use App\Models\Construction_images;
use App\Models\Doc_works;
use App\Models\Hw_vertical_works;
use App\Models\Site_equipment;
use App\Models\Site_work;
use App\Models\Work_categories;
use App\Models\Image_types;
use App\States;
use App\Traits\Util;
use App\Models\Kir;
use App\Models\Kir_work_categories;
use App\Oprema;
use Illuminate\Http\Request;
use Intervention\Image\ImageManager as Img;
use Illuminate\Support\Arr;

class KirController extends Controller
{

    protected function check_quantity($quantity){
        if(is_numeric($quantity))
        {
            if($quantity < 0)
                return 0;
            else
                return $quantity;
        }
        else
        {
            return 0;
        }
    }

    public function index()
    {
        $isConstructionManager =Util::isConstructionManager();
        $isAdmin = Util::isAdmin();
        $isSuperAdmin = Util::isSuperAdmin();
        $isHuaweiAdmin = Util::isHuaweiAdmin();
        $isProjectManager = Util::isProjectManager();
        $isProjectAdmin = Util::isProjectAdmin();
        $kirModel = new Kir();
        if ($isSuperAdmin || $isAdmin)
            $constructionSites = $kirModel->index();
        elseif ($isHuaweiAdmin)
            $constructionSites = $kirModel->index(null, null, null, null, Util::userPlace());
        elseif ($isConstructionManager)
            $constructionSites = $kirModel->index(null, Util::userId());
        elseif($isProjectManager)
            $constructionSites = $kirModel->index(null, null, Util::userId());
        elseif($isProjectAdmin)
            $constructionSites = $kirModel->index(null, null, null, true);
        else
            $constructionSites = $kirModel->index(Util::userId());

        session(['search_route' => false]);

        return view('kir.index', [
            'constructionSites' => $constructionSites,
            'search'=>false,
            'isSuperAdmin'=>$isSuperAdmin,
            'isHuaweiAdmin' => $isHuaweiAdmin
        ]);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $states = States::all();
        $cities = Cities::all();
        $areas = Areas::all();
        $statusesAccess = Huawei_access_statuses::all();
        $statusesVertical = Huawei_vertical_statuses::all();
        $builders = Util::builders();
        $monters = Util::monteri();
        $workers = $builders->merge($monters);
        $admins = Util::admini();
        $projectManagers = Util::projectManagers();
        $constructionManagers = Util::constructionManagers();
        $constructionManagers = $constructionManagers->merge($admins);
        $clusters = Clusters::all();
        return view('kir.create', [
            'states' => $states,
            'cities' => $cities,
            'areas' => $areas,
            'statusesAccess' => $statusesAccess,
            'statusesVertical' => $statusesVertical,
            'workers' => $workers,
            'projectManagers' => $projectManagers,
            'constructionManagers' => $constructionManagers,
            'clusters' => $clusters
        ]);
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $name = $request->input('name');
        $seller = $request->input('seller');
        $contactSeller = $request->input('contact_seller');
        $tel1 = $request->input('tel1');
        $tel2 = $request->input('tel2');
        $tel3 = $request->input('tel3');
        $manager = $request->input('manager');
        $mTel1 = $request->input('m_tel1');
        $mTel2 = $request->input('m_tel2');
        $mTel3 = $request->input('m_tel3');
        $state = $request->input('state');
        $city = $request->input('city');
        $municipality = $request->input('municipality');
        $address = $request->input('address');
        $numberOfFloors = $request->input('number_of_floors');
        $numberOfFlats = $request->input('number_of_flats');
        $area = $request->input('area');
        $statusAccess = $request->input('status_access');
        $statusVertical = $request->input('status_vertical');
        $statusSplicing = $request->input('status_splicing');
        $projectManager = $request->input("project_manager");
        $workerAccess = $request->input('worker_access');
        $workerVertical = $request->input('worker_vertical');
        $workerSplicing = $request->input('worker_splicing');
        $comment = $request->input('comment');
        $appointmentDateAccess = $request->input('appointment_date_access');
        $appointmentDateVertical = $request->input('appointment_date_vertical');
        $appointmentDateSplicing = $request->input('appointment_date_splicing');
        $appointmentTimeAccess = $request->input('appointment_time_access');
        $appointmentTimeVertical = $request->input('appointment_time_vertical');
        $appointmentTimeSplicing = $request->input('appointment_time_splicing');
        $delayDate = database_date($request->input('delay_date'));
        $delayTime = $request->input('delay_time');
        $realizationDateAccess = database_date($request->input('realization_date_access'));
        $realizationDateVertical = database_date($request->input('realization_date_vertical'));
        $withdrawalDate = database_date($request->input('withdrawal_date'));
        $cluster = $request->input('cluster');
        $odo = $request->input('odo');
        $izvod = $request->input('izvod');
        $connector = $request->input('connector');
        $technicalSolutionDate = database_date($request->input('technical_solution_date'));
        $atcMsanOlt = $request->input('atc_msan_olt');
        $odfModul = $request->input('odf_modul');
        $connectorNumber = $request->input('connector_number');
        $connectionPoint = $request->input('connection_point');
        $fiber = $request->input('fiber');
        $numerationOdo = $request->input('numeration_odo');
        $createdBy = Util::userId();
        $price = $request->input('price');
        $tisEntryDate = database_date($request->input('tis_entry_date'));

        if(Util::isProjectManager())
            $projectManager = Util::userId();
        if(Util::isConstructionManager())
            $projectManager = Util::userId();

        if(Util::isConstructionManager())
            $constructionManager = Util::userId();
        else
            $constructionManager = $request->input('construction_manager');

        $appointmentDateAccess = database_date_time($appointmentDateAccess, $appointmentTimeAccess);
        $appointmentDateVertical = database_date_time($appointmentDateVertical, $appointmentTimeVertical);
        $appointmentDateSplicing = database_date_time($appointmentDateSplicing, $appointmentTimeSplicing);
        $delayDate = database_date_time($delayDate, $delayTime);

        $request->validate([
            'name' => 'required',
            'address' => 'required',
            'state' => 'required',
            'city' => 'required',
            'area' => 'required'
        ]);

        $create = Kir::create([
            'name' => $name,
            'seller' => $seller,
            'contact_seller' => $contactSeller,
            'tel1' => $tel1,
            'tel2' => $tel2,
            'tel3' => $tel3,
            'manager' => $manager,
            'm_tel1' => $mTel1,
            'm_tel2' => $mTel2,
            'm_tel3' => $mTel3,
            'id_state' => $state,
            'id_city' => $city,
            'municipality' => $municipality,
            'id_area' => $area,
            'address' => $address,
            'number_of_floors' => $numberOfFloors,
            'number_of_flats' => $numberOfFlats,
            'id_status_vertical' => $statusVertical,
            'id_status_access' => $statusAccess,
            'id_status_splicing' => $statusSplicing,
            'project_manager' => $projectManager,
            'construction_manager' => $constructionManager,
            'id_user_vertical' => $workerVertical,
            'id_user_access' => $workerAccess,
            'id_user_splicing' => $workerSplicing,
            'appointment_date_vertical' => $appointmentDateVertical,
            'appointment_date_access' => $appointmentDateAccess,
            'appointment_date_splicing' => $appointmentDateSplicing,
            'delay_date' => $delayDate,
            'realization_date_vertical' => $realizationDateVertical,
            'realization_date_access' => $realizationDateAccess,
            'withdrawal_date' => $withdrawalDate,
            'cluster' => $cluster,
            'odo' => $odo,
            'izvod' => $izvod,
            'connector' => $connector,
            'technical_solution_date' => $technicalSolutionDate,
            'atc_msan_olt' => $atcMsanOlt,
            'odf_modul' => $odfModul,
            'connector_number' => $connectorNumber,
            'connection_point' => $connectionPoint,
            'fiber' => $fiber,
            'numeration_odo' => $numerationOdo,
            'created_by' => $createdBy,
            'price' => $price?$price:0,
            'tis_entry_date' => $tisEntryDate
        ]);

        if($create && $comment){
            Construction_comments::create([
                'comment' => $comment,
                'id_construction_site' => $create->id,
                'id_user' => $createdBy
            ]);
        }

        if($create)
            return redirect()->route('kir.show', ['kir' => $create->id]);
        else
            return back()->with('error', __("Data successfully added"));
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Huawei  $huawei
     * @return \Illuminate\Http\Response
     */
    public function show(Kir $kir)
    {
        $kMod = new Kir();
        $site = $kMod->kir_data($kir->id);
        $comMod = new Construction_comments();
        $comments = $comMod->comments($kir->id);
        $imgModel = new Construction_images();
        $images = $imgModel->images($kir->id);
        $equipmentModal = new Site_equipment();
        $workModal = new Site_work();
        $equipment = $equipmentModal->equipment($kir->id);
        $works = $workModal->accessWorks($kir->id);
        $verticalWorks = $workModal->verticalWorks($kir->id);
        $docWorks = $workModal->docWorks($kir->id);
        $allowedUsers = [$kir->id_user_access, $kir->id_user_vertical, $kir->id_user_splicing, $kir->construction_manager, $kir->project_manager];

        $totalAccess = 0;
        $totalVertical = 0;
        $totalDoc = 0;

        $accessWorks = $workModal->accessWorks($kir->id);
        foreach($accessWorks as $work){
            $totalAccess += $workModal->accessWorkQuantity($kir->id, $work->id)*$work->price;
        }
        $verticalWorks = $workModal->verticalWorks($kir->id);
        foreach($verticalWorks as $work){
            $totalVertical += $workModal->verticalWorkQuantity($kir->id, $work->id)*$work->price;
        }
        $docWorks = $workModal->docWorks($kir->id);
        foreach($docWorks as $work){
            $totalDoc += $workModal->docWorkQuantity($kir->id, $work->id)*$work->price;
        }

        $isHuaweiAdmin = Util::isHuaweiAdmin();
        $isSuperAdmin = Util::isSuperAdmin();
        $projectAdmin = Util::isProjectAdmin();
        $isAdmin = Util::isAdmin();
        if (!in_array(Util::userId(), $allowedUsers) && !$isHuaweiAdmin && !$isSuperAdmin && !$projectAdmin && !$isAdmin)
        {
            return view('missing_page');
        }
        if($isHuaweiAdmin && Util::userPlace() && Util::userPlace() != $kir->id_area){
            return view('missing_page');
        }

        $chModel = new Change_history();
        $history = $chModel->historyConstruction($kir->id);

        $files = Files::where('id_construction_site', $kir->id)->get();

        $reModel = new Kir_required_equipment();
        $requiredEquipment = $reModel->required_equipment($kir->id);

        session(['accessWorks' => json_encode($works), 'verticalWorks' => json_encode($verticalWorks)]);

        return view('kir.show', [
            'site' => $site,
            'comments' => $comments,
            'images' => $images,
            'equipment' => $equipment,
            'works' => $works,
            'history' => $history,
            'files' => $files,
            'verticalWorks' => $verticalWorks,
            'docWorks' => $docWorks,
            'requiredEquipment' => $requiredEquipment,
            'isHuaweiAdmin' => $isHuaweiAdmin,
            'isSuperAdmin' => $isSuperAdmin,
            'totalAccess' => $totalAccess,
            'totalVertical' => $totalVertical,
            'totalDoc' => $totalDoc
        ]);
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Huawei  $huawei
     * @return \Illuminate\Http\Response
     */
    public function edit(Kir $kir)
    {
        $states = States::all();
        $cities = Cities::all();
        $areas = Areas::all();
        $statusesAccess = Huawei_access_statuses::all();
        $statusesVertical = Huawei_vertical_statuses::all();
        $finalStatuses = Hw_final_statuses::all();
        $builders = Util::builders();
        $fitters = Util::monteri();
        $workers = $builders->merge($fitters);
        $workers = $workers->merge(Util::columnLeaders());
        $imageTypes = Image_types::all();
        $equipmentCategories = Equipment_categories::all();
        $workCategories = Kir_work_categories::all();
        $comModel = new Construction_comments();
        $comments = $comModel->comments($kir->id);
        $comModel = new Construction_images();
        $images = $comModel->images($kir->id);
        $files = Files::where('id_construction_site', $kir->id)->get();
        $equipmentModal = new Site_equipment();
        $workModal = new Site_work();
        $equipment = $equipmentModal->equipment($kir->id);
        $accessWorks = $workModal->accessWorks($kir->id);
        $admins = Util::admini();
        $projectManagers = Util::projectManagers();
        $constructionManagers = Util::constructionManagers();
        $constructionManagers = $constructionManagers->merge($admins);
        $vModel = new Hw_vertical_works();
        $workIds = $vModel->workIds();
        $workIds = Arr::pluck($workIds, 'id');
        $verticalWorks = array();
        $clusters = Clusters::all();
        foreach($workIds as $key=>$id){
            $work = $vModel->workData($id);
            $quantity = $workModal->workQuantity($kir->id, $id);
            $verticalWorks[$key]['id'] = $id;
            $verticalWorks[$key]['code'] = $work->code;
            $verticalWorks[$key]['work'] = $work->work;
            $verticalWorks[$key]['unit'] = $work->unit_short;
            $verticalWorks[$key]['quantity'] = $quantity;
        }

        $aMod = new Kir_access_works();
        $accessIds = $aMod->workIds();
        $accessIds = Arr::pluck($accessIds, 'id');
        $accessWorksFixed = array();
        foreach($accessIds as $key=>$id){
            $work = $aMod->workData($id);
            $quantity = $workModal->accessWorkQuantity($kir->id, $id);
            $accessWorksFixed[$key]['id'] = $id;
            $accessWorksFixed[$key]['code'] = $work->code;
            $accessWorksFixed[$key]['work'] = $work->work;
            $accessWorksFixed[$key]['unit'] = $work->unit_short;
            $accessWorksFixed[$key]['quantity'] = $quantity;
        }

        $docMod = new Doc_works();
        $docIds = $docMod->workIds();
        $docIds = Arr::pluck($docIds, 'id');
        $docWorksFixed = array();
        foreach($docIds as $key=>$id){
            $work = $docMod->workData($id);
            $quantity = $workModal->docWorkQuantity($kir->id, $id);
            $docWorksFixed[$key]['id'] = $id;
            $docWorksFixed[$key]['code'] = $work->code;
            $docWorksFixed[$key]['work'] = $work->work;
            $docWorksFixed[$key]['unit'] = $work->unit_short;
            $docWorksFixed[$key]['quantity'] = $quantity;
        }

        $allowedUsers = [$kir->id_user_access, $kir->id_user_vertical, $kir->id_user_splicing, $kir->construction_manager, $kir->project_manager];

        $isSuperAdmin = Util::isSuperAdmin();
        $isHuaweiAdmin = Util::isHuaweiAdmin();
        $isProjectAdmin = Util::isProjectAdmin();
        $isAdmin = Util::isAdmin();
        if (!in_array(Util::userId(), $allowedUsers) && !$isHuaweiAdmin && !$isSuperAdmin && !$isProjectAdmin && !$isAdmin)
        {
            return view('missing_page');
        }
        if($isHuaweiAdmin && Util::userPlace() && Util::userPlace() != $kir->id_area){
            return view('missing_page');
        }

        if(Util::isAdmin()){
            $workerEquipment = Oprema::all();
        }
        else {
            $storageModel = new Worker_equipment();
            $workerEquipment = $storageModel->kir_equipment(Util::userId());
        }

        $reModel = new Kir_required_equipment();
        $requiredEquipment = $reModel->required_equipment($kir->id);

        return view('kir.edit', [
            'states' => $states,
            'cities' => $cities,
            'areas' => $areas,
            'statusesAccess' => $statusesAccess,
            'statusesVertical' => $statusesVertical,
            'finalStatuses' => $finalStatuses,
            'workers' => $workers,
            'site' => $kir,
            'isSuperAdmin' => Util::isSuperAdmin(),
            'isAdmin' => Util::isAdmin(),
            'imageTypes' => $imageTypes,
            'workCategories' => $workCategories,
            'comments' => $comments,
            'images' => $images,
            'files' => $files,
            'equipment' => $equipment,
            'accessWorks' => $accessWorks,
            'verticalWorks' => $verticalWorks,
            'workerEquipment' => $workerEquipment,
            'isHuaweiAdmin' => $isHuaweiAdmin,
            'requiredEquipment' => $requiredEquipment,
            'projectManagers' => $projectManagers,
            'constructionManagers' => $constructionManagers,
            'isConstructionManager' => Util::isConstructionManager(),
            'isProjectManager' => Util::isProjectManager(),
            'isFitter' => Util::isMonter(),
            'isConstructionWorker' => Util::isConstructionWorker(),
            'isProjectAdmin' => $isProjectAdmin,
            'accessWorksFixed' => $accessWorksFixed,
            'docWorksFixed' => $docWorksFixed,
            'clusters' => $clusters
        ]);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Huawei  $huawei
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Kir $kir)
    {
        $name = $request->input('name');
        $seller = $request->input('seller');
        $contactSeller = $request->input('contact_seller');
        $tel1 = $request->input('tel1');
        $tel2 = $request->input('tel2');
        $tel3 = $request->input('tel3');
        $manager = $request->input('manager');
        $mTel1 = $request->input('m_tel1');
        $mTel2 = $request->input('m_tel2');
        $mTel3 = $request->input('m_tel3');
        $state = $request->input('state');
        $city = $request->input('city');
        $municipality = $request->input('municipality');
        $address = $request->input('address');
        $numberOfFloors = $request->input('number_of_floors');
        $numberOfFlats = $request->input('number_of_flats');
        $area = $request->input('area');
        $statusAccess = $request->input('status_access');
        $statusVertical = $request->input('status_vertical');
        $statusSplicing = $request->input('status_splicing');
        $finalStatus = $request->input('final_status');
        $projectManager = $request->input("project_manager");
        $constructionManager = $request->input('construction_manager');
        $workerAccess = $request->input('worker_access');
        $workerVertical = $request->input('worker_vertical');
        $workerSplicing = $request->input('worker_splicing');
        $comment = $request->input('comment');
        $appointmentDateAccess = $request->input('appointment_date_access');
        $appointmentDateVertical = $request->input('appointment_date_vertical');
        $appointmentDateSplicing = $request->input('appointment_date_splicing');
        $appointmentTimeAccess = $request->input('appointment_time_access');
        $appointmentTimeVertical = $request->input('appointment_time_vertical');
        $appointmentTimeSplicing = $request->input('appointment_time_splicing');
        $delayDate = database_date($request->input('delay_date'));
        $delayTime = $request->input('delay_time');
        $realizationDateAccess = database_date($request->input('realization_date_access'));
        $realizationDateVertical = database_date($request->input('realization_date_vertical'));
        $withdrawalDate = database_date($request->input('withdrawal_date'));
        $cluster = $request->input('cluster');
        $odo = $request->input('odo');
        $izvod = $request->input('izvod');
        $connector = $request->input('connector');
        $technicalSolutionDate = database_date($request->input('technical_solution_date'));
        $atcMsanOlt = $request->input('atc_msan_olt');
        $odfModul = $request->input('odf_modul');
        $connectorNumber = $request->input('connector_number');
        $connectionPoint = $request->input('connection_point');
        $fiber = $request->input('fiber');
        $numerationOdo = $request->input('numeration_odo');
        $disStartDate = database_date($request->input('dis_start_date'));
        $disEndDate = database_date($request->input('dis_end_date'));
        $price = $request->input('price');
        $tisEntryDate = database_date($request->input('tis_entry_date'));
        $setDis = $request->input('set_dis');

        $sentBoQ = $request->input('sent_boq');
        $approvedBoQ = $request->input('approved_boq');
        $boqSendDate = database_date($request->input('boq_send_date'));
        $boqApproveDate = database_date($request->input('boq_approve_date'));
        $correctionDateStart = database_date($request->input('correction_date_start'));
        $correctionDateEnd = database_date($request->input('correction_date_end'));
        $realizationDateSplicing = database_date($request->input('realization_date_splicing'));

        if($finalStatus == 1 && !$kir->dis_start_date){
            $disStartDate = date('Y-m-d');
        }
        if(in_array($finalStatus, [2,7,8]) && !$kir->dis_end_date){
            $disEndDate = date('Y-m-d');
        }

        $appointmentDateAccess = database_date_time($appointmentDateAccess, $appointmentTimeAccess);
        $appointmentDateVertical = database_date_time($appointmentDateVertical, $appointmentTimeVertical);
        $appointmentDateSplicing = database_date_time($appointmentDateSplicing, $appointmentTimeSplicing);
        $delayDate = database_date_time($delayDate, $delayTime);

        $files = $request->file('files');
        if($files){
            $request->validate([
                'files.*' => 'mimes:xlsx,xls,pdf,dwg,zip,sor,doc,docx'
            ]);
            $num = 0;
            foreach($files as $file){
                $originalFile = $file->getClientOriginalName();
                $filename = pathinfo($originalFile, PATHINFO_FILENAME);
                $extension = pathinfo($originalFile, PATHINFO_EXTENSION);
                $filename = $filename.'-'.time().'-'.$num.'.'.$extension;
                $folder = 'uploads/documents/'.quartal();
                create_folder($folder);
                $file->move($folder, $filename);
                Files::create([
                    'file_url' => '/'.$folder.'/'.$filename,
                    'id_construction_site' => $kir->id,
                    'filename' => $originalFile
                ]);
                $num++;
             }
        }

        if(Util::isAdmin() || Util::isHuaweiAdmin() || Util::isConstructionManager()){
            $request->validate([
                'name' => 'required',
                'address' => 'required',
                'state' => 'required',
                'city' => 'required',
                'area' => 'required',
                'sent_boq' => 'nullable|numeric',
                'approved_boq' => 'nullable|numeric',
                'price' => 'nullable|numeric'
            ]);
            $update = Kir::where('id', $kir->id)->update([
                'name' => $name,
                'seller' => $seller,
                'contact_seller' => $contactSeller,
                'tel1' => $tel1,
                'tel2' => $tel2,
                'tel3' => $tel3,
                'manager' => $manager,
                'm_tel1' => $mTel1,
                'm_tel2' => $mTel2,
                'm_tel3' => $mTel3,
                'id_state' => $state,
                'id_city' => $city,
                'municipality' => $municipality,
                'id_area' => $area,
                'address' => $address,
                'number_of_floors' => $numberOfFloors,
                'number_of_flats' => $numberOfFlats,
                'id_status_vertical' => $statusVertical,
                'id_status_access' => $statusAccess,
                'id_status_splicing' => $statusSplicing,
                'id_status_final' => $finalStatus,
                'project_manager' => $projectManager,
                'construction_manager' => $constructionManager,
                'id_user_vertical' => $workerVertical,
                'id_user_access' => $workerAccess,
                'id_user_splicing' => $workerSplicing,
                'appointment_date_vertical' => $appointmentDateVertical,
                'appointment_date_access' => $appointmentDateAccess,
                'appointment_date_splicing' => $appointmentDateSplicing,
                'delay_date' => $delayDate,
                'realization_date_vertical' => $realizationDateVertical,
                'realization_date_access' => $realizationDateAccess,
                'realization_date_splicing' => $realizationDateSplicing,
                'withdrawal_date' => $withdrawalDate,
                'cluster' => $cluster,
                'odo' => $odo,
                'izvod' => $izvod,
                'connector' => $connector,
                'technical_solution_date' => $technicalSolutionDate,
                'atc_msan_olt' => $atcMsanOlt,
                'odf_modul' => $odfModul,
                'connector_number' => $connectorNumber,
                'connection_point' => $connectionPoint,
                'fiber' => $fiber,
                'numeration_odo' => $numerationOdo,
                'dis_start_date' => $disStartDate,
                'dis_end_date' => $disEndDate,
                'sent_boq' => $sentBoQ,
                'approved_boq' => $approvedBoQ,
                'boq_send_date' => $boqSendDate,
                'boq_approve_date' => $boqApproveDate,
                'correction_date_start' => $correctionDateStart,
                'correction_date_end' => $correctionDateEnd,
                'tis_entry_date' => $tisEntryDate,
                'set_dis' => $setDis
            ]);
            if(Util::isSuperAdmin() && $update && $price){
                Kir::where('id', $kir->id)->update([
                    'price' => $price
                ]);
            }
        }
        else {
            $update = null;
            if(Util::userId() == $kir->id_user_access) {
                Kir::where('id', $kir->id)->update([
                    'id_status_access' => $statusAccess
                ]);
                $update = true;
                if($statusAccess == 6){
                    Kir::where('id', $kir->id)->update([
                        'realization_date_access' => date('Y-m-d')
                    ]);
                }
            }
            if(Util::userId() == $kir->id_user_vertical) {
                Kir::where('id', $kir->id)->update([
                    'id_status_vertical' => $statusVertical
                ]);
                $update = true;
                if($statusVertical == 6){
                    Kir::where('id', $kir->id)->update([
                        'realization_date_vertical' => date('Y-m-d')
                    ]);
                }
            }
            if(Util::userId() == $kir->id_user_splicing) {
                Kir::where('id', $kir->id)->update([
                    'id_status_splicing' => $statusSplicing
                ]);
                $update = true;
                if($statusSplicing == 6){
                    Kir::where('id', $kir->id)->update([
                        'realization_date_splicing' => date('Y-m-d')
                    ]);
                }
            }
            if(Util::isProjectManager()){
                Kir::where('id', $kir->id)->update([
                    'id_status_access' => $statusAccess,
                    'id_status_vertical' => $statusVertical,
                    'id_status_splicing' => $statusSplicing,
                    'id_status_final' => $finalStatus,
                    'cluster' => $cluster,
                    'odo' => $odo,
                    'izvod' => $izvod,
                    'connector' => $connector,
                    'technical_solution_date' => $technicalSolutionDate,
                    'atc_msan_olt' => $atcMsanOlt,
                    'odf_modul' => $odfModul,
                    'connector_number' => $connectorNumber,
                    'connection_point' => $connectionPoint,
                    'fiber' => $fiber,
                    'numeration_odo' => $numerationOdo,
                    'dis_start_date' => $disStartDate,
                    'dis_end_date' => $disEndDate,
                    'set_dis' => $setDis
                ]);
                $update = true;
            }
            if(Util::isProjectAdmin()) {
                Kir::where('id', $kir->id)->update([
                    'id_status_access' => $statusAccess,
                    'id_status_vertical' => $statusVertical,
                    'id_status_splicing' => $statusSplicing,
                    'id_status_final' => $finalStatus,
                    'project_manager' => $projectManager,
                    'cluster' => $cluster,
                    'odo' => $odo,
                    'izvod' => $izvod,
                    'connector' => $connector,
                    'technical_solution_date' => $technicalSolutionDate,
                    'atc_msan_olt' => $atcMsanOlt,
                    'odf_modul' => $odfModul,
                    'connector_number' => $connectorNumber,
                    'connection_point' => $connectionPoint,
                    'fiber' => $fiber,
                    'numeration_odo' => $numerationOdo,
                    'dis_start_date' => $disStartDate,
                    'dis_end_date' => $disEndDate,
                    'set_dis' => $setDis
                ]);
                $update = true;
            }
        }
        if($update){
            Change_history::create([
                'id_user' => Util::userId(),
                'id_construction_site' => $kir->id
            ]);
            if ($request->input('comment')) {
                Construction_comments::create([
                    'comment' => $comment,
                    'id_construction_site' => $kir->id,
                    'id_user' => Util::userId()
                ]);
            }

            $imageType = $request->input("image_type");
            $pictures = $request->file('pictures');
            $img = new Img();
            $folder = 'uploads/construction_images/'.quartal();
            if (!file_exists($folder)){
                mkdir($folder, 0755, true);
            }

            if($pictures){
                $this->validate($request, [
                    'pictures.*' => 'image|mimes:jpeg,png,jpg,gif',
                    'image_type' => 'required'
                ]);
                $num = 0;
                foreach($pictures as $file){
                    $extension = $file->getClientOriginalExtension();
                    $filename = time().'-'.$num.'-kir'.'.'.$extension;
                    $num++;
                    $fileInt = $img->make($file->getRealPath());
                    $fileInt->save($folder.'/'.$filename, 50);
                    $description = Image_types::find($imageType);
                    Construction_images::create([
                        'url' => '/'.$folder.'/'.$filename,
                        'id_construction_site' => $kir->id,
                        'image_type' => $imageType,
                        'description' => $description->type
                    ]);
                }
            }
            return redirect()->route('kir.show', ['kir' => $kir->id])->with('success', __("Data successfully changed"));
        }
        //project manager can only change file
        if(Util::isProjectManager()){
            return redirect()->route('kir.show', ['kir' => $kir->id])->with('success', __("File successfully added"));
        }
        else{
            return back()->with('error', __("Error"));
        }
    }

    /**
     * @param Request $request
     * @return $this
     */
    public function destroy(Request $request)
    {
        $findSite = Kir::find($request->input('id_site'));

        try{
            $images = Construction_images::where('id_site', $request->input('id_site'))->get();
            $files = Files::where('id_construction_site', $request->input('id_site'))->get();
            if($findSite->delete()){
                foreach ($images as $img){
                    $file = ltrim($img->url,'/');
                    if (file_exists($file)){
                        unlink($file);
                    }
                }
                foreach ($files as $fl){
                    $file = ltrim($fl->file_url,'/');
                    if (file_exists($file)){
                        unlink($file);
                    }
                }
            }
            return back()->withInput()->with('success', __("Data successfully deleted"));
        }
        catch (\Illuminate\Database\QueryException $e){
            return back()->withInput()->with('error', __("Item can't be deleted because it's in use"));
        }


        return back()->withInput()->with('error', __("Data cannot be deleted"));
    }

    public function delete_comment(Request $request){
        $findComment = Construction_comments::find($request->input('id_comment'));
        if($findComment->delete()){
            return back()->with('success', __("Comment successfully deleted"));
        }
        else {
            return back()->with('errors', __("Error"));
        }
    }

    public function delete_image(Request $request){
        $findImage = Construction_images::find($request->input('id_image'));
        $file = ltrim($findImage->url,'/');

        if(file_exists($file)){
            unlink($file);
        }

        if($findImage->delete()){
            return back()->with('success', __("Image successfully deleted"));
        }
        else {
            return back()->with('errors', __("Error"));
        }
    }

    public function add_kir_work(Request $request){

        $quantity = $request->get('quantity');
        $quantity = $this->check_quantity($quantity);
        $param = $request->get('param');
        $idSite = $request->get('id_site');
        $idWork = $request->get('idWork');

        //ajax refreshing page (access works)
        if($param == 'access' && $idWork){
            if($quantity > 0){
                $specWork = Kir_access_works::where('id', $idWork)->first();
                $price = $specWork->price;
                //update price on site
                if($price > 0){
                    $hMod = new Kir();
                    $hMod->updatePrice($price*$quantity, $idSite);
                }
                Site_work::create([
                    'id_construction_site' => $idSite,
                    'access_work_id' => $idWork,
                    'quantity' => $quantity,
                    'price' => $price
                ]);
            }
        }
        else {
            //this is not ajax (vertical works)
            $siteId = $request->get('site_id');
            $workId = $request->get('vertical_work_id');
            $operation = $request->get('operation');
            if($operation == 'minus')
                $quantity = -$quantity;
            if($workId) {
                $specWork = Kir_vertical_works::where('id', $workId)->first();
                $price = $specWork->price;
                //update price on site
                if($price > 0){
                    $hMod = new Kir();
                    $hMod->updatePrice($price*$quantity, $siteId);
                }
                Site_work::create([
                    'id_construction_site' => $siteId,
                    'vertical_work_id' => $workId,
                    'quantity' => $quantity,
                    'price' => $price
                ]);
            }
            return redirect(url()->previous().'#vWorks');
        }
    }

    public function kir_search(){
        $statusesAccess = Huawei_access_statuses::all();
        $statusesVertical = Huawei_vertical_statuses::all();
        $finalStatuses = Hw_final_statuses::all();
        $builders = Util::builders();
        $monters = Util::monteri();
        $workers = $builders->merge($monters);
        $projectManagers = Util::projectManagers();
        return view('kir.search', [
            'statusesAccess' => $statusesAccess,
            'statusesVertical' => $statusesVertical,
            'workers' => $workers,
            'projectManagers' => $projectManagers,
            'finalStatuses' => $finalStatuses
        ]);
    }

    public function kir_advanced_search(){
        $states = States::all();
        $cities = Cities::all();
        $areas = Areas::all();
        $statusesAccess = Huawei_access_statuses::all();
        $statusesVertical = Huawei_vertical_statuses::all();
        $finalStatuses = Hw_final_statuses::all();
        $builders = Util::builders();
        $fitters = Util::monteri();
        $workers = $builders->merge($fitters);
        $admins = Util::admini();
        $projectManagers = Util::projectManagers();
        $constructionManagers = Util::constructionManagers();
        $constructionManagers = $constructionManagers->merge($admins);
        $equipment = Equipment::all();
        return view('kir.advanced_search', [
            'states' => $states,
            'cities' => $cities,
            'areas' => $areas,
            'statusesAccess' => $statusesAccess,
            'statusesVertical' => $statusesVertical,
            'finalStatuses' => $finalStatuses,
            'workers' => $workers,
            'constructionManagers' => $constructionManagers,
            'projectManagers' => $projectManagers,
            'equipment' => $equipment
        ]);
    }

    public function kir_search_result(Request $request){
        $param = $request->input('param');
        $projectManager = $request->input("project_manager");
        $constructionManager = $request->input('construction_manager');
        $noAccessStatus = $request->input('no_access_status');
        $noVerticalStatus = $request->input('no_vertical_status');
        $noSplicingStatus = $request->input('no_splicing_status');
        $noFinalStatus = $request->input('no_final_status');
        $kModel = new Kir();
        $userId = Util::userId();
        if(Util::isProjectManager()){
            $projectManager = $userId;
            $userId = null;
        }
        if(Util::isConstructionManager()){
            $constructionManager = $userId;
            $userId = null;
        }
        if($param == 'basic'){
            $name = $request->input('name');
            $seller = $request->input('seller');
            $statusAccess = $request->input('status_access');
            $statusVertical = $request->input('status_vertical');
            $statusSplicing = $request->input('status_splicing');
            $finalStatus = $request->input('final_status');
            $appointmentDateAccess = database_date($request->input('appointment_date_access'));
            $appointmentDateVertical = database_date($request->input('appointment_date_vertical'));
            $appointmentDateSplicing = database_date($request->input('appointment_date_splicing'));
            $noAccessStatus = $request->input('no_access_status');
            $noVerticalStatus = $request->input('no_vertical_status');
            $noSplicingStatus = $request->input('no_splicing_status');
            $noFinalStatus = $request->input('no_final_status');

            if(Util::isHuaweiAdmin() || Util::isSuperAdmin() || Util::isProjectAdmin() || Util::isAdmin()){
                $result = $kModel->search($name,$seller,$statusAccess,$statusVertical,$statusSplicing,$finalStatus,$appointmentDateAccess,$appointmentDateVertical,$appointmentDateSplicing,$noAccessStatus,
                $noVerticalStatus,$noSplicingStatus,$noFinalStatus, $projectManager,null, true);
                $noPagination = $kModel->search($name,$seller,$statusAccess,$statusVertical,$statusSplicing,$finalStatus,$appointmentDateAccess,$appointmentDateVertical,$appointmentDateSplicing,$noAccessStatus,
                $noVerticalStatus,$noSplicingStatus,$noFinalStatus,$projectManager);
            }
            else{
                $result = $kModel->search($name,$seller,$statusAccess,$statusVertical,$statusSplicing,$finalStatus,$appointmentDateAccess,$appointmentDateVertical,$appointmentDateSplicing,$noAccessStatus,
                $noVerticalStatus,$noSplicingStatus,$noFinalStatus,$projectManager,$constructionManager,true);
                $noPagination = $kModel->search($name,$seller,$statusAccess,$statusVertical,$statusSplicing,$finalStatus,$appointmentDateAccess,$appointmentDateVertical,$appointmentDateSplicing,$noAccessStatus,
                $noVerticalStatus,$noSplicingStatus,$noFinalStatus,$projectManager,$constructionManager);
            }

            $ids = Arr::pluck($noPagination, 'id');
            $count = count($ids);
            $ids = json_encode($ids);
            session(['ids_export' => $ids]);
            
        }
        else {
            $name = $request->input('name');
            $seller = $request->input('seller');
            $contactSeller = $request->input('contact_seller');
            $tel1 = $request->input('tel1');
            $tel2 = $request->input('tel2');
            $tel3 = $request->input('tel3');
            $manager = $request->input('manager');
            $mTel1 = $request->input('m_tel1');
            $mTel2 = $request->input('m_tel2');
            $mTel3 = $request->input('m_tel3');
            $state = $request->input('state');
            $city = $request->input('city');
            $municipality = $request->input('municipality');
            $address = $request->input('address');
            $numberOfFloors = $request->input('number_of_floors');
            $numberOfFlats = $request->input('number_of_flats');
            $area = $request->input('area');
            $statusAccess = $request->input('status_access');
            $statusVertical = $request->input('status_vertical');
            $statusSplicing = $request->input('status_splicing');
            $finalStatus = $request->input('final_status');
            $workerAccess = $request->input('worker_access');
            $workerVertical = $request->input('worker_vertical');
            $workerSplicing = $request->input('worker_splicing');
            $appointmentDateAccess = database_date($request->input('appointment_date_access'));
            $appointmentDateVertical =  database_date($request->input('appointment_date_vertical'));
            $appointmentDateSplicing =  database_date($request->input('appointment_date_splicing'));
            $delayDate = database_date($request->input('delay_date'));
            $realizationDateAccess = database_date($request->input('realization_date_access'));
            $realizationDateVertical = database_date($request->input('realization_date_vertical'));
            $withdrawalDate = database_date($request->input('withdrawal_date'));
            $cluster = $request->input('cluster');
            $odo = $request->input('odo');
            $izvod = $request->input('izvod');
            $connector = $request->input('connector');
            $realizationAccessStart = database_date($request->input('realization_access_start'));
            $realizationAccessEnd = database_date($request->input('realization_access_end'));
            $realizationVerticalStart = database_date($request->input('realization_vertical_start'));
            $realizationVerticalEnd = database_date($request->input('realization_vertical_end'));
            $realizationSplicingStart = database_date($request->input('realization_splicing_start'));
            $realizationSplicingEnd = database_date($request->input('realization_splicing_end'));
            $appointmentAccessStart = database_date($request->input('appointment_access_start'));
            $appointmentAccessEnd = database_date($request->input('appointment_access_end'));
            $appointmentVerticalStart = database_date($request->input('appointment_vertical_start'));
            $appointmentVerticalEnd = database_date($request->input('appointment_vertical_end'));
            $appointmentSplicingStart = database_date($request->input('appointment_splicing_start'));
            $appointmentSplicingEnd = database_date($request->input('appointment_splicing_end'));
            $technicalSolutionDate = database_date($request->input('technical_solution_date'));
            $atcMsanOlt = $request->input('atc_msan_olt');
            $odfModul = $request->input('odf_modul');
            $connectorNumber = $request->input('connector_number');
            $connectionPoint = $request->input('connection_point');
            $fiber = $request->input('fiber');
            $numerationOdo = $request->input('numeration_odo');
            $flats = $request->input('flats');
            $operation = $request->input('operation');
            $equipment = $request->input('equipment');
            $disStartDate = database_date($request->input('dis_start_date'));
            $disEndDate = database_date($request->input('dis_end_date'));
            $tisEntryDate = database_date($request->input('tis_entry_date'));
            $setDis = $request->input('set_dis');

            if(Util::isHuaweiAdmin() || Util::isSuperAdmin() || Util::isProjectAdmin() || Util::isAdmin()) {
                $result = $kModel->advanced_search($name, $seller, $contactSeller, $tel1, $tel2, $tel3, $manager, $mTel1, $mTel2, $mTel3, $state, $city, $municipality, $address, $numberOfFloors, $numberOfFlats,
                    $area, $statusAccess, $statusVertical, $statusSplicing, $finalStatus, $projectManager, $constructionManager, $workerAccess, $workerVertical, $workerSplicing, $appointmentDateAccess, $appointmentDateVertical,
                    $appointmentDateSplicing, $delayDate, $realizationDateAccess, $realizationDateVertical, $withdrawalDate, $cluster, $odo, $izvod, $connector, $realizationAccessStart,
                    $realizationAccessEnd, $realizationVerticalStart, $realizationVerticalEnd, $realizationSplicingStart, $realizationSplicingEnd, $appointmentAccessStart, $appointmentAccessEnd, $appointmentVerticalStart, $appointmentVerticalEnd,
                    $appointmentSplicingStart, $appointmentSplicingEnd, $noAccessStatus, $noVerticalStatus, $noSplicingStatus, $noFinalStatus, $technicalSolutionDate, $atcMsanOlt, $odfModul, $connectorNumber, $connectionPoint,$fiber, $numerationOdo, 
                    $setDis,$disStartDate, $disEndDate, $flats, $operation, $tisEntryDate, null, true);
                $noPagination = $kModel->advanced_search($name, $seller, $contactSeller, $tel1, $tel2, $tel3, $manager, $mTel1, $mTel2, $mTel3, $state, $city, $municipality, $address, $numberOfFloors, $numberOfFlats,
                    $area, $statusAccess, $statusVertical, $statusSplicing, $finalStatus, $projectManager, $constructionManager, $workerAccess, $workerVertical, $workerSplicing, $appointmentDateAccess, $appointmentDateVertical,
                    $appointmentDateSplicing, $delayDate, $realizationDateAccess, $realizationDateVertical, $withdrawalDate, $cluster, $odo, $izvod, $connector, $realizationAccessStart,
                    $realizationAccessEnd, $realizationVerticalStart, $realizationVerticalEnd, $realizationSplicingStart, $realizationSplicingEnd, $appointmentAccessStart, $appointmentAccessEnd, $appointmentVerticalStart, $appointmentVerticalEnd,
                    $appointmentSplicingStart, $appointmentSplicingEnd, $noAccessStatus, $noVerticalStatus, $noSplicingStatus, $noFinalStatus, $technicalSolutionDate, $atcMsanOlt, $odfModul, $connectorNumber, $connectionPoint,$fiber, $numerationOdo, 
                    $setDis,$disStartDate, $disEndDate, $flats, $operation, $tisEntryDate);
            }
            else{
                $result = $kModel->advanced_search($name, $seller, $contactSeller, $tel1, $tel2, $tel3, $manager, $mTel1, $mTel2, $mTel3, $state, $city, $municipality, $address, $numberOfFloors, $numberOfFlats,
                    $area, $statusAccess, $statusVertical, $statusSplicing, $finalStatus, $projectManager, $constructionManager, $workerAccess, $workerVertical, $workerSplicing, $appointmentDateAccess, $appointmentDateVertical,
                    $appointmentDateSplicing, $delayDate, $realizationDateAccess, $realizationDateVertical, $withdrawalDate, $cluster, $odo, $izvod, $connector, $realizationAccessStart,
                    $realizationAccessEnd, $realizationVerticalStart, $realizationVerticalEnd, $realizationSplicingStart, $realizationSplicingEnd, $appointmentAccessStart, $appointmentAccessEnd, $appointmentVerticalStart, $appointmentVerticalEnd,
                    $appointmentSplicingStart, $appointmentSplicingEnd, $noAccessStatus, $noVerticalStatus, $noSplicingStatus, $noFinalStatus, $technicalSolutionDate, $atcMsanOlt, $odfModul, $connectorNumber, $connectionPoint,$fiber, $numerationOdo, 
                    $setDis,$disStartDate, $disEndDate, $flats, $operation,$tisEntryDate, $userId, true);
                $noPagination = $kModel->advanced_search($name, $seller, $contactSeller, $tel1, $tel2, $tel3, $manager, $mTel1, $mTel2, $mTel3, $state, $city, $municipality, $address, $numberOfFloors, $numberOfFlats,
                    $area, $statusAccess, $statusVertical, $statusSplicing, $finalStatus, $projectManager, $constructionManager, $workerAccess, $workerVertical, $workerSplicing, $appointmentDateAccess, $appointmentDateVertical,
                    $appointmentDateSplicing, $delayDate, $realizationDateAccess, $realizationDateVertical, $withdrawalDate, $cluster, $odo, $izvod, $connector, $realizationAccessStart,
                    $realizationAccessEnd, $realizationVerticalStart, $realizationVerticalEnd, $realizationSplicingStart, $realizationSplicingEnd, $appointmentAccessStart, $appointmentAccessEnd, $appointmentVerticalStart, $appointmentVerticalEnd,
                    $appointmentSplicingStart, $appointmentSplicingEnd, $noAccessStatus, $noVerticalStatus, $noSplicingStatus, $noFinalStatus, $technicalSolutionDate, $atcMsanOlt, $odfModul, $connectorNumber, $connectionPoint,$fiber, $numerationOdo, 
                    $setDis,$disStartDate, $disEndDate, $flats, $operation, $tisEntryDate, $userId);
            }

            $ids = Arr::pluck($noPagination, 'id');
            $count = count($ids);
            $ids = json_encode($ids);
            session(['ids_export' => $ids]);
            session(['kir_equipment_id' => $equipment]);
        }
        session(['search_route' => url()->full()]);
        return view('kir.search_result', [
            'constructionSites' => $result,
            'count' => $count,
            'isHuaweiAdmin' => Util::isHuaweiAdmin(),
            'isAdmin' => Util::isAdmin(),
            'isSuperAdmin' => Util::isSuperAdmin()
        ]);
    }

    public function delete_equipment_works(Request $request){
        $idEquipment = $request->input('id_equipment');
        $idAccessWork = $request->input('id_access_work');
        $idSite = $request->input('id_site');
        $text = '';
        if($idEquipment){
            Site_equipment::where('id_construction_site', $idSite)->where('id_equipment', $idEquipment)->delete();
            $text = __("Equipment successfully deleted");
        }
        elseif($idAccessWork){
            Site_work::where('id_construction_site', $idSite)->where('access_work_id', $idAccessWork)->delete();
            $text = __("Work successfully deleted");
        }
        return back()->with('success', $text);
    }

    public function import_index(){
        $companies = Companies::all();
        return view('kir.import', ['companies' => $companies]);
    }

    public function kir_import(Request $request){
        require '../vendor/autoload.php';
        $file = $request->file('import');
        $company = $request->input('company');
        $reader = new \PhpOffice\PhpSpreadsheet\Reader\Xlsx();

        if($file){
            $allowedExtensions = array('xls', 'xlsx');
            $extension = $file->getClientOriginalExtension();
            if (in_array($extension, $allowedExtensions)){
                $spreadsheet = $reader->load($file);
                $sheetData = $spreadsheet->getActiveSheet()->toArray();
                $errorMessages = array();
                foreach($sheetData as $br=>$data){
                    if ($br == 0)
                        continue;
                    if(!$data[2])
                        $errorMessages[] = __("Address is required field").' '.($br+1);
                }
                if (!empty($errorMessages))
                    return view('huawei.import', ['errorMessages'=>$errorMessages]);

                foreach ($sheetData as $key=>$data){
                    if ($key == 0)
                        continue;

                    $nameSeller = null;
                    $nameManager = null;
                    $namePartsSeller = explode(" ",preg_replace('/\s+/', ' ', $data[0]));
                    if($namePartsSeller){
                        $nameSeller = $namePartsSeller[0];
                        if(isset($namePartsSeller[1]))
                            $nameSeller .= ' '.$namePartsSeller[1];
                    }
                    $namePartsManager = explode(" ",preg_replace('/\s+/', ' ', $data[7]));
                    if($namePartsManager){
                        $nameManager = $namePartsManager[0];
                        if(isset($namePartsManager[1]))
                            $nameManager .= ' '.$namePartsManager[1];
                    }

                    $address = $data[2];

                    $ctMod = new Cities();
                    $cityId = $ctMod->getCityIdByName(trim($data[4]));

                    $create = Kir::create([
                        'name' => $address,
                        'seller' => $nameSeller,
                        'contact_seller' => $data[1],
                        'address' => $address,
                        'id_city' => $cityId,
                        'municipality' => $data[3],
                        'id_state' => 1,
                        'number_of_floors' => $data[5],
                        'number_of_flats' => $data[6],
                        'manager' => $nameManager,
                        'm_tel2' => $data[8],
                        'company_id' => $company
                    ]);

                    if($data[9]){
                        Construction_comments::create([
                            'comment' => $data[9],
                            'id_construction_site' => $create->id,
                            'id_user' => Util::userId()
                        ]);
                    }

                }
                return back()->with('success', __("Data successfully imported to database"));
            }
        }
        else {
            return back()->with('errors', __("Import excel file"));
        }
    }

    public function documentation(){
        $files = Hw_documentation::orderBy('filename')->get();
        $folders = Folders::orderBy('folder')->get();
        $docMod = new Hw_documentation();
        return view('huawei.documentation_index', ['files' => $files, 'folders' => $folders, 'docMod' => $docMod]);
    }

    public function documentation_create(){
        $folders = Folders::orderBy('folder')->get();
        return view('huawei.documentation_create', ['folders' => $folders]);
    }

    public function documentation_store(Request $request){
        $files = $request->file('files');
        $folderId = $request->input('folder');
        $request->validate(['folder' => 'required']);
        $folderName = Folders::find($folderId);
        $folderName = $folderName->folder;
        if($files){
            $request->validate([
                'files.*' => 'mimes:xlsx,xls,pdf,dwg,zip,sor,doc,docx'
            ]);
            $num = 0;
            foreach($files as $file){
                $extension = $file->getClientOriginalExtension();
                $originalFile = $file->getClientOriginalName();
                $filename = $originalFile.'-'.$num.'-'.time().'.'.$extension;
                $folder = 'uploads/documentation/'.$folderName;
                create_folder($folder);
                $file->move($folder, $filename);
                Hw_documentation::create([
                    'file_url' => '/'.$folder.'/'.$filename,
                    'filename' => $originalFile,
                    'folder_id' => $folderId
                ]);
                $num++;
            }
        }
        return redirect()->route('hw_documentation')->with('success', __("Files successfully uploaded"));
    }

    public function add_fixed_access_work(Request $request){
        $siteId = $request->get('site_id');
        $workId = $request->get('access_work_id');
        $operation = $request->get('access_operation');
        $quantity = $request->get('fixed_access_quantity');
        $request->validate([
            'fixed_access_quantity' => 'required|numeric'
        ]);
        if($operation == 'minus')
            $quantity = -$quantity;
        if($workId) {
            Site_work::create([
                'id_construction_site' => $siteId,
                'access_work_id' => $workId,
                'quantity' => $quantity
            ]);
        }
        return redirect(url()->previous().'#aWorks');
    }

    public function add_doc_work(Request $request){
        $siteId = $request->get('site_id');
        $workId = $request->get('doc_work_id');
        $operation = $request->get('doc_operation');
        $quantity = $request->get('fixed_doc_quantity');
        $request->validate([
            'fixed_doc_quantity' => 'required|numeric'
        ]);
        if($operation == 'minus')
            $quantity = -$quantity;
        if($workId) {
            Site_work::create([
                'id_construction_site' => $siteId,
                'doc_work' => $workId,
                'quantity' => $quantity
            ]);
        }
        return redirect(url()->previous().'#dWorks');
    }
}
