<?php

namespace App\Http\Controllers;

use App\Magz;
use App\Models\Demand_equipment_temp;
use App\Models\Kir_demand_equipment;
use App\Models\Kir_demands;
use App\Models\Mont_equipment_categories;
use App\Models\Storage_equipment;
use App\Oprema;
use Illuminate\Http\Request;
use App\Traits\Util;

class KirDemandsController extends Controller
{
   public function list(){
      $dMod = new Kir_demands();
      if(Util::isAdmin() || Util::isSuperAdmin())
         $demands = $dMod->demands();
      else
         $demands = $dMod->demands(Util::userId());
      return view('kirDemand.list', ['demands' => $demands]);
   }

   public function info($demand){
      $deMod = new Kir_demands();
      $dData = $deMod->demandData($demand);
      $eMod = new Kir_demand_equipment();
      $equipmentCategories = Mont_equipment_categories::orderBy('category', 'ASC')->get();
      $equipment = $eMod->equipmentList($demand);
      return view('kirDemand.info', ['dData' => $dData, 'equipmentCategories' => $equipmentCategories, 'equipment' => $equipment]);
   }

   public function create(){
      $workers = Util::workers();
      $warehouses = Magz::all();
      $equipmentCategories = Mont_equipment_categories::orderBy('category', 'ASC')->get();
      $kdMod = new Kir_demands();
      $freeId = $kdMod->freeId();
      $equipmentTemp = Demand_equipment_temp::where('user_id', Util::userId())->get();
      return view('kirDemand.create', ['workers' => $workers, 'warehouses' => $warehouses, 'equipmentCategories' => $equipmentCategories, 'id' => $freeId, 'equipmentTemp' => $equipmentTemp]);
   }

   public function store(Request $request){
      $worker = $request->input('worker_s');
      $warehouse = $request->input('warehouse_s');
      $request->validate([
         'worker_s' => 'required',
         'warehouse_s' => 'required'
      ]);
      $supplies = Demand_equipment_temp::where('user_id', Util::userId())->get();
      $demand = Kir_demands::create([
         'worker' => $worker,
         'storage_id' => $warehouse,
         'created_by' => Util::userId()
      ]);
      $equipment = false;
      // dd($supplies);
      foreach($supplies as $item){
         $equipment = Kir_demand_equipment::create([
            'equipment_id' => $item->equipment_id,
            'quantity' => $item->quantity,
            'package' => $item->package,
            'created_by' => Util::userId(),
            'demand_id' => $demand->id
         ]);
      }
      if($equipment){
         Demand_equipment_temp::where('user_id', Util::userId())->delete();
      }

      if($demand){
         return back()->with('success', __('Data successfully added'));
      }
      else {
         return back()->with('error', __('Error'));
      }
   }


   public function set_quantity(Request $request){
      $packageNumber = $request->input('package_number');
      $equipmentId = $request->input('equipment_id');
      $seMod = new Storage_equipment();
      $quantity = $seMod->packageQuantity($packageNumber, $equipmentId);
      return $quantity;
   }

   public function add_row(Request $request){
      $quantity = $request->input('quantity');
      $equipmentId = $request->input('equipment');
      $param = $request->input('param');
      if($quantity>0 && $equipmentId){
         $oMod = new Oprema();
         $equipmentData = $oMod->equipmentData($equipmentId);
         if($equipmentData->package){
            $package = $request->input('package_number');
         }
         else {
            $package = null;
         }
         $equipmentData->quantity = $quantity;
         if($equipmentData){
            if($param == 'edit'){
               Kir_demand_equipment::create([
                  'equipment_id' => $equipmentData->id,
                  'quantity' => $equipmentData->quantity,
                  'created_by' => Util::userId(),
                  'package' => $package,
                  'demand_id' => $request->input('demand'),
               ]);
            }
            else{
               Demand_equipment_temp::create([
                  'code' => $equipmentData->code,
                  'category' => $equipmentData->category,
                  'equipment_id' => $equipmentData->id,
                  'equipment' => $equipmentData->equipment,
                  'package' => $package,
                  'quantity' => $equipmentData->quantity,
                  'user_id' => Util::userId()
               ]);
            }
         }
      }
      return back()->with('success', __("Item successfully added"));
   }

   public function delete_row(Request $request){
      $id = $request->input('id_row');
      $param = $request->input('param');
      if($param == 'edit'){
         $item = Kir_demand_equipment::find($id);
         try{
            $item->delete();
            return back()->withInput()->with('success', __("Data successfully deleted"));
         }
        catch (\Illuminate\Database\QueryException $e){
            return back()->withInput()->with('errors', __("Data cannot be deleted"));
        }
   
        return back()->withInput()->with('errors', __("Data cannot be deleted"));
      }
      else{
         $item = Demand_equipment_temp::find($id);
         try{
            $item->delete();
            return back()->withInput()->with('success', __("Data successfully deleted"));
         }
        catch (\Illuminate\Database\QueryException $e){
            return back()->withInput()->with('errors', __("Data cannot be deleted"));
        }
   
        return back()->withInput()->with('errors', __("Data cannot be deleted"));
      }
   }

   
}
