<?php

namespace App\Http\Controllers;

use App\Klijenti_prodaja;
use App\Models\Commissions;
use App\Models\Network_groups;
use App\Napomene;
use App\Nov_servis;
use App\Paketi;
use App\Teams;
use App\Traits\Util;
use App\Vrste_paketa;
use Illuminate\Http\Request;
use Illuminate\Support\Arr;

class KlijentiProdajaController extends Controller
{
    private function sellersIds(){
        $tMod = new Teams();
        $sellersIds = $tMod->sellersLead(Util::userId());
        $ids = Arr::pluck($sellersIds, 'id');

        return $ids;
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $klijentModel = new Klijenti_prodaja();
        if (Util::isAdmin()){
            $klijenti = $klijentModel->klijentiAdmin();
        }
        elseif (Util::isProdavac()){
            $klijenti = $klijentModel->klijentiProdavac(Util::userId());
        }
        elseif (Util::isLider()){
            $klijenti = $klijentModel->klijentiLider($this->sellersIds(), Util::userId());
        }
        else{
            $klijenti = array();
        }
        session(['search_route' => false]);
        return view ('klijentiProdaja.index', [
            'klijenti' => $klijenti,
            'isAdmin' => Util::isAdmin(),
            'isSuperAdmin' => Util::isSuperAdmin(),
            'isLider' => Util::isLider()
        ]);
    }

    private function paketi(){
        $paketi = Paketi::all();
        return $paketi;
    }
    private function vrste_paketa(){
        $vrste_paketa = Vrste_paketa::all();
        return $vrste_paketa;
    }

    private function nov_servis(){
        $nov_servisi = Nov_servis::all();
        return $nov_servisi;
    }

    private function network_groups(){
        $networks = Network_groups::all();
        return $networks;
    }

    private function return_view($tip){
        return view('klijentiProdaja.create', [
            'paketi' => $this->paketi(),
            'vrste_paketa' => $this->vrste_paketa(),
            'nov_servisi' => $this->nov_servis(),
            'isAdmin' => Util::isAdmin(),
            'username' => Util::username(),
            'tipKlijenta' => $tip,
            'networkGroups' => $this->network_groups()
        ]);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create(){
        return $this->return_view(0);
    }

    public function create_optika(){
        return $this->return_view(1);
    }

    public function create_supernova(){
        return $this->return_view(2);
    }

    public function create_bakar(){
        return $this->return_view(3);
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $request->validate([
            'ime' => 'required',
            'prezime' => 'required',
            'jmbg' => 'required|digits:13',
            'tel2' => 'required',
            'datum_izdavanja_lk' => 'required',
            'mesto_izdavanja_lk' => 'required',
            'adresa_prebivalista' => 'required',
            'adresa_instalacije' => 'required'
        ]);

        $datumIzdavanjaLk = null;
        if ($request->input('datum_izdavanja_lk'))
            $datumIzdavanjaLk = date('Y-m-d', strtotime($request->input('datum_izdavanja_lk')));

        $points = (float)str_replace(',','.',$request->input('broj_bodova'));
        if($points == 0)
            $points = null;

        $packet = $request->input('paket');
        $packetType = $request->input('vrsta_paketa');
        if($packet){
            $price = Paketi::find($packet)->price;
        }
        else{
            $price = 0;
        }
        $comMod = new Commissions();
        $coefficient = $comMod->getCoefficient($packet, $packetType);
        $commission = $price*$coefficient;

        if (Util::isAdmin()){
            $klijent = Klijenti_prodaja::create([
                'br_ugovora' => $request->input('br_ugovora'),
                'ime' => $request->input('ime'),
                'prezime' => $request->input('prezime'),
                'jmbg' => $request->input('jmbg'),
                'mrezna_grupa' => $request->input('mrezna_grupa'),
                'tel1' => $request->input(' tel1'),
                'tel2' => $request->input('tel2'),
                'tel3' => $request->input('tel3'),
                'tis_id' => $request->input('tis_id'),
                'broj_lk' => $request->input('broj_lk'),
                'datum_izdavanja_lk' => $datumIzdavanjaLk,
                'mesto_izdavanja_lk' => $request->input('mesto_izdavanja_lk'),
                'adresa_prebivalista' => $request->input('adresa_prebivalista'),
                'adresa_instalacije' => $request->input('adresa_instalacije'),
                'id_paket' => $request->input('paket'),
                'id_vrsta_paketa' => $request->input('vrsta_paketa'),
                'id_nov_servis' => $request->input('nov_servis'),
                'dodatni_stb' => $request->input('dodatni_stb'),
                'broj_bodova' => $points,
                'izvodjac_prodavac' => $request->input('izvodjac_prodavac'),
                'tip_klijenta' => $request->input('tip_klijenta'),
                'id_prodavac' => Util::userId(),
                'created_by' => Util::userId(),
                'updated_by' => Util::userId(),
                'commission' => $commission

            ]);
        }
        else {
            $klijent = Klijenti_prodaja::create([
                'ime' => $request->input('ime'),
                'prezime' => $request->input('prezime'),
                'jmbg' => $request->input('jmbg'),
                'mrezna_grupa' => $request->input('mrezna_grupa'),
                'tel1' => $request->input('tel1'),
                'tel2' => $request->input('tel2'),
                'tel3' => $request->input('tel3'),
                'broj_lk' => $request->input('broj_lk'),
                'datum_izdavanja_lk' => $datumIzdavanjaLk,
                'mesto_izdavanja_lk' => $request->input('mesto_izdavanja_lk'),
                'adresa_prebivalista' => $request->input('adresa_prebivalista'),
                'adresa_instalacije' => $request->input('adresa_instalacije'),
                'id_paket' => $request->input('paket'),
                'id_vrsta_paketa' => $request->input('vrsta_paketa'),
                'id_nov_servis' => $request->input('nov_servis'),
                'dodatni_stb' => $request->input('dodatni_stb'),
                'izvodjac_prodavac' => $request->input('izvodjac_prodavac'),
                'tip_klijenta' => $request->input('tip_klijenta'),
                'id_prodavac' => Util::userId(),
                'created_by' => Util::userId(),
                'updated_by' => Util::userId(),
                'commission' => $commission
            ]);
        }
        if ($request->input('napomena')) {
            Napomene::create([
                'napomena' => $request->input('napomena'),
                'id_user' => Util::userId(),
                'id_klijent_prodaja' => $klijent->id
            ]);
        }

        if ($klijent){
            return redirect()->route('klijentiProdaja.index')->with('success', __("Data successfully added"));
        }

    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Klijenti_prodaja  $klijentiProdaja
     * @return \Illuminate\Http\Response
     */
    public function show(Klijenti_prodaja $klijentiProdaja)
    {
        $klijentModel = new Klijenti_prodaja();
        $klijent = $klijentModel->klijentPodaci($klijentiProdaja->id);
        $napModel = new Napomene();
        if ($klijent->prihvaceno != 1)
            $napomene = $napModel->napomeneProdaja($klijentiProdaja->id);
        else
            $napomene = $napModel->napomeneAccepted($klijent->id_dth, $klijent->id_optika, $klijent->id_supernova, $klijent->id_bakar);
        if (Util::isLider()){
            $sellersIds = $this->sellersIds();
            array_push($sellersIds, Util::userId());
        }
        else{
            $sellersIds = [Util::userId()];
        }

        return view('klijentiProdaja.show', [
            'klijent' => $klijent,
            'isAdmin' => Util::isAdmin(),
            'isLider' => Util::isLider(),
            'napomene' => $napomene,
            'sellersIds' => $sellersIds,
            'isSuperAdmin' => Util::isSuperAdmin()
        ]);
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Klijenti_prodaja  $klijentiProdaja
     * @return \Illuminate\Http\Response
     */
    public function edit(Klijenti_prodaja $klijentiProdaja)
    {

        $klijent = Klijenti_prodaja::find($klijentiProdaja->id);
        $paketi = Paketi::all();
        $vrste_paketa = Vrste_paketa::all();
        $nov_servisi = Nov_servis::all();

        $kpModel = new Klijenti_prodaja();
        $prodavac = $kpModel->prodavac($klijentiProdaja->id);

        $napModel = new Napomene();
        $napomene = $napModel->napomeneProdaja($klijentiProdaja->id);

        //prevencija zloupotrebe linka
        if (Util::isLider()){
            $sellersIds = $this->sellersIds();
            array_push($sellersIds, Util::userId());
        }
        else{
            $sellersIds = [Util::userId()];
        }

        return view('klijentiProdaja.edit', [
            'klijent' => $klijent,
            'vrste_paketa' => $vrste_paketa,
            'paketi' => $paketi,
            'nov_servisi' => $nov_servisi,
            'isAdmin' => Util::isAdmin(),
            'prodavac' => $prodavac->ime.' '.$prodavac->prezime,
            'napomene' => $napomene,
            'isSuperAdmin' => Util::isSuperAdmin(),
            'sellersIds' => $sellersIds,
            'networkGroups' => $this->network_groups()
        ]);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Klijenti_prodaja  $klijentiProdaja
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Klijenti_prodaja $klijentiProdaja)
    {
        $request->validate([
            'ime' => 'required',
            'prezime' => 'required',
            'jmbg' => 'required|digits:13',
            'tel2' => 'required',
            'datum_izdavanja_lk' => 'required',
            'mesto_izdavanja_lk' => 'required',
            'adresa_prebivalista' => 'required',
            'adresa_instalacije' => 'required'
        ]);

        $datumIzdavanjaLk = null;
        if ($request->input('datum_izdavanja_lk'))
            $datumIzdavanjaLk = date('Y-m-d', strtotime($request->input('datum_izdavanja_lk')));

        $points = (float)str_replace(',','.',$request->input('broj_bodova'));
        if($points == 0)
            $points = null;

        $packet = $request->input('paket');
        $packetType = $request->input('vrsta_paketa');
        if($packet){
            $price = Paketi::find($packet)->price;
        }
        else{
            $price = 0;
        }
        $comMod = new Commissions();
        $coefficient = $comMod->getCoefficient($packet, $packetType);
        $commission = $price*$coefficient;

        if (Util::isAdmin()){
            $klijentUpdate = Klijenti_prodaja::where('id', $klijentiProdaja->id)->update([
                'br_ugovora' => $request->input('br_ugovora'),
                'ime' => $request->input('ime'),
                'prezime' => $request->input('prezime'),
                'jmbg' => $request->input('jmbg'),
                'mrezna_grupa' => $request->input('mrezna_grupa'),
                'tel1' => $request->input('tel1'),
                'tel2' => $request->input('tel2'),
                'tel3' => $request->input('tel3'),
                'tis_id' => $request->input('tis_id'),
                'broj_lk' => $request->input('broj_lk'),
                'datum_izdavanja_lk' => $datumIzdavanjaLk,
                'mesto_izdavanja_lk' => $request->input('mesto_izdavanja_lk'),
                'adresa_prebivalista' => $request->input('adresa_prebivalista'),
                'adresa_instalacije' => $request->input('adresa_instalacije'),
                'id_paket' => $request->input('paket'),
                'id_vrsta_paketa' => $request->input('vrsta_paketa'),
                'id_nov_servis' => $request->input('nov_servis'),
                'dodatni_stb' => $request->input('dodatni_stb'),
                'broj_bodova' => $points,
                'izvodjac_prodavac' => $request->input('izvodjac_prodavac'),
                'created_by' => Util::userId(),
                'updated_by' => Util::userId(),
                'commission' => $commission
            ]);
        }
        else {
            $klijentUpdate = Klijenti_prodaja::where('id', $klijentiProdaja->id)->update([
                'ime' => $request->input('ime'),
                'prezime' => $request->input('prezime'),
                'jmbg' => $request->input('jmbg'),
                'mrezna_grupa' => $request->input('mrezna_grupa'),
                'tel1' => $request->input('tel1'),
                'tel2' => $request->input('tel2'),
                'tel3' => $request->input('tel3'),
                'broj_lk' => $request->input('broj_lk'),
                'datum_izdavanja_lk' => $datumIzdavanjaLk,
                'mesto_izdavanja_lk' => $request->input('mesto_izdavanja_lk'),
                'adresa_prebivalista' => $request->input('adresa_prebivalista'),
                'adresa_instalacije' => $request->input('adresa_instalacije'),
                'id_paket' => $request->input('paket'),
                'id_vrsta_paketa' => $request->input('vrsta_paketa'),
                'id_nov_servis' => $request->input('nov_servis'),
                'dodatni_stb' => $request->input('dodatni_stb'),
                'izvodjac_prodavac' => $request->input('izvodjac_prodavac'),
                'created_by' => Util::userId(),
                'updated_by' => Util::userId(),
                'commission' => $commission
            ]);
        }

        if ($request->input('napomena')) {
            Napomene::create([
                'napomena' => $request->input('napomena'),
                'id_user' => Util::userId(),
                'id_klijent_prodaja' => $klijentiProdaja->id
            ]);
        }

        if ($klijentUpdate){
            return redirect()->route('klijentiProdaja.show', ['klijentiProdaja'=>$klijentiProdaja->id])->with('success', __("Data successfully changed"));
        }

        return back()->withInput();
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Klijenti_prodaja  $klijentiProdaja
     * @return \Illuminate\Http\Response
     */
    public function destroy(Request $request)
    {
        $findKlijent = Klijenti_prodaja::find($request->input('id_klijent'));
        if ($findKlijent->delete()){
            return redirect()->route('klijentiProdaja.index')->with('success', __("Data successfully deleted"));
        }

        return back()->withInput()->with('errors', __("Data cannot be deleted"));
    }

    public function expedicija(Request $request){
        $expId = $request->input('id_expedicija');
        Klijenti_prodaja::where('id', $expId)->update([
            'ekspedovano' => 1,
            'vraceno' => 0,
            'datum_zahteva' => date('Y-m-d H:i:s')
        ]);

        return back()->withInput()->with('success', __("Request sent"));
    }

    public function vraceni_zahtevi(){
        $klijentModel = new Klijenti_prodaja();
        $zahtevi = $klijentModel->vraceni_zahtevi(Util::userId());
        session(['vraceno' => false]);

        return view ('klijentiProdaja.vraceni_zahtevi', [
            'zahtevi' => $zahtevi,
            'isAdmin' => Util::isAdmin(),
            'isSuperAdmin' => Util::isSuperAdmin()
        ]);
    }

    public function prodaja_search(){
        $paketi = Paketi::all();
        $vrste_paketa = Vrste_paketa::all();
        $nov_servisi = Nov_servis::all();
        session(['saleIds' => null]);

        return view('klijentiProdaja.prodaja_search', [
            'paketi' => $paketi,
            'vrste_paketa' => $vrste_paketa,
            'nov_servisi' => $nov_servisi,
            'prodavci' => Util::prodavci()
        ]);
    }

    public function prodaja_search_result(Request $request){
        $brUgovora = $request->input('br_ugovora');
        $ime = $request->input('ime');
        $prezime = $request->input('prezime');
        $jmbg = $request->input('jmbg');
        $mreznaGrupa = $request->input('mrezna_grupa');
        $tel1 = $request->input('tel1');
        $tel2 = $request->input('tel2');
        $tel3 = $request->input('tel3');
        $tisId = $request->input('tis_id');
        $brojLk = $request->input('broj_lk');
        $datumIzdavanjaLk = $request->input('datum_izdavanja_lk');
        $mestoIzdavanjaLk = $request->input('mesto_izdavanja_lk');
        $adresaPrebivalista = $request->input('adresa_prebivalista');
        $adresaInstalacije = $request->input('adresa_instalacije');
        $idPaket = $request->input('paket');
        $idVrstaPaketa = $request->input('vrsta_paketa');
        $idNovServis = $request->input('nov_servis');
        $dodatniStb = $request->input('dodatni_stb');
        $brojBodova = $request->input('broj_bodova');
        $izvodjacProdavac = $request->input('izvodjac_prodavac');
        $idProdavac = $request->input('prodavac');
        $createdStart = database_date($request->input('created_start'));
        $createdEnd = database_date($request->input('created_end'));

        if ($datumIzdavanjaLk)
            $datumIzdavanjaLk = date('Y-m-d', strtotime($datumIzdavanjaLk));

        $kpModel = new Klijenti_prodaja();
        if (Util::isAdmin()){
            $klijenti = $kpModel->prodaja_search_admin($brUgovora, $ime, $prezime, $jmbg, $mreznaGrupa, $tel1, $tel2, $tel3, $tisId,
                $brojLk, $datumIzdavanjaLk, $mestoIzdavanjaLk, $adresaPrebivalista, $adresaInstalacije, $idPaket,
                $idVrstaPaketa, $idNovServis, $dodatniStb, $brojBodova, $izvodjacProdavac, $idProdavac, $createdStart, $createdEnd, true);
            $ids = $kpModel->prodaja_search_admin($brUgovora, $ime, $prezime, $jmbg, $mreznaGrupa, $tel1, $tel2, $tel3, $tisId,
                $brojLk, $datumIzdavanjaLk, $mestoIzdavanjaLk, $adresaPrebivalista, $adresaInstalacije, $idPaket,
                $idVrstaPaketa, $idNovServis, $dodatniStb, $brojBodova, $izvodjacProdavac, $idProdavac, $createdStart, $createdEnd);
        }
        else{
            $klijenti = $kpModel->prodaja_search(Util::userId(), $brUgovora, $ime, $prezime, $jmbg, $mreznaGrupa, $tel1, $tel2, $tel3, $tisId,
                $brojLk, $datumIzdavanjaLk, $mestoIzdavanjaLk, $adresaPrebivalista, $adresaInstalacije, $idPaket,
                $idVrstaPaketa, $idNovServis, $dodatniStb, $brojBodova, $izvodjacProdavac, $createdStart, $createdEnd, true);
            $ids = $kpModel->prodaja_search(Util::userId(), $brUgovora, $ime, $prezime, $jmbg, $mreznaGrupa, $tel1, $tel2, $tel3, $tisId,
                $brojLk, $datumIzdavanjaLk, $mestoIzdavanjaLk, $adresaPrebivalista, $adresaInstalacije, $idPaket,
                $idVrstaPaketa, $idNovServis, $dodatniStb, $brojBodova, $izvodjacProdavac, $createdStart, $createdEnd);
        }

        $saleIds = json_encode(Arr::pluck($ids, 'id'));
        session(['saleIds' => $saleIds]);
        
  
        session(['search_route' => url()->full()]);
        return view('klijentiProdaja.prodaja_search_result', [
            'klijenti' => $klijenti,
            'isAdmin' => Util::isAdmin(),
            'isSuperAdmin' => Util::isSuperAdmin(),
            'count' => count($ids)
        ]);
    }

    public function change_type(Request $request){
        $idKlijent = $request->input('id_klijent');
        $tip = $request->input('tip_klijenta');
        Klijenti_prodaja::where('id',$idKlijent)->update([
            'prihvaceno' => 0,
            'tip_klijenta' => $tip
        ]);

        return redirect()->route('klijentiProdaja.index')->with('success', __("Client type successfully changed"));
    }

    public function edit_points(Request $request){
        $clientId = $request->input('id_client');
        $points = $request->input('points');
        $points = (float)str_replace(',','.',$points);
        Klijenti_prodaja::where('id',$clientId)->update([
            'broj_bodova' => $points
        ]);
        return redirect()->route('klijentiProdaja.index')->with('success', __("Points successfully changed"));
    }
}
