<?php

namespace App\Http\Controllers;

use App\Models\Mag_user;
use App\Magz;
use App\Models\Storage_tools;
use App\Models\Storage_types;
use Illuminate\Http\Request;
use App\Traits\Util;
use Illuminate\Support\Arr;

class MagzController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $magModel = new Magz();
        $magz = $magModel->magz();
        return view ('magz.index', ['magz' => $magz, 'magModel' => $magModel]);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $storeKeepers = Util::storeKeepers();
        $storageTypes = Storage_types::all();
        return view('magz.create', ['storeKeepers' => $storeKeepers, 'storageTypes' => $storageTypes]);
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $storage = $request->input('naziv');
        $storeKeepers = $request->input('storeKeepers');
        $request->validate(['naziv' => 'required']);
        $type = $request->input('type');
        $createMag = Magz::create([
            'naziv' => $storage,
            'type_id' => $type
        ]);
        if($createMag && $storeKeepers){
            foreach($storeKeepers as $stk){
                Mag_user::create([
                    'mag_id' => $createMag->id,
                    'user_id' => $stk
                ]);
            }
        }
        return redirect()->route('magz.index')->with('success', __("Data successfully added"));
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Magz  $mag
     * @return \Illuminate\Http\Response
     */
    public function show(Magz $mag)
    {
        $magModel = new Magz();
        $magData = $magModel->magData($mag->id);
        $currentStk = $magModel->storekeepersForStorage($mag->id);
        return view('magz.show', ['mag' => $magData, 'currentStk' => $currentStk]);
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Magz  $mag
     * @return \Illuminate\Http\Response
     */
    public function edit(Magz $mag)
    {
        $mag = Magz::find($mag->id);
        $magModel = new Magz();
        $currentStk = $magModel->storekeepersForStorage($mag->id);
        $exclude = Arr::pluck($currentStk, 'id');
        $storeKeepers = $magModel->remainingStorekeepers($exclude);
        $storageTypes = Storage_types::all();
        return view('magz.edit', ['mag' => $mag, 'storeKeepers' => $storeKeepers, 'currentStk' => $currentStk, 'storageTypes' => $storageTypes]);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Magz  $mag
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Magz $mag)
    {
        $storage = $request->input('naziv');
        $storeKeepers = $request->input('storeKeepers');
        $request->validate(['naziv' => 'required']);
        $type = $request->input('type');
        $update = Magz::where('id', $mag->id)->update([
            'naziv' => $storage,
            'type_id' => $type
        ]);
        if($storeKeepers && $update){
            foreach($storeKeepers as $stk){
                Mag_user::create([
                    'mag_id' => $mag->id,
                    'user_id' => $stk
                ]);
            }
        }
        if($update){
            return redirect()->route('magz.show', ['mag'=>$mag])->with('success', __("Data successfully changed"));
        }
        else {
            return back()->withInput()->with('error', __("Error"));
        }
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function destroy(Request $request)
    {
        $magId = $request->input('id_mag');
        $find = Magz::find($magId);

        try{
            $find->delete();
            Mag_user::where('mag_id', $magId)->delete();
            return back()->withInput()->with('success', __("Data successfully deleted"));
        }
        catch (\Illuminate\Database\QueryException $e){
            return back()->withInput()->with('error', __("Item can't be deleted because it's in use"));
        }

        return back()->withInput()->with('error', __("Data cannot be deleted"));
    }


    /**
     * Remove the specified resource from storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function storekeeper_delete(Request $request)
    {
        $userId = $request->input('id_storekeeper');
        $magId = $request->input('id_mag');
        $delete = Mag_user::where('mag_id', $magId)->where('user_id', $userId)->delete();
        return back()->withInput();
    }
}
