<?php

namespace App\Http\Controllers;

use App\Models\De_change_history;
use App\Models\De_site_materials;
use App\Models\Material_logs;
use App\Models\Material_rune;
use App\Models\Materials;
use App\Models\Rune_logs;
use App\Models\Worker_materials;
use Illuminate\Http\Request;
use App\Traits\Util;

class MaterialController extends Controller
{
    public function index()
    {
        $materials = Materials::all()->where('is_active', 1);
        return view('materials.index', ['materials' => $materials]);
    }

    public function create()
    {
        return view('materials.create');
    }

    public function store(Request $request)
    {
        $request->merge([
            'price' => str_replace(',', '.', $request->input('price'))
        ]);
        $request->validate(['material' => 'required', 'min_qnt' => 'nullable|numeric', 'price' => 'numeric']);
        $create = Materials::create([
            'code' => trim($request->input('code')),
            'material' => trim($request->input('material')),
            'min_qnt' => $request->input('min_qnt'),
            'price' => $request->input('price')
        ]);
        if ($create){
            return redirect()->route('material.show', ['material' => $create->id])->with('success', __("Data successfully added"));
        }
    }

    public function show(Materials $material)
    {
        return view('materials.show', ['material' => $material]);
    }

    public function edit(Materials $material)
    {
        return view('materials.edit', ['material' => $material]);
    }

    public function update(Request $request, Materials $material)
    {
        $request->merge([
            'price' => str_replace(',', '.', $request->input('price'))
        ]);
        $request->validate(['material' => 'required', 'min_qnt' => 'nullable|numeric', 'price' => 'numeric']);
        $update = Materials::where('id',$material->id)->update([
            'code' => trim($request->input('code')),
            'material' => trim($request->input('material')),
            'min_qnt' => $request->input('min_qnt'),
            'price' => $request->input('price'),
            'is_active' => $request->input('is_active')
        ]);
        if ($update){
            return redirect()->route('material.show', ['material' => $material->id])->with('success', __("Data successfully changed"));
        }
    }

    public function destroy(Request $request)
    {
        $find = Materials::find($request->input('id_material'));

        try{
            $find->delete();
            return back()->withInput()->with('success', __("Data successfully deleted"));
        }
        catch (\Illuminate\Database\QueryException $e){
            return back()->withInput()->with('error', __("Data cannot be deleted"));
        }

        return back()->withInput()->with('error', __("Error"));
    }


    public function add_material(Request $request){
        $materialId = $request->input('material');
        $clientId = $request->input('client_id');
        $qty = $request->input('qty');
        $fitterMaterial = $request->input('fitter_material');
        $param = $request->input('param');

        if ($materialId == 0)
            return back()->withInput()->with('error', __("Add rejected! You must select material"));
        if (!$qty)
            return back()->withInput()->with('error', __("Add rejected! You must enter quantity."));
        if (!is_float($qty) && $qty<1)
            return back()->withInput()->with('error', __("Quantity has to be positive number."));

        if($fitterMaterial){
            $fitterId = $fitterMaterial;
        }
        else {
            $fitterId = Util::userId();
        }

        $wmModel = new Worker_materials();

        if(!Util::isAdmin()){
            $material = $wmModel->specific_material($fitterId, $materialId);
            if(isset($material->quantity))
                $quantity = $material->quantity;
            else
                $quantity = 0;
            if($qty > $quantity)
                return back()->withInput()->with('error', __("Not enough material in warehouse"));
            if($qty < 0)
                return back()->withInput()->with('error', __("Quantity has to be positive number."));
            if($param == 'de'){
                $matCreate = De_site_materials::create([
                    'material_id' => $materialId,
                    'site_id' => $clientId,
                    'quantity' => $qty,
                    'fitter_id' => $fitterId
                ]);
                if($matCreate){
                    De_change_history::create([
                        'id_user' => $fitterId,
                        'id_site' => $clientId
                    ]);
                    $wmModel->material_update($fitterId, $materialId, -$qty);
                    return back()->withInput()->with('success', __("Equipment successfully added"));
                }
            }
            else{
                $matCreate = Material_rune::create([
                    'material_id' => $materialId,
                    'client_id' => $clientId,
                    'quantity' => $qty,
                    'fitter_id' => $fitterId
                ]);
                if($matCreate){
                    Rune_logs::create([
                        'user_id' => $fitterId,
                        'client_id' => $clientId
                    ]);
                    $wmModel->material_update($fitterId, $materialId, -$qty);
                    return back()->withInput()->with('success', __("Equipment successfully added"));
                }
            }
        }
        else {
            //if admin adds equipment in his own name
            if(!$fitterMaterial){
                if($param == 'de'){
                    $matCreate = De_site_materials::create([
                        'material_id' => $materialId,
                        'site_id' => $clientId,
                        'quantity' => $qty,
                        'fitter_id' => $fitterId
                    ]);
                }
                else{
                    $matCreate = Material_rune::create([
                        'material_id' => $materialId,
                        'client_id' => $clientId,
                        'quantity' => $qty,
                        'fitter_id' => $fitterId
                    ]);
                }
            }
            //if fitter is selected
            else{
                $material = $wmModel->specific_material($fitterId, $materialId);
                if(isset($material->quantity))
                    $quantity = $material->quantity;
                else
                    $quantity = 0;
                if($qty > $quantity)
                    return back()->with('error', __("The fitter does not have as much goods in stock"));
                if($param == 'de'){
                    $matCreate = De_site_materials::create([
                        'material_id' => $materialId,
                        'site_id' => $clientId,
                        'quantity' => $qty,
                        'fitter_id' => $fitterId
                    ]);
                }
                else{
                    $matCreate = Material_rune::create([
                        'material_id' => $materialId,
                        'client_id' => $clientId,
                        'quantity' => $qty,
                        'fitter_id' => $fitterId
                    ]);
                }
            }

            if ($matCreate){
                if($param == 'de'){
                    De_change_history::create([
                        'id_user' => $fitterId,
                        'id_site' => $clientId
                    ]);
                }
                else{
                    Rune_logs::create([
                        'user_id' => $fitterId,
                        'client_id' => $clientId
                    ]);
                }
                if($fitterId){
                    $wmModel->material_update($fitterId, $materialId, -$qty);
                }
            }
            return back()->withInput()->with('success', __("Equipment successfully added"));
        }
    }

    public function delete_material(Request $request){
        $materialId = $request->input('material_id');
        $siteId = $request->input('site_id');
        $param = $request->input('param');
        $createdAt = $request->input('created_at');

        if($param == 'de'){
            De_site_materials::where('material_id', $materialId)->where('created_at', $createdAt)->where('site_id', $siteId)->delete();
            De_change_history::create([
                'id_user' => Util::userId(),
                'id_site' => $siteId
            ]);
        }
        else{
            Material_rune::where('material_id', $materialId)->where('created_at', $createdAt)->where('client_id', $siteId)->delete();
            Rune_logs::create([
                'user_id' => Util::userId(),
                'client_id' => $siteId
            ]);
        }
        return back()->withInput()->with('success', __("Equipment successfully deleted"));
    }
}
