<?php

namespace App\Http\Controllers;

use App\Models\Network_groups;
use Illuminate\Http\Request;

class NetworkGroupController extends Controller
{

    private function allNetworks(){
        $networkGroups = Network_groups::orderBy('network', 'ASC')->get();
        return $networkGroups;
    }

    private function findNetwork($id){
        $network = Network_groups::find($id);
        return $network;
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        return view('network_group.index', ['networks' => $this->allNetworks()]);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('network_group.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $request->validate([
            'network' => 'required'
        ]);
        $networkGroup = Network_groups::create([
            'network' => trim($request->input('network'))
        ]);

        if ($networkGroup){
            return view('network_group.index', ['networks' => $this->allNetworks()]);
        }
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Network_groups  $network_group
     * @return \Illuminate\Http\Response
     */
    public function show(Network_groups $network_group)
    {
        return view('network_group.show', ['network' => $this->findNetwork($network_group->id)]);
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Network_groups  $network_group
     * @return \Illuminate\Http\Response
     */
    public function edit(Network_groups $network_group)
    {
        return view('network_group.edit', ['network' => $this->findNetwork($network_group->id)]);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Network_groups  $network_group
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Network_groups $network_group)
    {
        $request->validate([
            'network' => 'required'
        ]);
        $networkUpdate = Network_groups::where('id', $network_group->id)->update([
            'network'=>trim($request->input('network'))
        ]);

        if ($networkUpdate){
            return redirect()->route('network_group.show', ['network_group' => $network_group->id])->with('success', __("Data successfully changed"));
        }
        return back()->withInput();
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Network_groups  $network_groups
     * @return \Illuminate\Http\Response
     */
    public function destroy(Request $request)
    {
        $findNetwork = Network_groups::find($request->input('id_network'));

        try{
            $findNetwork->delete();
            return back()->withInput()->with('success', __("Data successfully deleted"));
        }
        catch (\Illuminate\Database\QueryException $e){
            return back()->withInput()->with('errors', __("Data cannot be deleted"));
        }


        return back()->withInput()->with('errors', __("Data cannot be deleted"));
    }
}
