<?php

namespace App\Http\Controllers;

use App\Models\Wf_task_equipment;
use App\Models\Equipment_categories;
use App\Models\Wf_statuses;
use App\Models\Wf_task_work;
use App\Models\Wf_works;
use App\Models\Wf_project_task;
use App\Traits\Util;
use App\User;
use App\Models\Wf_tasks;
use App\Models\Wf_projects;
use Illuminate\Http\Request;

class ProjectController extends Controller
{
    public function index()
    {
        /*
         * $date1 = "2007-03-24";
            $date2 = "2009-06-26";

            $diff = abs(strtotime($date2) - strtotime($date1));

            $years = floor($diff / (365*60*60*24));
            $months = floor(($diff - $years * 365*60*60*24) / (30*60*60*24));
            $days = floor(($diff - $years * 365*60*60*24 - $months*30*60*60*24)/ (60*60*24));

            printf("%d years, %d months, %d days\n", $years, $months, $days);
         */
        if(Util::isAdmin()){
            $pMod = new Wf_projects();
            $projects = $pMod->projectsIndex();
        }
        else{
            $pMod = new Wf_projects();
            $projects = $pMod->indexOtherUsers(Util::userId());
        }
        $tMod = new Wf_project_task();
        $wMod = new Wf_task_work();
        $taskMod = new Wf_tasks();
        $allTasks = $taskMod->tasks();

        return view ('workFlow.project_index', ['projects' => $projects, 'isAdmin' => Util::isAdmin(), 'tMod' => $tMod, 'wMod' => $wMod, 'allTasks' => $allTasks]);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $tasks = Wf_tasks::all();
        $users = User::all();
        return view ('workFlow.project_create', ['tasks' => $tasks, 'users' => $users]);
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $projectName = $request->input('project');
        $startDate = $request->input('start_date');
        $endDate = $request->input('end_date');
        $startTime = $request->input('start_time');
        $endTime = $request->input('end_time');
        $startDate = database_date_time($startDate, $startTime);
        $endDate = database_date_time($endDate, $endTime);
        $tasks = $request->input('task');
        $projectUser = $request->input('project_user');
        if(Util::isAdmin() || Util::isSuperAdmin())
            $user = $request->input('user');
        else
            $user = Util::userId();
        $request->validate([
            'project' => 'required',
            'start_date' => 'required',
            'end_date' => 'required'
        ]);
        $create = Wf_projects::create([
            'project_name' => $projectName,
            'start_date' => $startDate,
            'end_date' => $endDate,
            'user' => $projectUser
        ]);
        if($create){
            if($tasks){
                foreach($tasks as $taskId){
                    Wf_project_task::create([
                        'project_id' => $create->id,
                        'task_id' => $taskId,
                        'user_id' => $user,
                        'status_id' => null
                    ]);
                }
            }
            return redirect()->route('project.show', ['project' => $create->id])->with('success', __("Data successfully added"));
        }
        else{
            return redirect()->route('project.index')->with('error', __("Error"));
        }
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Models\Wf_projects  $project
     * @return \Illuminate\Http\Response
     */
    public function show(Wf_projects $project)
    {
        $tMod = new Wf_project_task();
        if(Util::isAdmin())
            $tasks = $tMod->tasks($project->id);
        else
            $tasks = $tMod->tasks($project->id, Util::userId());
        $works = Wf_works::all();
        $wMod = new Wf_task_work();
        $users = User::all();
        $statuses = Wf_statuses::all();
        $equipmentCategories = Equipment_categories::all();
        $teMod = new Wf_task_equipment();
        $done = Wf_project_task::where('project_id', $project->id)->where('done', '1')->get();
        $undone = Wf_project_task::where('project_id', $project->id)->where('done', '0')->get();
        if($undone->isEmpty())
            $taskPercentage = 100;
        elseif(!$done->isEmpty())
            $taskPercentage = number_format($done->count()*100/($done->count()+$undone->count()));
        else
            $taskPercentage = 0;

        $duration = timeDuration($project->start_date, $project->end_date);
        return view ('workFlow.project_show', [
            'duration' => $duration, 
            'project' => $project, 
            'tasks' => $tasks, 
            'works' => $works,
            'wMod' => $wMod,
            'taskPercentage' => $taskPercentage,
            'users' => $users,
            'statuses' => $statuses,
            'equipmentCategories' => $equipmentCategories,
            'teMod' => $teMod 
        ]);
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Models\Wf_projects  $project
     * @return \Illuminate\Http\Response
     */
    public function edit(Wf_projects $project)
    {
        if(!Util::isAdmin())
            return back()->with('error', __("Only Admins can see this page"));
        $tasks = Wf_tasks::all();
        $users = User::all();
        return view ('workFlow.project_edit', ['project' => $project, 'tasks' => $tasks, 'users' => $users]);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Models\Wf_projects  $project
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Wf_projects $project)
    {
        $projectName = $request->input('project');
        $startDate = $request->input('start_date');
        $endDate = $request->input('end_date');
        $startTime = $request->input('start_time');
        $endTime = $request->input('end_time');
        $tasks = $request->input('task');
        $user = $request->input('user');
        $projectUser = $request->input('project_user');
        $request->validate([
            'project' => 'required',
            'start_date' => 'required',
            'end_date' => 'required',
            'start_time' => 'required',
            'end_time' => 'required'
            ]);
        $startDate = database_date_time($startDate, $startTime);
        $endDate = database_date_time($endDate, $endTime);
        $update = Wf_projects::where('id', $project->id)->update([
            'project_name' => $projectName,
            'start_date' => $startDate,
            'end_date' => $endDate,
            'user' => $projectUser
        ]);

        if($update){
            if($tasks){
                foreach($tasks as $taskId){
                    Wf_project_task::create([
                        'project_id' => $project->id,
                        'task_id' => $taskId,
                        'user_id' => $user
                    ]);
                }
            }
            return redirect()->route('project.show', ['project' => $project])->with('success', __("Data successfully changed"));
        }
        else{
            return redirect()->route('project.index')->with('error', __("Error"));
        }
        
    }

    /**
     * @param Request $request
     */
    public function destroy(Request $request)
    {
        if(!Util::isAdmin())
            return back()->with('error', __("Only Admins can see this page"));
        $projectId = $request->input("id_project");
        $findProject = Wf_projects::where('id', $projectId);
        try{
            $findProject->delete();
            return back()->withInput()->with('success', __("Data successfully deleted"));
        }
        catch (\Illuminate\Database\QueryException $e){
            return back()->withInput()->with('error', __("Item can't be deleted because it's in use"));
        }
    }

    public function export(){
        
    }
}
