<?php

namespace App\Http\Controllers;

use App\Models\States;
use Illuminate\Http\Request;

class StateController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $stateModel = new States();
        $states = $stateModel->statesIndex();
        return view('state.index', ['states' => $states]);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('state.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $request->validate(['state' => 'required', 'state_short' => 'required']);
        $state = States::create([
            'state' => trim($request->input('state')),
            'state_short' => $request->input('state_short')
        ]);

        if ($state){
            return redirect()->route('state.index')->with('success', __("Data successfully added"));
        }
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\States  $state
     * @return \Illuminate\Http\Response
     */
    public function show(States $state)
    {
        $stateModel = new States();
        $state = $stateModel->statesIndex($state->id);
        return view('state.show', ['state' => $state]);
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\States  $state
     * @return \Illuminate\Http\Response
     */
    public function edit(States $state)
    {
        $stateModel = new States();
        $state = $stateModel->statesIndex($state->id);
        return view('state.edit', ['state' => $state]);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\States  $state
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, States $state)
    {
        $request->validate(['state' => 'required', 'state_short' => 'required']);
        $stateUpdate = States::where('id', $state->id)->update([
            'state' => trim($request->input('state')),
            'state_short' => $request->input('state_short')
        ]);

        if ($stateUpdate){
            return redirect()->route('state.show', ['state' => $state])->with('success', __("Data successfully changed"));
        }
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function destroy(Request $request)
    {
        $findState = States::find($request->input('id_state'));

        try{
            $findState->delete();
            return back()->withInput()->with('success', __("Data successfully deleted"));
        }
        catch (\Illuminate\Database\QueryException $e){
            return back()->withInput()->with('error', __("Data cannot be deleted"));
        }

        return back()->withInput()->with('error', __("Data cannot be deleted"));
    }
}
