<?php

namespace App\Http\Controllers;

use App\Models\Kir_required_equipment;
use Illuminate\Support\Arr;
use App\Magz;
use App\Models\Kir_demand_equipment;
use App\Models\Kir_demands;
use App\Models\Storage_equipment;
use App\Models\Storage_logs;
use App\Models\Worker_equipment;
use App\Traits\Util;
use App\Models\Required_equipment;
use App\Models\Worker_storage_logs;
use App\Oprema;
use Illuminate\Http\Request;

class StorageController extends Controller
{
    private function updateChangeLog($equipmentId, $storageId, $quantity, $montEquipmentId = null, $fitterId=null, $receiveNumber=null, $from=null, $packageNumber=null){
        if($quantity != 0){
            Storage_logs::create([
                'equipment_id' => $equipmentId,
                'mont_equipment_id' => $montEquipmentId,
                'user_id' => Util::userId(),
                'fitter_id' => $fitterId,
                'receive_number' => $receiveNumber,
                'from' => $from,
                'storage_id' => $storageId,
                'quantity' => $quantity,
                'package_number' => $packageNumber
            ]);
        }
    }

    public function worker_storage_logs(Request $request){
        $param = $request->input("param");
        $workerId = $request->input("worker_id");
        $logModel = new Worker_storage_logs();
        $route = null;
        if($param == 'montage'){
            $logs = $logModel->logsMontage($workerId);
        }
        elseif($param == 'construction') {
            $logs = $logModel->logsConstruction($workerId);
        }

        return view('storageLogs.logs', [
            'logs' => $logs,
            'logModel' => $logModel
        ]);
    }

    public function equipment_requirement_list(){
        $reMod = new Required_equipment();
        $mgMod = new Magz();
        $list = $reMod->required_equipment_list();
        if(Util::isSuperAdmin())
            $storages = Magz::all();
        else
            $storages = $mgMod->magzForUser(Util::userId());
        $builders = Util::builders();
        $monters = Util::monteri();
        $workers = $builders->merge($monters);
        return view('constructionStorage.requirement_list', [
            'list' => $list,
            'storages' => $storages,
            'workers' => $workers
        ]);
    }

    public function warehouse_info($demand){
        $deMod = new Kir_demands();
        $dData = $deMod->demandData($demand);
        $eMod = new Kir_demand_equipment();
        $equipment = $eMod->equipmentList($demand);
        return view('constructionStorage.demand_info', ['dData' => $dData, 'equipment' => $equipment]);
     }

    public function equipment_requirement_list_kir(){
        $dMod = new Kir_demands();
        if(Util::isAdmin() || Util::isSuperAdmin())
            $demands = $dMod->demands();
        else
            $demands = $dMod->demands(Util::userId());
        return view('constructionStorage.requirement_list_kir', ['demands' => $demands]);
    }

    public function required_equipment_supply(Request $request){
        $param = $request->input('param');
        $id = $request->input('list_id');
        $equipmentId = $request->input("equipment_id");
        $worker = $request->input('worker');
        $storageId = $request->input('storage');
        $quantity = $request->input('s_quantity');
        $supplied = $request->input('supplied');
        $constructionType = $request->input('construction_type');
        $packageNumber = $request->input('package_number');
        /* check if specific equipment needs number of packages */
        $specificEquipment = Oprema::where('id', $equipmentId)->first();
        if($specificEquipment->package != null)
            $packageIsset = true;
        else 
            $packageIsset = false;
        if($packageIsset && !$packageNumber){
            return back()->with('error', __("You must enter package number for this equipment"));
        }
        if(!$packageIsset){
            $packageNumber = null;
        }

        if(!$storageId)
            return back()->with('error', __("You must select warehouse"));

        $sModel = new Storage_equipment();
        $storageEquipment = $sModel->specific_equipment_mont($storageId, $equipmentId, $packageNumber);
        if($storageEquipment)
            $storageAmmount = $storageEquipment->quantity;
        else
            $storageAmmount = 0;
        $wModel = new Worker_equipment();
        $workerEquipment = $wModel->specific_equipment_mont($worker, $equipmentId);
        if(isset($workerEquipment->quantity))
            $workerQuantity = $workerEquipment->quantity;
        else
            $workerQuantity = 0;
        if($param == 'check'){
            if($supplied == 1)
                return back()->with('error', __("This equipment is already given to worker"));

            if($workerQuantity + $quantity < 0)
                return back()->with('error', __("Worker doesn't have goods in his inventory"));
            if($storageAmmount >= $quantity){
                if($workerEquipment){
                    //if there is a record in database, just update quantity
                    $wModel->equipment_update_mont($worker, $equipmentId, $quantity);
                    $sModel->storage_update_mont($storageId, $equipmentId, -$quantity, $packageNumber);
                    $this->updateChangeLog(null, $storageId, -$quantity, $equipmentId, $worker, $packageNumber);
                    Worker_storage_logs::create([
                        'mont_equipment_id' => $equipmentId,
                        'worker_id' => $worker,
                        'storage_id' => $storageId,
                        'quantity' => $quantity
                    ]);
                }
                //if there is no record, create new
                else{
                    Worker_equipment::create([
                        'user_id' => $worker,
                        'equipment_id' => null,
                        'mont_equipment_id' => $equipmentId,
                        'storage_id' => $storageId,
                        'quantity' => $quantity
                    ]);
                    Worker_storage_logs::create([
                        'mont_equipment_id' => $equipmentId,
                        'worker_id' => $worker,
                        'storage_id' => $storageId,
                        'quantity' => $quantity
                    ]);
                    $sModel->storage_update_mont($storageId, $equipmentId, -$quantity, $packageNumber);
                    $this->updateChangeLog(null, $storageId, -$quantity, $equipmentId, $worker, $packageNumber);
                }

                if($constructionType == 'kir'){
                    Kir_required_equipment::where('id', $id)->update([
                        'supplied' => 1,
                        'supplied_quantity' => $quantity,
                        'supplied_by' => Util::userId(),

                    ]);
                }
                else{
                    Required_equipment::where('id', $id)->update([
                        'supplied' => 1,
                        'supplied_quantity' => $quantity,
                        'supplied_by' => Util::userId(),
                        'supplied_to' => $worker
                    ]);
                }

                return back()->with('success', __("Equipment is successfully assigned to worker"));
            }
            else {
                return back()->with('error', __("not enough goods in warehouse"));
            }
        }
        if($param == 'undo'){
            if($supplied == 0)
                return back()->with('error', __("This equipment is not assigned"));
            if($workerQuantity >= $quantity){
                $wModel->equipment_update_mont($worker, $equipmentId, -$quantity);
                $sModel->storage_update_mont($storageId, $equipmentId, $quantity,$packageNumber);
                $this->updateChangeLog(null, $storageId, $quantity, $equipmentId, $worker,$packageNumber);
                Worker_storage_logs::create([
                    'mont_equipment_id' => $equipmentId,
                    'worker_id' => $worker,
                    'storage_id' => $storageId,
                    'quantity' => -$quantity
                ]);
                if($constructionType == 'kir'){
                    Kir_required_equipment::where('id', $id)->update([
                        'supplied' => 0,
                        'supplied_quantity' => 0,
                        'supplied_by' => null
                    ]);
                }
                else {
                    Required_equipment::where('id', $id)->update([
                        'supplied' => 0,
                        'supplied_quantity' => 0,
                        'supplied_by' => null
                    ]);
                }
                return back()->with('success', __("Equipment successfully returned to warehouse"));
            }
            else{
                return back()->with('error', __("Not enough equipment in worker inventory"));
            }
        }
    }

    public function requirement_search_result(Request $request){
        $address = $request->input('address');
        $table = $request->input('table');
        $site = $request->input('site');
        $reMod = new Required_equipment();
        $mgMod = new Magz();
        $list = $reMod->search_result($address, $table, $site,true);
        $sessionList = $reMod->search_result($address, $table, $site);
        if(Util::isSuperAdmin())
            $storages = Magz::all();
        else
            $storages = $mgMod->magzForUser(Util::userId());
        $builders = Util::builders();
        $monters = Util::monteri();
        $workers = $builders->merge($monters);
        $requirementIds = Arr::pluck($sessionList, 'id');
        session(["requirement_ids" => json_encode($requirementIds)]);
        return view('constructionStorage.requirement_search_result', [
            'list' => $list,
            'storages' => $storages,
            'workers' => $workers,
            'site' => $site
        ]);
    }

    public function requirement_search(){
        return view('constructionStorage.requirement_search');
    }

    public function requirement_search_kir(){
        return view('constructionStorage.requirement_search_kir');
    }

    public function populate(Request $request){
        $value = $request->input('value');
        $table = $request->input('table');
        $rMod = new Required_equipment();
        $data = $rMod->populate($value, $table);
        return $data;
    }


}
