<?php

namespace App\Http\Controllers;

use App\Models\Wf_tasks;
use Illuminate\Http\Request;
use App\Traits\Util;

class TaskController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $tasks = Wf_tasks::orderBy('id','DESC')->paginate(15);
        return view ('workFlow.task_index', ['tasks' => $tasks]);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('workFlow.task_create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $task = $request->input('task');
        $street = $request->input('street');
        $request->validate([
            'task' => 'required'
        ]);
        $create = Wf_tasks::create([
            'task' => $task,
            'street' => $street
        ]);

        if($create)
            return redirect()->route('task.index')->with('success', __("Data successfully added"));
        else
            return redirect()->route('task.index')->with('error', __("Error"));
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Models\Wf_tasks  $tasks
     * @return \Illuminate\Http\Response
     */
    public function show(Wf_tasks $task)
    {
        return view('workFlow.task_show', ['task' => $task]);
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Models\Wf_tasks  $task
     * @return \Illuminate\Http\Response
     */
    public function edit(Wf_tasks $task)
    {
        return view('workFlow.task_edit', ['task' => $task]);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Models\Wf_tasks  $tasks
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Wf_tasks $task)
    {
        $taskName = $request->input('task');
        $street = $request->input('street');
        $request->validate([
            'task' => 'required'
            ]);
        $update = Wf_tasks::where('id', $task->id)->update([
            'task' => $taskName,
            'street' => $street
        ]);

        if($update)
            return redirect()->route('task.show', ['task' => $task])->with('success', __("Data successfully changed"));
        else
            return redirect()->route('task.index')->with('error', __("Error"));
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function destroy(Request $request)
    {
        $taskId = $request->input('id_task');
        $delete = Wf_tasks::where('id', $taskId)->delete();
        if($delete)
            return back()->with('success', __("Data successfully deleted"));
        else
            return back()->with('error', __("Data cannot be deleted"));
    }
}
