<?php

namespace App\Http\Controllers;

use App\Models\Tool_types;
use Illuminate\Http\Request;

class ToolTypesController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $toolTypes = Tool_types::all();
        return view('toolTypes.index', ['toolTypes' => $toolTypes]);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('toolTypes.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $request->validate(['type' => 'required']);
        $create = Tool_types::create([
            'type' => trim($request->input('type'))
        ]);
        if ($create){
            return redirect()->route('tool_type.show', ['tool_type' => $create->id])->with('success', __("Data successfully added"));
        }
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Tool_types  $tool_type
     * @return \Illuminate\Http\Response
     */
    public function show(Tool_types $tool_type)
    {
        $type = Tool_types::find($tool_type->id);
        return view('toolTypes.show', ['type' => $type]);
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Tool_types  $tool_type
     * @return \Illuminate\Http\Response
     */
    public function edit(Tool_types $tool_type)
    {
        $type = Tool_types::find($tool_type->id);
        return view('toolTypes.edit', ['type' => $type]);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Tool_types  $tool_type
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Tool_types $tool_type)
    {
        $request->validate(['type' => 'required']);
        $update = Tool_types::where('id', $tool_type->id)->update([
            'type' => $request->input('type')
        ]);

        if ($update){
            return redirect()->route('tool_type.show', ['tool_type' => $tool_type->id])->with('success', __("Data successfully changed"));
        }
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function destroy(Request $request)
    {
        $find = Tool_types::find($request->input('id_type'));

        try{
            $find->delete();
            return back()->withInput()->with('success', __("Data successfully deleted"));
        }
        catch (\Illuminate\Database\QueryException $e){
            return back()->withInput()->with('error', __("Data cannot be deleted"));
        }

        return back()->withInput()->with('error', __("Error"));
    }
}
