<?php

namespace App\Http\Controllers;

use App\Models\Tool_origins;
use App\Models\Tool_providers;
use App\Models\Tool_types;
use App\Models\Tools;
use Illuminate\Http\Request;

class ToolsController extends Controller
{
    public function index()
    {
        $tMod = new Tools();
        $tools = $tMod->index();
        return view('tools.index', ['tools' => $tools]);
    }

    public function create()
    {
        $toolTypes = Tool_types::all();
        $providers = Tool_providers::all();
        $origins = Tool_origins::all();
        return view('tools.create', ['toolTypes' => $toolTypes, 'providers' => $providers, 'origins' => $origins]);
    }

    public function store(Request $request)
    {
        $request->merge([
            'price' => str_replace(',', '.', $request->input('price'))
        ]);
        $request->validate(['tool' => 'required', 'price' => 'numeric']);
        $create = Tools::create([
            'tool' => trim($request->input('tool')),
            'type_id' => $request->input('type'),
            'provider_id' => $request->input('provider'),
            'invoice_number' => $request->input('invoice_number'),
            'origin_id' => $request->input('origin'),
            'serial_number' => $request->input('serial_number'),
            'price' => $request->input('price')
        ]);
        if ($create){
            return redirect()->route('tool.show', ['tool' => $create->id])->with('success', __("Data successfully added"));
        }
    }

    public function show(Tools $tool)
    {
        $toolData = $tool->toolData($tool->id);
        return view('tools.show', ['tool' => $toolData]);
    }

    public function edit(Tools $tool)
    {
        $toolTypes = Tool_types::all();
        $providers = Tool_providers::all();
        $origins = Tool_origins::all();
        return view('tools.edit', ['tool' => $tool, 'toolTypes' => $toolTypes, 'providers' => $providers, 'origins' => $origins]);
    }

    public function update(Request $request, Tools $tool)
    {
        $request->merge([
            'price' => str_replace(',', '.', $request->input('price'))
        ]);
        $request->validate(['tool' => 'required', 'price' => 'numeric']);
        $update = Tools::where('id',$tool->id)->update([
            'tool' => trim($request->input('tool')),
            'type_id' => $request->input('type'),
            'provider_id' => $request->input('provider'),
            'invoice_number' => $request->input('invoice_number'),
            'origin_id' => $request->input('origin'),
            'serial_number' => $request->input('serial_number'),
            'price' => $request->input('price')
        ]);
        if ($update){
            return redirect()->route('tool.show', ['tool' => $tool->id])->with('success', __("Data successfully changed"));
        }
    }

    public function destroy(Request $request)
    {
        $find = Tools::find($request->input('id_tool'));

        try{
            $find->delete();
            return back()->withInput()->with('success', __("Data successfully deleted"));
        }
        catch (\Illuminate\Database\QueryException $e){
            return back()->withInput()->with('error', __("Data cannot be deleted"));
        }

        return back()->withInput()->with('error', __("Error"));
    }
}
