<?php

namespace App\Http\Controllers;

use App\Models\Units;
use Illuminate\Http\Request;

class UnitController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $units = Units::all();
        return view('units.index', ['units' => $units]);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('units.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $request->validate(['unit' => 'required', 'unit_short' => 'required']);
        $unit = Units::create([
            'unit' => trim($request->input('unit')),
            'unit_short' => $request->input('unit_short')
        ]);
        if ($unit){
            return redirect()->route('unit.show', ['unit' => $unit])->with('success', __("Item successfully added"));
        }
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Units  $unit
     * @return \Illuminate\Http\Response
     */
    public function show(Units $unit)
    {
        $unit = Units::find($unit->id);
        return view('units.show', ['unit' => $unit]);
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Units  $unit
     * @return \Illuminate\Http\Response
     */
    public function edit(Units $unit)
    {
        $unit = Units::find($unit->id);
        return view('units.edit', ['unit' => $unit]);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Units  $unit
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Units $unit)
    {
        $request->validate(['unit' => 'required', 'unit_short' => 'required']);
        $unitUpdate = Units::where('id', $unit->id)->update([
            'unit' => trim($request->input('unit')),
            'unit_short' => $request->input('unit_short')
        ]);

        if ($unitUpdate){
            return redirect()->route('unit.show', ['unit' => $unit])->with('success', __("Item successfully changed"));
        }
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function destroy(Request $request)
    {
        $find = Units::find($request->input('id_unit'));

        try{
            $find->delete();
            return back()->withInput()->with('success', __("Item successfully deleted"));
        }
        catch (\Illuminate\Database\QueryException $e){
            return back()->withInput()->with('error', __("Item can't be deleted because it's in use"));
        }

        return back()->withInput()->with('error', __("Error"));
    }
}
