<?php

namespace App\Http\Controllers;

use App\Models\Card_types;
use App\Models\Companies;
use App\Models\Vehicle_cards;
use Illuminate\Http\Request;

class VehicleCardsController extends Controller
{
    public function index()
    {
        $cardModel = new Vehicle_cards();
        $cards = $cardModel->cards();
        return view('vehicleCards.index', ['cards' => $cards]);
    }

    public function create()
    {
        $companies = Companies::all();
        $types = Card_types::all();
        return view('vehicleCards.create', ['companies' => $companies, 'types' => $types]);
    }

    public function store(Request $request)
    {
        $request->validate(['card_number' => 'required']);
        $card = Vehicle_cards::create([
            'card_number' => trim($request->input('card_number')),
            'company_id' => $request->input('company'),
            'type_id' => $request->input('type')
        ]);

        if ($card){
            return redirect()->route('vehicle_cards.show', ['vehicle_card' => $card])->with('success', __("Data successfully added"));
        }
    }

    public function show(Vehicle_cards $vehicle_card)
    {
        $cardMod = new Vehicle_cards();
        $card = $cardMod->card_data($vehicle_card->id);
        return view('vehicleCards.show', ['card' => $card]);
    }

    public function edit(Vehicle_cards $vehicle_card)
    {
        $cardMod = new Vehicle_cards();
        $card = $cardMod->card_data($vehicle_card->id);
        $companies = Companies::all();
        $types = Card_types::all();
        return view('vehicleCards.edit', ['card' => $card, 'companies' => $companies, 'types' => $types]);
    }

    public function update(Request $request, Vehicle_cards $vehicle_card)
    {
        $cardNumber = $request->input('card_number');
        $company = $request->input('company');
        $type = $request->input('type');
        $create = Vehicle_cards::where('id', $vehicle_card->id)->update([
            'card_number' => $cardNumber,
            'company_id' => $company,
            'type_id' => $type
        ]);
        if($create){
            return redirect()->route('vehicle_cards.show', ['vehicle_card' => $vehicle_card])->with('success', __("Data successfully changed"));
        }
    }

    public function destroy(Request $request)
    {
        $find = Vehicle_cards::find($request->input('card_id'));

        try{
            $find->delete();
            return back()->withInput()->with('success', __("Data successfully deleted"));
        }
        catch (\Illuminate\Database\QueryException $e){
            return back()->withInput()->with('error', __("Data cannot be deleted"));
        }

        return back()->withInput()->with('error', __("Data cannot be deleted"));
    }
}
