<?php

namespace App\Http\Controllers;

use App\Models\Vehicle_images;
use App\Traits\Util;
use App\User;
use App\Models\Vehicle_user;
use App\Models\Vehicle_comments;
use App\Vozila;
use Illuminate\Http\Request;
use Intervention\Image\ImageManager as Img;

class VehicleController extends Controller
{
    private function allowedUsers(){
        $allowedUsers = explode(',',env('ALLOWED_USERS_VEHICLES'));
        return $allowedUsers;
    }

    private function returnBackIfNotAllowed(){
        if(!in_array(Util::userId(), $this->allowedUsers()))
            return true;
        else
            return false;
    }

    public function vehicle_rent(){
        $vehicles = Vozila::all();
        $users = User::all();
        return view('administracija.vehicle_rent', ['vehicles' => $vehicles, 'users' => $users]);
    }

    public function rent_a_vehicle(Request $request){
        $vehicle = $request->input('vehicle');
        $user = $request->input('worker');
        $rentDate = database_date_time($request->input('rent_date'), date('H:i'));
        $returnDate = database_date_time($request->input('return_date'), date('H:i'));
        $imageType = $request->input('image_type');
        $comment = $request->input('comment');
        $color = $request->input('color');
        $request->validate([
            'vehicle' => 'required',
            'worker' => 'required'
        ]);

        $create = Vehicle_user::create([
            'vehicle_id' => $vehicle,
            'user_id' => $user,
            'rent_date' => $rentDate,
            'return_date' => $returnDate,
            'updated_by' => Util::userId(),
            'color' => $color
        ]);

        if($create){
            Vozila::where('id', $vehicle)->update([
                'id_user' => $user
            ]);
            if($comment){
                Vehicle_comments::create([
                    'comment' => $comment,
                    'vehicle_user_id' => $create->id,
                    'created_by' => Util::userId()
                ]);
            }
        }

        $pictures = $request->file('pictures');
        $img = new Img();
        $folder = 'uploads/vehicle_images/'.quartal();
        if (!file_exists($folder)){
            mkdir($folder, 0755, true);
        }

        if($pictures){
            $this->validate($request, [
                'pictures.*' => 'image|mimes:jpeg,png,jpg,gif'
            ]);
            $num = 0;
            foreach($pictures as $file){
                $extension = $file->getClientOriginalExtension();
                $filename = time().$num.'-vozilo.'.$extension;
                $num++;
                $fileInt = $img->make($file->getRealPath());
                $fileInt->save($folder.'/'.$filename, 50);
                Vehicle_images::create([
                    'image_url' => '/'.$folder.'/'.$filename,
                    'vehicle_user_id' => $create->id,
                    'type_id' => $imageType
                ]);
            }
        }
        if($create)
            return redirect()->route('vehicle_rent_list')->with('success', __("Vehicle successfully rented"));
        else
            return redirect()->route('vehicle_rent_list')->with('error', __("Error"));
    }
    public function vehicle_rent_list(Request $request){
        $vehicleId = $request->input('vehicle_id');
        $vMod = new Vehicle_user();
        $rents = $vMod->rent_list($vehicleId);
        $allowedUsers = $this->allowedUsers();
        return view('administracija.vehicle_rent_list', ['rents' => $rents, 'allowedUsers' => $allowedUsers]);
    }

    public function vehicle_images(Request $request){
        $id = $request->input('id');
        $iMod = new Vehicle_images();
        $rentImages = $iMod->images($id,0);
        $returnImages = $iMod->images($id,1);
        $vMod = new Vehicle_user();
        $rent = $vMod->rent_data($id);
        $cMod = new Vehicle_comments();
        $comments = $cMod->comments($id);
        $allowedUsers = $this->allowedUsers();

        return view('administracija.vehicle_rent_images', ['rent' => $rent, 'rentImages' => $rentImages, 'returnImages' => $returnImages, 'comments' => $comments, 'allowedUsers' => $allowedUsers]);
    }

    public function vehicle_rent_edit(Vehicle_user $rent){
        $iMod = new Vehicle_images();
        $rentImages = $iMod->images($rent->id,0);
        $returnImages = $iMod->images($rent->id,1);
        $vehicles = Vozila::all();
        $users = User::all();
        $cMod = new Vehicle_comments();
        $comments = $cMod->comments($rent->id);

        return view('administracija.vehicle_rent_edit', [
            'vehicles' => $vehicles,
            'users' => $users,
            'rentImages' => $rentImages,
            'returnImages' => $returnImages,
            'rent' => $rent,
            'comments' => $comments
        ]);
    }

    public function vehicle_rent_update(Vehicle_user $rent, Request $request){
        if($this->returnBackIfNotAllowed())
            return back()->with('error', __("Error"));
        $vehicle = $request->input('vehicle');
        $user = $request->input('worker');
        $color = $request->input('color');
        $changeRentDate = true;
        $changeReturnDate = true;
        //don't change date if it's the same as before
        if(database_date($rent->rent_date) == database_date($request->input('rent_date')))
            $changeRentDate = false;
        if(database_date($rent->return_date) == database_date($request->input('return_date')))
            $changeReturnDate = false;
        $rentDate = database_date_time($request->input('rent_date'), date('H:i'));
        $returnDate = database_date_time($request->input('return_date'), date('H:i'));
        $imageType = $request->input('image_type');
        $comment = $request->input('comment');
        $request->validate([
            'vehicle' => 'required',
            'worker' => 'required'
        ]);
        Vehicle_user::where('id', $rent->id)->update([
            'vehicle_id' => $vehicle,
            'user_id' => $user,
            'updated_by' => Util::userId(),
            'color' => $color
        ]);
        if($changeRentDate){
            Vehicle_user::where('id', $rent->id)->update([
                'rent_date' => $rentDate
            ]);
        }
        if($changeReturnDate){
            Vehicle_user::where('id', $rent->id)->update([
                'return_date' => $returnDate
            ]);
        }

        if($comment){
            Vehicle_comments::create([
                'comment' => $comment,
                'vehicle_user_id' => $rent->id,
                'created_by' => Util::userId()
            ]);
        }

        $pictures = $request->file('pictures');
        $img = new Img();
        $folder = 'uploads/vehicle_images/'.quartal();
        if (!file_exists($folder)){
            mkdir($folder, 0755, true);
        }

        if($pictures){
            $this->validate($request, [
                'pictures.*' => 'image|mimes:jpeg,png,jpg,gif'
            ]);
            $num = 0;
            foreach($pictures as $file){
                $extension = $file->getClientOriginalExtension();
                $filename = time().'-'.$num.'-vozilo.'.$extension;
                $num++;
                $fileInt = $img->make($file->getRealPath());
                $fileInt->save($folder.'/'.$filename, 50);
                Vehicle_images::create([
                    'image_url' => '/'.$folder.'/'.$filename,
                    'vehicle_user_id' => $rent->id,
                    'type_id' => $imageType
                ]);
            }
        }
        return redirect()->route('vehicle_images', ['id' => $rent->id])->with('success', __("Vehicle successfully rented"));
    }

    public function vehicle_image_delete(Request $request){
        $id = $request->input('image_id');
        Vehicle_images::find($id)->delete();
        return back()->with('success', __("Image successfully deleted"));
    }

    public function vehicle_delete_comment(Request $request){
        $id = $request->input('id_comment');
        $find = Vehicle_comments::find($id);
        if($find->delete()){
            return back()->with('success', __("Comment successfully deleted"));
        }
        else{
            return back()->with('error', __("Error"));
        }
    }

    public function delete_rent(Request $request){
        $rentId = $request->input('id_rent');
        $images = Vehicle_images::where('vehicle_user_id', $rentId)->get();
        $find = Vehicle_user::find($rentId);
        try{
            if($find->delete()){
                foreach ($images as $img){
                    $file = ltrim($img->image_url,'/');
                    if (file_exists($file)){
                        unlink($file);
                    }
                }
                return back()->with('success', __("Data successfully deleted"));
            }
        }
        catch(\Illuminate\Database\QueryException $e){
            return back()->with('error', __("Error"));
        }
    }
}
