<?php

namespace App\Http\Controllers;

use App\Models\Wf_task_images;
use App\Models\Wf_task_equipment;
use App\Traits\Util;
use App\Models\Worker_equipment;
use App\Models\Wf_task_work;
use App\Models\Wf_project_task;
use App\Models\Wf_projects;
use App\Models\Wf_task_files;
use App\Models\Wf_tasks;
use App\User;
use Illuminate\Http\Request;
use Illuminate\Support\Arr;
use Intervention\Image\ImageManager as Img;
use PhpOffice\PhpSpreadsheet\Spreadsheet;
use PhpOffice\PhpSpreadsheet\Writer\Xlsx;
use Symfony\Component\HttpFoundation\StreamedResponse;

class WorkflowController extends Controller
{
    protected function check_quantity($quantity){
        if(is_numeric($quantity))
        {
            if($quantity < 0)
                return 0;
            else
                return $quantity;
        }
        else 
        {
            return 0;
        }
    }

    public function search(){
        $users = User::all();
        return view('workFlow.project_search', ['users' => $users, 'isAdmin' => Util::isAdmin()]);
    }

    public function search_result(Request $request){
        $project = $request->input('project');
        $startDate = $request->input('start_date');
        $endDate = $request->input('end_date');
        $user = $request->input('user');
        $percentageStart = $request->input('percentage_start');
        $percentageEnd = $request->input('percentage_end');
        $percentageIsSet = false;

        $startDate = database_date($startDate);
        $endDate = database_date($endDate);

        $projectModel = new Wf_projects();
        if(Util::isAdmin()){
            $result = $projectModel->search($project, $startDate, $endDate, $user, true);
            $resultNoPag = $projectModel->search($project, $startDate, $endDate, $user);
        }
        else {
            $result = $projectModel->searchOtherUsers(Util::userId(), $project, $startDate, $endDate, true);
            $resultNoPag = $projectModel->searchOtherUsers(Util::userId(), $project, $startDate, $endDate);
        }
        if($percentageStart && $percentageEnd){
            $percentageIsSet = true;
            $tMod = new Wf_project_task();
            $selected = array();
            foreach($resultNoPag as $item){
                $done = $tMod->doneUndone($item->id, 1);
                $undone = $tMod->doneUndone($item->id, 0);
                if($undone->isEmpty())
                    $totalProgress = 100;
                elseif(!$done->isEmpty())
                    $totalProgress = number_format($done->count()*100/($done->count()+$undone->count()));
                else
                    $totalProgress = 0;

                if(($totalProgress >= $percentageStart) && ($totalProgress <= $percentageEnd)){
                    $selected[] = $item;
                }
            }
            $result = $selected;
            $resultNoPag = $selected;
        }

        $ids = Arr::pluck($resultNoPag, 'id');
        $count = count($ids);
        $ids = json_encode($ids);
        session(['ids_export' => $ids]);

        $tMod = new Wf_project_task();
        $wMod = new Wf_task_work();
        $taskMod = new Wf_tasks();
        $allTasks = $taskMod->tasks();
        return view('workFlow.project_search_result', ['projects' => $result, 'isAdmin' => Util::isAdmin(), 'tMod' => $tMod, 'wMod' => $wMod, 
        'allTasks' => $allTasks, 'percentageIsSet' => $percentageIsSet, 'count' => $count]);
    }

    public function delete_task(Request $request){
        $project_id = $request->input('project_id');
        $task_id = $request->input('task_id');
        $delete = Wf_project_task::where('task_id', $task_id)->where('project_id', $project_id)->delete();
        if($delete){
            Wf_task_work::where('task_id', $task_id)->delete();
            return back()->with('success', __("Project successfully deleted"));
        }
        else
            return back()->with('error', __("Error"));
    }

    public function add_work(Request $request){
        $taskId = $request->input('w_task_id');
        $id = $request->input('pt_id');
        $quantity = $request->input('quantity');
        $works = $request->input('work');

        if($works){
            foreach($works as $work){
                Wf_task_work::create([
                    'task_id' => $taskId,
                    'work_id' => $work,
                    'project_task_id' => $id,
                    'quantity' => $quantity
                ]);
            }
            return back()->with('success', __("Work successfully added"));
        }
    }

    public function delete_work(Request $request){
        $ptId = $request->input('d_pt_id');
        $taskId = $request->input('d_task_id');
        $workId = $request->input('d_work_id');
        $findWork = Wf_task_work::where('task_id', $taskId)->where('work_id', $workId)->where('project_task_id', $ptId);
        $images = Wf_task_images::where('project_task_id', '=', $ptId)->where('work_id', '=', $workId)->get();
        $files = Wf_task_files::where('project_task_id', '=', $ptId)->where('work_id', '=', $workId)->get();
        if($findWork->delete()){
            foreach($images as $img){
                $file = ltrim($img->image_url,'/');
                if (file_exists($file)){
                    unlink($file);
                }
            }
            foreach($files as $f){
                $file = ltrim($f->file_url,'/');
                if (file_exists($file)){
                    unlink($file);
                }
            }
            return back()->with('success', __("Work successfully deleted"));
        }
        else
            return back()->with('error', __("Error"));
            
    }

    public function mark_done(Request $request){
        $ptId = $request->input('m_pt_id');
        $taskId = $request->input('m_task_id');
        $workId = $request->input('m_work_id');
        $done = $request->input('done');

        $update = Wf_task_work::where('task_id', $taskId)
        ->where('work_id', $workId)
        ->where('project_task_id', $ptId)
        ->update([
            'done' => $done
        ]);
        $hasUndone = Wf_task_work::where('project_task_id', $ptId)
            ->where('done', 0)
            ->get();
        if($hasUndone->isEmpty()){
            Wf_project_task::where('id', $ptId)->update([
                'done' => 1
            ]);
        }
        else {
            Wf_project_task::where('id', $ptId)->update([
                'done' => 0
            ]);
        }
        return back()->with('success', __("Works are marked as finished"));
    }

    public function add_user(Request $request){
        $id = $request->input('u_pt_id');
        $worker = $request->input('worker');

        Wf_project_task::where('id', $id)->update([
            'user_id' => $worker
        ]);

        return back()->with('success', 'Radnik uspešno dodat.');

    }

    public function add_task_time(Request $request){
        $id = $request->input('t_pt_id');
        $startDate = $request->input('start_date');
        $endDate = $request->input('end_date');
        $startTime = $request->input('start_time');
        $endTime = $request->input('end_time');
        $startDate = database_date_time($startDate, $startTime);
        $endDate = database_date_time($endDate, $endTime);
        if($startDate && $endDate){
            Wf_project_task::where('id', $id)->update([
                'start_date' => $startDate,
                'end_date' => $endDate
            ]);
            return back()->with('success', __("Dates successfully added"));
        }
        else {
            return back()->with('error', __("Dates are required"));
        }
    }

    public function add_status(Request $request){
        $id = $request->input('s_pt_id');
        $status = $request->input('status');
        Wf_project_task::where('id', $id)->update([
            'status_id' => $status
        ]);
        return back()->with('success', __("Data successfully added"));
    }

    public function add_equipment(Request $request){
        $role = $request->input("role");
        $userId = Util::userId();
        $equipmentId = $request->input('equipment');
        $quantity = $request->get('quantity');
        $quantity = $this->check_quantity($quantity);
        $taskId = $request->input('e_pt_id');
        $wModel = new Worker_equipment();
        if($quantity <= 0)
            return back()->with('error', __("You must enter quantity"));
        if(!$equipmentId)
            return back()->with('error', __("Equipment field is required"));
        if($role == 'admin'){
            if($equipmentId){
                Wf_task_equipment::create([
                    'task_id' => $taskId,
                    'equipment_id' => $equipmentId,
                    'quantity' => $quantity
                ]);
                return back()->with('success', __("Equipment successfully added"));
            }
            else {
                return back()->with('success', __("you must choose equipment"));
            }
        }
        else{
            $workerEquipment = $wModel->specific_equipment($userId, $equipmentId);
            if(isset($workerEquipment->quantity))
                $workerQuantity = $workerEquipment->quantity;
            else
                $workerQuantity = 0;
            if($workerQuantity - $quantity < 0){
                return back()->with('error', __("You don't have that much equipment"));
            }
            else{
                if($workerEquipment && $equipmentId){
                    Wf_task_equipment::create([
                        'task_id' => $taskId,
                        'equipment_id' => $equipmentId,
                        'quantity' => $quantity
                    ]);
                    $wModel->equipment_update($userId, $equipmentId, -$quantity);
                    return back()->with('success', __("Equipment successfully added"));
                }
                else{
                    return back()->with('error', __("You don't have that much equipment"));
                }
            }
        }
    }

    public function images_form(Request $request){
        return view('workFlow.images_form', ['ptId' => $request->input('i_pt_id'), 'workId' => $request->input('i_work_id'), 'projectId' => $request->input('i_project_id')]);
    }

    public function upload_images(Request $request){
        $images = $request->file('images');
        $ptId = $request->input('pt_id');  
        $workId = $request->input('work_id');
        $projectId = $request->input('project_id');
        $img = new Img();
        $createImage = false;
        $folder = 'uploads/workflow_images/'.quartal();
        create_folder($folder);

        if($images){
            $this->validate($request, [
                'pictures.*' => 'image|mimes:jpeg,png,jpg,gif',
            ]);
            foreach($images as $key=>$file){
                $extension = $file->getClientOriginalExtension();
                $filename = time().$key.__('workflow').'.'.$extension;
                $fileInt = $img->make($file->getRealPath());
                $fileInt->save($folder.'/'.$filename, 50);
                $createImage = Wf_task_images::create([
                    'image_url' => '/'.$folder.'/'.$filename,
                    'project_task_id' => $ptId,
                    'work_id' => $workId
                ]);
            }
        }
        if($createImage){
            if(!$projectId)
                $projectId = Wf_project_task::find($ptId)->project_id;
            return redirect()->route('wf_images', [$ptId, $workId,$projectId]);
        }
        else {
            return back()->with('error', __('Error'));
        }
    }

    public function images($ptId, $workId, $projectId){
        $iMod = new Wf_task_images();
        $images = $iMod->images($ptId, $workId);
        $isAdmin = Util::isAdmin() || Util::isSuperAdmin();
        return view('workFlow.images', ['images' => $images, 'projectId'=>$projectId, 'isAdmin' => $isAdmin]);
    }

    public function delete_image(Request $request){
        $findImage = Wf_task_images::find($request->input('id_image'));
        $file = ltrim($findImage->image_url,'/');

        if(file_exists($file)){
            unlink($file);
        }

        if($findImage->delete()){
            return back()->with('success', __("Image successfully deleted"));
        }
        else {
            return back()->with('errors', __("Error"));
        }
    }

    public function files_form(Request $request){
        return view('workFlow.files_form', ['ptId' => $request->input('f_pt_id'), 'workId' => $request->input('f_work_id'), 'projectId' => $request->input('f_project_id')]);
    }

    public function upload_files(Request $request){
        $files = $request->file('files');
        $ptId = $request->input('pt_id');  
        $workId = $request->input('work_id');
        $projectId = $request->input('project_id');
        $folder = 'uploads/documents/'.quartal();
        create_folder($folder);


        if($files){
            $this->validate($request, [
                'files.*' => 'mimes:zip,dwg,pdf,msg',
            ]);
            $num = 0;
            foreach($files as $file){
                $originalFile = $file->getClientOriginalName();
                $filename = pathinfo($originalFile, PATHINFO_FILENAME);
                $extension = pathinfo($originalFile, PATHINFO_EXTENSION);
                $filename = $filename.'-'.time().'-'.$num.'.'.$extension;
                $file->move($folder, $filename);
                $createFile = Wf_task_files::create([
                    'file_url' => '/'.$folder.'/'.$filename,
                    'file_name' => $filename,
                    'project_task_id' => $ptId,
                    'work_id' => $workId
                ]);
                if($createFile){
                    if(!$projectId)
                        $projectId = Wf_project_task::find($ptId)->project_id;
                    return redirect()->route('wf_files', [$ptId, $workId,$projectId]);
                }
                $num++;
             }
        }
        else {
            return back()->with('error', __('Error'));
        }
    }

    public function files($ptId, $workId, $projectId){
        $fMod = new Wf_task_files();
        $files = $fMod->files($ptId, $workId);
        $isAdmin = Util::isAdmin() || Util::isSuperAdmin();
        return view('workFlow.files', ['files' => $files, 'projectId'=>$projectId, 'isAdmin' => $isAdmin]);
    }

    public function delete_file(Request $request){
        $find = Wf_task_files::find($request->input('id_file'));
        $file = ltrim($find->file_url,'/');

        if(file_exists($file)){
            unlink($file);
        }

        if($find->delete()){
            return back()->with('success', __("File successfully deleted"));
        }
        else {
            return back()->with('errors', __("Error"));
        }
    }

    private function done($wMod,$task){
        $specificWorks = $wMod->works($task); 
        $doneWorks = 0;
        $undoneWorks = 0; 
        $done = 0;
        foreach($specificWorks as $swork){
            if($swork->done == 0) {
                $undoneWorks++;
            }
            else {
                $doneWorks++;
            }
        }
        if($doneWorks > 0 || $undoneWorks > 0)
            $done = number_format($doneWorks*100/($doneWorks+$undoneWorks));

        return $done;
    }

    public function export(){
        require '../vendor/autoload.php';
        $ids = session('ids_export');
        $ids = json_decode($ids);

        $spreadsheet = new Spreadsheet();
        $sheet = $spreadsheet->getActiveSheet();

        $sheet->getColumnDimension('A')->setAutoSize(true);
        $sheet->getColumnDimension('B')->setAutoSize(true);
        $sheet->getColumnDimension('C')->setAutoSize(true);
        $sheet->getColumnDimension('D')->setAutoSize(true);
        $sheet->getColumnDimension('E')->setAutoSize(true);
        $sheet->getColumnDimension('F')->setAutoSize(true);
        $sheet->getColumnDimension('G')->setAutoSize(true);
        $sheet->getColumnDimension('H')->setAutoSize(true);
        $sheet->getColumnDimension('I')->setAutoSize(true);
        $sheet->getColumnDimension('J')->setAutoSize(true);

        $sheet->setCellValue('A1', __("PROJEKAT"));
        $sheet->setCellValue('B1', __("PERIOD"));
        $sheet->setCellValue('C1', __("AKVIZICIJA"));
        $sheet->setCellValue('D1', __("PRIPREMA PODLOGA"));
        $sheet->setCellValue('E1', __("OBILAZAK"));
        $sheet->setCellValue('F1', __("PROJEKTOVANJE"));
        $sheet->setCellValue('G1', __("SAGLASNOST"));
        $sheet->setCellValue('H1', __("PREDMER"));
        $sheet->setCellValue('I1', __("UKUPNI PROGRES"));
        $sheet->setCellValue('J1', __("KORISNIK"));


        $sheet->getStyle('A1:J1')->getAlignment()->setHorizontal('center');

        $sheet->getStyle('A1:J1')->getFill()->setFillType(\PhpOffice\PhpSpreadsheet\Style\Fill::FILL_SOLID)->getStartColor()->setARGB('8c8c8c');

        $tMod = new Wf_project_task();
        $wMod = new Wf_task_work();
        $projectMod = new Wf_projects();
        
        foreach ($ids as $br=>$id){
            $project = $projectMod->projectShow($id);
            $done = $tMod->doneUndone($id, 1);
            $undone = $tMod->doneUndone($id, 0);
            if($undone->isEmpty())
                $totalProgress = 100;
            elseif(!$done->isEmpty())
                $totalProgress = number_format($done->count()*100/($done->count()+$undone->count()));
            else
                $totalProgress = 0;

            $akvizicija = $tMod->specificTask($id, 3);
            $pripremaPodloga = $tMod->specificTask($id, 5);
            $obilazak = $tMod->specificTask($id, 6);
            $projektovanje = $tMod->specificTask($id, 1);
            $saglasnost = $tMod->specificTask($id, 2);
            $predmer = $tMod->specificTask($id, 7);

            $akvizicijaDone = $this->done($wMod, $akvizicija);
            $pripremaDone = $this->done($wMod, $pripremaPodloga);
            $projektovanjeDone = $this->done($wMod, $projektovanje);
            $obilazakDone = $this->done($wMod, $obilazak);
            $saglasnostDone = $this->done($wMod, $saglasnost);
            $predmerDone = $this->done($wMod, $predmer);




            $sheet->getStyle('A'.($br+2).':J'.($br+2))->getAlignment()->setHorizontal('left');
            $sheet->setCellValue('A'.($br+2), $project->project_name);
            $sheet->setCellValue('B'.($br+2), date('d.m.Y.', strtotime($project->start_date)).' - '.date('d.m.Y.', strtotime($project->end_date)));
            $sheet->setCellValue('C'.($br+2), $akvizicijaDone.'%');
            $sheet->setCellValue('D'.($br+2), $pripremaDone.'%');
            $sheet->setCellValue('E'.($br+2), $projektovanjeDone.'%');
            $sheet->setCellValue('F'.($br+2), $obilazakDone.'%');
            $sheet->setCellValue('G'.($br+2), $saglasnostDone.'%');
            $sheet->setCellValue('H'.($br+2), $predmerDone.'%');
            $sheet->setCellValue('I'.($br+2), $totalProgress.'%');
            $sheet->setCellValue('J'.($br+2), $project->name.' '.$project->surname);

        }

        $streamedResponse = new StreamedResponse();
        $streamedResponse->setCallback(function() use ($spreadsheet){
            $writter = new Xlsx($spreadsheet);
            $writter->save('php://output');
        });

        $streamedResponse->setStatusCode(200);
        $streamedResponse->headers->set('Content-Type', 'application/vnd.openxmlformats-officedocument.spreadsheetml.sheet');
        $streamedResponse->headers->set('Content-Disposition', 'attachment; filename="projects.xlsx"');
        return $streamedResponse->send();
    }
    
}
