<?php

namespace App;

use Illuminate\Database\Eloquent\Model;
use Illuminate\Support\Facades\DB;

class Klijent extends Model
{
    //
    protected $table = 'klijent';
    protected $fillable = [
        'br_ugovora',
        'ime',
        'prezime',
        'jmbg',
        'mrezna_grupa',
        'tel1',
        'tel2',
        'tel3',
        'tis_id',
        'broj_lk',
        'datum_izdavanja_lk',
        'mesto_izdavanja_lk',
        'adresa_prebivalista',
        'adresa_instalacije',
        'paket',
        'vrsta_paketa',
        'nov_servis',
        'dodatni_stb',
        'broj_bodova',
        'izvodjac_prodavac',
        'prodavac',
        'izvodjac',
        'datum_montaze',
        'lnb',
        'stb1',
        'stb2',
        'adsl',
        'vdsl',
        'mifi_imei',
        'mifi_iccd',
        'datum_odustajanja',
        'razlog_odustajanja',
        'napomena',
        'id_status',
        'datum_zakazivanja',
        'datum_odlaganja',
        'id_user',
        'datum_dodavanja',
        'created_by',
        'imported',
        'datum_zahteva',
        'complaint',
        'id_status_intervencije',
        'datum_intervencije',
        'id_user_reklamacije',
        'datum_reklamacije',
        'id_klijent_prodaja',
        'for_payment',
        'id_razlog_reklamacije',
        'helper',
        'on_terrain',
        'filed',
        'company_id',
        'price'
    ];

    public function klijentiPregled($userId){
        $query = DB::table('klijent as k')
            ->leftJoin('statusi as s', 's.id', '=', 'k.id_status')
            ->leftJoin('users as u', 'u.id', '=', 'k.id_user')
            ->select('k.id', 'k.br_ugovora', 'k.ime', 'k.prezime', 'k.jmbg', 'k.tel1', 'k.tel2', 'k.tel3', 'u.ime as user_ime',
                'k.adresa_instalacije', 'u.prezime as user_prezime', 's.status', 'k.created_at', 'k.datum_zahteva', 'k.datum_zakazivanja', 'k.datum_odustajanja', 'k.mrezna_grupa')
            ->where('id_user', '=', $userId)
            ->orderby('datum_dodavanja', 'DESC')
        ;
        $result = $query->paginate(20);

        return $result;
    }

    public function klijentPodaci($klijentId){
        $query = DB::table('klijent as k')
            ->leftJoin('users as u', 'u.id', '=', 'k.id_user')
            ->leftJoin('statusi as s', 's.id', '=', 'k.id_status')
            ->leftJoin('users as usr', 'usr.id', '=', 'k.created_by')
            ->leftJoin('statusi_intervencije as stsi', 'stsi.id', '=', 'k.id_status_intervencije')
            ->leftJoin('users as rek', 'rek.id', '=', 'k.id_user_reklamacije')
            ->leftJoin('razlozi_intervencije as rzi', 'rzi.id', '=', 'k.id_razlog_reklamacije')
            ->leftJoin('pomocnici as p', 'p.id', '=', 'k.helper')
            ->leftJoin('companies as com', 'com.id', '=', 'k.company_id')
            ->selectRaw('k.id, k.br_ugovora, k.ime, k.prezime, k.jmbg, k.mrezna_grupa, k.tel1, k.tel2, k.tel3, k.tis_id, k.broj_lk, k.datum_izdavanja_lk,
                        k.mesto_izdavanja_lk, k.adresa_prebivalista, k.adresa_instalacije, k.paket, k.vrsta_paketa, k.nov_servis, k.dodatni_stb, k.broj_bodova,
                        k.datum_montaze, k.lnb, k.stb1, k.stb2, k.stb2, k.adsl, k.vdsl, k.mifi_imei, k.mifi_iccd, k.mesto_izdavanja_lk,
                        k.datum_odustajanja, k.razlog_odustajanja, k.napomena, k.id_status, k.id_user, k.izvodjac, k.izvodjac_prodavac, k.prodavac, k.datum_zahteva,
                        u.ime as user_ime, u.prezime as user_prezime, s.status, k.datum_zakazivanja, k.datum_odustajanja, k.datum_odlaganja, usr.ime as kreirao_ime, 
                        usr.prezime as kreirao_prezime, k.datum_dodavanja, k.updated_at, stsi.status as status_intervencije, k.datum_intervencije, 
                        rek.ime as monter_reklamacije_ime, rek.prezime as monter_reklamacije_prezime, k.datum_reklamacije, k.id_user_reklamacije, rzi.razlog, k.for_payment,
                        p.ime as helper_name, p.prezime as helper_surname, k.on_terrain, k.filed, com.company, k.price')
            ->where('k.id', '=', $klijentId);

        $result = $query->get();
        return $result[0];
    }

    public function klijentiAdmin(){
        $query = DB::table('klijent as k')
            ->leftJoin('statusi as s', 's.id', '=', 'k.id_status')
            ->leftJoin('users as u', 'u.id', '=', 'k.id_user')
            ->select('k.id', 'k.br_ugovora', 'k.ime', 'k.prezime', 'k.jmbg', 'k.tel1', 'k.tel2', 'k.tel3', 'u.ime as user_ime',
                'k.adresa_instalacije', 'u.prezime as user_prezime', 's.status', 'k.created_at', 'k.datum_zahteva', 'k.datum_zakazivanja', 'k.datum_odustajanja', 'k.mrezna_grupa')
            ->orderby('datum_zakazivanja', 'DESC')
            ->orderby('datum_dodavanja', 'DESC')
        ;
        $result = $query->paginate(20);

        return $result;
    }

    public function pretragaAdmin($brUgovora = null, $ime = null, $prezime = null, $jmbg = null, $id_user = null, $fitterReclamation=null, $statusIds = null,
                                  $created_at = null, $datumMontaze=null, $datumOdustajanja = null, $datumZakazivanja = null, $datumOdlaganja = null, $bezStatusa = null, 
                                  $tisId=null, $append = null, $pagination=null)
    {
        $query = DB::table('klijent as k')
            ->leftJoin('statusi as s', 's.id', '=', 'k.id_status')
            ->leftJoin('users as u', 'u.id', '=', 'k.id_user')
            ->leftJoin('users as mont', 'mont.id', '=', 'k.id_user_reklamacije')
            ->select('k.id', 'k.br_ugovora', 'k.ime', 'k.prezime', 'k.jmbg', 'k.tel1', 'k.tel2', 'k.tel3', 'u.ime as user_ime', 'k.paket',
                'k.adresa_instalacije', 'u.prezime as user_prezime', 's.status', 's.id as status_id', 'k.created_at', 'k.datum_zahteva', 'k.datum_zakazivanja',
                'k.datum_montaze', 'k.datum_odustajanja', 'k.mrezna_grupa', 'mont.ime as monter_int_ime', 'mont.prezime as monter_int_prezime',
                'k.id_user','k.dodatni_stb', 'k.filed', 'k.id_status_intervencije')
        ;
        if ($brUgovora)
            $query->where('k.br_ugovora', '=', $brUgovora);
        if ($ime)
            $query->where('k.ime', 'like', $ime.'%');
        if ($prezime)
            $query->where('k.prezime', 'like', $prezime.'%');
        if ($jmbg)
            $query->where('k.jmbg', '=', $jmbg);
        if ($id_user)
            $query->where('k.id_user', '=', $id_user);
        if ($fitterReclamation)
            $query->where('k.id_user_reklamacije', '=', $fitterReclamation);
        if ($statusIds)
            $query->whereIn('k.id_status', $statusIds);
        if ($created_at)
            $query->where('k.datum_zahteva', '=', $created_at);
        if ($datumMontaze)
            $query->where('k.datum_montaze', '=', $datumMontaze);
        if ($datumOdustajanja)
            $query->where('k.datum_odustajanja', '=', $datumOdustajanja);
        if ($datumZakazivanja)
            $query->whereDate('k.datum_zakazivanja', '=', $datumZakazivanja);
        if ($datumOdlaganja)
            $query->whereDate('k.datum_odlaganja', '=', $datumOdlaganja);
        if ($bezStatusa){
            if($append)
                $query->where('k.id_status', '=', null);
            else
                $query->orWhere('k.id_status', '=', null);
        }
        if($tisId){
            $query->where('tis_id', '=', $tisId);
        }
        $query->orderBy('id_status_intervencije', 'DESC');
        $query->orderByRaw('ISNULL(datum_intervencije), datum_intervencije ASC');

        if($pagination)
            $result = $query->paginate(100);
        else
            $result = $query->get();

        return $result;
    }

    public function naprednaPretragaAdmin($brUgovora=null, $ime=null, $prezime=null, $jmbg=null, $mreznaGrupa=null, $tel1=null, $tel2=null, $tel3=null,
                    $tisId=null, $brLk=null, $datumIzdavanjaLk=null, $mestoIzdavanjaLk=null, $adresaPrebivalista=null, $adresaInstalacije=null, $paket=null,
                    $vrstaPaketa=null, $novServis=null, $dodatniStb=null, $brojBodova=null, $izvodjacProdavac=null, $prodavac=null, $izvodjac=null, $datumMontaze=null,
                    $lnb=null, $stb1=null, $stb2=null, $adsl=null, $vdsl=null, $mifiimei=null, $mifiiccd=null, $datumOdustajanja=null, $razlogOdustajanja=null,
                    $napomena=null, $statusIds=null, $datumZakazivanja=null, $datumOdlaganja=null, $idUser=null, $createdAt=null, $bezStatusa = null,
                    $statusIntIds=null, $datumIntervencije=null, $reklamacijaMonter=null, $datumReklamacije=null, $start=null, $end=null, $intStart=null,
                    $intEnd=null, $razlogIntervencije=null, $serial=null, $forPayment=null, $seller=null, $id=null, $append=null, $createdBy=null,
                    $imported=null, $helper=null, $terrain=null, $hasHelper=null, $company=null, $pagination=null)
    {
        $query = DB::table('klijent as k')
            ->leftJoin('statusi as s', 's.id', '=', 'k.id_status')
            ->leftJoin('users as u', 'u.id', '=', 'k.id_user')
            ->leftJoin('users as mont', 'mont.id', '=', 'k.id_user_reklamacije')
            ->leftJoin('klijenti_prodaja as kp', 'kp.id', '=', 'k.id_klijent_prodaja')
            ->select('k.id', 'k.br_ugovora', 'k.ime', 'k.prezime', 'k.jmbg', 'k.tel1', 'k.tel2', 'k.tel3', 'u.ime as user_ime',
                'k.adresa_instalacije', 'u.prezime as user_prezime', 's.status', 's.id as status_id', 'k.created_at', 'k.datum_zahteva', 'k.datum_zakazivanja',
                'k.datum_odustajanja', 'k.mrezna_grupa', 'mont.ime as monter_int_ime', 'mont.prezime as monter_int_prezime', 'k.paket',
                'k.id_user', 'k.dodatni_stb', 'k.filed', 'id_status_intervencije')
        ;
        if ($brUgovora)
            $query->where('k.br_ugovora', '=', $brUgovora);
        if ($ime)
            $query->where('k.ime', 'like', $ime.'%');
        if ($prezime)
            $query->where('k.prezime', 'like', $prezime.'%');
        if ($jmbg)
            $query->where('k.jmbg', '=', $jmbg);
        if ($mreznaGrupa)
            $query->where('k.mrezna_grupa', '=', $mreznaGrupa);
        if ($tel1)
            $query->where('k.tel1', '=', $tel1);
        if ($tel2)
            $query->where('k.tel2', '=', $tel2);
        if ($tel3)
            $query->where('k.tel3', '=', $tel3);
        if ($tisId)
            $query->where('k.tis_id', '=', $tisId);
        if ($brLk)
            $query->where('k.broj_lk', '=', $brLk);
        if ($datumIzdavanjaLk)
            $query->where('k.datum_izdavanja_lk', '=', $datumIzdavanjaLk);
        if ($mestoIzdavanjaLk)
            $query->where('k.mesto_izdavanja_lk', '=', $mestoIzdavanjaLk);
        if ($adresaPrebivalista)
            $query->where('k.adresa_prebivalista', 'like', '%'.$adresaPrebivalista.'%');
        if ($adresaInstalacije)
            $query->where('k.adresa_instalacije', 'like', '%'.$adresaInstalacije.'%');
        if ($paket)
            $query->where('k.paket', '=', $paket);
        if ($vrstaPaketa)
            $query->where('k.vrsta_paketa', '=', $vrstaPaketa);
        if ($novServis)
            $query->where('k.nov_servis', '=', $novServis);
        if ($dodatniStb)
            $query->where('k.dodatni_stb', '=', $dodatniStb);
        if ($brojBodova)
            $query->where('k.broj_bodova', '=', $brojBodova);
        if ($izvodjacProdavac)
            $query->where('k.izvodjac_prodavac', 'like', '%'.$izvodjacProdavac.'%');
        if ($izvodjac)
            $query->where('k.izvodjac', 'like', '%'.$izvodjac.'%');
        if ($prodavac)
            $query->where('k.prodavac', 'like', '%'.$prodavac.'%');
        if ($datumMontaze)
            $query->where('k.datum_montaze', '=', $datumMontaze);
        if ($lnb)
            $query->where('k.lnb', '=', $lnb);
        if ($stb1)
            $query->where('k.stb1', '=', $stb1);
        if ($stb2)
            $query->where('k.stb2', '=', $stb2);
        if ($adsl)
            $query->where('k.adsl', '=', $adsl);
        if ($vdsl)
            $query->where('k.vdsl', '=', $vdsl);
        if ($mifiimei)
            $query->where('k.mifi_imei', '=', $mifiimei);
        if ($mifiiccd)
            $query->where('k.mifi_iccd', '=', $mifiiccd);
        if ($datumOdustajanja)
            $query->where('k.datum_odustajanja', '=', $datumOdustajanja);
        if ($razlogOdustajanja)
            $query->where('k.razlog_odustajanja', 'like', '%'.$razlogOdustajanja.'%');
        if ($napomena)
            $query->where('k.napomena', 'like', '%'.$napomena.'%');
        if ($tisId)
            $query->where('k.tis_id', '=', $tisId);
        if ($statusIds)
            $query->whereIn('k.id_status', $statusIds);
        if ($datumZakazivanja)
            $query->whereDate('k.datum_zakazivanja', '=', $datumZakazivanja);
        if ($datumOdlaganja)
            $query->whereDate('k.datum_odlaganja', '=', $datumOdlaganja);
        if ($idUser)
            $query->where('k.id_user', '=', $idUser);
        if ($createdAt)
            $query->whereDate('k.created_at', '=', $createdAt);
        if ($bezStatusa){
            if($append)
                $query->orWhere('k.id_status', '=', null);
            else
                $query->where('k.id_status', '=', null);
        }
        if ($statusIntIds[0])
            $query->whereIn('k.id_status_intervencije', $statusIntIds);
        if ($datumIntervencije)
            $query->where('k.datum_intervencije', '=', $datumIntervencije);
        if ($reklamacijaMonter)
            $query->where('k.id_user_reklamacije', '=', $reklamacijaMonter);
        if ($datumReklamacije)
            $query->where('k.datum_reklamacije', '=', $datumReklamacije);
        if ($start && $end){
            $query->where('k.datum_montaze', '>=', $start);
            $query->where('k.datum_montaze', '<=', $end);
        }
        if ($intStart && $intEnd){
            $query->where('k.datum_intervencije', '>=', $intStart);
            $query->where('k.datum_intervencije', '<=', $intEnd);
        }
        if ($razlogIntervencije)
            $query->where('k.id_razlog_reklamacije', '=', $razlogIntervencije);
        if($serial){
            $query->leftJoin('montirani_uredjaji as mu', 'k.id', '=', 'mu.id_klijent')
                ->where('serijski_broj', '=', $serial)
                ->groupBy('mu.id_klijent');
        }
        if($forPayment){
            $query->where('k.for_payment', '=', $forPayment);
        }
        if($seller){
            $query->where('kp.id_prodavac', '=', $seller);
        }
        if($id){
            $query->where('k.id', '=', $id);
        }
        if ($createdBy)
            $query->where('k.created_by', '=', $createdBy);
        if ($imported)
            $query->where('k.imported', '=', 1);
        if ($helper)
            $query->where('k.helper', '=', $helper);
        if ($terrain)
            $query->where('k.on_terrain', '=', $terrain);
        if ($hasHelper)
            $query->where('k.helper', '!=', null);
        if ($company)
            $query->where('k.company_id', '=', $company);
        $query->orderBy('id_status_intervencije', 'DESC');
        $query->orderByRaw('ISNULL(datum_reklamacije), datum_reklamacije ASC');

        if($pagination)
            $result = $query->paginate(100);
        else
            $result = $query->get();

        return $result;
    }

    public function export($ids){
        $query = DB::table('klijent as k')
            ->leftJoin('statusi as s', 's.id', '=', 'k.id_status')
            ->leftJoin('users as u', 'u.id', '=', 'k.id_user')
            ->leftJoin('razlozi_intervencije as rai', 'rai.id', '=', 'k.id_razlog_reklamacije')
            ->select('k.id', 'k.br_ugovora', 'k.ime', 'k.prezime', 'k.jmbg', 'k.tel1', 'k.tel2', 'k.tel3', 'u.ime as user_ime',
                'u.prezime as user_prezime', 's.status', 's.id as id_status', 'k.created_at', 'k.mrezna_grupa', 'k.tis_id', 'k.broj_lk', 'k.datum_izdavanja_lk',
                'k.mesto_izdavanja_lk', 'k.adresa_prebivalista', 'k.adresa_instalacije', 'k.paket', 'k.vrsta_paketa', 'k.nov_servis', 'k.dodatni_stb',
                'k.broj_bodova', 'k.izvodjac_prodavac', 'k.prodavac', 'k.izvodjac', 'k.datum_montaze', 'k.lnb', 'k.stb1', 'k.stb2', 'k.adsl', 'k.vdsl',
                'k.mifi_imei', 'k.mifi_iccd', 'k.datum_odustajanja', 'k.razlog_odustajanja', 'k.napomena', 'k.datum_dodavanja', 'k.datum_zahteva', 'rai.razlog', 'k.for_payment'
            )
            ->whereIn('k.id', $ids);

        $result = $query->get();

        return $result;
    }

    public function odlozeni($datumOdlaganja){
        $query1 = DB::table('klijent')
            ->whereDate('datum_odlaganja', '=', $datumOdlaganja);
        $query2 = DB::table('klijenti_optika')
            ->whereDate('datum_odlaganja', '=', $datumOdlaganja);
        $query3 = DB::table('klijenti_supernova')
            ->whereDate('datum_odlaganja', '=', $datumOdlaganja);
        $query4 = DB::table('klijenti_bakar')
            ->whereDate('datum_odlaganja', '=', $datumOdlaganja);

        $dth = $query1->get();
        $optika = $query2->get();
        $supernova = $query3->get();
        $bakar = $query4->get();

        if ($dth->isEmpty() && $optika->isEmpty() && $supernova->isEmpty() && $bakar->isEmpty())
            return false;
        else
            return true;
    }

    public function odlozeniDth($datumOdlaganja){
        $query = DB::table('klijent as k')
            ->leftJoin('statusi as s', 's.id', '=', 'k.id_status')
            ->leftJoin('users as u', 'u.id', '=', 'k.id_user')
            ->select('k.id', 'k.br_ugovora', 'k.ime', 'k.prezime', 'k.jmbg', 'k.tel1', 'k.tel2', 'k.tel3', 'u.ime as user_ime',
                'k.adresa_instalacije', 'u.prezime as user_prezime', 's.status', 'k.created_at', 'k.datum_zahteva', 'k.datum_zakazivanja', 'k.datum_odustajanja', 'k.mrezna_grupa'
            )
            ->whereDate('k.datum_odlaganja', '=', $datumOdlaganja);

        $result = $query->get();

        return $result;
    }

    public function odlozeniOptika($datumOdlaganja){
        $query = DB::table('klijenti_optika as k')
            ->leftJoin('statusi as s', 's.id', '=', 'k.id_status')
            ->leftJoin('users as u', 'u.id', '=', 'k.id_user')
            ->select('k.id', 'k.ime', 'k.prezime', 'k.tel1', 'k.tel2', 'k.tel3', 'u.ime as user_ime',
                'k.adresa', 'u.prezime as user_prezime', 's.status', 'k.created_at', 'k.datum_zahteva', 'k.datum_zakazivanja', 'k.datum_odustajanja'
            )
            ->whereDate('k.datum_odlaganja', '=', $datumOdlaganja);

        $result = $query->get();

        return $result;
    }

    public function odlozeniSupernova($datumOdlaganja){
        $query = DB::table('klijenti_supernova as k')
            ->leftJoin('statusi as s', 's.id', '=', 'k.id_status')
            ->leftJoin('users as u', 'u.id', '=', 'k.id_user')
            ->select('k.id', 'k.klijent_ime', 'k.klijent_prezime', 'k.tel1', 'k.tel2', 'u.ime as user_ime',
                'u.prezime as user_prezime', 'k.ulica', 'k.kucni_broj', 's.status', 'k.created_at', 'k.datum_obilaska', 'k.datum_zakazivanja', 'k.datum_odustajanja'
            )
            ->whereDate('k.datum_odlaganja', '=', $datumOdlaganja);

        $result = $query->get();

        return $result;
    }

    public function odlozeniBakar($datumOdlaganja){
        $query = DB::table('klijenti_bakar as k')
            ->leftJoin('statusi as s', 's.id', '=', 'k.id_status')
            ->leftJoin('users as u', 'u.id', '=', 'k.id_user')
            ->select('k.id', 'k.ime', 'k.prezime', 'k.tel1', 'k.tel2', 'k.tel3', 'u.ime as user_ime',
                'k.adresa', 'u.prezime as user_prezime', 's.status', 'k.created_at', 'k.datum_zahteva', 'k.datum_zakazivanja', 'k.datum_odustajanja')
            ->whereDate('k.datum_odlaganja', '=', $datumOdlaganja);

        $result = $query->get();

        return $result;
    }

    public function odlozeniRune($delayDate){
        $query = DB::table('rune_optics as r')
            ->leftJoin('statusi as s', 's.id', '=', 'r.status')
            ->leftJoin('users as u', 'u.id', '=', 'r.user')
            ->leftJoin('clusters as c', 'c.id', '=', 'r.cluster')
            ->whereDate('r.delay_date', '=', $delayDate)
            ->select('r.id', 'c.cluster', 'r.name', 'r.surname', 'r.street', 'r.pan', 'u.ime as fitter_name', 'r.home_no', 'r.packet',
               'u.prezime as fitter_surname', 's.status', 'r.created_at', 'r.claim_date', 'r.appointment_date', 'r.withdrawal_date');

        $result = $query->get();

        return $result;
    }

    public function zakazaniMonter($datumZakazivanja, $idUser){
        $query = DB::table('klijent as k')
            ->leftJoin('statusi as s', 's.id', '=', 'k.id_status')
            ->leftJoin('users as u', 'u.id', '=', 'k.id_user')
            ->select('k.id', 'k.br_ugovora', 'k.ime', 'k.prezime', 'k.jmbg', 'k.tel1', 'k.tel2', 'k.tel3', 'u.ime as user_ime',
                'k.adresa_instalacije', 'u.prezime as user_prezime', 's.status', 'k.created_at', 'k.datum_zahteva', 'k.datum_zakazivanja', 'k.datum_odustajanja', 'k.mrezna_grupa',
                'id_status_intervencije'
            )
            ->whereDate('k.datum_zakazivanja', '=', $datumZakazivanja)
            ->where('k.id_status', '=', 1)
            ->where('k.id_user', '=', $idUser)
            ->orWhere(function ($q) use ($idUser){
                $q->where('k.id_status_intervencije', '=', 1)
                ->where('k.datum_intervencije', '=', date('Y-m-d'))
                ->where('k.id_user_reklamacije', '=', $idUser);
            })

            ->orderBy('k.datum_zakazivanja', 'ASC')
        ;

        $result = $query->get();

        return $result;
    }

    public function pdfUgovor($id){
        $query = DB::table('klijent as k')
            ->leftJoin('users as u', 'u.id', '=', 'k.id_user')
            ->select('k.id', 'k.br_ugovora', 'k.ime', 'k.prezime', 'k.jmbg', 'k.tel1', 'k.tel2', 'k.tel3', 'k.adresa_prebivalista',
                'k.adresa_instalacije', 'k.paket', 'k.datum_zakazivanja', 'k.tis_id', 'u.ime as monter_ime', 'u.prezime as monter_prezime',
                'k.mrezna_grupa'
            )
            ->where('k.id', '=', $id);

        $result = $query->get();

        return $result[0];
    }

    public function lnb($idUser=null, $start=null, $end=null){
        $query = DB::table('klijent')
        ->selectRaw('COUNT(lnb) as iznos')
        ->where('lnb', '!=', null);
        if ($idUser)
            $query->where('id_user', '=', $idUser);
        if($start)
            $query->where('datum_montaze', '>=', $start);
        if($end)
            $query->where('datum_montaze', '<=', $end);

        $result = $query->get();
        return $result[0];
    }

    public function stb1($idUser=null, $start=null, $end=null){
        $query = DB::table('klijent')
            ->selectRaw('COUNT(stb1) as iznos')
            ->where('stb1', '!=', null);
        if ($idUser)
            $query->where('id_user', '=', $idUser);
        if($start)
            $query->where('datum_montaze', '>=', $start);
        if($end)
            $query->where('datum_montaze', '<=', $end);

        $result = $query->get();
        return $result[0];
    }

    public function stb2($idUser=null, $start=null, $end=null){
        $query = DB::table('klijent')
            ->selectRaw('COUNT(stb2) as iznos')
            ->where('stb2', '!=', null);
        if ($idUser)
            $query->where('id_user', '=', $idUser);
        if($start)
            $query->where('datum_montaze', '>=', $start);
        if($end)
            $query->where('datum_montaze', '<=', $end);

        $result = $query->get();
        return $result[0];
    }

    public function vdsl($idUser=null, $start=null, $end=null){
        $query = DB::table('klijent')
            ->selectRaw('COUNT(vdsl) as iznos')
            ->where('vdsl', '!=', null);
        if ($idUser)
            $query->where('id_user', '=', $idUser);
        if($start)
            $query->where('datum_montaze', '>=', $start);
        if($end)
            $query->where('datum_montaze', '<=', $end);

        $result = $query->get();
        return $result[0];
    }

    public function intervencija($idUser=null, $start=null, $end=null){
        $query = DB::table('klijent')
            ->selectRaw('COUNT(id_user_reklamacije) as iznos')
            ->where('id_status_intervencije', '=', 2);
        if ($idUser)
            $query->where('id_user_reklamacije', '=', $idUser);
        if($start)
            $query->where('datum_intervencije', '>=', $start);
        if($end)
            $query->where('datum_intervencije', '<=', $end);

        $result = $query->get();
        return $result[0];
    }

    public function old_montages($years, $count=false){
        $date = new \DateTime();
        $date->modify("-$years years");
        $substractedDate = $date->format('Y-m-d');
        if($count) {
            $query = DB::table('klijent')
                ->selectRaw('count(id) as count')
                ->where('datum_montaze', '<', $substractedDate);
            $result = $query->get();
            return $result[0]->count;
        }
        else{
            $query = DB::table('klijent as k')
                ->leftJoin('statusi as s', 's.id', '=', 'k.id_status')
                ->leftJoin('users as u', 'u.id', '=', 'k.id_user')
                ->leftJoin('users as mont', 'mont.id', '=', 'k.id_user_reklamacije')
                ->leftJoin('razlozi_intervencije as rzi', 'rzi.id', '=', 'k.id_razlog_reklamacije')
                ->select('k.id', 'k.br_ugovora', 'k.ime', 'k.prezime', 'k.jmbg', 'k.tel1', 'k.tel2', 'k.tel3', 'u.ime as user_ime', 'k.for_payment',
                    'k.adresa_instalacije', 'u.prezime as user_prezime', 's.status', 'k.created_at', 'k.datum_zahteva', 'k.datum_zakazivanja', 'k.datum_odustajanja',
                    'k.mrezna_grupa', 'mont.ime as monter_int_ime', 'mont.prezime as monter_int_prezime', 'rzi.razlog')
                ->where('datum_montaze', '<', $substractedDate)
                ->orderby('datum_zakazivanja', 'DESC')
                ->orderby('datum_dodavanja', 'DESC')
            ;
            $result = $query->paginate(20);
            return $result;
        }
    }

    public function shortcut($intervention=false, $dismantling=false, $debt=false, $status){
        $query = DB::table('klijent as k')
            ->leftJoin('statusi as s', 's.id', '=', 'k.id_status')
            ->leftJoin('users as u', 'u.id', '=', 'k.id_user')
            ->leftJoin('users as mont', 'mont.id', '=', 'k.id_user_reklamacije')
            ->select('k.id', 'k.br_ugovora', 'k.ime', 'k.prezime', 'k.jmbg', 'k.tel1', 'k.tel2', 'k.tel3', 'u.ime as user_ime', 'k.paket',
                'k.adresa_instalacije', 'u.prezime as user_prezime', 's.status', 's.id as status_id', 'k.created_at', 'k.datum_zahteva', 'k.datum_zakazivanja',
                'k.datum_montaze', 'k.datum_odustajanja', 'k.mrezna_grupa', 'mont.ime as monter_int_ime', 'mont.prezime as monter_int_prezime',
                'k.id_user','k.dodatni_stb', 'k.filed', 'id_status_intervencije')
        ;

        if($intervention) {
            $query->where('datum_intervencije', '=', date('Y-m-d'))
                  ->where('id_status_intervencije', '=', $status)
                  ->where(function($q){
                    $q->where('id_razlog_reklamacije', '=', null)
                      ->orWhere('id_razlog_reklamacije', '!=', 6);
                  });
        }
        if($dismantling) {
            $query->where('datum_intervencije', '=', date('Y-m-d'))
                  ->where('id_status_intervencije', '=', $status)
                  ->where('id_razlog_reklamacije', '=', 6);
        }
        if($debt) {
            $query->where('datum_intervencije', '=', date('Y-m-d'))
                ->where('id_status_intervencije', '=', $status)
                ->where('id_razlog_reklamacije', '=', 13);
        }


        $query->orderBy('id_status_intervencije', 'DESC');
        $query->orderByRaw('ISNULL(datum_intervencije), datum_intervencije ASC');

        $result = $query->get();

        return $result;
    }

    public function priceUpdate($id, $price){
        DB::table('klijent')->where('id', '=', $id)->increment('price', $price);
    }

    public function priceSum($date){
        $query = DB::table('klijent')->selectRaw('SUM(price) as price')->where('datum_montaze', $date);
        $result = $query->get();
        return $result[0]->price;
    }

    public function countMontages($date){
        $query = DB::table('klijent')->selectRaw('COUNT(id) as count')->where('datum_montaze', $date);
        $result = $query->get();
        return $result[0]->count;
    }

}
