<?php

namespace App;

use App\Traits\Util;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Support\Facades\DB;

class Klijenti_optika extends Model
{
    protected $table = 'klijenti_optika';
    protected  $fillable = [
        'br_ugovora',
        'ime',
        'prezime',
        'zahtev_uneo',
        'podrucje',
        'tis_id',
        'adresa',
        'tel1',
        'tel2',
        'tel3',
        'zahtev',
        'prodavac',
        'broj_bodova',
        'report_id',
        'id_status',
        'id_user',
        'id_user_reklamacije',
        'origin_id',
        'created_by',
        'datum_zahteva',
        'datum_zakazivanja',
        'datum_odlaganja',
        'datum_reklamacije',
        'datum_montaze',
        'datum_odustajanja',
        'datum_intervencije',
        'razlog_odustajanja',
        'id_status_intervencije',
        'updated_at',
        'created_at',
        'id_tip_montaze',
        'id_klijent_prodaja',
        'imported',
        'helper',
        'on_terrain',
        'extra_stb',
        'company_id',
        'price'
    ];

    public function klijentiPregled($userId){
        $query = DB::table('klijenti_optika as k')
            ->leftJoin('statusi as s', 's.id', '=', 'k.id_status')
            ->leftJoin('users as u', 'u.id', '=', 'k.id_user')
            ->select('k.id', 'k.ime', 'k.prezime', 'k.tel1', 'k.tel2', 'k.tel3', 'u.ime as user_ime',
                'k.adresa', 'u.prezime as user_prezime', 's.status', 'k.created_at', 'k.datum_zahteva', 'k.datum_zakazivanja', 'k.datum_odustajanja')
            ->where('id_user', '=', $userId)
            ->orderby('created_at', 'DESC')
        ;
        $result = $query->paginate(15);

        return $result;
    }

    public function klijentiAdmin(){
        $query = DB::table('klijenti_optika as k')
            ->leftJoin('statusi as s', 's.id', '=', 'k.id_status')
            ->leftJoin('users as u', 'u.id', '=', 'k.id_user')
            ->select('k.id', 'k.ime', 'k.prezime', 'k.tel1', 'k.tel2', 'k.tel3', 'u.ime as user_ime',
                'k.adresa', 'u.prezime as user_prezime', 's.status', 'k.created_at', 'k.datum_zahteva', 'k.datum_zakazivanja', 'k.datum_odustajanja')
            ->orderby('datum_zakazivanja', 'DESC')
            ->orderby('created_at', 'DESC')
        ;
        $result = $query->paginate(15);

        return $result;
    }

    public function klijentPodaci($klijentId){
        $query = DB::table('klijenti_optika as ko')
            ->leftJoin('users as u', 'ko.id_user', '=', 'u.id')
            ->leftJoin('statusi as s', 'ko.id_status', '=', 's.id')
            ->leftJoin('users as usr', 'ko.updated_by', '=', 'usr.id')
            ->leftJoin('statusi_intervencije as stsi', 'ko.id_status_intervencije', '=', 'stsi.id')
            ->leftJoin('users as rek', 'ko.id_user_reklamacije', '=', 'rek.id')
            ->leftJoin('tip_montaze as tpm', 'tpm.id', '=', 'ko.id_tip_montaze')
            ->leftJoin('report_marks as rm', 'rm.id', '=', 'ko.report_id')
            ->leftJoin('users as ru', 'ru.id', '=', 'rm.edited_by')
            ->leftJoin('users as ruc', 'ruc.id', '=', 'rm.created_by')
            ->leftJoin('origin as o', 'o.id', '=', 'ko.origin_id')
            ->leftJoin('pomocnici as p', 'p.id', '=', 'ko.helper')
            ->leftJoin('companies as com', 'com.id', '=', 'ko.company_id')
            ->select('ko.id', 'ko.ime', 'ko.prezime', 'ko.zahtev_uneo', 'ko.podrucje', 'ko.tis_id', 'ko.adresa', 'ko.tel1', 'ko.tel2', 'ko.tel3',
                    'ko.zahtev', 'ko.prodavac', 'ko.broj_bodova', 'ko.id_status', 'ko.id_user', 'ko.id_user_reklamacije', 'ko.datum_montaze', 'ko.datum_odustajanja',
                    'ko.razlog_odustajanja', 'ko.datum_zahteva', 'u.ime as user_ime', 'u.prezime as user_prezime', 's.status', 'ko.datum_zakazivanja',
                    'ko.datum_odustajanja', 'ko.datum_odlaganja', 'usr.ime as kreirao_ime', 'usr.prezime as kreirao_prezime', 'u.id as id_user', 'ko.updated_at',
                    'stsi.status as status_intervencije', 'ko.datum_intervencije', 'rek.ime as monter_reklamacije_ime', 'rek.prezime as monter_reklamacije_prezime',
                    'ko.datum_reklamacije', 'ko.id_user_reklamacije', 'tpm.tip as tip_montaze', 'ko.report_id', 'ru.ime as edited_name', 'ru.prezime as edited_surname',
                    'ruc.ime as created_name', 'ruc.prezime as created_surname', 'rm.facility_enterance', 'rm.internal_cabling', 'rm.signal_level', 'rm.coupling_condition',
                    'rm.behavior', 'rm.customer_satisfaction', 'rm.updated_at as report_updated_at', 'rm.created_at as report_created_at', 'o.origin', 'p.ime as helper_name',
                    'p.prezime as helper_surname', 'ko.on_terrain', 'ko.extra_stb', 'com.company', 'ko.price')
            ->where('ko.id', '=', $klijentId)
        ;

        $result = $query->get();
        return $result[0];
    }

    public function pretragaOptika($ime = null, $prezime = null, $id_user = null, $statusIds = null,
                                  $created_at = null, $datumMontaze=null, $datumOdustajanja = null, $datumZakazivanja = null, $datumOdlaganja = null, $bezStatusa = null, $append=null, $pagination=null)
    {
        $query = DB::table('klijenti_optika as k')
            ->leftJoin('statusi as s', 's.id', '=', 'k.id_status')
            ->leftJoin('users as u', 'u.id', '=', 'k.id_user')
            ->leftJoin('users as mont', 'mont.id', '=', 'k.id_user_reklamacije')
            ->select('k.id', 'k.ime', 'k.prezime', 'k.tel1', 'k.tel2', 'k.tel3', 'u.ime as user_ime',
                'u.prezime as user_prezime', 's.status', 'k.created_at', 'k.datum_zahteva', 'k.datum_zakazivanja',
                'k.datum_montaze', 'k.datum_odustajanja', 'mont.ime as monter_int_ime', 'mont.prezime as monter_int_prezime', 'k.adresa')
        ;
        if ($ime)
            $query->where('k.ime', 'like', $ime.'%');
        if ($prezime)
            $query->where('k.prezime', 'like', $prezime.'%');
        if ($id_user)
            $query->where('k.id_user', '=', $id_user);
        if ($statusIds)
            $query->whereIn('k.id_status', $statusIds);
        if ($created_at)
            $query->where('k.datum_zahteva', '=', $created_at);
        if ($datumMontaze)
            $query->where('k.datum_montaze', '=', $datumMontaze);
        if ($datumOdustajanja)
            $query->where('k.datum_odustajanja', '=', $datumOdustajanja);
        if ($datumZakazivanja)
            $query->whereDate('k.datum_zakazivanja', '=', $datumZakazivanja);
        if ($datumOdlaganja)
            $query->whereDate('k.datum_odlaganja', '=', $datumOdlaganja);
        if ($bezStatusa){
            if($append)
                $query->orWhere('k.id_status', '=', null);
            else
                $query->where('k.id_status', '=', null);
        }

        if($pagination)
            $result = $query->paginate(100);
        else
            $result = $query->get();

        return $result;
    }

    public function  naprednaPretragaOptika($ime=null, $prezime=null, $zahtevUneo=null, $podrucje=null, $adresa=null, $tel1=null, $tel2=null, $tel3=null,
                  $tisId=null, $zahtev=null, $datumZahteva=null, $prodavac=null, $datumMontaze=null, $tipoviMontazeIds, $datumOdustajanja=null,
                  $razlogOdustajanja=null, $napomena=null, $statusIds=null, $datumZakazivanja=null, $datumOdlaganja=null, $idUser=null, $createdAt=null, $bezStatusa = null,
                  $statusIntIds=null, $datumIntervencije=null, $reklamacijaMonter=null, $datumReklamacije=null, $start=null, $end=null,
                  $serial=null, $reportDate=null, $seller=null, $callistoId=null, $append=null, $origin=null, $deviceId=null, $helper=null, $terrain=null, $hasHelper=null, $company=null, $pagination=null)
    {
        $query = DB::table('klijenti_optika as k')
            ->leftJoin('statusi as s', 's.id', '=', 'k.id_status')
            ->leftJoin('users as u', 'u.id', '=', 'k.id_user')
            ->leftJoin('users as mont', 'mont.id', '=', 'k.id_user_reklamacije')
            ->leftJoin('report_marks as rm', 'rm.id', '=', 'k.report_id')
            ->leftJoin('klijenti_prodaja as kp', 'kp.id', '=', 'k.id_klijent_prodaja')
            ->select('k.id', 'k.ime', 'k.prezime', 'k.tel1', 'k.tel2', 'k.tel3', 'u.ime as user_ime',
                'u.prezime as user_prezime', 's.status', 'k.created_at', 'k.datum_zahteva', 'k.datum_zakazivanja',
                'k.datum_montaze', 'k.datum_odustajanja', 'mont.ime as monter_int_ime', 'mont.prezime as monter_int_prezime', 'k.adresa')
        ;
        if ($ime)
            $query->where('k.ime', 'like', $ime.'%');
        if ($prezime)
            $query->where('k.prezime', 'like', $prezime.'%');
        if ($zahtevUneo)
            $query->where('k.zahtev_uneo', 'like', $zahtevUneo.'%');
        if ($podrucje)
            $query->where('k.podrucje', 'like', $podrucje.'%');
        if ($adresa)
            $query->where('k.adresa', 'like', $adresa.'%');
        if ($zahtev)
            $query->where('k.zahtev', 'like', $zahtev.'%');
        if ($datumZahteva)
            $query->where('k.datum_zahteva', '=', $datumZahteva);
        if ($tel1)
            $query->where('k.tel1', '=', $tel1);
        if ($tel2)
            $query->where('k.tel2', '=', $tel2);
        if ($tel3)
            $query->where('k.tel3', '=', $tel3);
        if ($tisId)
            $query->where('k.tis_id', '=', $tisId);
        if ($prodavac)
            $query->where('k.prodavac', 'like', '%'.$prodavac.'%');
        if ($datumMontaze)
            $query->where('k.datum_montaze', '=', $datumMontaze);
        if ($tipoviMontazeIds)
            $query->whereIn('k.id_tip_montaze', $tipoviMontazeIds);
        if ($datumOdustajanja)
            $query->where('k.datum_odustajanja', '=', $datumOdustajanja);
        if ($razlogOdustajanja)
            $query->where('k.razlog_odustajanja', 'like', '%'.$razlogOdustajanja.'%');
        if ($napomena)
            $query->where('k.napomena', 'like', '%'.$napomena.'%');
        if ($tisId)
            $query->where('k.tis_id', '=', $tisId);
        if ($statusIds)
            $query->whereIn('k.id_status', $statusIds);
        if ($datumZakazivanja)
            $query->whereDate('k.datum_zakazivanja', '=', $datumZakazivanja);
        if ($datumOdlaganja)
            $query->whereDate('k.datum_odlaganja', '=', $datumOdlaganja);
        if ($idUser)
            $query->where('k.id_user', '=', $idUser);
        if ($createdAt)
            $query->where('k.datum_zahteva', '=', $createdAt);
        if ($bezStatusa){
            if($append)
                $query->orWhere('k.id_status', '=', null);
            else
                $query->where('k.id_status', '=', null);
        }
        if ($statusIntIds)
            $query->whereIn('k.id_status_intervencije', $statusIntIds);
        if ($datumIntervencije)
            $query->where('k.datum_intervencije', '=', $datumIntervencije);
        if ($reklamacijaMonter)
            $query->where('k.id_user_reklamacije', '=', $reklamacijaMonter);
        if ($datumReklamacije)
            $query->where('k.datum_reklamacije', '=', $datumReklamacije);
        if ($start && $end){
            $query->where('k.datum_montaze', '>=', $start);
            $query->where('k.datum_montaze', '<=', $end);
        }
        if($serial){
            $query->leftJoin('montirani_uredjaji as mu', 'k.id', '=', 'mu.id_opticki_klijent')
            ->where('serijski_broj', '=', $serial)
            ->groupBy('mu.id_opticki_klijent');
        }
        if($reportDate){
            $query->whereDate('rm.created_at', '=', $reportDate);
        }
        if($seller){
            $query->where('kp.id_prodavac', '=', $seller);
        }
        if($callistoId){
            $query->where('k.id', '=', $callistoId);
        }

        if($origin)
            $query->where('k.origin_id', '=', $origin);

        if($deviceId){
            $query->leftJoin('montirani_uredjaji as mu', 'k.id', '=', 'mu.id_opticki_klijent')
                ->where('id_uredjaj', '=', $deviceId)
                ->havingRaw('count(mu.id)>1')
                ->groupBy('mu.id_opticki_klijent');
        }
        if ($helper)
            $query->where('k.helper', '=', $helper);
        if ($terrain)
            $query->where('k.on_terrain', '=', $terrain);
        if ($hasHelper)
            $query->where('k.helper', '!=', null);
        if ($company)
            $query->where('k.company_id', '=', $company);

        if($pagination)
            $result = $query->paginate(100);
        else
            $result = $query->get();

        return $result;
    }


    public function export($ids){
        $query = DB::table('klijenti_optika as k')
            ->leftJoin('statusi as s', 's.id', '=', 'k.id_status')
            ->leftJoin('users as u', 'u.id', '=', 'k.id_user')
            ->leftJoin('users as int', 'int.id', '=', 'k.id_user_reklamacije')
            ->leftJoin('tip_montaze as tm', 'tm.id', '=', 'k.id_tip_montaze')
            ->leftJoin('origin as o', 'o.id', '=', 'k.origin_id')
            ->select('k.id', 'k.ime', 'k.prezime', 'k.tel1', 'k.tel2', 'k.tel3', 'u.ime as user_ime', 'u.prezime as user_prezime', 'k.zahtev_uneo', 'k.podrucje',
                'k.adresa', 's.status', 'k.datum_zahteva', 'k.tis_id', 'k.adresa', 'k.zahtev', 'prodavac', 's.id as id_status', 'k.br_ugovora', 'k.broj_bodova',
                'int.ime as inter_ime', 'int.prezime as inter_prezime', 'tm.tip as tip_montaze', 's.status', 'k.datum_odustajanja', 'k.datum_montaze', 'k.datum_odlaganja',
                'datum_zakazivanja', 'k.razlog_odustajanja', 'k.extra_stb', 'o.origin'
            )
            ->whereIn('k.id', $ids);

        $result = $query->get();

        return $result;
    }


    public function zakazaniMonter($datumZakazivanja, $idUser){
        $query = DB::table('klijenti_optika as k')
            ->leftJoin('statusi as s', 's.id', '=', 'k.id_status')
            ->leftJoin('users as u', 'u.id', '=', 'k.id_user')
            ->select('k.id', 'k.ime', 'k.prezime', 'k.tel1', 'k.tel2', 'k.tel3', 'u.ime as user_ime',
                'k.adresa', 'u.prezime as user_prezime', 's.status', 'k.datum_zakazivanja', 'k.datum_odustajanja',
                'id_status_intervencije'
            )
            ->whereDate('k.datum_zakazivanja', '=', $datumZakazivanja)
            ->where('k.id_status', '=', 1)
            ->where('k.id_user', '=', $idUser)
            ->orWhere(function ($q) use ($idUser){
                $q->where('k.id_status_intervencije', '=', 1)
                  ->where('k.id_user_reklamacije', '=', $idUser);
                if(Util::firmaId() != 2)
                    $q->where('k.datum_intervencije', '=', date('Y-m-d'));
            })

            ->orderBy('k.datum_zakazivanja', 'ASC')
        ;

        $result = $query->get();

        return $result;
    }

    public function priceUpdate($id, $price){
        DB::table('klijenti_optika')->where('id', '=', $id)->increment('price', $price);
    }

    public function priceSum($date){
        $query = DB::table('klijenti_optika')->selectRaw('SUM(price) as price')->where('datum_montaze', $date);
        $result = $query->get();
        return $result[0]->price;
    }

    public function countMontages($date, $type){
        $query = DB::table('klijenti_optika')->selectRaw('COUNT(id) as count')->where('datum_montaze', $date);
        $result = $query->get();
        return $result[0]->count;
    }
}
