<?php

namespace App;

use Illuminate\Database\Eloquent\Model;
use DB;

class Klijenti_supernova extends Model
{
    protected $table = 'klijenti_supernova';
    protected $fillable = [
        'broj_ugovora',
        'klijent_ime',
        'klijent_prezime',
        'regionalni_centar',
        'agent_ime',
        'agent_prezime',
        'br_bodova',
        'provajder',
        'agencija',
        'mesec',
        'datum_obilaska',
        'datum_zahteva',
        'datum_zakazivanja',
        'datum_odlaganja',
        'datum_montaze',
        'datum_odustajanja',
        'ulica',
        'kucni_broj',
        'mesto',
        'email',
        'tel1',
        'tel2',
        'tip_ugovora',
        'paket',
        'id_status',
        'id_user',
        'id_user_reklamacije',
        'id_klijent_prodaja',
        'created_by',
        'updated_by',
        'id_klijent_prodaja',
        'helper',
        'on_terrain'
    ];

    public function klijentiPregled($userId){
        $query = DB::table('klijenti_supernova as k')
            ->leftJoin('statusi as s', 's.id', '=', 'k.id_status')
            ->leftJoin('users as u', 'u.id', '=', 'k.id_user')
            ->select('k.id', 'k.klijent_ime', 'k.klijent_prezime', 'k.tel1', 'k.tel2', 'u.ime as user_ime',
                'u.prezime as user_prezime', 'k.ulica', 'k.kucni_broj', 's.status', 'k.created_at', 'k.datum_obilaska', 'k.datum_zakazivanja', 'k.datum_odustajanja')
            ->where('id_user', '=', $userId)
            ->orderby('created_at', 'DESC')
        ;
        $result = $query->paginate(15);

        return $result;
    }

    public function klijentiAdmin(){
        $query = DB::table('klijenti_supernova as k')
            ->leftJoin('statusi as s', 's.id', '=', 'k.id_status')
            ->leftJoin('users as u', 'u.id', '=', 'k.id_user')
            ->select('k.id', 'k.klijent_ime', 'k.klijent_prezime', 'k.tel1', 'k.tel2', 'u.ime as user_ime', 'k.mesto',
                'u.prezime as user_prezime', 'k.ulica', 'k.kucni_broj', 's.status', 'k.created_at', 'k.datum_obilaska', 'k.datum_zakazivanja', 'k.datum_odustajanja')
            ->orderby('datum_zakazivanja', 'DESC')
            ->orderby('created_at', 'DESC')
        ;
        $result = $query->paginate(15);

        return $result;
    }

    public function klijentPodaci($klijentId){
        $query = DB::table('klijenti_supernova as ks')
            ->leftJoin('users as u', 'ks.id_user', '=', 'u.id')
            ->leftJoin('statusi as s', 'ks.id_status', '=', 's.id')
            ->leftJoin('users as usr', 'ks.updated_by', '=', 'usr.id')
            ->select('ks.broj_ugovora','ks.id', 'ks.klijent_ime', 'ks.klijent_prezime', 'ks.regionalni_centar', 'ks.agent_ime', 'ks.agent_prezime', 'ks.br_bodova', 'ks.provajder',
                'ks.agencija', 'ks.mesec', 'ks.datum_obilaska', 'ks.datum_zahteva', 'ks.datum_zakazivanja', 'ks.datum_odlaganja', 'ks.datum_montaze', 'ks.datum_odustajanja', 'ks.updated_at',
                'ks.ulica', 'ks.kucni_broj', 'ks.mesto', 'ks.email','ks.tel1', 'ks.tel2', 'ks.tip_ugovora', 'ks.updated_by', 'usr.ime as updated_ime', 'usr.prezime as updated_prezime',
                'u.ime as user_ime', 'u.prezime as user_prezime', 's.status', 'usr.ime as kreirao_ime', 'usr.prezime as kreirao_prezime', 'u.id as id_user', 'ks.datum_obilaska', 'ks.provajder',
                'ks.paket'
                )
            ->where('ks.id', '=', $klijentId)
        ;

        $result = $query->get();
        return $result[0];
    }

    public function zakazaniMonter($datumZakazivanja, $idUser){
        $query = DB::table('klijenti_supernova as k')
            ->leftJoin('statusi as s', 's.id', '=', 'k.id_status')
            ->leftJoin('users as u', 'u.id', '=', 'k.id_user')
            ->select('k.id', 'k.klijent_ime', 'k.klijent_prezime', 'k.tel1', 'k.tel2', 'u.ime as user_ime',
                'k.ulica', 'k.kucni_broj', 'u.prezime as user_prezime', 's.status', 'k.datum_zakazivanja', 'k.datum_odustajanja'
            )
            ->whereDate('k.datum_zakazivanja', '=', $datumZakazivanja)
            ->where('k.id_status', '=', 1)
            ->where('k.id_user', '=', $idUser)
            ->orderBy('k.datum_zakazivanja', 'ASC')
        ;

        $result = $query->get();

        return $result;
    }

    public function search($ime = null, $prezime = null, $id_user = null, $statusIds = null,
                                   $created_at = null, $datumMontaze=null, $datumOdustajanja = null, $datumZakazivanja = null, $datumOdlaganja = null, $bezStatusa = null, $paginate=false)
    {
        $query = DB::table('klijenti_supernova as k')
            ->leftJoin('statusi as s', 's.id', '=', 'k.id_status')
            ->leftJoin('users as u', 'u.id', '=', 'k.id_user')
            ->leftJoin('users as mont', 'mont.id', '=', 'k.id_user_reklamacije')
            ->select('k.id', 'k.klijent_ime as ime', 'k.klijent_prezime as prezime', 'k.tel1', 'k.tel2', 'u.ime as user_ime',
                'u.prezime as user_prezime', 's.status', 'k.datum_zakazivanja', 'k.mesto',
                'k.datum_montaze', 'k.datum_odustajanja', 'mont.ime as monter_int_ime', 'mont.prezime as monter_int_prezime')
        ;
        if ($ime)
            $query->where('k.klijent_ime', 'like', $ime.'%');
        if ($prezime)
            $query->where('k.klijent_prezime', 'like', $prezime.'%');
        if ($id_user)
            $query->where('k.id_user', '=', $id_user);
        if ($statusIds)
            $query->whereIn('k.id_status', $statusIds);
        if ($created_at)
            $query->where('k.datum_zahteva', '=', $created_at);
        if ($datumMontaze)
            $query->where('k.datum_montaze', '=', $datumMontaze);
        if ($datumOdustajanja)
            $query->where('k.datum_odustajanja', '=', $datumOdustajanja);
        if ($datumZakazivanja)
            $query->whereDate('k.datum_zakazivanja', '=', $datumZakazivanja);
        if ($datumOdlaganja)
            $query->whereDate('k.datum_odlaganja', '=', $datumOdlaganja);
        if ($bezStatusa)
            $query->orWhere('k.id_status', '=', null);

        if($paginate)
            $result = $query->paginate(100);
        else
            $result = $query->get();

        return $result;
    }

    public function advancedSearch($ime = null, $prezime = null, $id_user = null, $statusIds = null,
                                    $created_at = null, $datumMontaze=null, $datumOdustajanja = null, $datumZakazivanja = null, $datumOdlaganja = null, $bezStatusa = null, $brojUgovora=null,
                                    $ulica=null, $kucniBroj=null, $tel1=null, $tel2=null, $brojBodova=null, $mesec=null, $agentIme=null, $agentPrezime=null, $agencija=null, $regionalniCentar=null,
                                    $datumObilaska=null, $paket=null, $mesto=null, $email=null, $tipUgovora=null, $start=null, $end=null, $seller=null, 
                                    $callistoId=null, $paginate=false)
    {
        $query = DB::table('klijenti_supernova as k')
            ->leftJoin('statusi as s', 's.id', '=', 'k.id_status')
            ->leftJoin('users as u', 'u.id', '=', 'k.id_user')
            ->leftJoin('users as mont', 'mont.id', '=', 'k.id_user_reklamacije')
            ->leftJoin('klijenti_prodaja as kp', 'kp.id', '=', 'k.id_klijent_prodaja')
            ->select('k.id', 'k.klijent_ime as ime', 'k.klijent_prezime as prezime', 'k.tel1', 'k.tel2', 'u.ime as user_ime',
                'u.prezime as user_prezime', 's.status', 'k.datum_zakazivanja', 'k.mesto',
                'k.datum_montaze', 'k.datum_odustajanja', 'mont.ime as monter_int_ime', 'mont.prezime as monter_int_prezime')
        ;
        if ($ime)
            $query->where('k.klijent_ime', 'like', $ime.'%');
        if ($prezime)
            $query->where('k.klijent_prezime', 'like', $prezime.'%');
        if ($id_user)
            $query->where('k.id_user', '=', $id_user);
        if ($statusIds)
            $query->whereIn('k.id_status', $statusIds);
        if ($created_at)
            $query->where('k.datum_zahteva', '=', $created_at);
        if ($datumMontaze)
            $query->where('k.datum_montaze', '=', $datumMontaze);
        if ($datumOdustajanja)
            $query->where('k.datum_odustajanja', '=', $datumOdustajanja);
        if ($datumZakazivanja)
            $query->whereDate('k.datum_zakazivanja', '=', $datumZakazivanja);
        if ($datumOdlaganja)
            $query->whereDate('k.datum_odlaganja', '=', $datumOdlaganja);
        if ($bezStatusa)
            $query->orWhere('k.id_status', '=', null);
        if ($brojUgovora)
            $query->where('k.broj_ugovora', '=', $brojUgovora);
        if ($ulica)
            $query->where('k.ulica', '=', $ulica);
        if ($kucniBroj)
            $query->where('k.kucni_broj', '=', $kucniBroj);
        if ($tel1)
            $query->where('k.tel1', '=', $tel1);
        if ($tel2)
            $query->where('k.tel2', '=', $tel2);
        if ($brojBodova)
            $query->where('k.br_bodova', '=', $brojBodova);
        if ($mesec)
            $query->where('k.mesec', '=', $mesec);
        if ($agentIme)
            $query->where('k.agent_ime', '=', $agentIme);
        if ($agentPrezime)
            $query->where('k.agent_prezime', '=', $agentPrezime);
        if ($agencija)
            $query->where('k.agencija', '=', $agencija);
        if ($regionalniCentar)
            $query->where('k.regionalni_centar', '=', $regionalniCentar);
        if ($datumObilaska)
            $query->where('k.datum_obilaska', '=', $datumObilaska);
        if ($paket)
            $query->where('k.paket', '=', $paket);
        if ($mesto)
            $query->where('k.mesto', '=', $mesto);
        if ($email)
            $query->where('k.email', '=', $email);
        if ($tipUgovora)
            $query->where('k.tip_ugovora', '=', $tipUgovora);
        if ($start && $end){
            $query->where('k.datum_montaze', '>=', $start);
            $query->where('k.datum_montaze', '<=', $end);
        }
        if($seller){
            $query->where('kp.id_prodavac', '=', $seller);
        }
        if($callistoId){
            $query->where('k.id', '=', $callistoId);
        }

        if($paginate)
            $result = $query->paginate(100);
        else
            $result = $query->get();

        return $result;
    }

    public function export($ids){
        $query = DB::table('klijenti_supernova as ks')
            ->leftJoin('statusi as s', 's.id', '=', 'ks.id_status')
            ->leftJoin('users as u', 'u.id', '=', 'ks.id_user')
            ->leftJoin('users as int', 'int.id', '=', 'ks.id_user_reklamacije')
            ->select('ks.broj_ugovora','ks.id', 'ks.klijent_ime as ime', 'ks.klijent_prezime as prezime', 'ks.regionalni_centar', 'ks.agent_ime', 'ks.agent_prezime', 'ks.br_bodova', 'ks.provajder',
                'ks.agencija', 'ks.mesec', 'ks.datum_obilaska', 'ks.datum_zahteva', 'ks.datum_zakazivanja', 'ks.datum_odlaganja', 'ks.datum_montaze', 'ks.datum_odustajanja', 'ks.updated_at',
                'ks.ulica', 'ks.kucni_broj', 'ks.mesto', 'ks.email','ks.tel1', 'ks.tel2', 'ks.tip_ugovora', 'ks.updated_by',  'u.ime as user_ime', 'u.prezime as user_prezime', 's.status',
                'u.id as id_user', 'ks.id_status', 'ks.paket', 'mesec', 'int.ime as nomen', 'int.prezime as surnomen'
            )
            ->whereIn('ks.id', $ids);

        $result = $query->get();

        return $result;
    }
}
