<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Model;
use Illuminate\Support\Facades\DB;

class Construction_sites extends Model
{
    protected $fillable = [
        'name',
        'tis_id',
        'contact_person',
        'tel1',
        'tel2',
        'tel3',
        'address',
        'id_city',
        'id_area',
        'id_status',
        'id_state',
        'id_currency',
        'discount_percent',
        'discount_percent_customer',
        'transport_costs',
        'project_manager',
        'id_contractor',
        'id_user',
        'appointment_date', 
        'delay_date', 
        'realization_date', 
        'withdrawal_date',
        'cluster',
        'odo',
        'izvod',
        'connector',
        'construction_manager',
        'price'
    ];
    public function construction_index($idUser=null, $idArea=null, $constructionManager=null){
        $query = DB::table('construction_sites as cs')
            ->leftJoin('cities as c', 'c.id', '=', 'cs.id_city')
            ->leftJoin('states as s', 's.id', '=', 'cs.id_state')
            ->leftJoin('areas as a', 'a.id', '=', 'cs.id_area')
            ->leftJoin('construction_status as st', 'st.id', '=', 'cs.id_status')
            ->leftJoin('users as u', 'u.id', '=', 'cs.id_user')
            ->select('cs.name', 'cs.address', 'c.city', 's.state', 'st.status', 'a.area', 'u.ime', 'u.prezime', 'cs.id');
        if ($idUser)
            $query->where('cs.id_user', '=', $idUser);
        if ($idArea)
            $query->where('cs.id_area', '=', $idArea);
        if ($constructionManager)
            $query->where('cs.construction_manager', '=', $constructionManager);

        $result = $query->paginate(50);
        return $result;
    }

    public function construction_monter($idUser=null){
        $query = DB::table('construction_sites as cs')
            ->leftJoin('cities as c', 'c.id', '=', 'cs.id_city')
            ->leftJoin('states as s', 's.id', '=', 'cs.id_state')
            ->leftJoin('areas as a', 'a.id', '=', 'cs.id_area')
            ->leftJoin('construction_status as st', 'st.id', '=', 'cs.id_status')
            ->leftJoin('users as u', 'u.id', '=', 'cs.id_user')
            ->select('cs.name', 'cs.address', 'c.city', 's.state', 'st.status', 'a.area', 'u.ime', 'u.prezime', 'cs.id')
            ->where('id_status', '=', 5)
            ;
        if ($idUser)
            $query->where('cs.id_user', '=', $idUser);

        $result = $query->paginate(50);
        return $result;
    }

    public function construction_data($id){
        $query = DB::table('construction_sites as cs')
            ->leftJoin('cities as c', 'c.id', '=', 'cs.id_city')
            ->leftJoin('states as s', 's.id', '=', 'cs.id_state')
            ->leftJoin('areas as a', 'a.id', '=', 'cs.id_area')
            ->leftJoin('construction_status as st', 'st.id', '=', 'cs.id_status')
            ->leftJoin('users as u', 'u.id', '=', 'cs.id_user')
            ->leftJoin('users as cm', 'cm.id', '=', 'cs.construction_manager')
            ->leftJoin('contractors as ctr', 'ctr.id', '=', 'cs.id_contractor')
            ->leftJoin('currency as cur', 'cur.id', '=', 'cs.id_currency')
            ->select('cs.id_user', 'cs.id', 'cs.name', 'cs.tis_id', 'contact_person', 'address', 'state', 'city', 'a.area', 'status',
                'currency', 'discount_percent', 'transport_costs', 'project_manager', 'contractor', 'u.ime as builder_name',
                'u.prezime as builder_surname', 'tel1', 'tel2', 'tel3', 'cs.id_city', 'cs.id_state', 'cs.id_area', 'cs.id_status', 'cs.id_user',
                'cs.id_contractor', 'cs.id_currency', 'cs.discount_percent_customer', 'appointment_date', 'delay_date', 'realization_date', 'withdrawal_date',
                'cs.created_at', 'cs.cluster', 'cs.odo', 'cs.izvod', 'cs.connector', 'cm.ime as construction_manager_name', 'cs.construction_manager',
                'cm.prezime as construction_manager_surname', 'price'
            )
            ->where('cs.id', '=', $id);

        $result = $query->get();
        return $result[0];
    }

    public function search($name=null, $tisId=null, $contactPerson=null, $tel1=null, $tel2=null, $tel3=null, $address=null, $state=null, $city=null, 
    $area=null, $status=null, $currency=null, $discount1=null, $discount2=null, $transport=null, $contractor=null, $worker=null, $projectManager=null, 
    $appointmentDate=null, $delayDate=null, $realizationDate=null, $withdrawalDate=null, $noStatus=null, $realStart=null, $realEnd=null, $cluster=null,
                           $odo=null, $izvod=null, $connector=null, $constructionManager=null, $paginate=false){
        $query = DB::table('construction_sites as cs')
            ->leftJoin('cities as c', 'c.id', '=', 'cs.id_city')
            ->leftJoin('states as s', 's.id', '=', 'cs.id_state')
            ->leftJoin('areas as a', 'a.id', '=', 'cs.id_area')
            ->leftJoin('construction_status as st', 'st.id', '=', 'cs.id_status')
            ->leftJoin('users as u', 'u.id', '=', 'cs.id_user')
            ->select('cs.name', 'cs.address', 'c.city', 's.state', 'st.status', 'a.area', 'u.ime', 'u.prezime', 'cs.id');
        if ($name)
            $query->where('cs.name', 'like',  '%'.$name.'%');
        if ($tisId)
            $query->where('cs.tis_id', '=', $tisId);
        if ($contactPerson)
            $query->where('cs.contact_person', 'like',  '%'.$contactPerson.'%');
        if ($tel1)
            $query->where('cs.tel1', '=', $tel1);
        if ($tel2)
            $query->where('cs.tel2', '=', $tel2);
        if ($tel3)
            $query->where('cs.tel3', '=', $tel3);
        if ($address)
            $query->where('cs.address', 'like',  '%'.$address.'%');
        if ($state)
            $query->where('cs.id_state', '=', $state);
        if ($city)
            $query->where('cs.id_city', '=', $city);
        if ($area)
            $query->where('cs.id_area', '=', $area);
        if ($status)
            $query->where('cs.id_status', '=', $status);
        if ($currency)
            $query->where('cs.id_currency', '=', $currency);
        if ($discount1)
            $query->where('cs.discount_percent', '=', $discount1);
        if ($discount2)
            $query->where('cs.discount_percent_customer', '=', $discount2);
        if ($transport)
            $query->where('cs.transport_costs', '=', $transport);
        if ($projectManager)
            $query->where('cs.project_manager', 'like',  '%'.$projectManager.'%');
        if ($contractor)
            $query->where('cs.id_contractor', '=', $contractor);
        if ($worker)
            $query->where('cs.id_user', '=', $worker);
        if ($appointmentDate)
            $query->whereDate('cs.appointment_date', '=', $appointmentDate);
        if ($delayDate)
            $query->whereDate('cs.delay_date', '=', $delayDate);
        if ($realizationDate)
            $query->where('cs.realization_date', '=', $realizationDate);
        if ($withdrawalDate)
            $query->where('cs.withdrawal_date', '=', $withdrawalDate);
        if($noStatus)
            $query->where('id_status', '=', null);
        if ($realStart && $realEnd){
            $query->where('cs.realization_date', '>=', $realStart);
            $query->where('cs.realization_date', '<=', $realEnd);
        }
        if($cluster)
            $query->where('cluster', '=', $cluster);
        if($odo)
            $query->where('odo', '=', $odo);
        if($izvod)
            $query->where('izvod', '=', $izvod);
        if($connector)
            $query->where('connector', '=', $connector);
        if($constructionManager)
            $query->where('construction_manager', '=', $constructionManager);
            

        if($paginate)
            $result = $query->paginate(50);
        else
            $result = $query->get();
        return $result;
    }
}
