<?php

namespace App\Models;

use App\User;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Support\Facades\DB;

class De_site_work extends Model
{
    protected $table = 'de_site_work';
    protected $fillable = ['site_id', 'work_id', 'quantity', 'price', 'sub_price'];

    public function works($site){
        $query = DB::table('de_site_work as sw')
            ->leftJoin('de_works as w', 'w.id', '=', 'sw.work_id')
            ->leftJoin('units as u', 'u.id', '=', 'w.unit_id')
            ->selectRaw('w.work, SUM(sw.quantity) as quantity, sw.work_id, w.code, u.unit_short, w.id, w.price, w.sub_price')
            ->where('sw.site_id', '=', $site)
            ->where('sw.work_id', '!=', null)
            ->groupBy('sw.work_id')
            ->orderBy('w.code', 'ASC')
        ;

        $result = $query->get();
        return $result;
    }

    public function workQuantity($site,$workId){
        $query = DB::table('de_site_work as sw')
            ->leftJoin('de_works as w', 'w.id', '=', 'sw.work_id')
            ->leftJoin('units as u', 'u.id', '=', 'w.unit_id')
            ->selectRaw('SUM(sw.quantity) as quantity')
            ->where('sw.site_id', '=', $site)
            ->where('sw.work_id', '=', $workId)
            ->groupBy('sw.work_id')
            ->orderBy('w.id', 'ASC')
        ;

        $result = $query->get();
        if($result->isEmpty())
            return 0;
        else
            return $result[0]->quantity;
    }

    public function workStatistic($start, $end, $leader, $polished){
        $query = DB::table('de_site_work as sw')
            ->leftJoin("de_works as w", 'w.id', '=', "sw.work_id")
            ->leftJoin("de_construction_sites as s", 's.id', '=', "sw.site_id")
            ->selectRaw("SUM(sw.quantity) as quantity, w.price*SUM(sw.quantity) as price, w.sub_price*SUM(sw.quantity) as sub_price, w.work")
            ->where('s.date', '>=', $start)
            ->where('s.date', '<=', $end)
            ->where('s.leader', '=', $leader)
            ->where('s.report_confirmed', '=', $polished)
            ->groupBy("sw.work_id")
            ->orderBy('w.work', 'ASC')
        ;

        $result = $query->get();
        if($result->isEmpty())
            return null;
        else
            return $result;
    }

    public function syntStatistic($start, $end, $leader, $cluster, $pan, $provider, $polished){
        $query = DB::table('de_site_work as sw')
            ->leftJoin("de_works as w", 'w.id', '=', "sw.work_id")
            ->leftJoin("de_construction_sites as s", 's.id', '=', "sw.site_id")
            ->selectRaw("SUM(sw.quantity) as quantity, w.price*SUM(sw.quantity) as price, w.sub_price*SUM(sw.quantity) as sub_price, w.work")
            ->where('s.date', '>=', $start)
            ->where('s.date', '<=', $end)
            ->whereIn('s.leader', $leader)
            ->where('s.report_confirmed', '=', $polished)
        ;

        if($cluster){
            $query->where('s.cluster', '=', $cluster);
        }
        if($pan){
            $query->where('s.pan_id', '=', $pan);
        }
        if($provider){
            $query->where('s.provider', '=', $provider);
        }

        $query->groupBy("sw.work_id")
                ->orderBy('w.work', 'ASC');

        $result = $query->get();
        if($result->isEmpty())
            return null;
        else
            return $result;
    }

}
