<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Model;
use Illuminate\Support\Facades\DB;

class Equipment extends Model
{
    protected $table = 'equipment';
    protected $fillable = ['code', 'equipment', 'id_category', 'quantity', 'is_active', 'type'];

    public function equipment($idCategory){
        $query = DB::table('equipment as e')
            ->select('*')
            ->where('id_category', '=', $idCategory)
            ->where('is_active', '=', 1);
            
        $result = $query->get();
        return $result;
    }

    /**
     * $code string
     * $name string
     * find id by code and name
     */
    public function equipmentId($code, $name){
        $query = DB::table('equipment')->select('id')->where('code', '=', $code);
        if($name){
            $query->orWhere('equipment', '=', $name);
        }
        $result = $query->get();
        if($result->isEmpty())
            return false;
        else
            return $result[0];
    }

    public function equipmentData($id){
        $query = DB::table('equipment as e')
            ->leftJoin('equipment_categories as ec', 'ec.id', '=', 'e.id_category')
            ->leftJoin('equipment_types as et', 'et.id', '=', 'e.type')
            ->select('e.code', 'e.equipment', 'e.id_category', 'ec.category', 'e.id', 'e.is_active', 'et.type', 'et.id as type_id')
            ->where('e.id', '=', $id);
            
        $result = $query->get();
        return $result[0];
    }

    public function equipmentIndex(){
        $query = DB::table('equipment as e')
            ->leftJoin('equipment_categories as ec', 'ec.id', '=', 'e.id_category')
            ->leftJoin('equipment_types as et', 'et.id', '=', 'e.type')
            ->select('e.code', 'e.equipment', 'e.id_category', 'ec.category', 'e.id', 'et.type')
            ->orderBy('e.id_category', 'ASC')
            ->orderBy('e.equipment', 'ASC');
            
        $result = $query->paginate(50);
        return $result;
    }
}
