<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Model;
use Illuminate\Support\Facades\DB;

class Fobos extends Model
{
    protected $fillable = [
        'cluster',
        'name_phone',
        'surname_phone',
        'street',
        'network_group',
        'tel1',
        'tel2',
        'tel3',
        'tis_id',
        'home_no',
        'enterance',
        'floor',
        'apartment',
        'statement_type',
        'packet',
        'uo_expire',
        'black_list',
        'recomended_tariff',
        'name_adsl',
        'surname_adsl',
        'adsl_tis_id',
        'adsl_isp',
        'uo_expire_adsl',
        'speed',
        'name_iptv',
        'surname_iptv',
        'iptv_tis',
        'hd_service',
        'setup_boxes',
        'uo_expire_iptv',
        'iptv_packet',
        'first_offer',
        'operator',
        'month',
        'year',
        'status_id',
        'seller_id',
        'expedited',
        'accepted',
        'contract_expire_date',
        'withdrawal_date',
        'withdrawal_reason',
        'created_by',
        'updated_by'
    ];
    public function clientsIndex($sellers=null, $lead=null, $expedited=null){
        $query = DB::table('fobos as f')
            ->leftJoin('users as u', 'u.id', '=', 'f.seller_id')
            ->select('f.id', 'f.name_phone as name', 'f.surname_phone as surname', 'f.tel1', 'f.tel2', 'f.tel3', 'u.ime as seller_name',
                'u.prezime as seller_surname', 'f.street', 'f.home_no', 'f.packet', 'f.created_at', 'f.network_group',
                'f.accepted', 'f.expedited', 'name_adsl', 'surname_adsl', 'name_iptv', 'surname_iptv')
            ->orderby('created_at', 'DESC')
        ;
        if($sellers){
            if(is_array($sellers)){
                $query->whereIn('seller_id', $sellers);
            }
            else {
                $query->where('seller_id', '=', $sellers);
            }
        }
        if($sellers && $lead){
            $query->whereIn('f.seller_id', $sellers)
                ->orWhere('k.seller_id', '=', $lead);
        }
        if($expedited){
            $query->where('f.expedited', '=', 1)->where('f.accepted', '!=', 1);
        }
        $result = $query->paginate(30);

        return $result;
    }

    public function clientData($id){
        $query = DB::table('fobos as f')
            ->leftJoin('users as u', 'u.id', '=', 'f.seller_id')
            ->leftJoin('fobos_statuses as s', 's.id', '=', 'f.status_id')
            ->leftJoin('users as upu', 'upu.id', '=', 'f.updated_by')
            ->select('f.id', 'f.cluster', 'f.name_phone', 'f.surname_phone', 'f.street', 'f.network_group', 'f.tel1', 'f.tel2', 'f.tel3', 'f.tis_id', 'f.home_no', 
            'f.enterance', 'f.floor', 'f.apartment', 'f.statement_type', 'f.packet', 'f.uo_expire', 'f.black_list', 'f.recomended_tariff', 'f.name_adsl', 
            'f.surname_adsl', 'f.adsl_tis_id', 'f.adsl_isp', 'f.uo_expire_adsl', 'f.speed', 'f.name_iptv', 'f.surname_iptv', 'f.iptv_tis', 'f.hd_service', 
            'f.setup_boxes', 'f.uo_expire_iptv', 'f.iptv_packet', 'f.first_offer', 'f.operator', 'f.month', 'f.year', 'f.seller_id', 'f.status_id', 'f.expedited', 
            'f.accepted', 'f.contract_expire_date', 'f.withdrawal_date', 'f.withdrawal_reason', 'f.created_by', 'f.updated_by', 'f.created_at', 'f.updated_at', 
            'upu.ime as updated_name', 'upu.prezime as updated_surname', 'u.ime as seller_name', 'u.prezime as seller_surname', 's.status')
            ->where('f.id', '=', $id)
        ;
        $result = $query->get();
        return $result[0];
    }


    public function search($cluster=null, $namePhone=null, $surnamePhone=null, $street=null, $homeNo=null, $enterance=null, $tel1=null, $tel2=null, $tel3=null, 
                            $floor=null, $apartment=null, $statementType=null, $networkGroup=null, $tisId=null, $packet=null, $uoExpire=null, $blackList=null, 
                            $recommendedTariff=null, $nameAdsl=null, $surnameAdsl=null, $adslTisId=null, $adslIsp=null, $uoExpireAdsl=null, $speed=null, 
                            $nameIptv=null, $surnameIptv=null, $iptvTis=null, $hdService=null, $setupBoxes=null, $uoExpireIptv=null, $iptvPacket=null, $firstOffer=null, 
                            $operator=null, $month=null, $year=null, $statusId=null, $accepted=null, $contractExpireDate=null, $withdrawalDate=null, 
                            $withdrawalReason=null, $sellerId=null){
        $query = DB::table('fobos as f')
            ->leftJoin('users as u', 'u.id', '=', 'f.seller_id')
            ->select('f.id', 'f.name_phone as name', 'f.surname_phone as surname', 'f.tel1', 'f.tel2', 'f.tel3', 'u.ime as seller_name',
                    'u.prezime as seller_surname', 'f.street', 'f.home_no', 'f.packet', 'f.created_at', 'f.network_group',
                    'f.accepted', 'f.expedited', 'name_adsl', 'surname_adsl', 'name_iptv', 'surname_iptv')
            ->orderby('created_at', 'DESC')
        ;
        if($cluster)
            $query->where('f.cluster', '=', $cluster);
        if($namePhone)
            $query->where('name_phone', 'like', '%'.$namePhone.'%');
        if($surnamePhone)
            $query->where('f.surname_phone', 'like', '%'.$surnamePhone.'%');
        if($street)
            $query->where('f.street', 'like', '%'.$street.'%');
        if($homeNo)
            $query->where('f.home_no', '=', $homeNo);
        if($enterance)
            $query->where('f.enterance', '=', $enterance);
        if($tel1)
            $query->where('f.tel1', '=', $tel1);
        if($tel2)
            $query->where('f.tel2', '=', $tel2);
        if($tel3)
            $query->where('f.tel3', '=', $tel3);
        if($floor)
            $query->where('f.floor', '=', $floor);
        if($apartment)
            $query->where('f.apartment', '=', $apartment);
        if($statementType)
            $query->where('f.statement_type', '=', $statementType);
        if($networkGroup)
            $query->where('f.network_group', '=', $networkGroup);
        if($tisId)
            $query->where('f.tis_id', '=', $tisId);
        if($packet)
            $query->where('f.packet', '=', $packet);
        if($uoExpire)
            $query->where('f.uo_expire', '=', $uoExpire);
        if($blackList)
            $query->where('f.black_list', '=', $blackList);
        if($recommendedTariff)
            $query->where('f.recomended_tariff', '=', $recommendedTariff);
        if($nameAdsl)
            $query->where('name_adsl', 'like', '%'.$nameAdsl.'%');
        if($surnameAdsl)
            $query->where('f.surname_adsl', 'like', '%'.$surnameAdsl.'%');
        if($adslTisId)
            $query->where('f.adsl_tis_id', '=', $adslTisId);
        if($adslIsp)
            $query->where('f.adsl_isp', '=', $adslIsp);
        if($uoExpireAdsl)
            $query->where('f.uo_expire_adsl', '=', $uoExpireAdsl);
        if($speed)
            $query->where('f.speed', '=', $speed);
        if($nameIptv)
            $query->where('name_iptv', 'like', '%'.$nameIptv.'%');
        if($surnameIptv)
            $query->where('f.surname_iptv', 'like', '%'.$surnameIptv.'%');
        if($iptvTis)
            $query->where('f.iptv_tis', '=', $iptvTis);
        if($hdService)
            $query->where('f.hd_service', '=', $hdService);
        if($setupBoxes)
            $query->where('f.setup_boxes', '=', $setupBoxes);
        if($uoExpireIptv)
            $query->where('f.uo_expire_iptv', '=', $uoExpireIptv);
        if($iptvPacket)
            $query->where('f.iptv_packet', '=', $iptvPacket);
        if($firstOffer)
            $query->where('f.first_offer', '=', $firstOffer);
        if($operator)
            $query->where('f.operator', '=', $operator);
        if($month)
            $query->where('f.month', '=', $month);
        if($year)
            $query->where('f.year', '=', $year);
        if($statusId)
            $query->where('f.status_id', '=', $statusId);
        if($accepted)
            $query->where('f.accepted', '=', $accepted);
        if($contractExpireDate)
            $query->where('f.contract_expire_date', '=', $contractExpireDate);
        if($withdrawalDate)
            $query->where('f.withdrawal_date', '=', $withdrawalDate);
        if($withdrawalReason)
            $query->where('f.withdrawal_reason', '=', $withdrawalReason);
        if($sellerId)
            $query->where('f.seller_id', '=', $sellerId);

        $result = $query->paginate(30);

        return $result;
    }

    public function expireList(){
        $date = date('Y-m-d');
        $oneMoreMonth = date('Y-m-d', strtotime('+1 months'));
        $query = DB::table('fobos as f')
            ->leftJoin('users as u', 'u.id', '=', 'f.seller_id')
            ->select('f.id', 'f.name_phone as name', 'f.surname_phone as surname', 'f.tel1', 'f.tel2', 'f.tel3', 'u.ime as seller_name',
                'u.prezime as seller_surname', 'f.street', 'f.home_no', 'f.packet', 'f.created_at', 'f.network_group',
                'f.accepted', 'f.expedited')
            ->where('f.contract_expire_date', '<=', $oneMoreMonth)
            ->where('f.contract_expire_date', '>=', $date)
        ;
        $result = $query->paginate(30);
        if ($result->isEmpty())
            return false;
        else
            return $result;
    }
}
