<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Model;
use DB;

class Fobos_copper extends Model
{
    protected $table = 'fobos_copper';
    protected $fillable = [
        'distributor',
        'cust_id',
        'name',
        'surname',
        'town',
        'subsettlement',
        'street',
        'home_no',
        'tel1',
        'tel2',
        'tel3',
        'network_group',
        'packet',
        'expiration_date_box',
        'resource',
        'max_net',
        'stb_no',
        'total_stb_box',
        'postpaid_number',
        'postpaid_expiration_date',
        'benefit',
        'postpaid_tariff',
        'recommended_tariff',
        'name_adsl',
        'surname_adsl',
        'cust_id_adsl',
        'expiration_date_adsl',
        'campain_adsl',
        'speed_adsl',
        'modem_type',
        'free_pair',
        'free_adsl',
        'free_vdsl',
        'name_iptv',
        'surname_iptv',
        'cust_id_iptv',
        'iptv_expiration_date',
        'campain_vdsl',
        'iptv_packet',
        'first_offer',
        'second_offer',
        'other_operators',
        'connection_date',
        'box2',
        'box3',
        'box4',
        'campain_box',
        'postpaid_tariff_box',
        'adsl',
        'campain_adsl_solo',
        'speed_adsl_solo',
        'iptv',
        'iptv_solo',
        'campain_iptv_solo',
        'status_id',
        'points',
        'seller_id',
        'expedited',
        'accepted',
        'contract_expire_date',
        'withdrawal_date',
        'withdrawal_reason',
        'created_by',
        'updated_by'
    ];

    public function clientsIndex($sellers=null, $lead=null, $expedited=null){
        $query = DB::table('fobos_copper as f')
            ->leftJoin('users as u', 'u.id', '=', 'f.seller_id')
            ->select('f.id', 'f.name', 'f.surname', 'f.tel1', 'f.tel2', 'f.tel3', 'u.ime as seller_name',
                'u.prezime as seller_surname', 'f.street', 'f.home_no', 'f.packet', 'f.created_at', 'f.network_group',
                'f.accepted', 'f.expedited', 'name_iptv', 'surname_iptv', 'name_iptv', 'surname_iptv', 'name_adsl', 'surname_adsl')
            ->orderby('created_at', 'DESC')
        ;
        if($sellers){
            if(is_array($sellers)){
                $query->whereIn('seller_id', $sellers);
            }
            else {
                $query->where('seller_id', '=', $sellers);
            }
        }
        if($sellers && $lead){
            $query->whereIn('f.seller_id', $sellers)
                ->orWhere('k.seller_id', '=', $lead);
        }
        if($expedited){
            $query->where('f.expedited', '=', 1)->where('f.accepted', '!=', 1);
        }
        $result = $query->paginate(30);

        return $result;
    }

    public function clientData($id){
        $query = DB::table('fobos_copper as f')
            ->leftJoin('users as u', 'u.id', '=', 'f.seller_id')
            ->leftJoin('fobos_statuses as s', 's.id', '=', 'f.status_id')
            ->leftJoin('postpaid_tariffs as pt', 'pt.id', '=', 'f.postpaid_tariff_box')
            ->leftJoin('users as ub', 'ub.id', '=', 'f.updated_by')
            ->leftJoin('users as cb', 'cb.id', '=', 'f.created_by')
            ->select('f.id', 'distributor','cust_id','name','surname','town','subsettlement','street','home_no','tel1','tel2','tel3','network_group','packet',
            'expiration_date_box','resource','max_net','stb_no','total_stb_box','postpaid_number','postpaid_expiration_date','benefit','postpaid_tariff',
            'recommended_tariff','name_adsl','surname_adsl','cust_id_adsl','expiration_date_adsl','campain_adsl','speed_adsl','modem_type','free_pair',
            'free_adsl','free_vdsl','name_iptv','surname_iptv','cust_id_iptv','iptv_expiration_date','campain_vdsl','iptv_packet','first_offer','second_offer',
            'other_operators','connection_date','box2','box3','box4','campain_box','pt.tariff','adsl','campain_adsl_solo','speed_adsl_solo','iptv','iptv_solo',
            'campain_iptv_solo','s.status', 'status_id', 'points','u.ime as seller_name','u.prezime as seller_surname','expedited','accepted','contract_expire_date',
            'withdrawal_date','withdrawal_reason','ub.ime as updated_name','ub.prezime as updated_surname','cb.ime as created_name', 
            'cb.prezime as created_surname','seller_id','f.updated_at','f.created_at')
            ->where('f.id', '=', $id)
        ;
        $result = $query->get();
        return $result[0];
    }

    public function search($custId=null,$name=null,$surname=null,$distributor=null,$town=null,$subsettlement=null,$street=null,$homeNo=null,$tel1=null,$tel2=null,
        $tel3=null,$networkGroup=null,$packet=null,$expirationDateBox=null,$resource=null,$maxNet=null,$stbNo=null,$totalStbBox=null,$postpaidNumber=null,
        $postpaidExpirationDate=null,$benefit=null,$postpaidTariff=null,$recommendedTariff=null,$nameAdsl=null,$surnameAdsl=null,$custIdAdsl=null,
        $expirationDateAdsl=null,$campainAdsl=null,$speedAdsl=null,$modemType=null,$freePair=null,$freeAdsl=null,$freeVdsl=null,$nameIptv=null,$surnameIptv=null,
        $custIdIptv=null,$iptvExpirationDate=null,$campainVdsl=null,$iptvPacket=null,$firstOffer=null,$secondOffer=null,$otherOperators=null,
        $connectionDate=null, $box2=null,
        $box3=null,$box4=null,$campainBox=null,$postpaidTariffBox=null,$adsl=null,$campainAdslSolo=null,$speedAdslSolo=null,$iptv=null,$iptvSolo=null,
        $campainIptvSolo=null,$statusId=null,$points=null,$sellerId=null,$contractExpireDate=null,$withdrawalDate=null,$withdrawalReason=null,$accepted=null){
        $query = DB::table('fobos_copper as f')
            ->leftJoin('users as u', 'u.id', '=', 'f.seller_id')
            ->select('f.id', 'f.name', 'f.surname', 'f.tel1', 'f.tel2', 'f.tel3', 'u.ime as seller_name',
                'u.prezime as seller_surname', 'f.street', 'f.home_no', 'f.packet', 'f.created_at', 'f.network_group',
                'f.accepted', 'f.expedited', 'name_iptv', 'surname_iptv', 'name_iptv', 'surname_iptv', 'name_adsl', 'surname_adsl')
            ->orderby('created_at', 'DESC')
        ;
        if($custId)
            $query->where('f.cust_id', '=', $custId);
        if($name)
            $query->where('f.name', '=', $name);
        if($surname)
            $query->where('f.surname', '=', $surname);
        if($distributor)
            $query->where('f.distributor', '=', $surname);
        if($town)
            $query->where('f.town', '=', $town);
        if($subsettlement)
            $query->where('f.subsettlement', '=', $subsettlement);
        if($street)
            $query->where('f.street', 'like', $street.'%');
        if($homeNo)
            $query->where('f.home_no', '=', $homeNo);
        if($tel1)
            $query->where('f.tel1', '=', $tel1);
        if($tel2)
            $query->where('f.tel2', '=', $tel2);
        if($tel3)
            $query->where('f.tel3', '=', $tel3);
        if($networkGroup)
            $query->where('f.network_group', '=', $networkGroup);
        if($packet)
            $query->where('f.packet', '=', $packet);
        if($expirationDateBox)
            $query->where('f.expiration_date_box', '=', $expirationDateBox);
        if($resource)
            $query->where('f.resource', '=', $resource);
        if($maxNet)
            $query->where('f.max_net', '=', $maxNet);
        if($stbNo)
            $query->where('f.stb_no', '=', $stbNo);
        if($totalStbBox)
            $query->where('f.total_stb_box', '=', $totalStbBox);
        if($postpaidNumber)
            $query->where('f.postpaid_number', '=', $postpaidNumber);
        if($postpaidExpirationDate)
            $query->where('f.postpaid_expiration_date', '=', $postpaidExpirationDate);
        if($benefit)
            $query->where('f.benefit', '=', $benefit);
        if($postpaidTariff)
            $query->where('f.postpaid_tariff', '=', $postpaidTariff);
        if($recommendedTariff)
            $query->where('f.recommended_tariff', '=', $recommendedTariff);
        if($nameAdsl)
            $query->where('f.name_adsl', '=', $nameAdsl);
        if($surnameAdsl)
            $query->where('f.surname_adsl', '=', $surnameAdsl);
        if($custIdAdsl)
            $query->where('f.cust_id_adsl', '=', $custIdAdsl);
        if($expirationDateAdsl)
            $query->where('f.expiration_date_adsl', '=', $expirationDateAdsl);
        if($campainAdsl)
            $query->where('f.campain_adsl', '=', $campainAdsl);
        if($speedAdsl)
            $query->where('f.speed_adsl', '=', $speedAdsl);
        if($modemType)
            $query->where('f.modem_type', '=', $modemType);
        if($freePair)
            $query->where('f.free_pair', '=', $freePair);
        if($freeAdsl)
            $query->where('f.free_adsl', '=', $freeAdsl);
        if($freeVdsl)
            $query->where('f.free_vdsl', '=', $freeVdsl);
        if($nameIptv)
            $query->where('f.name_iptv', '=', $nameIptv);
        if($surnameIptv)
            $query->where('f.surname_iptv', '=', $surnameIptv);
        if($custIdIptv)
            $query->where('f.cust_id_iptv', '=', $custIdIptv);
        if($iptvExpirationDate)
            $query->where('f.iptv_expiration_date', '=', $iptvExpirationDate);
        if($campainVdsl)
            $query->where('f.campain_vdsl', '=', $campainVdsl);
        if($iptvPacket)
            $query->where('f.iptv_packet', '=', $iptvPacket);
        if($firstOffer)
            $query->where('f.first_offer', '=', $firstOffer);
        if($secondOffer)
            $query->where('f.second_offer', '=', $secondOffer);
        if($otherOperators)
            $query->where('f.other_operators', '=', $otherOperators);
        if($connectionDate)
            $query->where('f.connection_date', '=', $connection_date);
        if($box2)
            $query->where('f.box2', '=', $box2);
        if($box3)
            $query->where('f.box3', '=', $box3);
        if($box4)
            $query->where('f.box4', '=', $box4);
        if($campainBox)
            $query->where('f.campain_box', '=', $campainBox);
        if($postpaidTariffBox)
            $query->where('f.postpaid_tariff_box', '=', $postpaidTariffBox);
        if($adsl)
            $query->where('f.adsl', '=', $adsl);
        if($campainAdslSolo)
            $query->where('f.campain_adsl_solo', '=', $campainAdslSolo);
        if($speedAdslSolo)
            $query->where('f.speed_adsl_solo', '=', $speedAdslSolo);
        if($iptv)
            $query->where('f.iptv', '=', $iptv);
        if($iptvSolo)
            $query->where('f.iptv_solo', '=', $iptvSolo);
        if($campainIptvSolo)
            $query->where('f.campain_iptv_solo', '=', $campainIptvSolo);
        if($statusId)
            $query->where('f.status_id', '=', $statusId);
        if($points)
            $query->where('f.points', '=', $points);
        if($sellerId)
            $query->where('f.seller_id', '=', $sellerId);
        if($contractExpireDate)
            $query->where('f.contract_expire_date', '=', $contractExpireDate);
        if($withdrawalDate)
            $query->where('f.withdrawal_date', '=', $withdrawalDate);
        if($withdrawalReason)
            $query->where('f.withdrawal_reason', 'like', '%'.$withdrawalReason.'%');
        if($accepted)
            $query->where('f.accepted', '=', 1);

        $result = $query->paginate(30);

        return $result;
    }

    public function expireList(){
        $date = date('Y-m-d');
        $oneMoreMonth = date('Y-m-d', strtotime('+1 months'));
        $query = DB::table('fobos_copper as f')
            ->leftJoin('users as u', 'u.id', '=', 'f.seller_id')
            ->select('f.id', 'f.name', 'f.surname', 'f.tel1', 'f.tel2', 'f.tel3', 'u.ime as seller_name',
                'u.prezime as seller_surname', 'f.street', 'f.home_no', 'f.packet', 'f.created_at', 'f.network_group',
                'f.accepted', 'f.expedited')
            ->where('f.contract_expire_date', '<=', $oneMoreMonth)
            ->where('f.contract_expire_date', '>=', $date)
        ;
        $result = $query->paginate(30);
        if ($result->isEmpty())
            return false;
        else
            return $result;
    }
}
