<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Model;
use Illuminate\Support\Facades\DB;

class Fobos_rune extends Model
{
    protected $table = 'fobos_rune';
    protected $fillable = ['cluster', 'name', 'surname','street','network_group','tel1','tel2','tel3','home_no','enterance','floor','apartment','packet','black_list','recomended_tariff',
    'first_offer','operator','month','year','status_id','seller_id','expedited','accepted','returned','contract_expire_date','withdrawal_date','withdrawal_reason','created_by',
        'updated_by','project_manager','pan','household','households','fobos_id','county','city','settlement','state','state_services','cable','thread','tube','case',
        'points','eta','x_coordinate','y_coordinate', 'team_leader', 'seller_assign_date', 'leader_assign_date', 'date_ku','date_rp','date_nz', 'date_nzv','date_nn',
        'date_ro', 'date_nnn', 'pan_id', 'penetration'
    ];
    public function clientsIndex($sellers=null, $lead=null, $expedited=null, $projectManagers=null){
        $query = DB::table('fobos_rune as f')
            ->leftJoin('users as u', 'u.id', '=', 'f.seller_id')
            ->leftJoin('fobos_statuses as s', 's.id', '=', 'f.status_id')
            ->leftJoin('clusters as c', 'c.id', '=', 'f.cluster')
            ->leftJoin('pans as p', 'p.id', '=', 'f.pan_id')
            ->select('f.id', 'c.cluster', 'c.id as cluster_id', 'f.name', 'f.surname', 'f.street', 'p.pan', 'u.ime as seller_name', 'u.prezime as seller_surname', 'f.home_no', 
            'f.packet', 'f.created_at',  'f.accepted', 'f.expedited', 's.status', 'f.returned', 's.id as status_id', 'fobos_id')
            ->orderby('created_at', 'DESC')
        ;
        if($sellers){
            if(is_array($sellers)){
                $query->whereIn('seller_id', $sellers);
            }
            else {
                $query->where('seller_id', '=', $sellers);
            }
        }
        if($lead){
            $query->where('f.team_leader', '=', $lead);
        }
        if($expedited){
            $query->where('f.expedited', '=', 1)->where('f.accepted', '!=', 1);
        }
        if($projectManagers){
            if(is_array($projectManagers)){
                $query->whereIn('project_manager', $projectManagers);
            }
            else {
                $query->where('projectManagers', '=', $projectManagers);
            }
        }
        $result = $query->paginate(30);

        return $result;
    }

    public function clientData($id){
        $query = DB::table('fobos_rune as f')
            ->leftJoin('users as u', 'u.id', '=', 'f.seller_id')
            ->leftJoin('users as tl', 'tl.id', '=', 'f.team_leader')
            ->leftJoin('fobos_statuses as s', 's.id', '=', 'f.status_id')
            ->leftJoin('users as upu', 'upu.id', '=', 'f.updated_by')
            ->leftJoin('users as pm', 'pm.id', '=', 'f.project_manager')
            ->leftJoin('clusters as c', 'c.id', '=', 'f.cluster')
            ->leftJoin('pans as p', 'p.id', '=', 'f.pan_id')
            ->select('f.id', 'c.cluster', 'f.name', 'f.surname','street','network_group','tel1','tel2','tel3','home_no','enterance','floor','apartment','packet','black_list','recomended_tariff','points',
            'first_offer','operator','month','year','status_id','seller_id','expedited','accepted','contract_expire_date','withdrawal_date','withdrawal_reason','created_by', 'f.pan_id',
            'updated_by','project_manager','p.pan','household','households','fobos_id','county','city','settlement','state','state_services','cable','thread','tube','case',
            'eta','x_coordinate','y_coordinate', 'upu.ime as updated_name', 'upu.prezime as updated_surname', 'u.ime as seller_name', 'u.prezime as seller_surname', 's.status', 'pm.ime as pm_name', 
            'pm.prezime as pm_surname', 'f.project_manager', 'f.updated_at', 'f.created_at', 'tl.ime as leader_name', 'tl.prezime as leader_surname', 'f.team_leader', 'f.cluster as cluster_id',
            'f.penetration')
            ->where('f.id', '=', $id)
        ;
        $result = $query->get();
        return $result[0];
    }


    public function search($cluster=null,$street=null,$pan=null,$homeNo=null,$enterance=null,$floor=null,$apartment=null,$tel1=null,$tel2=null,$tel3=null,$networkGroup=null,
    $statementType=null,$fobosId=null,$county=null,$city=null,$settlement=null,$household=null,$households=null,$state=null,$stateServices=null,$packet=null,$recommendedTariff=null,
    $blackList=null,$firstOffer=null,$operator=null,$month=null,$year=null,$seller=null,$status=null,$withdrawalDate=null,$withdrawalReason=null,$contractExpireDate=null,
    $projectManager=null,$points=null,$cable=null,$thread=null,$tube=null,$case=null,$xCoordinate=null,$yCoordinate=null,$teamLeader=null,$accepted=null,$statusLog=null,
    $statusStart,$statusEnd,$pagination=null){
        $query = DB::table('fobos_rune as f')
            ->leftJoin('users as u', 'u.id', '=', 'f.seller_id')
            ->leftJoin('fobos_statuses as s', 's.id', '=', 'f.status_id')
            ->leftJoin('clusters as c', 'c.id', '=', 'f.cluster')
            ->select('f.id', 'c.cluster', 'f.name', 'f.surname', 'f.street', 'f.pan', 'u.ime as seller_name', 'u.prezime as seller_surname', 'f.home_no', 
            'f.packet', 'f.created_at',  'f.accepted', 'f.expedited', 's.status', 'f.returned', 's.id as status_id', 'fobos_id')
            ->orderby('created_at', 'DESC')
        ;
        if($cluster)
            $query->where('f.cluster', '=', $cluster);
        if($street)
            $query->where('f.street', 'like', '%'.$street.'%');
        if($homeNo)
            $query->where('f.home_no', 'like', $homeNo.'%');
        if($enterance)
            $query->where('f.enterance', '=', $enterance);
        if($tel1)
            $query->where('f.tel1', '=', $tel1);
        if($tel2)
            $query->where('f.tel2', '=', $tel2);
        if($tel3)
            $query->where('f.tel3', '=', $tel3);
        if($floor)
            $query->where('f.floor', '=', $floor);
        if($apartment)
            $query->where('f.apartment', '=', $apartment);
        if($statementType)
            $query->where('f.eta', '=', $statementType);
        if($networkGroup)
            $query->where('f.network_group', '=', $networkGroup);
        if($pan)
            $query->where('f.pan_id', '=', $pan);
        if($packet)
            $query->where('f.packet', '=', $packet);
        if($fobosId)
            $query->where('f.fobos_id', '=', $fobosId);
        if($blackList)
            $query->where('f.black_list', '=', $blackList);
        if($recommendedTariff)
            $query->where('f.recomended_tariff', '=', $recommendedTariff);
        if($county)
            $query->where('f.county', '=', $county);
        if($city)
            $query->where('f.city', '=', $city);
        if($settlement)
            $query->where('f.settlement', '=', $settlement);
        if($household)
            $query->where('f.houslehold', '=', $household);
        if($households)
            $query->where('f.households', '=', $households);
        if($state)
            $query->where('f.state', '=', $state);
        if($stateServices)
            $query->where('f.state_services', '=', $stateServices);
        if($points)
            $query->where('f.points', '=', $points);
        if($cable)
            $query->where('f.cable', '=', $cable);
        if($tube)
            $query->where('f.tube', '=', $tube);
        if($thread)
            $query->where('f.thread', '=', $thread);
        if($case)
            $query->where('f.case', '=', $case);
        if($thread)
            $query->where('f.thread', '=', $thread);
        if($firstOffer)
            $query->where('f.first_offer', '=', $firstOffer);
        if($operator)
            $query->where('f.operator', '=', $operator);
        if($month)
            $query->where('f.month', '=', $month);
        if($year)
            $query->where('f.year', '=', $year);
        if($status)
            $query->whereIn('f.status_id', $status);
        if($accepted)
            $query->where('f.accepted', '=', $accepted);
        if($contractExpireDate)
            $query->where('f.contract_expire_date', '=', $contractExpireDate);
        if($withdrawalDate)
            $query->where('f.withdrawal_date', '=', $withdrawalDate);
        if($withdrawalReason)
            $query->where('f.withdrawal_reason', '=', $withdrawalReason);
        if($seller & !$statusLog && !$statusStart && !$statusEnd)
            $query->whereIn('f.seller_id', $seller);
        if($projectManager)
            $query->where('project_manager', '=', $projectManager);
        if($xCoordinate)
            $query->where('x_coordinate', '=', $xCoordinate);
        if($yCoordinate)
            $query->where('y_coordinate', '=', $yCoordinate);
        if($teamLeader)
            $query->where('team_leader', '=', $teamLeader);

        if($statusLog&&$statusStart&&$statusEnd){
            foreach($statusLog as $status){
                switch($status){
                    case 1 : $query->orWhere(function($q) use ($statusStart, $statusEnd, $status, $seller) {
                        $q->where('date_ku', '>=', $statusStart)->where('date_ku', '<=', $statusEnd)->where('status_id', '=', $status);
                        if($seller){
                            $q->whereIn('f.seller_id', $seller);
                        }
                    });
                    break;
                    case 2 : $query->orWhere(function($q) use ($statusStart, $statusEnd, $status, $seller) {
                        $q->where('date_rp', '>=', $statusStart)->where('date_rp', '<=', $statusEnd)->where('status_id', '=', $status);
                        if($seller){
                            $q->whereIn('f.seller_id', $seller);
                        }
                    });
                    break;
                    case 3 : $query->orWhere(function($q) use ($statusStart, $statusEnd, $status, $seller) {
                        $q->where('date_nz', '>=', $statusStart)->where('date_nz', '<=', $statusEnd)->where('status_id', '=', $status);
                        if($seller){
                            $q->whereIn('f.seller_id', $seller);
                        }
                    });
                    break;
                    case 4 : $query->orWhere(function($q) use ($statusStart, $statusEnd, $status, $seller) {
                        $q->where('date_nzv', '>=', $statusStart)->where('date_nzv', '<=', $statusEnd)->where('status_id', '=', $status);
                        if($seller){
                            $q->whereIn('f.seller_id', $seller);
                        }
                    });
                    break;
                    case 5 : $query->orWhere(function($q) use ($statusStart, $statusEnd, $status, $seller) {
                        $q->where('date_nn', '>=', $statusStart)->where('date_nn', '<=', $statusEnd)->where('status_id', '=', $status);
                        if($seller){
                            $q->whereIn('f.seller_id', $seller);
                        }
                    });
                    break;
                    case 6 : $query->orWhere(function($q) use ($statusStart, $statusEnd, $status, $seller) {
                        $q->where('date_ro', '>=', $statusStart)->where('date_rp', '<=', $statusEnd)->where('status_id', '=', $status);
                        if($seller){
                            $q->whereIn('f.seller_id', $seller);
                        }
                    });
                    break;
                    case 7 : $query->orWhere(function($q) use ($statusStart, $statusEnd, $status, $seller) {
                        $q->where('date_nnn', '>=', $statusStart)->where('date_nnn', '<=', $statusEnd)->where('status_id', '=', $status);
                        if($seller){
                            $q->whereIn('f.seller_id', $seller);
                        }
                    });
                    break;
                }
            }
        }

        if($pagination){
            $result = $query->paginate(30);
        }
        else{
            $result = $query->get();
        }

        return $result;
    }

    public function searchStatusLogs($status,$start,$end,$pagination=null){
        $query = DB::table('fobos_rune as f')
            ->leftJoin('users as u', 'u.id', '=', 'f.seller_id')
            ->leftJoin('fobos_statuses as s', 's.id', '=', 'f.status_id')
            ->leftJoin('clusters as c', 'c.id', '=', 'f.cluster')
            ->leftJoin('fobos_status_logs as fsl', 'fsl.fobos_id', '=', 'f.id')
            ->select('f.id', 'c.cluster', 'f.name', 'f.surname', 'f.street', 'f.pan', 'u.ime as seller_name', 'u.prezime as seller_surname', 'f.home_no', 
            'f.packet', 'f.created_at',  'f.accepted', 'f.expedited', 's.status', 'f.returned')
            ->whereDate('fsl.created_at', '>=', $start)
            ->whereDate('fsl.created_at', '<=', $end)
            ->where('fsl.status_id', $status)
            ->orderby('f.created_at', 'DESC')
            ->orderby('fsl.created_at', 'DESC')
            ->distinct()
        ;
        if($pagination){
            $result = $query->paginate(30);
        }
        else{
            $result = $query->get();
        }

        return $result;
    }

    public function expireList($seller=null){
        $date = date('Y-m-d');
        $oneMoreMonth = date('Y-m-d', strtotime('+1 months'));
        $query = DB::table('fobos_rune as f')
            ->leftJoin('users as u', 'u.id', '=', 'f.seller_id')
            ->leftJoin('fobos_statuses as s', 's.id', '=', 'f.status_id')
            ->leftJoin('clusters as c', 'c.id', '=', 'f.cluster')
            ->select('f.id', 'c.cluster', 'c.id as cluster_id', 'f.name', 'f.surname', 'f.street', 'f.pan', 'u.ime as seller_name', 'u.prezime as seller_surname', 'f.home_no', 
            'f.packet', 'f.created_at',  'f.accepted', 'f.expedited', 's.status', 'f.returned')
            ->where('f.contract_expire_date', '<=', $oneMoreMonth)
            ->where('f.contract_expire_date', '>=', $date)
        ;
        if($seller)
            $query->where('seller_id', $seller);
        $result = $query->paginate(30);
        if ($result->isEmpty())
            return false;
        else
            return $result;
    }

    public function export($id){
        $query = DB::table('fobos_rune as f')
            ->leftJoin('users as u', 'u.id', '=', 'f.seller_id')
            ->leftJoin('users as tl', 'tl.id', '=', 'f.team_leader')
            ->leftJoin('fobos_statuses as s', 's.id', '=', 'f.status_id')
            ->leftJoin('users as upu', 'upu.id', '=', 'f.updated_by')
            ->leftJoin('users as pm', 'pm.id', '=', 'f.project_manager')
            ->select('f.id', 'cluster', 'f.name', 'f.surname','street','network_group','tel1','tel2','tel3','home_no','enterance','floor','apartment','packet','black_list','recomended_tariff','points',
            'first_offer','operator','month','year','status_id','seller_id','expedited','accepted','contract_expire_date','withdrawal_date','withdrawal_reason','created_by',
            'updated_by','project_manager','pan','household','households','fobos_id','county','city','settlement','state','state_services','cable','thread','tube','case',
            'eta','x_coordinate','y_coordinate', 'upu.ime as updated_name', 'upu.prezime as updated_surname', 'u.ime as seller_name', 'u.prezime as seller_surname', 's.status', 'pm.ime as pm_name', 
            'pm.prezime as pm_surname', 'f.project_manager', 'f.updated_at', 'f.created_at', 'tl.ime as leader_name', 'tl.prezime as leader_surname', 'f.team_leader')
            ->whereIn('f.id', $id)
        ;
        $result = $query->get();
        return $result;
    }

    public function fobosScoreboard($id){
        $query = DB::table('fobos_rune as f')
            ->leftJoin('users as u', 'u.id', '=', 'f.seller_id')
            ->leftJoin('users as tl', 'tl.id', '=', 'f.team_leader')
            ->select('f.id', 'cluster', 'f.name', 'f.surname','street','network_group','tel1','tel2','tel3','home_no','enterance','floor','apartment','packet','black_list','recomended_tariff','points',
            'first_offer','operator','month','year','status_id','seller_id','expedited','accepted','contract_expire_date','withdrawal_date','withdrawal_reason','created_by',
            'updated_by','project_manager','pan','household','households','fobos_id','county','city','settlement','state','state_services','cable','thread','tube','case',
            'eta','x_coordinate','y_coordinate', 'upu.ime as updated_name', 'upu.prezime as updated_surname', 'u.ime as seller_name', 'u.prezime as seller_surname', 's.status', 'pm.ime as pm_name', 
            'pm.prezime as pm_surname', 'f.project_manager', 'f.updated_at', 'f.created_at', 'tl.ime as leader_name', 'tl.prezime as leader_surname', 'f.team_leader')
            ->whereIn('f.seller_id', $id)
        ;
        $result = $query->get();
        return $result;
    }

    public function totalAssigned($id){
        $query = DB::table('fobos_rune')
        ->selectRaw('count(id) as count')
        ->where('seller_id', $id)
        ->orderBy('status_id');

        $result = $query->get()->first();
        return $result->count;
    }
    public function totalAssignedInRange($id,$start,$end){
        $query = DB::table('fobos_rune')
        ->selectRaw('count(id) as count')
        ->where('seller_id', $id)
        ->where(function($q) use ($start, $end){
            $q->where('date_ku', '>=', $start)->where('date_ku', '<=', $end)
            ->orWhere('date_rp', '>=', $start)->where('date_rp', '<=', $end)
            ->orWhere('date_nz', '>=', $start)->where('date_nz', '<=', $end)
            ->orWhere('date_nzv', '>=', $start)->where('date_nzv', '<=', $end)
            ->orWhere('date_nn', '>=', $start)->where('date_nn', '<=', $end)
            ->orWhere('date_ro', '>=', $start)->where('date_ro', '<=', $end)
            ->orWhere('date_nnn', '>=', $start)->where('date_nnn', '<=', $end)
            ;
        });
        $query->orderBy('status_id');

        $result = $query->get()->first();
        return $result->count;
    }

    public function totalAssignedLead($id){
        $query = DB::table('fobos_rune')
            ->selectRaw('count(id) as count')
            ->where('team_leader', $id)
        ;
        $result = $query->get()->first();
        return $result->count;
    }

    public function totalAssignedInRangeLead($sellers,$start,$end){
        $query = DB::table('fobos_rune')
            ->selectRaw('count(id) as count')
            ->whereIn('seller_id', $sellers)
            ->where(function($q) use ($start, $end){
                $q->where('date_ku', '>=', $start)->where('date_ku', '<=', $end)
                ->orWhere('date_rp', '>=', $start)->where('date_rp', '<=', $end)
                ->orWhere('date_nz', '>=', $start)->where('date_nz', '<=', $end)
                ->orWhere('date_nzv', '>=', $start)->where('date_nzv', '<=', $end)
                ->orWhere('date_nn', '>=', $start)->where('date_nn', '<=', $end)
                ->orWhere('date_ro', '>=', $start)->where('date_ro', '<=', $end)
                ->orWhere('date_nnn', '>=', $start)->where('date_nnn', '<=', $end)
                ;
            });
        ;
        $result = $query->get()->first();
        return $result->count;
    }

    public function countForStatus($id,$status,$start,$end,$sellers=null){

        $query = DB::table('fobos_rune')
            ->selectRaw('count(id) as count')
            ->where('status_id', $status)
            ;
        if($id)
            $query->where('seller_id', $id);
        else
            $query->whereIn('seller_id', $sellers);
        if($start && $end){
            switch($status){
                case 1 : 
                    $query->where('date_ku', '>=', $start)->where('date_ku', '<=', $end);
                break;
                case 2 : 
                    $query->where('date_rp', '>=', $start)->where('date_rp', '<=', $end);
                break;
                case 3 : 
                    $query->where('date_nz', '>=', $start)->where('date_nz', '<=', $end);
                break;
                case 4 : 
                    $query->where('date_nzv', '>=', $start)->where('date_nzv', '<=', $end);
                break;
                case 5 : 
                    $query->where('date_nn', '>=', $start)->where('date_nn', '<=', $end);
                break;
                case 6 : 
                    $query->where('date_ro', '>=', $start)->where('date_ro', '<=', $end);
                break;
                case 7 : 
                    $query->where('date_nnn', '>=', $start)->where('date_nnn', '<=', $end);
                break;
            }
        }
        $result = $query->get()->first();
        return $result->count;
    }

    public function totalByStatus($pan,$status=null){
        $query = DB::table('fobos_rune')
        ->selectRaw('count(id) as count')
        ->where('pan_id', $pan);
        
        if($status)
            $query->where('status_id', $status);

        $result = $query->get()->first();
        return $result->count;
    }

    public function scoreboard($date=null, $start=null, $end=null, $seller, $status){
        $query = DB::table('fobos_rune as f')
        ->leftJoin('users as u', 'u.id', '=', 'f.seller_id')
        ->leftJoin('users as tl', 'tl.id', '=', 'f.team_leader')
        ->selectRaw('count(f.id) as count, u.ime as seller_name, u.prezime as seller_surname, tl.ime as team_name, tl.prezime as team_surname')
        ->where('f.seller_id', $seller)
        ->where('f.status_id', $status)
        ;

        if($date){
            $query->where('date_ku', '=', $date);
        }
        elseif($start && $end){
            $query->where('date_ku', '>=', $start)->where('date_ku', '<=', $end);
        }

        $result = $query->orderBy('u.ime', 'ASC')->get()->first();

        return $result;
    }

    public function scoreboardTotal($date=null, $start=null, $end=null){
        $query = DB::table('fobos_rune as f')
        ->selectRaw('count(f.id) as count')
        ->where('f.status_id', 1)
        ->whereNotNull('f.seller_id')
        ;

        if($date){
            $query->where('date_ku', '=', $date);
        }
        elseif($start && $end){
            $query->where('date_ku', '>=', $start)->where('date_ku', '<=', $end);
        }

        $result = $query->get();
        if($result->isEmpty())
            return 0;
        else
            return $result[0]->count*30;
    }

    public function scoreboardAnal($date=null, $start=null, $end=null, $status){
        $query = DB::table('fobos_rune as f')
        ->leftJoin('users as u', 'u.id', '=', 'f.seller_id')
        ->leftJoin('users as tl', 'tl.id', '=', 'f.team_leader')
        ->leftJoin('clusters as c', 'c.id', '=', 'f.cluster')
        ->leftJoin('pans as p', 'p.id', '=', 'f.pan_id')
        ->selectRaw('distinct(f.id),u.ime as seller_name, u.prezime as seller_surname, tl.ime as team_name, tl.prezime as team_surname, f.fobos_id, c.cluster, p.pan');

        if($date){
            $query->where('date_ku', '=', $date);
        }
        elseif($start && $end){
            $query->where('date_ku', '>=', $start)->where('date_ku', '<=', $end);
        }

        $query->where('f.status_id', $status)
            ->orderBy('u.ime', 'ASC');

        $data = $query->get();

        return $data;
    }


}
