<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Model;
use Illuminate\Support\Facades\DB;

class Fobos_status_logs extends Model
{
    protected $fillable = ['user_id', 'status_id', 'fobos_id', 'updated_at', 'created_at'];

    public function findLog($date, $seller, $status){
        $data = DB::table('fobos_status_logs as l')
        ->leftJoin('fobos_rune as f', 'f.id', '=', 'l.fobos_id')
        ->leftJoin('users as u', 'u.id', '=', 'f.seller_id')
        ->leftJoin('users as tl', 'tl.id', '=', 'f.team_leader')
        ->selectRaw('count(l.id) as count, u.ime as seller_name, u.prezime as seller_surname, tl.ime as team_name, tl.prezime as team_surname')
        ->whereDate('l.created_at', $date)
        ->where('l.user_id', $seller)
        ->where('l.status_id', $status)
        ->get()
        ->first();

        return $data;
    }

    public function fobosScoreboard($date, $status){
        $data = DB::table('fobos_status_logs as l')
        ->leftJoin('fobos_rune as f', 'f.id', '=', 'l.fobos_id')
        ->leftJoin('users as u', 'u.id', '=', 'f.seller_id')
        ->leftJoin('users as tl', 'tl.id', '=', 'f.team_leader')
        ->leftJoin('clusters as c', 'c.id', '=', 'f.cluster')
        ->selectRaw('distinct(l.fobos_id),u.ime as seller_name, u.prezime as seller_surname, tl.ime as team_name, tl.prezime as team_surname, f.fobos_id, c.cluster')
        ->whereDate('l.created_at', $date)
        ->where('l.status_id', $status)
        ->orderBy('u.ime', 'ASC')
        ->get();

        return $data;
    }

    public function statistic($date, $seller, $start=null, $end=null){
        $query = DB::table('fobos_status_logs as l')
        ->selectRaw('count(distinct(l.fobos_id)) as count, s.status')
        ->leftJoin('fobos_statuses as s', 's.id','l.status_id')
        ->where('user_id', $seller)
        ;

        if($start && $end){
            $query->whereDate('l.created_at', '>=', $start)->whereDate('l.created_at', '<=', $end);
        }
        else{
            $query->whereDate('l.created_at', $date);
        }
        $query->groupBy('user_id', 'status_id')->orderBy('status_id', 'ASC');

        return $query->get();
    }

    public function allChanges($date, $seller=null, $start=null, $end=null, $sellers=null){
        $query = DB::table('fobos_status_logs as l')
        ->selectRaw('count(l.id) as count')
        ;

        if($seller){
            $query->where('user_id', $seller);
        }
        if($sellers){
            $query->whereIn('user_id', $sellers);
        }

        if($start && $end){
            $query->whereDate('l.created_at', '>=', $start)->whereDate('l.created_at', '<=', $end);
        }
        else{
            $query->whereDate('l.created_at', $date);
        }
        $query->orderBy('status_id', 'ASC');

        $result = $query->get()->first();
        if($result){
            return $result->count;
        }
        else {
            return 0;
        }
    }

    public function statisticTeam($date, $sellers, $start=null, $end=null){
        $query = DB::table('fobos_status_logs as l')
        ->selectRaw('count(distinct(l.id)) as count, s.status')
        ->leftJoin('fobos_statuses as s', 's.id','l.status_id')
        ->whereIn('user_id', $sellers)
        ;

        if($start && $end){
            $query->whereDate('l.created_at', '>=', $start)->whereDate('l.created_at', '<=', $end);
        }
        else{
            $query->whereDate('l.created_at', $date);
        }
        $query->groupBy('status_id')->orderBy('status_id', 'ASC');

        return $query->get();
    }

}
