<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Model;
use Illuminate\Support\Facades\DB;

class Ger_site_work extends Model
{
    protected $table = 'ger_site_work';
    protected $fillable = ['site_id', 'work_id', 'quantity', 'price'];

    public function works($site){
        $query = DB::table('ger_site_work as sw')
            ->leftJoin('ger_works as w', 'w.id', '=', 'sw.work_id')
            ->leftJoin('units as u', 'u.id', '=', 'w.unit_id')
            ->selectRaw('w.work, SUM(sw.quantity) as quantity, sw.work_id, w.code, u.unit_short, w.id, w.price')
            ->where('sw.site_id', '=', $site)
            ->where('sw.work_id', '!=', null)
            ->groupBy('sw.work_id')
            ->orderBy('w.id', 'ASC')
        ;

        $result = $query->get();
        return $result;
    }

    public function workQuantity($site,$workId){
        $query = DB::table('ger_site_work as sw')
            ->leftJoin('ger_works as w', 'w.id', '=', 'sw.work_id')
            ->leftJoin('units as u', 'u.id', '=', 'w.unit_id')
            ->selectRaw('SUM(sw.quantity) as quantity')
            ->where('sw.site_id', '=', $site)
            ->where('sw.work_id', '=', $workId)
            ->groupBy('sw.work_id')
            ->orderBy('w.id', 'ASC')
        ;

        $result = $query->get();
        if($result->isEmpty())
            return 0;
        else
            return $result[0]->quantity;
    }

    public function workStatistic($start, $end, $leader){
        $query = DB::table('ger_site_work as sw')
            ->leftJoin("ger_works as w", 'w.id', '=', "sw.work_id")
            ->leftJoin("ger_construction_sites as s", 's.id', '=', "sw.site_id")
            ->selectRaw('SUM(sw.quantity) as quantity, w.price*SUM(sw.quantity) as price, w.work')
            ->where('s.date', '>=', $start)
            ->where('s.date', '<=', $end)
            ->where('s.leader', '=', $leader)
            ->groupBy("sw.work_id")
            ->orderBy('w.work', 'ASC')
        ;

        $result = $query->get();
        if($result->isEmpty())
            return null;
        else
            return $result;
    }

}
