<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Model;
use Illuminate\Support\Facades\DB;

class Required_equipment extends Model
{
    protected $table = 'required_equipment';
    protected $fillable = ['equipment_id', 'site_id', 'quantity', 'created_by', 'supplied', 'supplied_by', 'supplied_to', 'edited_quantity', 'supplied_quantity'];

    public function required_equipment($siteId){
        $query = DB::table('required_equipment as re')
            ->leftJoin('equipment as e', 'e.id', '=', 're.equipment_id')
            ->leftJoin('users as u', 'u.id', '=', 're.created_by')
            ->select('e.code', 'e.equipment', 're.quantity', 'u.ime as name', 'u.prezime as surname', 're.id')
            ->where('site_id', '=', $siteId)
        ;

        $result = $query->get();
        return $result;
    }

    public function required_equipment_list(){
        $query = DB::table('required_equipment as re')
            ->leftJoin('equipment as e', 'e.id', '=', 're.equipment_id')
            ->leftJoin('users as u', 'u.id', '=', 're.created_by')
            ->leftJoin('users as sp', 'sp.id', '=', 're.supplied_by')
            ->leftJoin('huawei as h', 'h.id', '=', 're.site_id')
            ->leftJoin('users as vu', 'vu.id', '=', 'h.id_user_vertical')
            ->leftJoin('users as su', 'su.id', '=', 'h.id_user_splicing')
            ->leftJoin('users as sup', 'sup.id', '=', 're.supplied_to')
            ->select('e.code', 'e.equipment', 're.quantity', 'u.ime as require_name', 'u.prezime as require_surname', 're.id', 'h.name as construction_site', 'sp.ime as supply_name',
                'sp.prezime as supply_surname', 're.created_at', 're.supplied', 'vu.ime as fitter_name', 'vu.prezime as fitter_surname', 'h.appointment_date_vertical', 'h.id_user_vertical', 're.equipment_id',
                'su.ime as splicing_name', 'su.prezime as splicing_surname', 'edited_quantity', 'supplied_quantity', 'sup.ime as  supplied_to_name', 'sup.prezime as  supplied_to_surname', 'ready')
            ->orderBy('re.created_at', 'desc')
        ;

        $result = $query->paginate(50);
        return $result;
    }

    public function sum_equipment($siteId, $equipmentId){
        $query = DB::table('required_equipment as re')
            ->selectRaw('SUM(quantity) as quantity')
            ->where('site_id', '=', $siteId)
            ->where('equipment_id', '=', $equipmentId)
            ->groupBy('equipment_id');
        ;

        $result = $query->get();
        if($result->isEmpty())
            return 0;
        else
            return $result[0]->quantity;
    }

    public function search_result($address=null, $table, $site, $pagination=false){
        $query = DB::table("$table as re")
            ->leftJoin('equipment as e', 'e.id', '=', 're.equipment_id')
            ->leftJoin('users as u', 'u.id', '=', 're.created_by')
            ->leftJoin('users as sp', 'sp.id', '=', 're.supplied_by')
            ->leftJoin("$site as h", 'h.id', '=', 're.site_id')
            ->leftJoin('users as vu', 'vu.id', '=', 'h.id_user_vertical')
            ->leftJoin('users as su', 'su.id', '=', 'h.id_user_splicing')
            ->leftJoin('users as sup', 'sup.id', '=', 're.supplied_to')
            ->select('e.code', 'e.equipment', 're.quantity', 'u.ime as require_name', 'u.prezime as require_surname', 're.id', 'h.name as construction_site', 'sp.ime as supply_name',
                'sp.prezime as supply_surname', 're.created_at', 're.supplied', 'vu.ime as fitter_name', 'vu.prezime as fitter_surname', 'h.appointment_date_vertical', 'h.id_user_vertical', 
                're.supplied_quantity','re.equipment_id', 'su.ime as splicing_name', 'su.prezime as splicing_surname', 'edited_quantity', 'supplied_quantity', 'sup.ime as  supplied_to_name',
                'sup.prezime as  supplied_to_surname', 'ready')
        ;

        if($address){
            $query->where('h.id', '=', $address);
        }
        $query->orderBy('re.created_at', 'desc')
        ;

        if($pagination)
            $result = $query->paginate(100);
        else
            $result = $query->get();
        return $result;
    }

    public function data($id){
        $query = DB::table('required_equipment as re')
            ->leftJoin('equipment as e', 'e.id', '=', 're.equipment_id')
            ->leftJoin('users as u', 'u.id', '=', 're.created_by')
            ->leftJoin('users as sp', 'sp.id', '=', 're.supplied_by')
            ->leftJoin('huawei as h', 'h.id', '=', 're.site_id')
            ->leftJoin('users as vu', 'vu.id', '=', 'h.id_user_vertical')
            ->leftJoin('users as su', 'su.id', '=', 'h.id_user_splicing')
            ->leftJoin('users as sup', 'sup.id', '=', 're.supplied_to')
            ->select('e.code', 'e.equipment', 're.quantity', 'u.ime as require_name', 'u.prezime as require_surname', 're.id', 'h.name as construction_site', 'sp.ime as supply_name',
                'sp.prezime as supply_surname', 're.created_at', 're.supplied', 'vu.ime as fitter_name', 'vu.prezime as fitter_surname', 'h.appointment_date_vertical', 'h.id_user_vertical', 're.equipment_id',
                'su.ime as splicing_name', 'su.prezime as splicing_surname', 'edited_quantity', 'supplied_quantity', 'sup.ime as  supplied_to_name', 'sup.prezime as  supplied_to_surname', 'ready')
            ->where('re.id', '=', $id)
            ->orderBy('re.created_at', 'desc')
        ;

        $result = $query->first();
        return $result;
    }

    public function populate($value, $table){
        $query = DB::table($table)
            ->select('*')
            ->where("name", 'like', '%'.$value.'%')
            ->orderBy('name', 'ASC');
        $result = $query->get();
        return $result->toArray();
    }
}
