<?php

namespace App\Models;

use Hamcrest\Util;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Support\Facades\DB;

class Rune_optics extends Model
{
    protected $fillable = [
        'contract_number',
        'name',
        'surname',
        'claim_created_by',
        'area',
        'address',
        'claim',
        'seller',
        'points',
        'report_id',
        'user',
        'reclamation_user',
        'origin',
        'created_by',
        'claim_date',
        'appointment_date',
        'date_of_disposal',
        'reclamation_date',
        'montage_date',
        'montage_type',
        'client_sale',
        'withdrawal_date',
        'delay_date',
        'intervention_date',
        'withdrawal_reason',
        'intervention_status',
        'helper',
        'extra_stb',
        'on_terrain',
        'imported',
        'done',
        'decimal',
        'company_id',
        'cluster',
        'pan',
        'street',
        'eta',
        'network_group',
        'email',
        'tel1',
        'tel2',
        'tel3',
        'fobos_id',
        'county',
        'city',
        'settlement',
        'household',
        'households',
        'state',
        'state_services',
        'home_no',
        'enterance',
        'floor',
        'apartment',
        'packet',
        'black_list',
        'recomended_tariff',
        'first_offer',
        'operator',
        'month',
        'year',
        'status',
        'team_leader',
        'seller_id',
        'project_manager',
        'construction_manager',
        'contract_expire_date',
        'created_by',
        'updated_by',
        'cable',
        'tube',
        'thread',
        'case',
        'x_coordinate',
        'y_coordinate',
        'provider',
        'confirmed_in_rune_app',
        'rune_app_date',
        'drawn_into_qgis',
        'qgis_date',
        'additional_work',
        'additional_splicing',
        'contacted',
        'contact_date'
    ];

    public function index($userId=null, $projectManager=null,$constructionManager=null,$area=null,$providers=null,$seller=null){
        $query = DB::table('rune_optics as r')
            ->leftJoin('statusi as s', 's.id', '=', 'r.status')
            ->leftJoin('users as u', 'u.id', '=', 'r.user')
            ->leftJoin('clusters as c', 'c.id', '=', 'r.cluster')
            ->select('r.id', 'c.cluster', 'r.name', 'r.surname', 'r.street', 'r.pan', 'u.ime as fitter_name', 'r.home_no', 'r.packet',
               'u.prezime as fitter_surname', 's.status', 'r.created_at', 'r.claim_date', 'r.appointment_date', 'r.withdrawal_date', 'fobos_id');
        if($userId){
            $query->where('user', '=', $userId);
        }
        if($projectManager){
            $query->where('project_manager', '=', $projectManager);
        }
        if($constructionManager){
            $query->where('construction_manager', '=', $constructionManager);
        }
        if($seller){
            $query->where('seller_id', '=', $seller);
        }
        if($area && $providers){
            $query->where('area','=',$area);
            $query->whereIn('r.provider',$providers);
        }

        $query->orderby('r.created_at', 'DESC');

        $result = $query->paginate(15);

        return $result;
    }

    public function indexAdmin(){
        $query = DB::table('rune_optics as r')
            ->leftJoin('statusi as s', 's.id', '=', 'r.status')
            ->leftJoin('users as u', 'u.id', '=', 'r.user')
            ->leftJoin('clusters as c', 'c.id', '=', 'r.cluster')
            ->select('r.id', 'c.cluster', 'r.name', 'r.surname', 'r.street', 'r.pan', 'u.ime as fitter_name', 'r.home_no', 'r.packet',
                'u.prezime as fitter_surname', 's.status', 'r.created_at', 'r.claim_date', 'r.appointment_date', 'r.withdrawal_date', 'fobos_id')
            ->orderby('appointment_date', 'DESC')
            ->orderby('created_at', 'DESC')
        ;
        $result = $query->paginate(15);

        return $result;
    }

    public function data($clientId){
        $query = DB::table('rune_optics as r')
            ->leftJoin('users as u', 'r.user', '=', 'u.id')
            ->leftJoin('statusi as s', 'r.status', '=', 's.id')
            ->leftJoin('statusi_intervencije as stsi', 'r.intervention_status', '=', 'stsi.id')
            ->leftJoin('users as rek', 'r.reclamation_user', '=', 'rek.id')
            ->leftJoin('tip_montaze as tpm', 'tpm.id', '=', 'r.montage_type')
            ->leftJoin('users as ru', 'ru.id', '=', 'r.updated_by')
            ->leftJoin('users as ruc', 'ruc.id', '=', 'r.created_by')
            ->leftJoin('users as pm', 'pm.id', '=', 'r.project_manager')
            ->leftJoin('users as cm', 'cm.id', '=', 'r.construction_manager')
            ->leftJoin('users as sel', 'sel.id', '=', 'r.seller_id')
            ->leftJoin('users as tl', 'tl.id', '=', 'r.team_leader')
            ->leftJoin('origin as o', 'o.id', '=', 'r.origin')
            ->leftJoin('pomocnici as p', 'p.id', '=', 'r.helper')
            ->leftJoin('companies as com', 'com.id', '=', 'r.company_id')
            ->leftJoin('areas as a', 'a.id', '=', 'r.area')
            ->leftJoin('providers as pr', 'pr.id', '=', 'r.provider')
            ->leftJoin('clusters as c', 'c.id', '=', 'r.cluster')
            ->select('r.id','contract_number','name','surname','claim_created_by','address','claim','seller','points','report_id','user','reclamation_user',
            'o.origin','created_by','claim_date','appointment_date','date_of_disposal','reclamation_date','montage_date','montage_type','client_sale','withdrawal_date',
            'intervention_date','withdrawal_reason','intervention_status','helper','extra_stb','on_terrain','imported','done','decimal','r.company_id','c.cluster','pan',
            'street','eta','network_group','tel1','tel2','tel3','fobos_id','county','city','settlement','household','households','state','state_services',
            'home_no','enterance','floor','apartment','packet','black_list','recomended_tariff','first_offer','operator','month','year','s.status','seller_id',
            'project_manager','contract_expire_date','created_by','updated_by','cable','tube','thread','case','x_coordinate','y_coordinate', 'pm.ime as pm_name', 
            'pm.prezime as pm_surname', 'u.ime as fitter_name', 'u.prezime as fitter_surname', 'r.delay_date', 'r.intervention_date', 'rek.ime as reclamation_name', 
            'rek.prezime as reclamation_surname', 'ruc.ime as created_name', 'ruc.prezime as created_surname', 'p.ime as helper_name', 'p.prezime as helper_surname','r.updated_at',
            'sel.ime as seller_name', 'sel.prezime as seller_surname', 'r.email', 'tl.ime as team_leader_name', 'tl.prezime as team_leader_surname', 'a.area', 'pr.provider',
            'cm.ime as cm_name', 'cm.prezime as cm_surname', 'tpm.tip', 'rune_app_date', 'qgis_date', 'additional_work', 'additional_splicing', 'contacted', 'contact_date')
            ->where('r.id', '=', $clientId)
        ;

        $result = $query->get();
        return $result[0];
    }

    public function search($name = null, $surname = null, $fobosId=null, $user = null, $statusIds = null,
                                  $created_at = null, $montageDate=null, $withdrawalDate = null, $appointmentDate = null, $delayDate = null, $projectManager=null, 
                                  $constructionManager = null, $seller=null, $withoutStatus = null, $append=null, $pagination=null, $area=null, $providers=null)
    {
        $query = DB::table('rune_optics as r')
            ->leftJoin('statusi as s', 's.id', '=', 'r.status')
            ->leftJoin('users as u', 'u.id', '=', 'r.user')
            ->leftJoin('users as mont', 'mont.id', '=', 'r.reclamation_user')
            ->leftJoin('clusters as c', 'c.id', '=', 'r.cluster')
            ->select('r.id', 'r.name', 'r.surname', 'r.tel1', 'r.tel2', 'r.tel3', 'u.ime as fitter_name', 'c.cluster', 'r.street', 'home_no',
                'u.prezime as fitter_surname', 's.status', 'r.created_at', 'r.claim_date', 'r.appointment_date', 'r.packet', 
                'r.montage_date', 'r.withdrawal_date', 'mont.ime as monter_int_ime', 'mont.prezime as monter_int_prezime', 'r.address', 'fobos_id')
        ;
        if ($name)
            $query->where('r.name', 'like', $name.'%');
        if ($surname)
            $query->where('r.surname', 'like', $surname.'%');
        if ($fobosId)
            $query->where('r.fobos_id', '=', $fobosId);
        if ($user)
            $query->where('r.user', '=', $user);
        if ($statusIds)
            $query->whereIn('r.status', $statusIds);
        if ($created_at)
            $query->where('r.claim_date', '=', $created_at);
        if ($montageDate)
            $query->where('r.montage_date', '=', $montageDate);
        if ($withdrawalDate)
            $query->where('r.withdrawal_date', '=', $withdrawalDate);
        if ($appointmentDate)
            $query->whereDate('r.appointment_date', '=', $appointmentDate);
        if ($delayDate)
            $query->whereDate('r.delay_date', '=', $delayDate);
        if ($projectManager)
            $query->where('r.project_manager', '=', $projectManager);
        if ($constructionManager)
            $query->where('r.construction_manager', '=', $constructionManager);
        if ($seller)
            $query->where('r.seller_id', '=', $seller);
        if ($withoutStatus){
            if($append)
                $query->orWhere('r.status', '=', null);
            else
                $query->where('r.status', '=', null);
        }
        if($area && $providers){
            $query->where('area','=',$area);
            $query->where('r.provider',$providers);
        }

        if($pagination)
            $result = $query->paginate(100);
        else
            $result = $query->get();


        return $result;
    }

    public function advancedSearch($cluster=null,$street=null,$pan=null,$homeNo=null,$enterance=null,$floor=null,$apartment=null,$tel1=null,$tel2=null,$tel3=null,$eta=null,
    $fobosId=null,$networkGroup=null,$county=null,$city=null,$settlement=null,$household=null,$households=null,$state=null,$stateServices=null,$email=null,$packet=null,$seller=null,
    $status=null,$points=null,$recommendedTariff=null,$firstOffer=null,$cable=null,$thread=null,$tube=null,$case=null,$operator=null,$month=null,$year=null,$withdrawalDate=null,
    $contractExpireDate=null,$withdrawalReason=null,$xCoordinate=null,$yCoordinate=null,$teamLeader=null,$name=null,$surname=null,$claimCreatedby=null,$tisId=null,$address=null,
    $claim=null,$user=null,$projectManager=null,$constructionManager=null,$area=null,$montageType=null,$appointmentDate=null,$delayDate=null,$montageDate=null,$interventionStatus=null,$interventionDate=null,
    $reclamationUser=null,$reclamationDate=null,$montageStart=null,$montageEnd=null,$extraStb=null,$withoutStatus=null,$serial=null,$withoutProjectManager,
    $withoutConstructionManager,$notConfirmedInRune,$runeAppDate=null,$qgisDate=null,$additionalWork=null,$additionalSplicing=null,$contacted,$contactDate,$pagination=false)
    {
        $query = DB::table('rune_optics as r')
            ->leftJoin('statusi as s', 's.id', '=', 'r.status')
            ->leftJoin('users as u', 'u.id', '=', 'r.user')
            ->leftJoin('users as mont', 'mont.id', '=', 'r.reclamation_user')
            ->leftJoin('clusters as c', 'c.id', '=', 'r.cluster')
            ->select('r.id', 'r.name', 'r.surname', 'r.tel1', 'r.tel2', 'r.tel3', 'u.ime as fitter_name', 'c.cluster', 'r.street', 'home_no',
                'u.prezime as fitter_surname', 's.status', 'r.created_at', 'r.claim_date', 'r.appointment_date', 'r.packet', 
                'r.montage_date', 'r.withdrawal_date', 'mont.ime as monter_int_ime', 'mont.prezime as monter_int_prezime', 'r.address', 'fobos_id')
        ;
        if ($cluster)
            $query->where('r.cluster', '=', $cluster);
        if ($street)
            $query->where('r.street', 'like', $street.'%');
        if ($pan)
            $query->where('r.pan', '=', $pan);
        if ($homeNo)
            $query->where('r.home_no', '=', $homeNo);
        if ($enterance)
            $query->where('r.enterance', '=', $enterance);
        if ($floor)
            $query->where('r.floor', '=', $floor);
        if ($apartment)
            $query->where('r.apartment', '=', $apartment);
        if ($tel1)
            $query->where('r.tel1', '=', $tel1);
        if ($tel2)
            $query->where('r.tel2', '=', $tel2);
        if ($tel3)
            $query->where('r.tel3', '=', $tel3);
        if ($eta)
            $query->where('r.eta', '=', $eta);
        if ($fobosId)
            $query->where('r.fobos_id', '=', $fobosId);
        if ($networkGroup)
            $query->where('r.network_group', '=', $networkGroup);
        if ($county)
            $query->where('r.county', '=', $county);
        if ($city)
            $query->where('r.city', '=', $city);
        if ($settlement)
            $query->where('r.settlement', '=', $settlement);
        if ($household)
            $query->where('r.household', '=', $household);
        if ($households)
            $query->where('r.households', '=', $households);
        if ($state)
            $query->where('r.state', '=', $state);
        if ($stateServices)
            $query->where('r.state_services', '=', $stateServices);
        if ($email)
            $query->where('r.email', '=', $email);
        if ($points)
            $query->where('r.points', '=', $points);
        if ($recommendedTariff)
            $query->where('r.recomended_tariff', '=', $recommendedTariff);
        if ($firstOffer)
            $query->where('r.first_offer', '=', $firstOffer);
        if ($cable)
            $query->where('r.cable', '=', $cable);
        if($tube)
            $query->where('r.tube', '=', $tube);
        if($thread)
            $query->where('r.thread', '=', $thread);
        if($case)
            $query->where('r.case', '=', $case);
        if($thread)
            $query->where('r.thread', '=', $thread);
        if($operator)
            $query->where('r.operator', '=', $operator);
        if($month)
            $query->where('r.month', '=', $month);
        if($year)
            $query->where('r.year', '=', $year);
        if($packet)
            $query->where('r.packet', '=', $packet);
        if($contractExpireDate)
            $query->where('r.contract_expire_date', '=', $contractExpireDate);
        if($withdrawalReason)
            $query->where('r.withdrawal_reason', '=', $withdrawalReason);
        if($seller)
            $query->where('r.seller_id', '=', $seller);
        if($projectManager)
            $query->where('project_manager', '=', $projectManager);
        if ($constructionManager)
            $query->where('r.construction_manager', '=', $constructionManager);
        if($xCoordinate)
            $query->where('x_coordinate', '=', $xCoordinate);
        if($yCoordinate)
            $query->where('y_coordinate', '=', $yCoordinate);
        if($teamLeader)
            $query->where('team_leader', '=', $teamLeader);
        if ($name)
            $query->where('r.name', 'like', $name.'%');
        if ($surname)
            $query->where('r.surname', 'like', $surname.'%');
        if ($user)
            $query->where('r.user', '=', $user);
        if ($status)
            $query->whereIn('r.status', $status);
        if ($claimCreatedby)
            $query->where('r.claim_created_by', '=', $claimCreatedby);
        if ($montageDate)
            $query->where('r.montage_date', '=', $montageDate);
        if ($withdrawalDate)
            $query->where('r.withdrawal_date', '=', $withdrawalDate);
        if ($appointmentDate)
            $query->whereDate('r.appointment_date', '=', $appointmentDate);
        if ($delayDate)
            $query->whereDate('r.delay_date', '=', $delayDate);
        if ($projectManager)
            $query->whereDate('r.project_manager', '=', $projectManager);
        if ($withoutStatus){
            $query->where('r.status', '=', null);
        }
        if ($tisId){
            $query->where('r.tis_id', '=', $tisId);
        }
        if ($address){
            $query->where('r.address', '=', $address);
        }
        if ($claim){
            $query->where('r.claim', '=', $claim);
        }
        if ($area){
            $query->where('r.area', '=', $area);
        }
        if ($montageType){
            $query->where('r.montage_type', '=', $montageType);
        }
        if ($interventionStatus){
            $query->where('r.intervention_status', '=', $interventionStatus);
        }
        if ($interventionDate){
            $query->where('r.intervention_date', '=', $interventionDate);
        }
        if ($reclamationUser){
            $query->where('r.reclamation_user', '=', $reclamationUser);
        }
        if ($reclamationDate){
            $query->where('r.reclamation_date', '=', $reclamationDate);
        }
        if ($extraStb){
            $query->where('r.extra_stb', '=', $extraStb);
        }
        if ($withoutProjectManager){
            $query->where('r.project_manager', '=', null);
        }
        if ($withoutConstructionManager){
            $query->where('r.construction_manager', '=', null);
        }
        if ($notConfirmedInRune){
            $query->where('r.confirmed_in_rune_app', '=', 0);
        }
        if ($runeAppDate){
            $query->where('r.rune_app_date', '=', $runeAppDate);
        }
        if ($qgisDate){
            $query->where('r.qgis_date', '=',$qgisDate);
        }
        if ($additionalWork){
            $query->where('r.additional_work', '=',$additionalWork);
        }
        if ($additionalSplicing){
            $query->where('r.additional_splicing', '=',$additionalSplicing);
        }
        if ($contacted){
            $query->where('r.contacted', '=',$contacted);
        }
        if ($contactDate){
            $query->where('r.contact_date', '=',$contactDate);
        }
        
        
        if ($montageStart && $montageEnd){
            $query->where('r.montage_date', '>=', $montageStart);
            $query->where('r.montage_date', '<=', $montageEnd);
        }
        if($serial){
            $query->leftJoin('montirani_uredjaji as mu', 'r.id', '=', 'mu.id_rune')
            ->where('serijski_broj', '=', $serial)
            ->groupBy('mu.id_rune');
        }

        if($pagination)
            $result = $query->paginate(100);
        else
            $result = $query->get();

        return $result;
    }

    public function export($ids){
        $query = DB::table('rune_optics as r')
            ->leftJoin('users as u', 'r.user', '=', 'u.id')
            ->leftJoin('clusters as c', 'c.id', '=', 'r.cluster')
            ->leftJoin('statusi as s', 'r.status', '=', 's.id')
            ->leftJoin('statusi_intervencije as stsi', 'r.intervention_status', '=', 'stsi.id')
            ->leftJoin('users as rek', 'r.reclamation_user', '=', 'rek.id')
            ->leftJoin('tip_montaze as tpm', 'tpm.id', '=', 'r.montage_type')
            ->leftJoin('users as ru', 'ru.id', '=', 'r.updated_by')
            ->leftJoin('users as ruc', 'ruc.id', '=', 'r.created_by')
            ->leftJoin('users as pm', 'pm.id', '=', 'r.project_manager')
            ->leftJoin('users as cm', 'cm.id', '=', 'r.construction_manager')
            ->leftJoin('users as sel', 'sel.id', '=', 'r.seller_id')
            ->leftJoin('origin as o', 'o.id', '=', 'r.origin')
            ->leftJoin('pomocnici as p', 'p.id', '=', 'r.helper')
            ->leftJoin('companies as com', 'com.id', '=', 'r.company_id')
            ->select('r.id','contract_number','name','surname','claim_created_by','area','address','claim','seller','points','report_id','user','reclamation_user',
            'o.origin','created_by','claim_date','appointment_date','date_of_disposal','reclamation_date','montage_date','montage_type','client_sale','withdrawal_date',
            'intervention_date','withdrawal_reason','intervention_status','helper','extra_stb','on_terrain','imported','done','decimal','r.company_id','c.cluster','pan',
            'street','eta','network_group','tel1','tel2','tel3','fobos_id','county','city','settlement','household','households','state','state_services',
            'home_no','enterance','floor','apartment','packet','black_list','recomended_tariff','first_offer','operator','month','year','s.status','seller_id',
            'project_manager','contract_expire_date','created_by','updated_by','cable','tube','thread','case','x_coordinate','y_coordinate', 'pm.ime as pm_name', 
            'pm.prezime as pm_surname', 'u.ime as fitter_name', 'u.prezime as fitter_surname', 'r.delay_date', 'r.intervention_date', 'rek.ime as reclamation_name', 
            'rek.prezime as reclamation_surname', 'ruc.ime as created_name', 'ruc.prezime as created_surname', 'p.ime as helper_name', 'p.prezime as helper_surname','r.updated_at',
            'sel.ime as seller_name', 'sel.prezime as seller_surname', 'r.email', 'r.status as status_id', 'cm.ime as cm_name', 'cm.prezime as cm_surname', 'r.additional_work',
            'r.additional_splicing', 'contacted', 'contact_date')
            ->whereIn('r.id',  $ids)
        ;

        $result = $query->get();
        return $result;
    }


    public function appointed($appointmentDate, $idUser){
        $query = DB::table('rune_optics as r')
            ->leftJoin('statusi as s', 's.id', '=', 'r.status')
            ->leftJoin('users as u', 'u.id', '=', 'r.user')
            ->select('r.id', 'r.name', 'r.surname', 'r.tel1', 'r.tel2', 'r.tel3', 'u.ime',
                'r.address', 'u.prezime', 's.status', 'r.appointment_date', 'r.withdrawal_date',
                'intervention_status'
            )
            ->whereDate('r.appointment_date', '=', $appointmentDate)
            ->where('r.status', '=', 1)
            ->where('r.user', '=', $idUser)
            ->orWhere(function ($q) use ($idUser){
                $q->where('r.intervention_status', '=', 1)
                  ->where('r.reclamation_user', '=', $idUser);
            })

            ->orderBy('r.appointment_date', 'ASC')
        ;

        $result = $query->get();

        return $result;
    }

    public function countMontages($date, $type, $fitter=null, $start=null, $end=null, $status){
        $query = DB::table('rune_optics')->selectRaw('COUNT(id) as count')->where('montage_type', $type)->where('status', $status);
        if($fitter){
            $query->where('user', $fitter);
        }
        if($start && $end){
            $query->where('montage_date', '>=', $start)->where('montage_date', '<=', $end);
        }
        else{
            $query->where('montage_date', $date);
        }
        $result = $query->get();
        return $result[0]->count;
    }

    public function linkCheck($id, $fitter=null, $projectManager=null,$constructionManager=null, $area=null, $provider=null){
        $query = DB::table('rune_optics')->select('id');
        if($fitter){
            $query->where('user', '=', $fitter)
                  ->orWhere('reclamation_user', '=', $fitter);
        }
        if($projectManager){
            $query->where('project_manager', '=', $projectManager)->where('area','=', $area)->whereIn('provider', $provider);
        }
        if($constructionManager){
            $query->where('construction_manager', '=', $constructionManager);
        }
        $query->where('id', '=', $id);
        $result = $query->get();

        if($result->isEmpty()){
            return false;
        }
        else{
            return true;
        }
        
    }

    public function clientsForUser($userId, $montageDate, $start=null, $end=null){
        // dd($start);
        $query = DB::table('rune_optics as r')
            ->leftJoin('statusi as s', 's.id', '=', 'r.status')
            ->leftJoin('users as u', 'u.id', '=', 'r.user')
            ->leftJoin('clusters as c', 'c.id', '=', 'r.cluster')
            ->leftJoin('tip_montaze as tpm', 'tpm.id', '=', 'r.montage_type')
            ->select('r.id', 'c.cluster', 'r.name', 'r.surname', 'r.street', 'r.pan', 'u.ime as fitter_name', 'r.home_no', 'r.packet',
               'u.prezime as fitter_surname', 's.status', 'r.created_at', 'r.claim_date', 'r.appointment_date', 'r.withdrawal_date', 'tpm.tip', 
               'tpm.price', 's.id as status_id', 'r.montage_type', 'pan')
            ->where('user', '=', $userId)
            ;
        if($start && $end){
            $query->where('montage_date', '>=', $start)->where('montage_date', '<=', $end);
        }
        else{
            $query->where('montage_date', '=', $montageDate);
        }

        $query->orderby('r.created_at', 'DESC');

        $result = $query->get();

        return $result;
    }
}
