<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Model;
use Illuminate\Support\Facades\DB;

class Storage_logs extends Model
{
    protected $fillable = ['equipment_id', 'mont_equipment_id', 'user_id', 'fitter_id', 'receive_number', 'from', 'storage_id', 'quantity', 'package_number'];

    public function logs($storageId){
        $query = DB::table('storage_logs as sl')
        ->leftJoin('users as u', 'u.id', '=', 'sl.user_id')
        ->leftJoin('equipment as e', 'e.id', '=', 'sl.equipment_id')
        ->leftJoin('users as f', 'f.id', '=', 'sl.fitter_id')
        ->select('sl.quantity', 'e.equipment', 'u.ime as user_name', 'u.prezime as user_surname', 'sl.created_at', 'f.ime as fitter_name', 'f.prezime as fitter_surname',
                 'receive_number', 'from')
        ->where('storage_id', '=', $storageId)
        ->where('sl.equipment_id', '!=', null)
        ->orderBy('created_at', 'DESC');
        $result = $query->paginate(50);
        return $result;
    }

    public function logs_search($storageId, $receiveNumber=null, $from=null, $fitter=null){
        $query = DB::table('storage_logs as sl')
            ->leftJoin('users as u', 'u.id', '=', 'sl.user_id')
            ->leftJoin('equipment as e', 'e.id', '=', 'sl.equipment_id')
            ->leftJoin('users as f', 'f.id', '=', 'sl.fitter_id')
            ->select('sl.quantity', 'e.equipment', 'u.ime as user_name', 'u.prezime as user_surname', 'sl.created_at', 'f.ime as fitter_name', 'f.prezime as fitter_surname',
                'receive_number', 'from')
            ->where('storage_id', '=', $storageId)
            ->where('sl.equipment_id', '!=', null);
        if($receiveNumber)
            $query->where('receive_number', '=', $receiveNumber);
        if($from)
            $query->where('from', '=', $from);
        if($fitter)
            $query->where('fitter_id', '=', $fitter);

        $query->orderBy('created_at', 'DESC');

        $result = $query->paginate(50);
        return $result;
    }

    public function logs_mont($storageId){
        $query = DB::table('storage_logs as sl')
        ->leftJoin('users as u', 'u.id', '=', 'sl.user_id')
        ->leftJoin('oprema as o', 'o.id', '=', 'sl.mont_equipment_id')
        ->leftJoin('users as f', 'f.id', '=', 'sl.fitter_id')
        ->select('sl.quantity', 'o.naziv as equipment', 'u.ime as user_name', 'u.prezime as user_surname', 'sl.created_at', 'f.ime as fitter_name', 'f.prezime as fitter_surname',
                 'receive_number', 'from', 'package_number', 'o.code')
        ->where('storage_id', '=', $storageId)
        ->where('sl.mont_equipment_id', '!=', null)
        ->orderBy('sl.created_at', 'DESC');
        $result = $query->paginate(50);
        return $result;
    }

    public function logs_search_mont($storageId, $receiveNumber=null, $from=null, $fitter=null, $createdAt=null){
        $query = DB::table('storage_logs as sl')
            ->leftJoin('users as u', 'u.id', '=', 'sl.user_id')
            ->leftJoin('oprema as e', 'e.id', '=', 'sl.mont_equipment_id')
            ->leftJoin('users as f', 'f.id', '=', 'sl.fitter_id')
            ->select('sl.quantity', 'e.naziv as equipment', 'u.ime as user_name', 'u.prezime as user_surname', 'sl.created_at', 'f.ime as fitter_name', 'f.prezime as fitter_surname',
                'receive_number', 'from', 'e.code')
            ->where('storage_id', '=', $storageId)
            ->where('sl.mont_equipment_id', '!=', null);
        if($receiveNumber)
            $query->where('receive_number', '=', $receiveNumber);
        if($from)
            $query->where('from', '=', $from);
        if($fitter)
            $query->where('fitter_id', '=', $fitter);
        if($createdAt)
            $query->whereDate('sl.created_at', '=', $createdAt);


        $query->orderBy('created_at', 'DESC');

        $result = $query->get()->take(500);
        return $result;
    }
}
