<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Model;
use Illuminate\Support\Facades\DB;

class Storage_tools extends Model
{
    protected $fillable = ['tool_id', 'quantity', 'storage_id'];

    public function tools_for_storage($idStorage){
        $query = DB::table('storage_tools as st')
            ->leftJoin('tools as t', 't.id', '=', 'st.tool_id')
            ->leftJoin('tool_providers as p', 'p.id', '=', 't.provider_id')
            ->leftJoin('tool_types as tt', 'tt.id', '=', 't.type_id')
            ->leftJoin('tool_origins as o', 'o.id', '=', 't.origin_id')
            ->select('st.quantity', 't.tool', 'st.tool_id', 'tt.type', 'p.provider', 't.invoice_number', 'o.origin')
            ->where('storage_id', '=', $idStorage)
            ->where('st.quantity', '>', 0)
            ->orderBy('tt.type', 'ASC');
        $result = $query->get();
        return $result;
    }

    public function specific_tool($storageId, $toolId){
        $query = DB::table('storage_tools as st')
            ->leftJoin('tools as t', 't.id', '=', 'st.tool_id')
            ->leftJoin('tool_types as tt', 'tt.id', '=', 't.type_id')
            ->leftJoin('tool_providers as p', 'p.id', '=', 't.provider_id')
            ->leftJoin('tool_origins as o', 'o.id', '=', 't.origin_id')
            ->select('st.quantity', 't.tool', 'st.tool_id', 'tt.type', 'p.provider', 't.invoice_number', 'o.origin')
            ->where('st.storage_id', '=', $storageId)
            ->where('tool_id', '=', $toolId)
            ->orderBy('tt.type', 'ASC');
        $result = $query->get();
        if ($result->isEmpty())
            return false;
        else
            return $result[0];
    }

    public function storage_update($storageId, $toolId, $quantity){
        $isEmpty = DB::table('storage_tools')
            ->where('storage_id', '=', $storageId)
            ->where('tool_id', '=', $toolId)->get()->isEmpty();
        if($isEmpty){
            Storage_tools::create([
                'storage_id' => $storageId,
                'tool_id' => $toolId,
                'quantity' => $quantity
            ]);
        }
        else{
            DB::table('storage_tools')
            ->where('storage_id', '=', $storageId)
            ->where('tool_id', '=', $toolId)
            ->increment('quantity', $quantity);
        }
    }

    public function search($serial=null, $device=null, $storage=null, $storekeeper=null, $start=null, $end=null, $notOnReverse=null, $deviceState=null){
        $query = DB::table('magacin as m')
            ->leftJoin('uredjaji as u', 'm.id_uredjaj', '=', 'u.id')
            ->leftJoin('magz as mg', 'mg.id', '=', 'm.id_mag')
            ->leftJoin('users as usr', 'usr.id', '=', 'm.id_magacioner')
            ->leftJoin('device_states as ds', 'ds.id', '=', 'm.state_id')
            ->select('m.serijski_broj', 'm.created_at', 'u.uredjaj', 'mg.naziv as magacin', 'm.id', 'usr.ime as magacioner_ime', 'usr.prezime as magacioner_prezime', 'provider', 'invoice_number', 'ds.state')
            ->where('u.category_id', '=', 2)
            ->orderBy('m.id_uredjaj', 'ASC')
        ;

        if ($serial)
            $query->where('m.serijski_broj', 'like', '%'.$serial.'%');
        if ($device)
            $query->where('m.id_uredjaj', '=', $device);
        if ($storage)
            $query->where('m.id_mag', '=', $storage);
        if ($storekeeper)
            $query->where('m.id_magacioner', '=', $storekeeper);
        if ($start)
            $query->whereDate('m.created_at', '>=', $start);
        if ($end)
            $query->whereDate('m.created_at', '<=', $end);
        //nested query
        if($notOnReverse){
            $query->whereNotIn('m.serijski_broj', function($query) use ($storage){
                $query->from('tool_reverse_goods')->select('serial_number')->where('obsolete', '=', 0);
                if($storage){
                    $query->where('storage_id', '=', $storage);
                }
            });
        }
        if($deviceState){
            $query->where('m.state_id', '=', $deviceState);
        }


        $result = $query->get();
        return $result;
    }

}
