<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Model;
use Illuminate\Support\Facades\DB;

class Tool_reverse extends Model
{
    protected $table = 'tool_reverse';
    protected $fillable = ['text', 'worker_id', 'storekeeper_id', 'storage_id'];

    public function reverses(){
        $query = DB::table('tool_reverse as r')
            ->leftJoin('users as mon', 'r.worker_id', '=', 'mon.id')
            ->leftJoin('users as mag', 'r.storekeeper_id', '=', 'mag.id')
            ->leftJoin('magz as m', 'r.storage_id', '=', 'm.id')
            ->select('mon.ime as monter_ime', 'mon.prezime as monter_prezime', 'mag.ime as magacioner_ime',
                'mag.prezime as magacioner_prezime', 'r.created_at', 'r.id', 'r.worker_id', 'r.text', 'm.naziv as storage')
            ->orderBy('r.created_at', 'DESC')
        ;

        $result = $query->paginate(50);
        return $result;
    }

    public function revers($idRev){
        $query = DB::table('tool_reverse as r')
            ->leftJoin('users as mon', 'r.worker_id', '=', 'mon.id')
            ->leftJoin('users as mag', 'r.storekeeper_id', '=', 'mag.id')
            ->select('mon.ime as monter_ime', 'mon.prezime as monter_prezime', 'mag.ime as magacioner_ime',
                'mag.prezime as magacioner_prezime', 'r.created_at', 'r.id', 'r.text')
            ->where('r.id', '=', $idRev)
            ->orderBy('r.created_at', 'DESC')
        ;

        $result = $query->get();
        return $result[0];
    }

    public function robaStavke($idRev){
        $query = DB::table('tool_reverse as r')
            ->leftJoin('tool_reverse_goods as rr', 'r.id', '=', 'rr.reverse_id')
            ->leftJoin('uredjaji as u', 'u.id', '=', 'rr.device_id')
            ->select('rr.serial_number', 'rr.device_id', 'u.uredjaj')
            ->where('r.id', '=', $idRev)
            ->orderBy('rr.device_id', 'ASC')
        ;

        $result = $query->get();
        return $result;
    }

    public function robaCount($idRev){
        $query = DB::table('tool_reverse_goods as r')
            ->leftJoin('uredjaji as u', 'u.id', '=', 'r.device_id')
            ->select(DB::raw('COUNT(r.id) as count, u.uredjaj'))
            ->where('r.reverse_id', '=', $idRev)
            ->groupBy('r.device_id')
        ;

        $result = $query->get();
        return $result;
    }

    public function checkSerial($serial, $idRevers){
        $query = DB::table('tool_reverse_goods')
            ->selectRaw('count(id) as count')
            ->where('serial_number', '=', $serial)
            ->where('reverse_id', '=', $idRevers)
        ;
        $result = $query->get();
        if ($result[0]->count != 0)
            return true;
        else
            return false;
    }

    public function checkIfOnRevers($serial){
        $query = DB::table('tool_reverse_goods as rg')
            ->leftJoin('tool_reverse as r', 'r.id', '=', 'rg.reverse_id')
            ->selectRaw('rg.reverse_id')
            ->where('rg.serial_number', '=', $serial)
            ->where('obsolete', '!=', 1)
        ;
        $result = $query->get();
        if($result->isEmpty())
            return false;
        else
            return $result[0]->reverse_id;
    }

    public function reverse_search($monter=null, $magacioner=null, $serijskiBroj=null, $start=null, $end=null, $brojReversa=null){
        $query = DB::table('tool_reverse as r')
            ->leftJoin('users as mon', 'r.worker_id', '=', 'mon.id')
            ->leftJoin('users as mag', 'r.storekeeper_id', '=', 'mag.id')
            ->leftJoin('tool_reverse_goods as rr', 'rr.reverse_id', '=', 'r.id')
            ->leftJoin('magz as m', 'r.storage_id', '=', 'm.id')
            ->select('mon.ime as monter_ime', 'mon.prezime as monter_prezime', 'mag.ime as magacioner_ime',
                'mag.prezime as magacioner_prezime', 'r.created_at', 'r.id', 'r.worker_id', 'r.text', 'm.naziv as storage')
            ->orderBy('r.created_at', 'DESC')
            ->groupBy('r.id')
        ;

        if ($monter)
            $query->where('r.worker_id', '=', $monter);
        if ($magacioner)
            $query->where('r.storekeeper_id', '=', $magacioner);
        if ($serijskiBroj)
            $query->where('rr.serial_number', '=', $serijskiBroj);
        if ($start)
            $query->whereDate('r.created_at', '>=', $start);
        if ($end)
            $query->whereDate('r.created_at', '<=', $end);
        if ($brojReversa)
            $query->where('r.id', '=', $brojReversa);

        $result = $query->get();
        return $result;
    }

    public function checkSerialRevers($serial, $idMonter){
        $query = DB::table('revers_roba as rr')
            ->leftJoin('revers as r', 'r.id', '=', 'rr.id_revers')
            ->select('r.id')
            ->where('serijski_broj', '=', $serial)
            ->where('worker_id', '=', $idMonter)
            ->where('rr.obsolete', '=', 0)
        ;
        $result = $query->get();
        if($result->isEmpty())
            return true;
        else
            return false;
    }
}
