<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Model;
use Illuminate\Support\Facades\DB;

class Wf_projects extends Model
{
    protected $fillable = ['project_name', 'start_date', 'end_date', 'user'];

    public function projectsIndex(){
        $query = DB::table('wf_projects as p')
            ->leftJoin('users as u', 'u.id', '=', 'p.user')
            ->select('p.project_name', 'p.start_date', 'p.end_date', 'u.ime as name', 'u.prezime as surname', 'p.id')
            ->orderBy('p.id','DESC');

        $result = $query->paginate(15);
        return $result;
    }

    public function projectShow($projectId){
        $query = DB::table('wf_projects as p')
            ->leftJoin('users as u', 'u.id', '=', 'p.user')
            ->select('p.project_name', 'p.start_date', 'p.end_date', 'u.ime as name', 'u.prezime as surname')
            ->where('p.id', '=', $projectId);

        $result = $query->get();
        return $result[0];
    }


    public function search($project=null, $startDate=null, $endDate=null, $user=null, $paginate=false){
        $query = DB::table('wf_projects as p')
            ->leftJoin('users as u', 'u.id', '=', 'p.user')
            ->select('p.id', 'p.project_name', 'p.start_date', 'p.end_date', 'u.ime as name', 'u.prezime as surname');
        if($project){
            $query->where('p.project_name', 'like', '%'.$project.'%');
        }
        if($startDate){
            $query->whereDate('p.start_date', '=', $startDate);
        }
        if($endDate){
            $query->whereDate('p.end_date', '=', $endDate);
        }
        if($user){
            $query->where('p.user', '=', $user);
        }

        if($paginate){
            $result = $query->paginate(15);
        }
        else {
            $result = $query->get();
        }
        return $result;
    }

    public function indexOtherUsers($user){
        $query = DB::table('wf_projects as p')
            ->leftJoin('users as u', 'u.id', '=', 'p.user')
            ->leftJoin('wf_project_task as pt', 'pt.project_id', '=', 'p.id')
            ->select('p.project_name', 'p.start_date', 'p.end_date', 'p.id', 'u.ime as name', 'u.prezime as surname')
            ->distinct()
            ->where('pt.user_id', '=', $user);

        $result = $query->paginate(15);
        return $result;
    }

    public function searchOtherUsers($user, $project=null, $startDate=null, $endDate=null, $pagination=false){
        $query = DB::table('wf_projects as p')
            ->leftJoin('wf_project_task as pt', 'pt.project_id', '=', 'p.id')
            ->select('p.project_name', 'p.start_date', 'p.end_date', 'p.id')
            ->distinct()
            ->where('pt.user_id', '=', $user);

        if($project){
            $query->where('p.project_name', 'like', '%'.$project.'%');
        }
        if($startDate){
            $query->whereDate('p.start_date', '=', $startDate);
        }
        if($endDate){
            $query->whereDate('p.end_date', '=', $endDate);
        }
            
        if($pagination)
            $result = $query->paginate(15);
        else
            $result = $query->get();
        return $result;
    }
}
