<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Model;
use Illuminate\Support\Facades\DB;

class Worker_equipment extends Model
{
    protected $table = 'worker_equipment';
    protected $fillable = [
        'user_id',
        'equipment_id',
        'mont_equipment_id',
        'storage_id',
        'quantity'
    ];

    public function equipment_for_user($idUser){
        $query = DB::table('worker_equipment as we')
            ->leftJoin('equipment as e', 'e.id', '=', 'we.equipment_id')
            ->leftJoin('equipment_types as t', 't.id', '=', 'e.type')
            ->select('we.quantity', 'e.code', 'e.equipment', 'e.id as equipment_id', 't.type')
            ->where('user_id', '=', $idUser)
            ->where('we.equipment_id', '!=', null)
            ->where('we.quantity', '>', 0)
            ->orderBy('e.type', 'asc')
            ->orderBy('e.equipment', 'asc');
        $result = $query->get();
        return $result;
    }

    public function mont_equipment_for_user($idUser){
        $query = DB::table('worker_equipment as we')
            ->leftJoin('oprema as o', 'o.id', '=', 'we.mont_equipment_id')
            ->leftJoin('tip_opreme as t', 't.id', '=', 'o.id_tip_opreme')
            ->select('we.quantity', 'o.naziv as equipment', 'o.id as equipment_id', 't.tip')
            ->where('user_id', '=', $idUser)
            ->where('we.mont_equipment_id', '!=', null)
            ->where('we.quantity', '>', 0)
            ->orderBy('t.tip', 'asc')
            ->orderBy('o.naziv', 'asc');
        $result = $query->get();
        return $result;
    }

    public function specific_equipment($userId, $equipmentId){
        $query = DB::table('worker_equipment as we')
            ->leftJoin('oprema as e', 'e.id', '=', 'we.equipment_id')
            ->select('we.quantity', 'e.naziv')
            ->where('user_id', '=', $userId)
            ->where('equipment_id', '=', $equipmentId);
        $result = $query->get();
        if ($result->isEmpty())
            return false;
        else
            return $result[0];
    }

    public function equipment_update($userId, $equipmentId, $quantity){
        DB::table('worker_equipment as we')
            ->where('user_id', '=', $userId)
            ->where('equipment_id', '=', $equipmentId)
            ->increment('quantity', $quantity);
    }

    public function equipment_for_user_mont($idUser){
        $query = DB::table('worker_equipment as we')
            ->leftJoin('oprema as o', 'o.id', '=', 'we.mont_equipment_id')
            ->leftJoin('mont_equipment_categories as mec', 'mec.id', '=', 'o.id_category')
            ->select('we.quantity', 'o.naziv as equipment', 'o.price', 'o.code', 'o.id_category', 'mec.category', 'o.price')
            ->where('user_id', '=', $idUser)
            ->where('we.mont_equipment_id', '!=', null)
            ->where('we.quantity', '>', 0);
        $result = $query->get();
        return $result;
    }

    public function specific_equipment_mont($userId, $equipmentId){
        $query = DB::table('worker_equipment as we')
            ->leftJoin('oprema as o', 'o.id', '=', 'we.mont_equipment_id')
            ->select('we.quantity', 'o.naziv as equipment')
            ->where('user_id', '=', $userId)
            ->where('mont_equipment_id', '=', $equipmentId);
        $result = $query->get();
        if ($result->isEmpty())
            return false;
        else
            return $result[0];
    }

    public function equipment_update_mont($userId, $equipmentId, $quantity, $storageId=null){
        DB::table('worker_equipment as we')
            ->where('user_id', '=', $userId)
            ->where('mont_equipment_id', '=', $equipmentId)
            ->increment('quantity', $quantity);

        if($storageId){
            DB::table('worker_equipment as we')
                ->where('user_id', '=', $userId)
                ->where('mont_equipment_id', '=', $equipmentId)
                ->update(['storage_id' => $storageId]);
        }
    }

    public function mont_client_equipment($idUser){
        $query = DB::table('worker_equipment as we')
            ->leftJoin('oprema as o', 'o.id', '=', 'we.mont_equipment_id')
            ->select('we.quantity', 'o.naziv', 'o.id', 'o.code')
            ->where('user_id', '=', $idUser)
            ->where('we.mont_equipment_id', '!=', null)
            ->where('we.quantity', '>', 0);
        $result = $query->get();
        return $result;
    }

    public function kir_equipment($idUser){
        $query = DB::table('worker_equipment as we')
            ->leftJoin('oprema as o', 'o.id', '=', 'we.mont_equipment_id')
            ->select('we.quantity', 'o.naziv', 'o.id')
            ->where('user_id', '=', $idUser)
            ->where('we.mont_equipment_id', '!=', null)
            ->where('we.quantity', '>', 0);
        $result = $query->get();
        return $result;
    }
}
