<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Model;
use Illuminate\Support\Facades\DB;

class Worker_tools extends Model
{
    protected $fillable = ['user_id', 'tool_id', 'storage_id', 'quantity'];

    public function tools_for_user($userId){
        $query = DB::table('worker_tools as wt')
            ->leftJoin('tools as t', 't.id', '=', 'wt.tool_id')
            ->leftJoin('tool_types as tt', 'tt.id', '=', 't.type_id')
            ->leftJoin('tool_providers as p', 'p.id', '=', 't.provider_id')
            ->leftJoin('tool_origins as o', 'o.id', '=', 't.origin_id')
            ->select('wt.quantity', 't.tool', 'wt.tool_id', 'tt.type', 'p.provider', 'o.origin', 't.invoice_number')
            ->where('user_id', '=', $userId)
            ->where('wt.quantity', '>', 0)
            ->orderBy('tt.type', 'ASC');
        $result = $query->get();
        return $result;
    }

    public function specific_equipment($userId, $toolId){
        $query = DB::table('worker_tools as wt')
            ->leftJoin('tools as t', 't.id', '=', 'wt.tool_id')
            ->leftJoin('tool_types as tt', 'tt.id', '=', 't.type_id')
            ->select('wt.quantity', 't.tool', 'tt.type')
            ->where('user_id', '=', $userId)
            ->where('tool_id', '=', $toolId)
            ->orderBy('tt.type', 'ASC');
        $result = $query->get();
        if ($result->isEmpty())
            return false;
        else
            return $result[0];
    }

    public function tool_update($userId, $toolId, $quantity){
        DB::table('worker_tools')
            ->where('user_id', '=', $userId)
            ->where('tool_id', '=', $toolId)
            ->increment('quantity', $quantity);
    }

    public function specific_equipment_for_storage($storageId, $toolId){
        $query = DB::table('worker_tools as wt')
            ->leftJoin('tools as t', 't.id', '=', 'wt.tool_id')
            ->leftJoin('tool_types as tt', 'tt.id', '=', 't.type_id')
            ->selectRaw('SUM(quantity) as quantity')
            ->where('storage_id', '=', $storageId)
            ->where('tool_id', '=', $toolId)
            ->orderBy('tt.type', 'ASC');
        $result = $query->get();
        if ($result->isEmpty())
            return false;
        else
            return $result[0];
    }
}
