<?php

namespace App;

use Illuminate\Database\Eloquent\Model;
use Illuminate\Support\Facades\DB;

class Montirani_uredjaji extends Model
{
    protected $table = 'montirani_uredjaji';
    protected $fillable = [
        'serijski_broj',
        'mac1',
        'mac2',
        'id_uredjaj',
        'id_klijent',
        'id_opticki_klijent',
        'id_supernova_klijent',
        'id_bakar_klijent',
        'id_rune',
        'id_monter',
        'created_at',
        'updated_at'
    ];

    public function montiran($serial){
        $query = DB::table('montirani_uredjaji')
            ->selectRaw('count(id) as count')
            ->where('serijski_broj', '=', $serial)
        ;

        $result = $query->get();
        if ($result[0]->count != 0)
            return true;
        else
            return false;
    }

    public function montiranCheck($serial, $idKlijent){
        $query = DB::table('montirani_uredjaji')
            ->selectRaw('count(id) as count')
            ->where('id_klijent', '!=', $idKlijent)
            ->where('serijski_broj', '=', $serial)
        ;
        $result = $query->get();
        if ($result[0]->count != 0)
            return true;
        else
            return false;
    }

    public function montiraniSerials($date=null){
        $query = DB::table('montirani_uredjaji')->select('serijski_broj');
        if ($date)
            $query->whereDate('created_at', '<=', $date);
        $result = $query->get()->toArray();
        return $result;
    }

    public function montiraniList($idKlijent){
        $query = DB::table('montirani_uredjaji as mu')
            ->leftJoin('uredjaji as u', 'u.id', '=', 'mu.id_uredjaj')
            ->select('serijski_broj', 'uredjaj', 'mu.id', 'id_uredjaj', 'mu.created_at')
            ->where('id_klijent', '=', $idKlijent)
            ->orderBy('id_uredjaj');
        $result = $query->get();
        return $result;
    }

    public function montiraniOptikaList($idKlijent){
        $query = DB::table('montirani_uredjaji as mu')
            ->leftJoin('uredjaji as u', 'u.id', '=', 'mu.id_uredjaj')
            ->select('serijski_broj', 'uredjaj', 'mu.id', 'mu.created_at')
            ->where('id_opticki_klijent', '=', $idKlijent)
            ->orderBy('id_uredjaj');
        $result = $query->get();
        return $result;
    }

    public function montiraniRuneList($idKlijent){
        $query = DB::table('montirani_uredjaji as mu')
            ->leftJoin('uredjaji as u', 'u.id', '=', 'mu.id_uredjaj')
            ->select('serijski_broj', 'uredjaj', 'mu.id', 'mu.created_at')
            ->where('id_rune', '=', $idKlijent)
            ->orderBy('id_uredjaj');
        $result = $query->get();
        return $result;
    }

    public function montiraniSupernovaList($idKlijent){
        $query = DB::table('montirani_uredjaji as mu')
            ->leftJoin('uredjaji as u', 'u.id', '=', 'mu.id_uredjaj')
            ->select('serijski_broj', 'uredjaj', 'mu.id', 'mu.created_at')
            ->where('id_supernova_klijent', '=', $idKlijent)
            ->orderBy('id_uredjaj');
        $result = $query->get();
        return $result;
    }

    public function montiraniBakarList($idKlijent){
        $query = DB::table('montirani_uredjaji as mu')
            ->leftJoin('uredjaji as u', 'u.id', '=', 'mu.id_uredjaj')
            ->select('serijski_broj', 'uredjaj', 'mu.id', 'mu.created_at')
            ->where('id_bakar_klijent', '=', $idKlijent)
            ->orderBy('id_uredjaj');
        $result = $query->get();
        return $result;
    }

    public function montiraniRune($idKlijent){
        $query = DB::table('montirani_uredjaji as mu')
            ->leftJoin('uredjaji as u', 'u.id', '=', 'mu.id_uredjaj')
            ->select('serijski_broj', 'uredjaj', 'mu.id', 'mu.created_at')
            ->where('id_rune', '=', $idKlijent)
            ->orderBy('id_uredjaj');
        $result = $query->get();
        return $result;
    }

    public function monterDevice($idMonter, $idUredjaj, $table, $field, $start, $end){
        $query = DB::table('montirani_uredjaji as mu')
            ->leftJoin("$table as k", 'k.id', '=', "mu.$field")
            ->selectRaw("count(mu.id) as kol")
            ->where('id_user', '=', $idMonter)
            ->where('datum_montaze', '>=', $start)
            ->where('datum_montaze', '<=', $end)
            ->where($field, '!=', null);

        //bodovi se uracunavaju ako razlozi reklamacije nisu stelovanje i izmestanje antene
        if($table == 'klijent'){
            $query->whereNotIn('id_razlog_reklamacije', [1,2]);
        }
        else{
            $query->where('id_user_reklamacije', '=', null);
        }
        if (is_array($idUredjaj))
            $query->whereIn('id_uredjaj', $idUredjaj);
        else
            $query->where('id_uredjaj', '=', $idUredjaj);

        ;
        $result = $query->get()->toArray();
        return $result[0];
    }

    /**
     * @param $idMonter
     * @param $start
     * @param $end
     * @param $razlog
     * @return mixed
     *
     */
    public function reklamacija($idMonter, $start, $end, $razlog){
        $query = DB::table('klijent as k')
            ->selectRaw("count(k.id) as kol")
            ->where('datum_intervencije', '>=', $start)
            ->where('datum_intervencije', '<=', $end)
            ->where('id_user_reklamacije', '=', $idMonter)
            ->where('id_razlog_reklamacije', '=', $razlog)
            ->where('id_status_intervencije', '=', 2)
        ;
        $result = $query->get()->toArray();
        return $result[0];
    }

    public function reklamacijaOptika($idMonter, $start, $end){
        $query = DB::table('klijenti_optika as k')
            ->selectRaw("count(k.id) as kol")
            ->where('datum_intervencije', '>=', $start)
            ->where('datum_intervencije', '<=', $end)
            ->where('id_user_reklamacije', '=', $idMonter)
            ->where('id_status_intervencije', '=', 2)
            ->where('id_user', '!=', $idMonter)
        ;
        $result = $query->get()->toArray();
        return $result[0];
    }

    public function supernova($idMonter, $start, $end){
        $query = DB::table('klijenti_supernova as k')
            ->selectRaw("count(k.id) as kol")
            ->where('datum_montaze', '>=', $start)
            ->where('datum_montaze', '<=', $end)
            ->where('id_user_reklamacije', '=', null)
            ->where('id_user', '=', $idMonter)
            ->where('id_status', '=', 5)
        ;
        $result = $query->get()->toArray();
        return $result[0];
    }

    public function copper($idMonter, $start, $end){
        $query = DB::table('klijenti_bakar as k')
            ->selectRaw("count(k.id) as kol")
            ->where('datum_montaze', '>=', $start)
            ->where('datum_montaze', '<=', $end)
            ->where('id_user_reklamacije', '=', null)
            ->where('id_user', '=', $idMonter)
            ->where('id_status', '=', 5)
        ;
        $result = $query->get()->toArray();
        return $result[0];
    }

    public function checkSerial($serial, $idDevice){
        $query = DB::table('montirani_uredjaji')
            ->select('serijski_broj')
            ->where('serijski_broj', '=', $serial)
            ->where('id_uredjaj' , '=', $idDevice);
        $result = $query->get();
        if ($result->isEmpty())
            return false;
        else
            return true;
    }

    public function deviceBySerial($serial){
        $query = DB::table('montirani_uredjaji')
            ->select('serijski_broj', 'mac1', 'mac2', 'id_uredjaj')
            ->where('serijski_broj', '=', $serial)
        ;

        $result = $query->get();
        if($result->isEmpty())
            return false;
        else
            return $result[0];
    }

    /**
     * This function is allowing deletion of mounted equipment if jmbg is the same on multiple clients.
     * One client can have more than one contracts on his name
     * @param $serial
     * @param $jmbg
     */
    public function deleteMountedDevice($serial, $jmbg, $tisId){
        DB::table('montirani_uredjaji as mu')
            ->leftJoin("klijent as k", 'k.id', '=', "mu.id_klijent")
            ->where('mu.serijski_broj', '=', $serial)
            ->where(function ($q) use ($jmbg, $tisId){
                $q->where('k.jmbg', '=', $jmbg)
                ->orWhere('k.tis_id', '=', $tisId);
            })
            ->delete();
        ;
    }

    public function checkIfMounted($serial){
        $query = DB::table('montirani_uredjaji')
            ->select('serijski_broj')
            ->where('serijski_broj', '=', $serial);
        $result = $query->get();
        if ($result->isEmpty())
            return false;
        else
            return true;
    }

    public function countStbsMsat($client){
        $query = DB::table('montirani_uredjaji')->selectRaw('COUNT(id) as count')->where('id_klijent', '=', $client)->where('id_uredjaj', '=', 2);
        $result = $query->get();
        return $result[0]->count;
    }

    public function countStbsOptics($client){
        $query = DB::table('montirani_uredjaji')->selectRaw('COUNT(id) as count')->where('id_opticki_klijent', '=', $client)->whereIn('id_uredjaj', [18,23]);
        $result = $query->get();
        return $result[0]->count;
    }

    public function devicesOnDate($column,$date){
        $query = DB::table('montirani_uredjaji as mu')
            ->leftJoin('uredjaji as u', 'u.id', '=', 'mu.id_uredjaj')
            ->selectRaw('COUNT(mu.id) as count, u.uredjaj as device')
            ->whereDate('mu.created_at','=', $date)
            ->whereNotNull($column)
            ->groupBy('id_uredjaj')
        ;

        $result = $query->get();
        return $result;
    }

    public function mountedDevices($uredjaj, $klijent, $column){
        $query = DB::table('montirani_uredjaji as mu')
            ->selectRaw('COUNT(mu.id) as count')
            ->where('id_uredjaj', '=', $uredjaj)
            ->where($column, '=', $klijent)
        ;

        $result = $query->get();
        return $result[0]->count;
    }

}
