<?php

namespace App;

use Illuminate\Database\Eloquent\Model;
use Illuminate\Support\Facades\DB;

class Oprema extends Model
{
    protected $table = 'oprema';

    protected $fillable = ['naziv', 'id_tip_opreme', 'is_active', 'id_category', 'code', 'package', 'price'];

    /**
     * @param null $tip
     * @return mixed
     */
    public function oprema($tip=null){
        $query = DB::table('oprema')
            ->select('id');
        ;
        if ($tip)
            $query->where('id_tip_opreme', '=', $tip);
        $result = $query->get()->all();
        return $result;
    }

    public function equipment($idCategory){
        $query = DB::table('oprema')
            ->select('*')
            ->where('id_category', '=', $idCategory)
            ->where('is_active', '=', 1);
            
        $result = $query->get();
        return $result;
    }

    public function mountedEquipment($idMonter, $start, $end){
        $query = DB::table('oprema_klijent as o')
            ->leftJoin('oprema as opr', 'opr.id', '=', 'id_oprema')
            ->selectRaw('opr.naziv as oprema, sum(kol) as kol_montirano, id_oprema')
            ->whereDate('o.created_at', '>=', $start)
            ->whereDate('o.created_at', '<=', $end)
            ->where('o.id_monter', '=', $idMonter);
            $query->orderBy('o.id_oprema');
        $query->groupBy('o.id_oprema');
        ;

        $result = $query->get()->all();
        return $result;
    }

    public function reversEquipment($idMonter, $start, $end){
        $query = DB::table('oprema_revers as or')
            ->leftJoin('revers as r', 'r.id', '=', 'or.id_revers')
            ->leftJoin('oprema as o', 'o.id', '=', 'id_oprema')
            ->selectRaw('o.naziv as oprema, sum(kol) as kol_revers, id_oprema')
            ->whereDate('or.created_at', '>=', $start)
            ->whereDate('or.created_at', '<=', $end)
            ->where('id_monter', '=', $idMonter)
            ->orderBy('id_oprema')
            ->groupBy('id_oprema');
        ;

        $result = $query->get()->all();
        return $result;
    }

    public function otpremnicaEquipment($idMonter, $start, $end){
        $query = DB::table('oprema_otpremnica as oo')
            ->leftJoin('otpremnice as otp', 'otp.id', '=', 'oo.id_otpremnica')
            ->leftJoin('oprema as o', 'o.id', '=', 'oo.id_oprema')
            ->selectRaw('o.naziv as oprema, sum(kol) as kol_otpremnica, id_oprema')
            ->whereDate('oo.created_at', '>=', $start)
            ->whereDate('oo.created_at', '<=', $end)
            ->where('id_monter', '=', $idMonter)
            ->orderBy('id_oprema')
            ->groupBy('id_oprema');
        ;

        $result = $query->get()->all();
        return $result;
    }

    public function opremaIndex(){
        $query = DB::table('oprema as o')
            ->leftJoin('tip_opreme as to', 'to.id', '=', 'o.id_tip_opreme')
            ->leftJoin('mont_equipment_categories as mec', 'mec.id', '=', 'o.id_category')
            ->select('o.id', 'to.tip', 'o.naziv', 'o.is_active', 'o.code', 'o.price', 'mec.category')
            ->where('is_active', '=', 1)
            ->orderBy('id_category', 'ASC')
        ;

        $result = $query->get()->all();
        return $result;
    }

    public function opremaShow($id){
        $query = DB::table('oprema as o')
            ->leftJoin('tip_opreme as to', 'to.id', '=', 'o.id_tip_opreme')
            ->leftJoin('mont_equipment_categories as mec', 'mec.id', '=', 'o.id_category')
            ->leftJoin('equipment_packages as pac', 'pac.id', '=', 'o.package')
            ->select('o.id', 'o.naziv', 'to.tip', 'o.id_tip_opreme', 'o.is_active', 'mec.category', 'o.code', 'pac.package', 'price')
            ->where('o.id', '=', $id)
        ;

        $result = $query->get()->all();
        return $result[0];
    }

    public function mountedMonter($idMonter, $idOprema){
        $query = DB::table('oprema_klijent as o')
            ->selectRaw('sum(kol) as kol_montirano')
            ->where('o.id_monter', '=', $idMonter)
            ->where('o.id_oprema', '=', $idOprema)
        ;
        
        $result = $query->get();
        if(!$result->isEmpty())
            return $result[0]->kol_montirano;
        else
            return 0;
    }

    public function equipmentData($id){
        $query = DB::table('oprema as o')
            ->leftJoin('mont_equipment_categories as mec', 'mec.id', '=', 'o.id_category')
            ->select('o.id', 'o.naziv as equipment', 'mec.category', 'o.code', 'o.package')
            ->where('o.id', '=', $id)
        ;

        $result = $query->get();
        return $result[0];
    }

}
