<?php

namespace App;

use Illuminate\Support\Facades\DB;
use Illuminate\Database\Eloquent\Model;

class Oprema_klijent extends Model
{
    protected $table = 'oprema_klijent';
    protected $fillable = [
        'id_oprema',
        'id_klijent',
        'id_opticki_klijent',
        'id_supernova_klijent',
        'id_bakar_klijent',
        'id_rune',
        'kol',
        'id_monter'
    ];

    public function equipment($idKlijent){
        $query = DB::table('oprema_klijent as ok')
            ->leftJoin('oprema as o', 'o.id', '=', 'ok.id_oprema')
            ->selectRaw('kol, o.naziv, o.id, ok.created_at')
            ->where('id_klijent', '=', $idKlijent);

        $result = $query->get();
        return $result;
    }

    public function equipmentOptika($idKlijent){
        $query = DB::table('oprema_klijent as ok')
            ->leftJoin('oprema as o', 'o.id', '=', 'ok.id_oprema')
            ->selectRaw('kol, o.naziv, o.id, ok.created_at')
            ->where('id_opticki_klijent', '=', $idKlijent);

        $result = $query->get();
        return $result;
    }

    public function equipemtnRune($idKlijent){
        $query = DB::table('oprema_klijent as ok')
            ->leftJoin('oprema as o', 'o.id', '=', 'ok.id_oprema')
            ->selectRaw('kol, o.naziv, o.id, ok.created_at')
            ->where('id_rune', '=', $idKlijent);

        $result = $query->get();
        return $result;
    }

    public function equipmentSupernova($idKlijent){
        $query = DB::table('oprema_klijent as ok')
            ->leftJoin('oprema as o', 'o.id', '=', 'ok.id_oprema')
            ->selectRaw('kol, o.naziv, o.id, ok.created_at')
            ->where('id_supernova_klijent', '=', $idKlijent);

        $result = $query->get();
        return $result;
    }

    public function equipmentBakar($idKlijent){
        $query = DB::table('oprema_klijent as ok')
            ->leftJoin('oprema as o', 'o.id', '=', 'ok.id_oprema')
            ->selectRaw('kol, o.naziv, o.id, ok.created_at')
            ->where('id_bakar_klijent', '=', $idKlijent);

        $result = $query->get();
        return $result;
    }

    public function equipmentRune($idKlijent){
        $query = DB::table('oprema_klijent as ok')
            ->leftJoin('oprema as o', 'o.id', '=', 'ok.id_oprema')
            ->selectRaw('kol, o.naziv, o.id, ok.created_at, code')
            ->where('id_rune', '=', $idKlijent);

        $result = $query->get();
        return $result;
    }

    /**
     * @param $client
     * @param $field
     * @param $idMonter
     * @param null $start datum montaze
     * @param null $end   datum montaze
     * @return mixed
     * funkcija racuna koliko prosecno opreme monter koristi kod klijenta
     */
    public function equipmentStat($client, $field, $idMonter=null, $start=null, $end=null){
        $clientQuery = DB::table($client)->selectRaw('count(id)');
        if($idMonter) {
            $clientQuery->where('id_user', '=', $idMonter);
            $params = [$idMonter];
        }
        else {
            $params = array();
        }

        if ($start && $end) {
            $clientQuery->where('datum_montaze', '>=', $start)
                        ->where('datum_montaze', '<=', $end);
            array_push($params, $start, $end);
        }
        else {
            $clientQuery->where('datum_montaze', '>=', date('Y-m-01'))
                        ->where('datum_montaze', '<=', date('Y-m-t'));
            array_push($params, date('Y-m-01'), date('Y-m-t'));
        }
        $subQuery = str_replace(array('?'), array('\'%s\''), $clientQuery->toSql());
        $subQuery = vsprintf($subQuery, $params);
        $query = DB::table('oprema_klijent as ok')
            ->leftJoin('oprema as o', 'o.id', '=', 'ok.id_oprema')
            ->leftJoin($client.' as k', 'k.id', '=', 'ok.'.$field)
            ->selectRaw("SUM(kol)/($subQuery) as kol_prosek, o.naziv, id_oprema")
            ->where($field, '!=', null);
        if ($start && $end) {
            $query->where('k.datum_montaze', '>=', $start);
            $query->where('k.datum_montaze', '<=', $end);
        }
        else {
            $query->where('k.datum_montaze', '>=', date('Y-m-01'))
                  ->where('k.datum_montaze', '<=', date('Y-m-t'));
        }
        if ($idMonter){
            $query->where('k.id_user', '=', $idMonter);
        }

        $query->groupBy('id_oprema');

        $result = $query->get()->toArray();
        return $result;
    }

    public function usedEquipmentStatistic($from,$to,$equipmentId){
        $query = DB::table('oprema_klijent')->selectRaw('SUM(kol) as quantity')
            ->whereDate('created_at', '>=', $from)
            ->whereDate('created_at', '<=', $to)
            ->where('id_oprema', '=', $equipmentId)
            ->groupBy('id_oprema');
        $result = $query->get();
        if($result->isEmpty())
            return 0;
        else
            return $result[0]->quantity;
    }

    public function specificEquipment($code, $runeId){
        $query = DB::table('oprema_klijent')
            ->leftJoin('oprema as o', 'o.id', '=', 'id_oprema')
            ->selectRaw('sum(kol) as quantity')
            ->where('o.code', '=', $code)
            ->where('id_rune', '=', $runeId)
            ->groupBy('id_oprema')
            ;

        $result = $query->first();
        return $result;
    }
}
