<?php

namespace App;
use DB;
use App\Traits\Util;
use Illuminate\Support\Arr;

use Illuminate\Database\Eloquent\Model;

class Oprema_otpremnica extends Model
{
    protected $table = 'oprema_otpremnica';
    protected $fillable = [
        'id_oprema',
        'id_otpremnica',
        'kol'
    ];

    private function monterIds(){
        $monteri = Util::monteri();
        return Arr::pluck($monteri, 'id');
    }

    public function oprema($id){
        $query = DB::table('oprema_otpremnica as oo')
            ->leftJoin('oprema as o', 'o.id', '=', 'oo.id_oprema')
            ->selectRaw('o.naziv, oo.id_otpremnica, oo.id_oprema, sum(kol) as kol')
            ->where('id_otpremnica', '=', $id)
            ->groupBy('id_oprema')
        ;

        $result = $query->get();
        return $result;
    }

    public function opremaMonter($idMonter=null){
        $query = DB::table('oprema_otpremnica as oo')
            ->leftJoin('oprema as o', 'o.id', '=', 'oo.id_oprema')
            ->leftJoin('otpremnice as otp', 'otp.id', '=', 'oo.id_otpremnica')
            ->leftJoin('users as m', 'm.id', '=', 'otp.id_monter')
            ->selectRaw('o.naziv, sum(kol) as kol, CONCAT(m.ime, " ", m.prezime) as monter, oo.id_oprema, m.id as monter_id')
            ->where('otp.id_monter', '=', $idMonter)
            ->orderBy('otp.id_monter', 'asc')
            ->orderBy('oo.id_oprema', 'asc')
            ->groupBy('id_oprema')
        ;

        $result = $query->get();
        return $result;
    }

    /**
     * f-ja vraca broj uredjaja koji su na otpremnicama a nisu montirani. uzimaju se u obzir samo otpremnice koje su adresirane na aktivnog montera
     */
    public function otpremnica_minus_montirano($id){
        $query1 = DB::table('oprema_otpremnica as oo')
            ->leftJoin('oprema as o', 'o.id', '=', 'oo.id_oprema')
            ->leftJoin('otpremnice as otp', 'otp.id', '=', 'oo.id_otpremnica')
            ->selectRaw('sum(kol) as kol')
            ->where('id_oprema', '=', $id)
            ->whereIn('otp.id_monter', $this->monterIds())
            ->orderBy('id_oprema')
            ->groupBy('id_oprema')
        ;

        $query2 = DB::table('oprema_klijent as o')
            ->leftJoin('oprema as opr', 'opr.id', '=', 'o.id_oprema')
            ->selectRaw('sum(kol) as kol, id_oprema, opr.naziv')
            ->where('o.id_oprema', '=', $id)
            ->whereIn('o.id_monter', $this->monterIds())
            ->orderBy('o.id_oprema')
            ->groupBy('o.id_oprema');

        $result1 = $query1->get();
        $result2 = $query2->get();
        if(!$result1->isEmpty())
            $result1 = $result1[0]->kol;
        else
            $result1 = 0;
        if(!$result2->isEmpty())
            $result2 = $result2[0]->kol;
        else
            $result2 = 0;

        return $result1 - $result2;
        
    }


}
