<?php

namespace App;

use Illuminate\Support\Facades\DB;
use Illuminate\Database\Eloquent\Model;

class Revers extends Model
{
    protected $table = 'revers';

    protected $fillable = [
        'id_monter',
        'id_magacioner',
        'text',
        'storage_id'
    ];

    public function reversi(){
        $query = DB::table('revers as r')
            ->leftJoin('users as mon', 'r.id_monter', '=', 'mon.id')
            ->leftJoin('users as mag', 'r.id_magacioner', '=', 'mag.id')
            ->leftJoin('magz as m', 'r.storage_id', '=', 'm.id')
            ->select('mon.ime as monter_ime', 'mon.prezime as monter_prezime', 'mag.ime as magacioner_ime',
                'mag.prezime as magacioner_prezime', 'r.created_at', 'r.id', 'r.id_monter', 'r.text', 'm.naziv as storage')
            ->orderBy('r.created_at', 'DESC')
        ;

        $result = $query->paginate(50);
        return $result;
    }

    public function revers($idRev){
        $query = DB::table('revers as r')
            ->leftJoin('users as mon', 'r.id_monter', '=', 'mon.id')
            ->leftJoin('vozila as v', 'mon.id', '=', 'v.id_user')
            ->leftJoin('users as mag', 'r.id_magacioner', '=', 'mag.id')
            ->select('mon.ime as monter_ime', 'mon.prezime as monter_prezime', 'mag.ime as magacioner_ime',
                'mag.prezime as magacioner_prezime', 'r.created_at', 'r.id', 'v.reg_br', 'r.text')
            ->where('r.id', '=', $idRev)
            ->orderBy('r.created_at', 'DESC')
        ;

        $result = $query->get();
        return $result[0];
    }

    public function robaStavke($idRev){
        $query = DB::table('revers as r')
            ->leftJoin('revers_roba as rr', 'r.id', '=', 'rr.id_revers')
            ->leftJoin('uredjaji as u', 'u.id', '=', 'rr.id_uredjaj')
            ->select('rr.serijski_broj', 'rr.id_uredjaj', 'u.uredjaj')
            ->where('r.id', '=', $idRev)
            ->orderBy('rr.id_uredjaj', 'ASC')
        ;

        $result = $query->get();
        return $result;
    }

    public function robaCount($idRev){
        $query = DB::table('revers_roba as r')
            ->leftJoin('uredjaji as u', 'u.id', '=', 'r.id_uredjaj')
            ->select(DB::raw('COUNT(r.id) as count, u.uredjaj'))
            ->where('r.id_revers', '=', $idRev)
            ->groupBy('r.id_uredjaj')
        ;

        $result = $query->get();
        return $result;
    }

    public function checkSerial($serial, $idRevers){
        $query = DB::table('revers_roba')
            ->selectRaw('count(id) as count')
            ->where('serijski_broj', '=', $serial)
            ->where('id_revers', '=', $idRevers)
        ;
        $result = $query->get();
        if ($result[0]->count != 0)
            return true;
        else
            return false;
    }

    public function checkIfMounted($serial){
        $query = DB::table('revers_roba')
            ->selectRaw('id')
            ->where('serijski_broj', '=', $serial)
            ->where('mounted', '=', 1)
            ->limit(1)
        ;
        $result = $query->get();
        if ($result->isEmpty())
            return false;
        else
            return true;
    }

    public function checkIfOnRevers($serial){
        $query = DB::table('revers_roba as rr')
            ->leftJoin('revers as r', 'r.id', '=', 'rr.id_revers')
            ->selectRaw('r.id')
            ->where('rr.serijski_broj', '=', $serial)
            ->orderBy('r.id', 'asc')
        ;
        $result = $query->get();
        return $result;
    }

    public function reversi_pretraga($monter=null, $magacioner=null, $serijskiBroj=null, $start=null, $end=null, $brojReversa=null){
        $query = DB::table('revers as r')
            ->leftJoin('users as mon', 'r.id_monter', '=', 'mon.id')
            ->leftJoin('users as mag', 'r.id_magacioner', '=', 'mag.id')
            ->leftJoin('revers_roba as rr', 'rr.id_revers', '=', 'r.id')
            ->leftJoin('magz as m', 'r.storage_id', '=', 'm.id')
            ->select('mon.ime as monter_ime', 'mon.prezime as monter_prezime', 'mag.ime as magacioner_ime',
                'mag.prezime as magacioner_prezime', 'r.created_at', 'r.id', 'r.id_monter', 'r.text', 'm.naziv as storage')
            ->orderBy('r.created_at', 'DESC')
            ->groupBy('r.id')
        ;

        if ($monter)
            $query->where('r.id_monter', '=', $monter);
        if ($magacioner)
            $query->where('r.id_magacioner', '=', $magacioner);
        if ($serijskiBroj)
            $query->where('rr.serijski_broj', '=', $serijskiBroj);
        if ($start)
            $query->whereDate('r.created_at', '>=', $start);
        if ($end)
            $query->whereDate('r.created_at', '<=', $end);
        if ($brojReversa)
            $query->where('r.id', '=', $brojReversa);

        $result = $query->get();
        return $result;
    }

    public function checkSerialRevers($serial, $idMonter){
        $query = DB::table('revers_roba as rr')
            ->leftJoin('revers as r', 'r.id', '=', 'rr.id_revers')
            ->select('r.id')
            ->where('serijski_broj', '=', $serial)
            ->where('id_monter', '=', $idMonter)
            ->where('rr.obsolete', '=', 0)
        ;
        $result = $query->get();
        if($result->isEmpty())
            return true;
        else
            return false;
    }
}
