<?php
namespace App\Traits;

use Illuminate\Support\Facades\DB;

trait Statistika {
    public static function klijentCount($id_status=null){
        $query = DB::table('klijent')
            ->selectRaw('COUNT(id) as count');
        if ($id_status)
            $query->where('id_status', '=', $id_status);
        $query1 = DB::table('klijenti_optika')
            ->selectRaw('COUNT(id) as optika_count');
        if ($id_status)
            $query1->where('id_status', '=', $id_status);
        $query2 = DB::table('klijenti_supernova')
            ->selectRaw('COUNT(id) as supernova_count');
        if ($id_status)
            $query2->where('id_status', '=', $id_status);
        $query3 = DB::table('klijenti_bakar')
            ->selectRaw('COUNT(id) as bakar_count');
        if ($id_status)
            $query3->where('id_status', '=', $id_status);

        $query->union($query1)->union($query2)->union($query3);

        $result = $query->get();
        return $result;
    }

    public static function clientStat($field, $id_status=null, $start=null, $end=null, $resto=false){
        $query = DB::table($field)
            ->selectRaw('COUNT(id) as count');
        if (is_array($id_status))
            $query->whereIn('status', $id_status);
        elseif ($id_status)
            $query->where('status', '=', $id_status);
        if ($start && $end) {
            $query->whereDate('created_at', '>=', $start);
            $query->whereDate('created_at', '<=', $end);
        }
        else {
            $query->whereMonth('created_at', '=', date('m'));
            $query->whereYear('created_at', '=', date('Y'));
        }
        if ($resto){
            $query->where('status', '=', null);
        }

        $result = $query->get();
        return $result[0]->count;
    }

    public static function statistikaMonter($table, $idMonter, $id_status=null, $start=null, $end=null, $resto=false){
        $query = DB::table($table)
            ->selectRaw('COUNT(id) as count');
        if ($idMonter)
            $query->where('user', '=', $idMonter);
        if (is_array($id_status))
            $query->whereIn('status', $id_status);
        elseif ($id_status)
            $query->where('status', '=', $id_status);
        if ($start && $end) {
            $query->whereDate('created_at', '>=', $start);
            $query->whereDate('created_at', '<=', $end);
        }
        else {
            $query->whereMonth('created_at', '=', date('m'));
            $query->whereYear('created_at', '=', date('Y'));
        }
        if ($resto){
            $query->where('status', '=', null);
        }
        $query->orderBy('status');

        $result = $query->get();
        return $result[0]->count;
    }

    public static function zakazanMontiran($field, $idMonter, $id_status=null, $start=null, $end=null, $resto=false){
        $query = DB::table($field)
            ->selectRaw('COUNT(id) as count');
        if ($idMonter)
            $query->where('id_user', '=', $idMonter);
        if (is_array($id_status))
            $query->whereIn('id_status', $id_status);
        elseif ($id_status)
            $query->where('id_status', '=', $id_status);
        if ($start && $end) {
            $query->whereDate('datum_zakazivanja', '>=', $start);
            $query->whereDate('datum_zakazivanja', '<=', $end);
        }
        else {
            $query->whereMonth('datum_zakazivanja', '=', date('m'));
            $query->whereYear('datum_zakazivanja', '=', date('Y'));
        }
        if ($resto){
            $query->where('id_status', '=', null);
        }
        $query->orderBy('id_status');

        $result = $query->get();
        return $result[0]->count;
    }

    /**
     * @param $field
     * @param null $id_status
     * @param null $start
     * @param null $end
     * @param bool $prihvaceno
     * @param bool $vraceno
     * @param null $idSeller
     * @param null $nov
     * @return mixed
     */
    public static function saleStat($field, $id_status=null, $start=null, $end=null, $prihvaceno=false, $vraceno=false,
                                    $idSeller=null, $nov=null, $vrstaPaketa=null, $resto=false, $restoVrsta=false, $restoNov=false,
                                    $paket=null, $restoPaket=null){
        $query = DB::table('klijenti_prodaja as kp')
            ->leftJoin($field.' as k', 'kp.id', '=', 'k.id_klijent_prodaja')
            ->selectRaw('COUNT(kp.id) as count');
        ;
        if (is_array($id_status))
            $query->whereIn('k.id_status', $id_status);
        elseif ($id_status)
            $query->where('k.id_status', '=', $id_status);
        if ($start && $end) {
            $query->whereDate('kp.created_at', '>=', $start);
            $query->whereDate('kp.created_at', '<=', $end);
        }
        else {
            $query->whereMonth('kp.created_at', '=', date('m'));
            $query->whereYear('kp.created_at', '=', date('Y'));
        }
        if ($prihvaceno) {
            $query->where('prihvaceno', '=', 1);
            $query->where('k.id_status', '=', null);
        }
        if ($vraceno){
            $query->where('vraceno', '=', 1);
            $query->where('k.id_status', '=', null);
        }
        if ($idSeller){
            if (is_array($idSeller))
                $query->whereIn('id_prodavac', $idSeller);
            else
                $query->where('id_prodavac', '=', $idSeller);
        }
        if ($nov){
            $query->where('id_nov_servis', '=', $nov);
        }
        if ($vrstaPaketa){
            $query->where('id_vrsta_paketa', '=', $paket);
        }
        if ($paket){
            $query->where('id_paket', '=', $paket);
        }
        switch ($field) {
            case 'klijent' :
                $query->where('tip_klijenta', '=', 0);
                break;
            case 'klijenti_optika' :
                $query->where('tip_klijenta', '=', 1);
                break;
            case 'klijenti_supernova' :
                $query->where('tip_klijenta', '=', 2);
                break;
            case 'klijenti_bakar' :
                $query->where('tip_klijenta', '=', 3);
                break;
        }

        if($resto){
            $query->where('id_status', '=', null)
                  ->where('vraceno', '=', 0)
                  ->where('prihvaceno', '=', 0);
        }
        if($restoVrsta){
            $query->where('id_vrsta_paketa', '=', null);
        }
        if($restoNov){
            $query->where('id_nov_servis', '=', null);
        }
        if($restoPaket){
            $query->where('id_paket', '=', null);
        }


        $result = $query->get();
        return $result[0]->count;
    }

    public static function sellAll($field, $start=null, $end=null, $seller=null){
        $query = DB::table('klijenti_prodaja')
            ->selectRaw('COUNT(id) as count');
        if ($start && $end) {
            $query->whereDate('created_at', '>=', $start);
            $query->whereDate('created_at', '<=', $end);
        }
        else {
            $query->whereMonth('created_at', '=', date('m'));
            $query->whereYear('created_at', '=', date('Y'));
        }
        if ($seller){
            if (is_array($seller))
                $query->whereIn('id_prodavac', $seller);
            else
                $query->where('id_prodavac', '=', $seller);
        }
        switch ($field) {
            case 'klijent' :
                $query->where('tip_klijenta', '=', 0);
                break;
            case 'klijenti_optika' :
                $query->where('tip_klijenta', '=', 1);
                break;
            case 'klijenti_supernova' :
                $query->where('tip_klijenta', '=', 2);
                break;
            case 'klijenti_bakar' :
                $query->where('tip_klijenta', '=', 3);
                break;
        }

        $result = $query->get();
        return $result[0]->count;
    }

    /*
     * ova funkcija uzima u obzir samo dth klijente zato sto u ostalim ne postoji razlog_intervencije
     */
    public static function interventionStat($razlog=null, $start=null, $end=null, $idMonter=null, $resto=false, $razloziIds=null){
        $query = DB::table('klijent')
            ->selectRaw('COUNT(id) as count')
            ->where('id_user_reklamacije', '!=', null);
        if ($razlog)
            $query->where('id_razlog_reklamacije', '=', $razlog);
        if ($start && $end) {
            $query->where('datum_intervencije', '>=', $start);
            $query->where('datum_intervencije', '<=', $end);
        }
        else {
            $query->whereMonth('datum_intervencije', '=', date('m'));
            $query->whereYear('datum_intervencije', '=', date('Y'));
        }
        if ($idMonter)
            $query->where('id_user', '=', $idMonter);
        if ($resto) {
            $query->where('id_razlog_reklamacije', '=', null);
        }
        if ($razloziIds){
            $query->whereIn('id_razlog_reklamacije', $razloziIds);
        }

        $result = $query->get();
        return $result[0]->count;
    }

    public static function marks($start, $end, $monterId=null){
        $query = DB::table('klijenti_optika as opt')
            ->leftJoin('users as u', 'u.id', '=', 'opt.id_user')
            ->join('report_marks as rm', 'rm.id', '=', 'opt.report_id')
            ->selectRaw("CONCAT(u.ime, ' ', u.prezime) as user, AVG(rm.facility_enterance) as facility_enterance, AVG(rm.internal_cabling) as internal_cabling, 
                        AVG(rm.signal_level) as signal_level, AVG(rm.coupling_condition) as coupling_condition, AVG(rm.behavior) as behavior,
                        AVG(rm.customer_satisfaction) as customer_satisfaction, (AVG(rm.facility_enterance)+AVG(rm.internal_cabling)+AVG(rm.signal_level)+AVG(rm.coupling_condition)
                        +AVG(rm.behavior)+AVG(rm.customer_satisfaction))/6 as final_mark")
            ->where('opt.datum_montaze', '>=', $start)
            ->where('opt.datum_montaze', '<=', $end)
            ->groupBy('u.id');
        if ($monterId)
            $query->where('id_user', '=', $monterId);

        $result = $query->get();
        return $result;
    }

    public static function points($start, $end, $sellerId=null, $table){
        if ($table=='klijenti_supernova' || $table=='klijenti_bakar')
            $field = 'br_bodova';
        else
            $field = 'broj_bodova';
        $query = DB::table('klijenti_prodaja as k')
            ->leftJoin("$table as kl", 'kl.id_klijent_prodaja', '=', 'k.id')
            ->selectRaw("SUM(kl.$field) as kol")
            ->where('kl.id_status', '=', 5)
            ->where('kl.datum_montaze', '>=', $start)
            ->where('kl.datum_montaze', '<=', $end)
        ;
        if($sellerId)
            $query->where('k.id_prodavac', '=', $sellerId);


        $result = $query->get();
        if($result->isEmpty())
            return 0;
        else
            return $result[0]->kol;
    }

    public static function work_days($fitter, $start, $end){
        // $query = DB::table('klijent as k')
        //     ->leftJoin('users as u', 'u.id', '=', 'k.id_user')
        //     ->selectRaw("COUNT(DISTINCT(datum_montaze)) as days, CONCAT(u.ime, ' ', u.prezime) as fitter")
        //     ->where('k.id_user', '=', $fitter)
        //     ->where('k.datum_montaze', '>=', $start)
        //     ->where('k.datum_montaze', '<=', $end)
        //     ;

        // $result = $query->get();
        // return $result[0];

        $query = "select fitter, count(datum_montaze) as days from 
                ((select CONCAT(u.ime, ' ', u.prezime) as fitter, k.datum_montaze from klijent k
                left join users u on u.id = k.id_user
                where k.datum_montaze BETWEEN '$start' and '$end'
                and k.id_user = $fitter)
                UNION
                (select CONCAT(u2.ime, ' ', u2.prezime) as fitter, ko.datum_montaze from klijenti_optika ko
                left join users u2 on u2.id = ko.id_user
                where ko.datum_montaze BETWEEN '$start' and '$end'
                and ko.id_user = $fitter)
                UNION
                (select CONCAT(u3.ime, ' ', u3.prezime) as fitter, ks.datum_montaze from klijenti_supernova ks
                left join users u3 on u3.id = ks.id_user
                where ks.datum_montaze BETWEEN '$start' and '$end'
                and ks.id_user = $fitter)
                UNION
                (select CONCAT(u4.ime, ' ', u4.prezime) as fitter, kb.datum_montaze from klijenti_bakar kb
                left join users u4 on u4.id = kb.id_user
                where kb.datum_montaze BETWEEN '$start' and '$end'
                and kb.id_user = $fitter)) as client
                group by fitter";

        $result = DB::select($query);
        if(!empty($result))
            return $result[0];
        else
            return false;
    }
}