<?php

namespace App;

use Illuminate\Notifications\Notifiable;
use Illuminate\Contracts\Auth\MustVerifyEmail;
use Illuminate\Foundation\Auth\User as Authenticatable;
use Illuminate\Support\Facades\DB;

class User extends Authenticatable
{
    use Notifiable;

    /**
     * The attributes that are mass assignable.
     *
     * @var array
     */
    protected $fillable = [
        'id',
        'username',
        'ime',
        'prezime',
        'email',
        'password',
        'jmbg',
        'adresa',
        'zanimanje',
        'id_ugovor',
        'datum_pocetka_osiguranja',
        'datum_prestanka_osiguranja',
        'oprema',
        'telefon',
        'is_active',
        'role_id',
        'area_id',
        'last_login',
        'online_status',
        'type',
        'locale',
        'provider',
        'is_subcontractor'
    ];

    /**
     * The attributes that should be hidden for arrays.
     *
     * @var array
     */
    protected $hidden = [
        'password', 'remember_token',
    ];

    /**
     * The attributes that should be cast to native types.
     *
     * @var array
     */
    protected $casts = [
        'email_verified_at' => 'datetime',
    ];

    public function podaciUser($idUser){
        $query = DB::table('users as u')
            ->leftJoin('ugovori as ug', 'ug.id', '=', 'u.id_ugovor')
            ->leftJoin('pomocnici as p', 'p.id_user', '=', 'u.id')
            ->leftJoin('roles as r', 'r.id', '=', 'u.role_id')
            ->leftJoin('areas as a', 'a.id', '=', 'u.area_id')
            ->leftJoin('providers as pr', 'pr.id', '=', 'u.provider')
            ->select('u.ime', 'u.prezime', 'u.id', 'u.email', 'r.rola', 'u.jmbg', 'u.zanimanje', 'ug.ugovor',
                    'u.datum_prestanka_osiguranja', 'u.datum_pocetka_osiguranja', 'u.oprema', 'u.id_ugovor',
                    'p.ime as pomocnik_ime', 'p.prezime as pomocnik_prezime', 'p.id as id_pomocnik', 'role_id',
                    'u.username', 'area_id', 'area', 'description', 'pr.provider', 'u.provider as provider_id', 'is_subcontractor'
            )
            ->where('u.id', '=', $idUser)
            ->where('u.is_active', '=', 1)
        ;
        $result = $query->get();

        return $result[0];
    }

    public static function lastActiveId(){
        $query = DB::table('users as u')
            ->where('u.id', '<', 1001)
            ->select('u.id')
            ->orderBy('u.id', 'DESC')
            ->limit(1);
        $result = $query->get();
        if($result->isEmpty())
            return false;
        else
            return $result[0]->id;
    }

    public function user_salary(){
        $query = DB::table('users as u')
            ->leftJoin('roles as r', 'r.id', '=', 'u.role_id')
            ->select('u.ime as username', 'u.prezime as usersurname', 'u.id', 'role_id', 'rola')
            ->where('u.is_active', '=', 1)
            ->whereIn('role_id', [2,4])
        ;
        $result = $query->get();

        return $result;
    }

    public function allUsers(){
        $query = DB::table('users as u')
            ->leftJoin('roles as r', 'r.id', '=', 'u.role_id')
            ->select('u.ime', 'u.prezime', 'u.id', 'role_id', 'description', 'username', 'email', 'is_active')
            ->where('u.is_active', '=', 1)
            ->where('u.id', '!=', 1001)
            ->orderBy('r.id')
            ->orderBy('u.id')
        ;
        $result = $query->get();

        return $result;
    }
}
