<?php

namespace App;

use Illuminate\Database\Eloquent\Model;
use Illuminate\Support\Facades\DB;

class Vraceni_uredjaji extends Model
{
    protected $table = 'vraceni_uredjaji';
    protected $fillable = [
        'serijski_broj',
        'mac1',
        'mac2',
        'id_uredjaj',
        'id_klijent',
        'id_opticki_klijent',
        'id_supernova_klijent',
        'id_bakar_klijent',
        'id_rune',
        'id_monter',
        'id_razlog_vracanja',
        'created_at',
        'updated_at'
    ];

    public function vraceniList($field, $id){
        $query = DB::table('vraceni_uredjaji as vr')
            ->leftJoin('uredjaji as u', 'u.id', '=', 'vr.id_uredjaj')
            ->leftJoin('razlozi_vracanja as rv', 'rv.id', '=', 'vr.id_razlog_vracanja')
            ->select('serijski_broj', 'uredjaj', 'vr.id', 'vr.created_at', 'rv.razlog')
            ->where($field, '=', $id)
            ->orderBy('id_uredjaj');
        $result = $query->get();
        return $result;
    }

    public function checkSerial($serial){
        $query = DB::table('vraceni_uredjaji')
            ->select('serijski_broj')
            ->where('serijski_broj', '=', $serial);
        $result = $query->get();
        if ($result->isEmpty())
            return false;
        else
            return true;
    }

    /**
     * @param null $serial
     * @param null $idMonter
     * @param null $field ovde se bira tip klijenta
     * @return mixed
     */
    public function vraceni($serial=null, $idMonter=null, $field=null, $od=null, $do=null, $razlog=null, $paginate=false){
        $query = DB::table('vraceni_uredjaji as vr')
            ->leftJoin('uredjaji as u', 'u.id', '=', 'vr.id_uredjaj')
            ->leftJoin("klijent as kl", 'kl.id', '=', 'vr.id_klijent')
            ->leftJoin('klijenti_optika as ko', 'ko.id', '=', 'vr.id_opticki_klijent')
            ->leftJoin('klijenti_supernova as ks', 'ks.id', '=', 'vr.id_supernova_klijent')
            ->leftJoin('klijenti_bakar as kb', 'kb.id', '=', 'vr.id_bakar_klijent')
            ->leftJoin('rune_optics as ro', 'ro.id', '=', 'vr.id_rune')
            ->leftJoin('users as usr', 'usr.id', '=', 'vr.id_monter')
            ->leftJoin('razlozi_vracanja as rv', 'rv.id', '=', 'vr.id_razlog_vracanja')
            ->select('serijski_broj', 'uredjaj', 'vr.id', 'kl.ime', 'kl.prezime', 'ko.ime as ime_optika', 'ko.prezime as prezime_optika',
                'kb.ime as ime_bakar', 'kb.prezime as prezime_bakar', 'ks.klijent_ime as ime_supernova', 'ks.klijent_prezime as prezime_supernova', 'usr.ime as monter_ime',
                'usr.prezime as monter_prezime', 'vr.created_at', 'rv.razlog', 'kl.tis_id as tis', 'ko.tis_id as optika_tis', 'kb.tis_id as bakar_tis', 'ro.name as ime_rune', 
                'ro.surname as prezime_rune');
            if ($serial)
                $query->where('vr.serijski_broj', '=', $serial);
            if ($idMonter)
                $query->where('vr.id_monter', '=', $idMonter);
            if ($field)
                $query->whereNotNull($field);
            if ($od && $do){
                $query->whereDate('vr.created_at', '>=', $od);
                $query->whereDate('vr.created_at', '<=', $do);
            }
            if ($razlog)
                $query->where('id_razlog_vracanja', '=', $razlog);
            $query->orderBy('vr.created_at', 'DESC');
        if($paginate)
            $result = $query->paginate(150);
        else
            $result = $query->get();
        return $result;
    }

    public function vraceniCount($id){
        $query = DB::table('vraceni_uredjaji')
            ->selectRaw("count(id) as count")
            ->where('id_uredjaj', '=', $id);
        $result = $query->get();
        return $result[0];
    }
}
