<?php

use Illuminate\Support\Facades\Schema;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Database\Migrations\Migration;

class CreateConstructionTables extends Migration
{
    /**
     * Run the migrations.
     *
     * @return void
     */
    public function up()
    {
        Schema::create('states', function (Blueprint $table){
            $table->bigIncrements('id');
            $table->char('state');
            $table->char('state_short');
            $table->timestamps();
        });

        Schema::create('cities', function (Blueprint $table){
            $table->bigIncrements('id');
            $table->char('city');
            $table->unsignedBigInteger('id_state');
            $table->timestamps();
            $table->foreign('id_state')->references('id')->on('states')->onDelete('restrict')->onUpdate('cascade');

        });

        Schema::create('areas', function (Blueprint $table){
            $table->bigIncrements('id');
            $table->char('area');
            $table->timestamps();
        });

        Schema::create('construction_status', function (Blueprint $table){
            $table->bigIncrements('id');
            $table->char('status');
            $table->timestamps();
        });

        Schema::create('currency', function (Blueprint $table){
            $table->bigIncrements('id');
            $table->char('currency');
            $table->char('currency_short');
            $table->timestamps();
        });

        Schema::create('construction_sites', function (Blueprint $table) {
            $table->bigIncrements('id');
            $table->char('name');
            $table->bigInteger('tis_id')->nullable();
            $table->char('contact_person')->nullable();
            $table->char('tel1')->nullable();
            $table->char('tel2')->nullable();
            $table->char('tel3')->nullable();
            $table->char('address')->nullable();
            $table->unsignedBigInteger('id_state')->nullable();
            $table->unsignedBigInteger('id_city')->nullable();
            $table->unsignedBigInteger('id_area')->nullable();
            $table->unsignedBigInteger('id_status')->nullable();
            $table->unsignedBigInteger('id_currency')->nullable();
            $table->double('discount_percent')->nullable();
            $table->double('transport_costs')->nullable();
            $table->timestamps();
            $table->foreign('id_state')->references('id')->on('states')->onDelete('restrict')->onUpdate('cascade');
            $table->foreign('id_city')->references('id')->on('cities')->onDelete('restrict')->onUpdate('cascade');
            $table->foreign('id_area')->references('id')->on('areas')->onDelete('restrict')->onUpdate('cascade');
            $table->foreign('id_status')->references('id')->on('construction_status')->onDelete('restrict')->onUpdate('cascade');
            $table->foreign('id_currency')->references('id')->on('currency')->onDelete('restrict')->onUpdate('cascade');

        });

        Schema::create('image_types', function (Blueprint $table){
            $table->bigIncrements('id');
            $table->char('type');
            $table->timestamps();
        });

        Schema::create('construction_images', function (Blueprint $table){
            $table->bigIncrements('id');
            $table->char('url');
            $table->unsignedBigInteger('id_construction_site')->nullable();
            $table->char('description')->nullable();
            $table->unsignedBigInteger('image_type')->nullable();
            $table->timestamps();
            $table->foreign('id_construction_site')->references('id')->on('construction_sites')->onDelete('cascade')->onUpdate('cascade');
            $table->foreign('image_type')->references('id')->on('image_types')->onDelete('cascade')->onUpdate('cascade');
        });

        Schema::create('equipment_categories', function (Blueprint $table){
            $table->bigIncrements('id');
            $table->char('category');
            $table->timestamps();
        });

        Schema::create('work_categories', function (Blueprint $table){
            $table->bigIncrements('id');
            $table->char('category');
            $table->timestamps();
        });

        Schema::create('construction_prices', function (Blueprint $table){
            $table->bigIncrements('id');
            $table->char('price');
            $table->unsignedBigInteger('id_area');
            $table->unsignedBigInteger('id_currency');
            $table->timestamps();
            $table->foreign('id_area')->references('id')->on('areas')->onDelete('restrict')->onUpdate('cascade');
            $table->foreign('id_currency')->references('id')->on('currency')->onDelete('restrict')->onUpdate('cascade');

        });

        Schema::create('equipment', function (Blueprint $table){
            $table->bigIncrements('id');
            $table->char('equipment');
            $table->unsignedBigInteger('id_price')->nullable();
            $table->unsignedBigInteger('id_category')->nullable();
            $table->timestamps();
            $table->foreign('id_price')->references('id')->on('construction_prices')->onDelete('cascade')->onUpdate('cascade');
            $table->foreign('id_category')->references('id')->on('equipment_categories')->onDelete('cascade')->onUpdate('cascade');
        });

        Schema::create('construction_works', function (Blueprint $table){
            $table->bigIncrements('id');
            $table->char('work');
            $table->unsignedBigInteger('id_price')->nullable();
            $table->unsignedBigInteger('id_category')->nullable();
            $table->timestamps();
            $table->foreign('id_price')->references('id')->on('construction_prices')->onDelete('cascade')->onUpdate('cascade');
            $table->foreign('id_category')->references('id')->on('work_categories')->onDelete('cascade')->onUpdate('cascade');
        });

        Schema::create('payments', function (Blueprint $table){
            $table->bigIncrements('id');
            $table->float('amount');
            $table->unsignedBigInteger('updated_by');
            $table->unsignedBigInteger('id_construction_site');
            $table->unsignedBigInteger('id_currency');
            $table->timestamps();
            $table->foreign('id_construction_site')->references('id')->on('construction_sites')->onDelete('cascade')->onUpdate('cascade');
            $table->foreign('id_currency')->references('id')->on('currency')->onDelete('restrict')->onUpdate('cascade');
        });

        Schema::create('construction_comments', function (Blueprint $table){
            $table->bigIncrements('id');
            $table->char('comment');
            $table->unsignedBigInteger('id_construction_site');
            $table->unsignedBigInteger('id_user');
            $table->timestamps();
            $table->foreign('id_construction_site')->references('id')->on('construction_sites')->onDelete('cascade')->onUpdate('cascade');
            $table->foreign('id_user')->references('id')->on('users')->onDelete('cascade')->onUpdate('cascade');
        });

        Schema::create('site_equipment', function (Blueprint $table){
            $table->unsignedBigInteger('id_site');
            $table->unsignedBigInteger('id_equipment');
            $table->double('quantity');
            $table->timestamps();
            $table->foreign('id_site')->references('id')->on('construction_sites')->onDelete('cascade')->onUpdate('cascade');
            $table->foreign('id_equipment')->references('id')->on('equipment')->onDelete('restrict')->onUpdate('cascade');
        });

        Schema::create('site_works', function (Blueprint $table){
            $table->unsignedBigInteger('id_site');
            $table->unsignedBigInteger('id_work');
            $table->double('quantity');
            $table->timestamps();
            $table->foreign('id_site')->references('id')->on('construction_sites')->onDelete('cascade')->onUpdate('cascade');
            $table->foreign('id_work')->references('id')->on('construction_works')->onDelete('restrict')->onUpdate('cascade');
        });

    }

    /**
     * Reverse the migrations.
     *
     * @return void
     */
    public function down()
    {
        Schema::dropIfExists('cities');
        Schema::dropIfExists('states');
        Schema::dropIfExists('areas');
        Schema::dropIfExists('construction_sites');
        Schema::dropIfExists('image_types');
        Schema::dropIfExists('currency');
        Schema::dropIfExists('construction_images');
        Schema::dropIfExists('equipment_categories');
        Schema::dropIfExists('work_categories');
        Schema::dropIfExists('equipment');
        Schema::dropIfExists('construction_works');
        Schema::dropIfExists('construction_status');
        Schema::dropIfExists('construction_prices');
        Schema::dropIfExists('payments');
        Schema::dropIfExists('construction_comments');
    }
}
